## Circulation

## AHA/ACC/HFSA CLINICAL PRACTICE GUIDELINE

2022 AHA/ACC/HFSA Guideline for the Management of Heart Failure: A Report of the American College of Cardiology/American Heart Association Joint Committee on Clinical Practice Guidelines

## Writing Committee Members*

Paul A. Heidenreich, MD, MS, FACC, FAHA, FHFSA, Chair†; Biykem Bozkurt, MD, PhD, FACC, FAHA, FHFSA, Vice Chair†; David Aguilar, MD, MSc, FAHA†; Larry A. Allen, MD, MHS, FACC, FAHA, FHFSA†; Joni J. Byun†; Monica M. Colvin, MD, MS, FAHA†; Anita Deswal, MD, MPH, FACC, FAHA, FHFSA‡; Mark H. Drazner, MD, MSc, FACC, FAHA, FHFSA†; Shannon M. Dunlay, MD, MS, FAHA, FHFSA†; Linda R. Evers, JD†; James C. Fang, MD, FACC, FAHA, FHFSA†; Savitri E. Fedson, MD, MA†; Gregg C. Fonarow, MD, FACC, FAHA, FHFSA§; Salim S. Hayek, MD, FACC†; Adrian F. Hernandez, MD, MHS‡; Prateeti Khazanie, MD, MPH, FHFSA†; Michelle M. Kittleson, MD, PhD†; Christopher S. Lee, PhD, RN, FAHA, FHFSA†; Mark S. Link, MD†; Carmelo A. Milano, MD†; Lorraine C. Nnacheta, DrPH, MPH†; Alexander T. Sandhu, MD, MS†; Lynne Warner Stevenson, MD, FACC, FAHA, FHFSA†; Orly Vardeny, PharmD, MS, FAHA, FHFSA ‖ ; Amanda R. Vest, MBBS, MPH, FHFSA ‖ ; Clyde W. Yancy, MD, MSc, MACC, FAHA, FHFSA†

AIM: The '2022 AHA/ACC/HFSA Guideline for the Management of Heart Failure' replaces the '2013 ACCF/AHA Guideline for the Management of Heart Failure' and the '2017 ACC/AHA/HFSA Focused Update of the 2013 ACCF/AHA Guideline for  the  Management  of  Heart  Failure.'  The  2022  guideline  is  intended  to  provide  patient-centric  recommendations  for clinicians to prevent, diagnose, and manage patients with heart failure.

METHODS: A comprehensive literature search was conducted from May 2020 to December 2020, encompassing studies, reviews,  and  other  evidence  conducted  on  human  subjects  that  were  published  in  English  from  MEDLINE  (PubMed), EMBASE, the Cochrane Collaboration, the Agency for Healthcare Research and Quality, and other relevant databases. Additional  relevant  clinical  trials  and  research  studies,  published  through  September  2021,  were  also  considered.  This guideline was harmonized with other American Heart Association/American College of Cardiology guidelines published through December 2021.

STRUCTURE: Heart failure remains a leading cause of morbidity and mortality globally. The 2022 heart failure guideline provides recommendations based on contemporary evidence for the treatment of these patients. The recommendations present an evidence-based approach to managing patients with heart failure, with the intent to improve quality of care and align with patients' interests. Many recommendations from the earlier heart failure guidelines have been updated with new evidence, and new recommendations have been created when supported by published data. Value statements are provided for certain treatments with high-quality published economic analyses.

*Writing committee members are required to recuse themselves from voting on sections to which their specific relationships with industry may apply; see Appendix 1 for detailed information. †ACC/AHA Representative. ‡ACC/AHA Joint Committee on Clinical Practice Guidelines Liaison. §ACC/AHA Task Force on Performance Measures Representative. ‖ HFSA Representative.

ACC/AHA Joint Committee on Clinical Practice Guidelines Members, see page e986.

The American Heart Association requests that this document be cited as follows: Heidenreich PA, Bozkurt B, Aguilar D, Allen LA, Byun JJ, Colvin MM, Deswal A, Drazner MH, Dunlay SM, Evers LR, Fang JC, Fedson SE, Fonarow GC, Hayek SS, Hernandez AF, Khazanie P, Kittleson MM, Lee CS, Link MS, Milano CA, Nnacheta LC, Sandhu AT, Stevenson LW, Vardeny O, Vest AR, Yancy CW. 2022 AHA/ACC/HFSA guideline for the management of heart failure: a report of the American College of Cardiology/American Heart Association Joint Committee on Clinical Practice Guidelines. Circulation . 2022;145:e895-e1032. doi: 10.1161/CIR.0000000000001063

© 2022 by the American Heart Association, Inc., the American College of Cardiology Foundation, and the Heart Failure Society of America.

Circulation is available at www.ahajournals.org/journal/circ

<!-- image -->

AHA Scientific Statements

Key Words:

◼

◼

heart failure heart failure with mildly reduced ejection fraction

◼

◼

heart failure with reduced ejection fraction systolic heart failure

◼

◼

heart failure with preserved ejection fraction heart failure rehabilitation

◼

cardiac failure

◼

chronic heart failure

- ◼ acute decompensated heart failure ◼ cardiogenic shock ◼ beta blockers ◼ mineralocorticoid receptor antagonists ◼ ACE inhibitors
- ◼ angiotensin and neprilysin receptor antagonist ◼ sacubitril valsartan ◼ angiotensin receptor antagonist ◼ sodium glucose co-transporter 2
- ◼ SGLT2 inhibitors ◼ cardiac amyloidosis ◼ atrial fibrillation ◼ congestive heart failure ◼ guideline-directed medical therapy
- ◼ diabetes ◼ cardiomyopathy ◼ valvular heart disease ◼ mitral regurgitation ◼ cardiomyopathy in pregnancy ◼ reduced ejection fraction ◼ right heart pressure ◼ palliative care ◼ cardio-oncology ◼ social determinants of health

## TABLE OF CONTENTS

| Abstract .............................................................   | Abstract .............................................................   | Abstract .............................................................                                                                                          | e895                                           |
|--------------------------------------------------------------------------|--------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------|
| Top 10 Take-Home Messages ............................                   | Top 10 Take-Home Messages ............................                   | Top 10 Take-Home Messages ............................                                                                                                          | e897                                           |
| Preamble ...........................................................     | Preamble ...........................................................     | Preamble ...........................................................                                                                                            | e898                                           |
| 1. Introduction ...................................................      | 1. Introduction ...................................................      | 1. Introduction ...................................................                                                                                             | e899                                           |
|                                                                          | 1.1.                                                                     | Methodology and Evidence Review .........                                                                                                                       | e899                                           |
|                                                                          | 1.2.                                                                     | Organization of the Writing Committee                                                                                                                           | .... e899                                      |
|                                                                          | 1.3.                                                                     | Document Review and Approval                                                                                                                                    | ............. e899                             |
|                                                                          | 1.4.                                                                     | Scope of the Guideline ...........................                                                                                                              | e899                                           |
|                                                                          | 1.5.                                                                     | Class of Recommendation and Level of Evidence ...................................                                                                               | e900                                           |
|                                                                          | 1.6.                                                                     | Abbreviations                                                                                                                                                   | ......................................... e900 |
| 2.                                                                       | Definition of HF .............................................           | Definition of HF .............................................                                                                                                  | e901                                           |
|                                                                          | 2.1.                                                                     | Stages of HF                                                                                                                                                    | ......................................... e901 |
|                                                                          | 2.2.                                                                     | Classification of HF by Left Ventricular Ejection Fraction (LVEF) .........................                                                                     | e901                                           |
|                                                                          | 2.3.                                                                     | Diagnostic Algorithm for Classification of HF According to LVEF ....................... .....................                                                   | e905                                           |
| 3.                                                                       | Epidemiology and Causes of HF 3.1.                                       | Epidemiology of HF                                                                                                                                              | e906 ............................... e906      |
|                                                                          | 3.2.                                                                     | Cause of HF ..........................................                                                                                                          | e907                                           |
| 4.                                                                       | Initial and Serial Evaluation .............................              | Initial and Serial Evaluation .............................                                                                                                     | e908                                           |
|                                                                          | 4.1.                                                                     | Clinical Assessment: History and Physical Examination .............................                                                                             | e908                                           |
|                                                                          |                                                                          | 4.1.1. Initial Laboratory and Electrocardiographic Testing                                                                                                      | ....... e910                                   |
|                                                                          | 4.2.                                                                     | Use of Biomarkers for Prevention, Initial Diagnosis, and Risk Stratification ............                                                                       | e911                                           |
|                                                                          | 4.3.                                                                     | Genetic Evaluation and Testing ...............                                                                                                                  | e912                                           |
|                                                                          |                                                                          | Evaluation With Cardiac Imaging                                                                                                                                 | ............. e913                             |
|                                                                          | 4.4. 4.5.                                                                | Invasive Evaluation                                                                                                                                             | e915                                           |
|                                                                          | 4.6.                                                                     | ................................. Wearables and Remote Monitoring (Including Telemonitoring and Device Monitoring) ............................................ | e916                                           |
|                                                                          | 4.7.                                                                     | Exercise and Functional Capacity                                                                                                                                | e917                                           |
|                                                                          | 4.8.                                                                     | Testing .................................................. Initial and Serial Evaluation: Clinical Assessment: HF Risk Scoring ................                 | e918                                           |
| 5.                                                                       | Stage A (Patients at Risk for HF) ...................                    | Stage A (Patients at Risk for HF) ...................                                                                                                           | e919                                           |
|                                                                          | 5.1.                                                                     | Patients at Risk for HF (Stage A: Primary Prevention) ................................                                                                          | e919                                           |
| 6.                                                                       | Stage B (Patients With Pre-HF) ......................                    | Stage B (Patients With Pre-HF) ......................                                                                                                           | e921                                           |
|                                                                          | 6.1.                                                                     | Management of Stage B: Preventing the Syndrome of Clinical HF in Patients With Pre-HF .............................                                             | e921                                           |
| 7.                                                                       | Stage C HF ...................................................           | Stage C HF ...................................................                                                                                                  | e923                                           |

| 7.1.   | Nonpharmacological Interventions ..........                                                                          | Nonpharmacological Interventions ..........                                                                          | Nonpharmacological Interventions ..........                                                                          | e923                                   |
|--------|----------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------|----------------------------------------|
|        | 7.1.1.                                                                                                               | Self-Care Support in HF .............                                                                                | Self-Care Support in HF .............                                                                                | e923                                   |
|        | 7.1.2.                                                                                                               | Dietary Sodium Restriction ..........                                                                                | Dietary Sodium Restriction ..........                                                                                | e925                                   |
|        | 7.1.3.                                                                                                               | Management of Stage C HF: Activity, Exercise Prescription, and Cardiac Rehabilitation ...........                    | Management of Stage C HF: Activity, Exercise Prescription, and Cardiac Rehabilitation ...........                    | e926                                   |
| 7.2.   | Diuretics and Decongestion Strategies in Patients With HF ................................                           | Diuretics and Decongestion Strategies in Patients With HF ................................                           | Diuretics and Decongestion Strategies in Patients With HF ................................                           | e927                                   |
| 7.3.   | Pharmacological Treatment for HFrEF.......e928                                                                       | Pharmacological Treatment for HFrEF.......e928                                                                       | Pharmacological Treatment for HFrEF.......e928                                                                       |                                        |
|        | 7.3.1.                                                                                                               | Renin-Angiotensin System Inhibition With ACEi or ARB or ARNi ..........                                              | Renin-Angiotensin System Inhibition With ACEi or ARB or ARNi ..........                                              | e928                                   |
|        | 7.3.2.                                                                                                               | Beta Blockers .............................                                                                          | Beta Blockers .............................                                                                          | e931                                   |
|        | 7.3.3.                                                                                                               | Mineralocorticoid Receptor Antagonists (MRAs) ....................                                                   | Mineralocorticoid Receptor Antagonists (MRAs) ....................                                                   | e931                                   |
|        | 7.3.4.                                                                                                               | Sodium-Glucose Cotransporter 2 Inhibitors                                                                            | Sodium-Glucose Cotransporter 2 Inhibitors                                                                            | ................................. e932 |
|        | 7.3.5.                                                                                                               | Hydralazine and Isosorbide Dinitrate .....................................                                           | Hydralazine and Isosorbide Dinitrate .....................................                                           | e933                                   |
|        | 7.3.6.                                                                                                               | Other Drug Treatment .................                                                                               | Other Drug Treatment .................                                                                               | e934                                   |
|        | 7.3.7 .                                                                                                              | Drugs of Unproven Value or That May Worsen HF ..................                                                     | Drugs of Unproven Value or That May Worsen HF ..................                                                     | e935                                   |
|        | 7.3.8.                                                                                                               | GDMT Dosing: Sequencing and Uptitration ............................                                                 | GDMT Dosing: Sequencing and Uptitration ............................                                                 | e937                                   |
|        | 7.3.9.                                                                                                               | Additional Medical Therapies .......                                                                                 | Additional Medical Therapies .......                                                                                 | e939                                   |
|        |                                                                                                                      | 7.3.9.1.                                                                                                             | Management of Stage C HF: Ivabradine ...............                                                                 | e939                                   |
|        |                                                                                                                      | 7.3.9.2.                                                                                                             | Pharmacological Treatment for Stage C HFrEF (Digoxin) ............                                                   | e940                                   |
|        |                                                                                                                      | 7.3.9.3.                                                                                                             | Pharmacological Treatment for Stage C HFrEF: Soluble Guanylyl Cyclase Stimulators .......                            | e941                                   |
| 7.4.   | Device and Interventional Therapies for HFrEF ..............................................                         | Device and Interventional Therapies for HFrEF ..............................................                         | Device and Interventional Therapies for HFrEF ..............................................                         | e941                                   |
|        | 7.4.1.                                                                                                               | ICDs and CRTs ...........................                                                                            | ICDs and CRTs ...........................                                                                            | e941                                   |
|        | 7.4.2.                                                                                                               | Other Implantable Electrical Interventions ...............................                                           | Other Implantable Electrical Interventions ...............................                                           | e945                                   |
|        | 7.4.3.                                                                                                               | Revascularization for CAD ...........                                                                                | Revascularization for CAD ...........                                                                                | e945                                   |
| 7.5.   | Valvular Heart Disease ...........................                                                                   | Valvular Heart Disease ...........................                                                                   | Valvular Heart Disease ...........................                                                                   | e946                                   |
| 7.6.   | Heart Failure With Mildly Reduced EF (HFmrEF) and Improved EF (HFimpHF) ............................................ | Heart Failure With Mildly Reduced EF (HFmrEF) and Improved EF (HFimpHF) ............................................ | Heart Failure With Mildly Reduced EF (HFmrEF) and Improved EF (HFimpHF) ............................................ | e948                                   |
|        | 7.6.1.                                                                                                               | HF With Mildly Reduced Ejection Fraction .........................                                                   | HF With Mildly Reduced Ejection Fraction .........................                                                   | e948                                   |
|        | 7.6.2.                                                                                                               | HF With Improved Ejection Fraction ......................................                                            | HF With Improved Ejection Fraction ......................................                                            | e949                                   |

|                                                                                 | 7.7 .                                                                                                                                       | Preserved EF (HFpEF) .......................... 7.7                                                                                         | e949                                         |
|---------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------|
|                                                                                 |                                                                                                                                             | .1. HF With Preserved Ejection Fraction ......................................                                                              | e949                                         |
|                                                                                 | 7.8.                                                                                                                                        | Cardiac Amyloidosis ...............................                                                                                         | e952                                         |
|                                                                                 |                                                                                                                                             | 7.8.1. Diagnosis of Cardiac Amyloidosis                                                                                                     | .... e952                                    |
|                                                                                 |                                                                                                                                             | 7.8.2. Treatment of Cardiac Amyloidosis ....                                                                                                | e954                                         |
| 8.                                                                              | Stage D (Advanced) HF .................................                                                                                     | Stage D (Advanced) HF .................................                                                                                     | e955                                         |
|                                                                                 | 8.1.                                                                                                                                        | Specialty Referral for Advanced HF Nonpharmacological Management:                                                                           | ........ e955                                |
|                                                                                 | 8.2.                                                                                                                                        | Advanced HF ........................................                                                                                        | e956                                         |
|                                                                                 | 8.3.                                                                                                                                        | Inotropic Support                                                                                                                           | ................................... e957     |
|                                                                                 | 8.4.                                                                                                                                        | Mechanical Circulatory Support                                                                                                              | .............. e958                          |
|                                                                                 | 8.5. Cardiac Transplantation ..........................                                                                                     | 8.5. Cardiac Transplantation ..........................                                                                                     | e960                                         |
| 9.                                                                              | Patients Hospitalized With Acute                                                                                                            | Patients Hospitalized With Acute                                                                                                            |                                              |
|                                                                                 | Decompensated HF .......................................                                                                                    | Decompensated HF .......................................                                                                                    | e960                                         |
|                                                                                 | 9.1.                                                                                                                                        | Assessment of Patients Hospitalized With Decompensated HF .......................                                                           | e960                                         |
|                                                                                 | 9.2.                                                                                                                                        | Maintenance or Optimization of GDMT During Hospitalization .................                                                                | e962                                         |
|                                                                                 | 9.3.                                                                                                                                        | Diuretics in Hospitalized Patients: Decongestion Strategy ...........................                                                       | e963                                         |
|                                                                                 | 9.4a.                                                                                                                                       | Parenteral Vasodilation Therapy in Patients Hospitalized With HF ................                                                           | e964                                         |
|                                                                                 | 9.4b. 9.5.                                                                                                                                  | VTE Prophylaxis in Hospitalized Patients ................................................. Evaluation and Management of                     | e965                                         |
|                                                                                 | 9.6.                                                                                                                                        | Cardiogenic Shock ................................. Integration of Care: Transitions and                                                    | e965                                         |
| 10.                                                                             | Team-Based Approaches .......................                                                                                               | Team-Based Approaches .......................                                                                                               | e967 e969                                    |
|                                                                                 | Comorbidities in Patients With HF ................ 10.1. Management of Comorbidities in                                                     | Patients With HF                                                                                                                            | ............................... e969         |
|                                                                                 | 10.2. Management of AF in HF ...................                                                                                            | 10.2. Management of AF in HF ...................                                                                                            | e972                                         |
| 11.                                                                             | Special Populations ......................................                                                                                  | Special Populations ......................................                                                                                  | e973                                         |
|                                                                                 | 11.1. Disparities and Vulnerable                                                                                                            | Populations                                                                                                                                 | ....................................... e973 |
| 12.                                                                             | 11.2. Cardio-Oncology ................................ 11.3.                                                                                | HF and Pregnancy                                                                                                                            | e975 ............................. e978      |
|                                                                                 | Quality Metrics and Reporting ...................... 12.1. Performance Measurement                                                          | Quality Metrics and Reporting ...................... 12.1. Performance Measurement                                                          | e980                                         |
|                                                                                 | ................ of Care                                                                                                                    | ................ of Care                                                                                                                    | e980                                         |
| 13.                                                                             | Goals .............................................. 13.1. Palliative and Supportive Care, Shared Decision-Making, and End-of-Life ........ | Goals .............................................. 13.1. Palliative and Supportive Care, Shared Decision-Making, and End-of-Life ........ | e980                                         |
|                                                                                 | for Patient-Reported and Evidence Gaps and                                                                                                  | for Patient-Reported and Evidence Gaps and                                                                                                  |                                              |
| 14.                                                                             | Recommendation Outcomes Future Research Directions ..........................                                                               | Recommendation Outcomes Future Research Directions ..........................                                                               | e986                                         |
|                                                                                 | 14.1.                                                                                                                                       | Patient-Reported Outcomes                                                                                                                   | ............... e986                         |
| References ......................................................... Appendix 1 | References ......................................................... Appendix 1                                                             | References ......................................................... Appendix 1                                                             | ........................... e986             |
|                                                                                 |                                                                                                                                             |                                                                                                                                             | e987                                         |
| Author Relationships With Industry and                                          | Author Relationships With Industry and                                                                                                      | Author Relationships With Industry and                                                                                                      |                                              |
| Other Entities (Relevant) ...................................                   | Other Entities (Relevant) ...................................                                                                               | Other Entities (Relevant) ...................................                                                                               | e1026                                        |
| Appendix 2 Reviewer Relationships With Industry and                             | Appendix 2 Reviewer Relationships With Industry and                                                                                         | Appendix 2 Reviewer Relationships With Industry and                                                                                         | Other                                        |
|                                                                                 | Entities                                                                                                                                    | (Comprehensive)                                                                                                                             | e1029                                        |
|                                                                                 |                                                                                                                                             |                                                                                                                                             | ..................................           |

## Appendix 3

| Appendix for Tables 3 and 4. Suggested                       |
|--------------------------------------------------------------|
| Thresholds for Structural Heart Disease and                  |
| Evidence of Increased Filling Pressures .............. e1032 |

## TOP 10 TAKE-HOME MESSAGES

1.  Guideline-directed  medical  therapy  (GDMT)  for heart  failure  (HF)  with  reduced  ejection  fraction (HFrEF)  now  includes  4  medication  classes  that include  sodium-glucose  cotransporter-2  inhibitors (SGLT2i).
2.  SGLT2i  have  a  Class  of  Recommendation  2a in HF with mildly reduced ejection fraction (HFmrEF).  Weaker  recommendations  (Class  of Recommendation  2b)  are  made  for  ARNi,  ACEi, ARB, MRA, and beta blockers in this population.
3.  New  recommendations  for  HFpEF  are  made  for SGLT2i  (Class  of  Recommendation  2a),  MRAs (Class  of  Recommendation 2b), and ARNi (Class of Recommendation 2b). Several prior recommendations have been renewed including treatment of hypertension (Class of Recommendation 1), treatment of atrial fibrillation (Class of Recommendation 2a), use of ARBs (Class of Recommendation 2b), and avoidance of routine use of nitrates or phosphodiesterase-5 inhibitors (Class of Recommendation 3: No Benefit).
4.  Improved LVEF is used to refer to those patients with  previous  HFrEF  who  now  have  an  LVEF &gt;40%. These patients should continue their HFrEF treatment.
5. Value  statements  were  created  for  select  recommendations  where  high-quality,  cost-effectiveness  studies  of  the  intervention  have  been published.
6.  Amyloid heart disease has new recommendations for  treatment  including  screening  for  serum  and urine  monoclonal  light  chains,  bone  scintigraphy, genetic sequencing, tetramer stabilizer therapy, and anticoagulation.
7. Evidence supporting increased filling pressures is important  for  the  diagnosis  of  HF  if  the  L VEF  is &gt;40%. Evidence for increased filling pressures can be obtained from noninvasive (eg, natriuretic peptide, diastolic function on imaging) or invasive testing (eg, hemodynamic measurement).
8.  Patients with advanced HF who wish to prolong survival should be referred to a team specializing in HF. A HF specialty team reviews HF management, assesses suitability for advanced HF therapies,  and  uses  palliative  care  including  palliative inotropes  where  consistent  with  the  patient's goals of care.
9. Primary  prevention  is  important  for  those  at  risk for HF (stage A) or pre-HF (stage B). Stages of

HF were revised to emphasize the new terminologies of 'at risk' for HF for stage A and pre-HF for stage B.

10.  Recommendations are provided for select patients with HF and iron deficiency, anemia, hypertension, sleep disorders,  type  2  diabetes,  atrial  fibrillation, coronary artery disease, and malignancy.

## PREAMBLE

Since 1980, the American College of Cardiology (ACC) and American Heart Association (AHA) have translated scientific  evidence  into  clinical  practice  guidelines  with recommendations to improve cardiovascular health. These guidelines, which are based on systematic methods to evaluate and classify evidence, provide a foundation  for  the  delivery  of  quality  cardiovascular  care.  The ACC and AHA sponsor the development and publication of  clinical  practice  guidelines  without  commercial  support, and members volunteer their time to the writing and review efforts. Guidelines are official policy of the ACC and AHA. For some guidelines, the ACC and AHA partner with other organizations.

## Intended Use

Clinical practice guidelines provide recommendations applicable to patients with or at risk of developing cardiovascular  disease  (CVD).  The  focus  is  on  medical practice in the United States, but these guidelines are relevant to patients throughout the world. Although guidelines may be used to inform regulatory or payer decisions, the intent is to improve quality of care and align with patients'  interests.  Guidelines  are  intended  to  define  practices meeting the needs of patients in most, but not all, circumstances and should not replace clinical judgment.

## Clinical Implementation

Management, in accordance with guideline recommendations, is effective only when followed by both practitioners and  patients.  Adherence  to  recommendations  can  be enhanced by shared decision-making between clinicians and patients, with patient engagement in selecting interventions  on  the  basis  of  individual  values,  preferences, and associated conditions and comorbidities.

## Methodology and Modernization

The ACC/AHA Joint Committee on Clinical Practice Guidelines (Joint Committee) continuously reviews, updates, and modifies guideline methodology on the basis of published standards from organizations, including the National Academy of Medicine (formerly, the Institute of Medicine), 1,2 and on the basis of internal reevaluation. Similarly, presentation and delivery of guidelines are reevaluated and modified in response to evolving technologies and other factors to optimally facilitate dissemination of information to health care professionals at the point of care.

Numerous modifications to the guidelines have been implemented  to  make  them  shorter  and  enhance  'user friendliness.'  Guidelines  are  written  and  presented  in  a modular, 'knowledge chunk' format in which each chunk includes a table of recommendations, a brief synopsis, recommendation-specific  supportive  text  and,  when  appropriate,  flow  diagrams  or  additional  tables.  Hyperlinked references  are  provided  for  each  modular  knowledge chunk to facilitate quick access and review.In recognition of the importance of cost-value considerations, in certain guidelines, when appropriate and feasible, an assessment of  value  for  a  drug,  device,  or  intervention  may  be  performed in accordance with the ACC/AHA methodology. 3

To ensure that guideline recommendations remain current, new data will be reviewed on an ongoing basis by the writing committee and staff. Going forward, targeted sections/knowledge chunks will be revised dynamically after  publication  and  timely  peer  review  of  potentially practice-changing science. The previous designations of 'full  revision'  and  'focused  update'  will  be  phased  out. For additional information and policies on guideline development,  readers  may  consult  the  ACC/AHA  guideline methodology manual 4  and other methodology articles. 5-7

## Selection of Writing Committee Members

The Joint Committee strives to ensure that the guideline writing committee contains requisite content expertise and is representative of the broader cardiovascular community by selection of experts across a spectrum of backgrounds, representing different geographic regions, sexes, races, ethnicities, intellectual perspectives/biases, and clinical practice settings. Organizations and professional societies with related interests and expertise are invited to participate as partners or collaborators.

## Relationships With Industry and Other Entities

The ACC and AHA have rigorous policies and methods to ensure that documents are developed without bias or improper influence. The complete policy on relationships with industry and other entities (RWI) can be found online. Appendix 1 of the guideline lists writing committee members' relevant RWI; for the purposes of full transparency, their comprehensive disclosure information is available in a Supplemental Appendix. Comprehensive disclosure information for the Joint Committee is also available online.

## Evidence Review and Evidence Review Committees

In  developing  recommendations,  the  writing  committee uses evidence-based methodologies that are based on

all  available  data. 4,5 Literature  searches  focus  on  randomized controlled trials (RCTs) but also include registries,  nonrandomized comparative and descriptive studies, case series, cohort studies, systematic reviews, and expert opinion. Only key references are cited.

An independent evidence review committee is commissioned  when  there  are ≥ 1  questions  deemed  of utmost  clinical  importance  and  merit  formal  systematic review to determine which patients are most likely to benefit from a drug, device, or treatment strategy, and to what degree.  Criteria  for  commissioning  an  evidence  review committee and formal systematic review include absence of a current authoritative systematic review, feasibility of defining the benefit and risk in a time frame consistent with the writing of a guideline, relevance to a substantial number of patients, and likelihood that the findings can be translated into actionable recommendations. Evidence review committee members may include methodologists, epidemiologists,  clinicians,  and  biostatisticians.  Recommendations developed by the writing committee on the basis of the systematic review are marked ' SR . '

## Guideline-Directed Medical Therapy

The  term  guideline-directed  medical  therapy  (GDMT) encompasses clinical evaluation, diagnostic testing, and both  pharmacological  and  procedural  treatments.  For these and all recommended drug treatment regimens, the reader should confirm dosage with product insert material and evaluate for contraindications and interactions. Recommendations are  limited  to  drugs,  devices,  and  treatments approved for clinical use in the United States.

Joshua A. Beckman, MD, MS, FAHA, FACC Chair, ACC/AHA Joint Committee on Clinical Practice Guidelines

## 1. INTRODUCTION

## 1.1. Methodology and Evidence Review

The  recommendations  listed  in  this  guideline  are, whenever possible,  evidence  based.  An  initial  extensive evidence review, which included literature derived from research involving human subjects, published in English, and indexed in MEDLINE (through PubMed), EMBASE, the Cochrane Collaboration, the Agency for Healthcare Research and Quality, and other selected databases  relevant  to  this  guideline,  was  conducted from May 2020 to December 2020. Key search words included  but  were  not  limited  to  the  following: heart failure; heart failure with reduced ejection fraction; heart failure with preserved ejection fraction; heart failure with mildly  reduced  ejection  fraction;  systolic  heart  failure; heart failure rehabilitation; cardiac failure; chronic heart failure; acute decompensated heart failure; cardiogenic shock; beta blockers; mineralocorticoid receptor antag- onists; ACE-inhibitors, angiotensin and neprilysin receptor antagonist; sacubitril valsartan; angiotensin receptor antagonist; Sodium glucose co-transporter 2 or SGLT2 inhibitors; cardiac amyloidosis; atrial fibrillation; congestive  heart  failure;  guideline-directed  medical  therapy; HFrEF; diabetes mellitus; cardiomyopathy; cardiac amyloidosis; valvular heart disease; mitral regurgitation; cardiomyopathy in pregnancy; reduced ejection fraction; right heart pressure; palliative care .

Additional  relevant  studies,  published  through  September 2021 during the guideline writing process, were also considered by the writing committee and added to the evidence tables when appropriate. This guideline was harmonized with other ACC/AHA guidelines published through December 2021.The final evidence tables are included in the Online Data Supplement and summarize the evidence used by the writing committee to formulate recommendations.  References  selected  and  published in the present document are representative and not allinclusive.

## 1.2. Organization of the Writing Committee

The writing committee consisted of cardiologists, HF specialists, internists, interventionalists, an  electrophysiologist,  surgeons,  a  pharmacist,  an  advanced nurse  practitioner,  and  2  lay/patient  representatives. The  writing  committee  included  representatives  from the ACC, AHA, and Heart Failure Society of America (HFSA). Appendix 1 of the present document lists writing committee members' relevant RWI. For the purposes of full transparency, the writing committee members' comprehensive disclosure information is available in a Supplemental Appendix.

## 1.3. Document Review and Approval

This document was reviewed by 2 official reviewers nominated by the AHA; 1 official reviewer nominated by the ACC; 2 official reviewers from the HFSA; 1 official Joint Committee on Clinical Practice Guidelines reviewer; and 32 individual content reviewers. Reviewers' RWI information was distributed to the writing committee and is published in this document (Appendix 2).This document was approved for publication by the governing bodies of the ACC, AHA, and HFSA.

## 1.4. Scope of the Guideline

The purpose of the '2022 AHA/ACC/HFSA Guideline for the Management of Heart Failure' (2022 HF guideline) is to provide an update and to consolidate the '2013 ACCF/AHA  Guideline  for  the  Management  of  Heart Failure' 1   for  adults  and  the  '2017  ACC/AHA/HFSA Focused Update of the 2013 ACCF/AHA Guideline for the Management of Heart Failure' 2  into a new document.

Related ACC/AHA guidelines include recommendations relevant to HF and, in such cases, the HF guideline refers to these documents. For example, the 2019 primary prevention of cardiovascular disease guideline 3 includes recommendations that will  be  useful  in  preventing  HF, and the 2021 valvular heart disease guideline 4  provides recommendations for mitral valve (MV) clipping in mitral regurgitation (MR).

## Areas of focus include:

- Prevention of HF.
- Management strategies in stage C HF, including:
- New  treatment  strategies in HF, including sodium-glucose cotransporter-2 inhibitors (SGLT2i)  and  angiotensin  receptor-neprilysin inhibitors (ARNi).
- Management of HF and atrial fibrillation (AF), including ablation of AF.
- Management of HF and secondary MR, including MV transcatheter edge-to-edge repair.
- Specific management strategies, including:
- Cardiac amyloidosis.
- Cardio-oncology.
- Implantable devices.
- Left ventricular assist device (L VAD) use in stage D HF.

The  intended  primary  target  audience  consists  of clinicians who are involved in the care of patients with HF.  Recommendations  are  stated  in  reference  to  the patients and their condition. The focus is to provide the most up-to-date evidence to inform the clinician during shared decision-making with the patient. Although the present document is not intended to be a proceduralbased  manual  of  recommendations  that  outlines  the best  practice  for  HF,  there  are  certain  practices  that clinicians might use that are associated with improved clinical outcomes.

In developing the 2022 HF guideline, the writing committee  reviewed  previously  published  guidelines  and related statements. Table 1 contains a list of these guidelines  and  statements  deemed  pertinent  to  this  writing effort and is intended for use as a resource, thus obviating the need to repeat existing guideline recommendations.

## 1.5. Class of Recommendation and Level of Evidence

The  Class  of  Recommendation  (COR)  indicates  the strength of recommendation, encompassing the estimated  magnitude  and  certainty  of  benefit  in  proportion  to risk. The Level of Evidence (LOE) rates the quality of scientific evidence supporting the intervention on the basis of the type, quantity, and consistency of data from clinical trials and other sources (Table 2). 1

## 1.6. Abbreviations

| Abbreviation   | Meaning/Phrase                                        |
|----------------|-------------------------------------------------------|
| ACEi           | angiotensin-converting enzyme inhibitors              |
| ACS            | acute coronary syndrome                               |
| ARNi           | angiotensin receptor-neprilysin inhibitors            |
| ARB            | angiotensin (II) receptor blockers                    |
| AF             | atrial fibrillation                                   |
| AL-CM          | immunoglobulin light chain amyloid cardiomyopathy     |
| ATTR-CM        | transthyretin amyloid cardiomyopathy                  |
| ATTRv          | variant transthyretin amyloidosis                     |
| ATTRwt         | wild-type transthyretin amyloidosis                   |
| BNP            | B-type natriuretic peptide                            |
| CABG           | coronary artery bypass graft                          |
| CAD            | coronary artery disease                               |
| CCM            | cardiac contractility modulation                      |
| CHF            | congestive heart failure                              |
| CKD            | chronic kidney disease                                |
| CMR            | cardiovascular magnetic resonance                     |
| COVID-19       | coronavirus disease 2019                              |
| CPET           | cardiopulmonary exercise test                         |
| CRT            | cardiac resynchronization therapy                     |
| CRT-D          | cardiac resynchronization therapy with defibrillation |
| CRT-P          | cardiac resynchronization therapy with pacemaker      |
| CT             | computed tomography                                   |
| CVD            | cardiovascular disease                                |
| CVP            | central venous pressure                               |
| DOAC           | direct-acting oral anticoagulants                     |
| DPP-4          | dipeptidyl peptidase-4                                |
| ECG            | electrocardiogram                                     |
| EF             | ejection fraction                                     |
| eGFR           | estimated glomerular filtration rate                  |
| FDA            | US Food and Drug Administration                       |
| FLC            | free light chain                                      |
| GDMT           | guideline-directed medical therapy                    |
| HF             | heart failure                                         |
| HFimpEF        | heart failure with improved ejection fraction         |
| HFmrEF         | heart failure with mildly reduced ejection fraction   |
| HFpEF          | heart failure with preserved ejection fraction        |
| HFrEF          | heart failure with reduced ejection fraction          |
| ICD            | implantable cardioverter-defibrillator                |
| IFE            | immunofixation electrophoresis                        |
| LBBB           | left bundle branch block                              |
| LV             | left ventricular                                      |
| LVAD           | left ventricular assist device                        |
| LVEDV          | left ventricular end-diastolic volume                 |
| LVEF           | left ventricular ejection fraction                    |
| LVH            | left ventricular hypertrophy                          |

| Abbreviation   | Meaning/Phrase                                      |
|----------------|-----------------------------------------------------|
| MCS            | mechanical circulatory support                      |
| MI             | myocardial infarction                               |
| MR             | mitral regurgitation                                |
| MRA            | mineralocorticoid receptor antagonist               |
| MV             | mitral valve                                        |
| NSAID          | nonsteroidal anti-inflammatory drug                 |
| NSVT           | nonsustained ventricular tachycardia                |
| NT-proBNP      | N-terminal prohormone of B-type natriuretic peptide |
| NYHA           | New York Heart Association                          |
| QALY           | quality-adjusted life year                          |
| QOL            | quality of life                                     |
| PA             | pulmonary artery                                    |
| PCWP           | pulmonary capillary wedge pressure                  |
| PET            | positron emission tomography                        |
| PPAR- γ        | peroxisome proliferator-activated receptor gamma    |
| PUFA           | polyunsaturated fatty acid                          |
| RA             | right atrial                                        |
| RASS           | renin-angiotensin-aldosterone system                |
| RAASi          | renin-angiotensin-aldosterone system inhibitors     |
| RCT            | randomized controlled trial                         |
| RV             | right ventricular                                   |
| SCD            | sudden cardiac death                                |
| SGLT2i         | sodium-glucose cotransporter-2 inhibitors           |
| SPECT          | single photon emission CT                           |
| 99m Tc-PYP     | technetium pyrophosphate                            |
| TEER           | transcatheter mitral edge-to-edge repair            |
| TTE            | transthoracic echocardiogram                        |
| VA             | ventricular arrhythmia                              |
| VF             | ventricular fibrillation                            |
| VHD            | valvular heart disease                              |
| VO 2           | oxygen consumption/oxygen uptake                    |
| VT             | ventricular tachycardia                             |

## 2. DEFINITION OF HF

## HF Description

HF is a complex clinical syndrome with symptoms and signs  that  result  from  any  structural  or  functional  impairment  of  ventricular  filling  or  ejection  of  blood.  The writing committee recognizes that asymptomatic stages with  structural  heart  disease  or  cardiomyopathies  are not  covered  under  the  above  definition  as  having  HF. Such asymptomatic stages are considered at-risk for HF (stage A) or pre-HF (stage B), as explained in Section 2.1, 'Stages of HF.  '

## 2.1. Stages of HF

The  ACC/AHA  stages  of  HF  (Figure  1,  Table  3) emphasize the development and progression of disease, 1,2  and advanced stages and progression are as- sociated with reduced survival. 3  Therapeutic interventions in each stage aim to modify risk factors (stage A), treat risk and structural heart disease to prevent HF (stage B),  and  reduce  symptoms,  morbidity,  and mortality  (stages  C  and  D).  To  address  the  evolving role of biomarkers and structural changes for recognition of patients who are at risk of developing HF, who are potential candidates for targeted treatment strategies  for  the  prevention  of  HF,  and  to  enhance  the understanding and adoption of these classifications, the  writing  committee  proposed  the  terminologies listed in Table 3 for the stages of HF. For thresholds of cardiac structural, functional changes, elevated filling pressures, and biomarker elevations, refer to Appendix 3.

## New York Heart Association (NYHA) Classification

The NYHA classification is used to characterize symptoms  and  functional  capacity  of  patients  with  symptomatic  (stage  C)  HF  or  advanced  HF  (stage  D).  It  is a subjective assessment by a clinician and can change over  time.  Although  reproducibility  and  validity  can  be limited, 4,5  the NYHA functional classification is an independent predictor of mortality, 6,7 and it is widely used in clinical practice to determine the eligibility of patients for treatment strategies. Clinicians specify NYHA classification at baseline after the initial diagnosis and after treatment through  the  continuum  of  care  of  a  patient  with HF. Although a patient with symptomatic HF (stage C) may become asymptomatic with treatment (NYHA class I), that patient will still be categorized as stage C HF. Patients with stage C HF can be classified according to the trajectory of their symptoms (Figure 2).

## 2.2. Classification of HF by Left Ventricular Ejection Fraction (LVEF)

LVEF is considered important in the classification of patients with HF because of differing prognosis and response to treatments and because most clinical trials  select  patients  based  on  ejection  fraction  (EF). RCTs with evidence of survival benefit in patients with HF  have  mainly  enrolled  patients  with  HF  with  an LVEF ≤ 35% or ≤ 40%, often labeled HF with reduced ejection fraction (HFrEF). 1  In this guideline, HFrEF is defined as LVEF ≤ 40% (Table 4). HF with preserved EF (HFpEF) represents at least 50% of the population with HF, and its prevalence is increasing. 2  HFpEF has been variably classified as LVEF &gt;40%, &gt;45%, or ≥ 50%. Because some of these patients do not have entirely  normal  LVEF but also do not have major reduction in systolic function, the term preserved EF has been used. In this guideline, the threshold for HFpEF is an LVEF ≥ 50% (Table 4).

Table 1. Associated Guidelines and Statements

| Title                                                                                                                                                                                                                                                              | Organization                                              | Publication Year (Reference)   |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------|--------------------------------|
| Guidelines                                                                                                                                                                                                                                                         |                                                           |                                |
| 2011 ACCF/AHA Guideline for Coronary Artery Bypass Graft Surgery Hillis et al., '2011 ACCF/AHA Guideline for Coronary Artery Bypass Graft Surgery' is now replaced and retired by the '2021 ACC/AHA/SCAI Guideline for Coronary Artery Revascularization' 5        | ACCF/AHA                                                  | 2011 6                         |
| 2011 ACCF/AHA/SCAI Guideline for Percutaneous Coronary Intervention Levine et al., '2011 ACCF/AHA/SCAI Guideline for Percutaneous Coronary Intervention,' is now replaced and retired by the '2021 ACC/AHA/SCAI Guideline for Coronary Artery Revascularization' 5 | ACCF/AHA/SCAI                                             | 2011 7                         |
| 2015 ACCF/AHA/SCAI Focused Update Guideline for Percutaneous Coronary Intervention                                                                                                                                                                                 | ACCF/AHA/SCAI                                             | 2016 8                         |
| 2020 ACC/AHA Guideline for the Management of Patients With Valvular Heart Disease                                                                                                                                                                                  | ACC/AHA                                                   | 2021 4                         |
| 2020 AHA/ACC Guideline for the Diagnosis and Treatment of Patients With Hypertrophic Cardiomyopathy                                                                                                                                                                | ACC/AHA                                                   | 2020 9                         |
| 2019 ACC/AHA Guideline on the Primary Prevention of Cardiovascular Disease                                                                                                                                                                                         | ACC/AHA                                                   | 2019 3                         |
| 2019 AHA/ACC/HRS Focused Update of the 2014 AHA/ACC/HRS Guideline for the Management of Patients With Atrial Fibrillation                                                                                                                                          | AHA/ACC/HRS                                               | 2019 10                        |
| 2017 ACC/AHA/AAPA/ABC/ACPM/AGS/APhA/ASH/ASPC/NMA/PCNA Guideline for the Prevention, Detec- tion, Evaluation, and Management of High Blood Pressure in Adults                                                                                                       | ACC/AHA/AAPA/ABC/ ACPM/AGS/AphA/ASH/ ASPC/NMA/PCNA        | 2018 11                        |
| 2017 ACC/AHA/HFSA Focused Update of the 2013 ACCF/AHA Guideline for the Management of Heart Failure                                                                                                                                                                | ACC/AHA/HFSA                                              | 2017 2                         |
| 2016 ACC/AHA/HFSA Focused Update on New Pharmacological Therapy for Heart Failure: An Update of the 2013 ACCF/AHA Guideline for the Management of Heart Failure                                                                                                    | ACC/AHA/HFSA                                              | 2016 12                        |
| 2014 ACC/AHA/AATS/PCNA/SCAI/STS Focused Update of the Guideline for the Diagnosis and Management of Patients With Stable Ischemic Heart Disease                                                                                                                    | ACC/AHA/AATS/PCNA/ SCAI/STS                               | 2014 13 *                      |
| 2013 AHA/ACC Guideline on Lifestyle Management to Reduce Cardiovascular Risk                                                                                                                                                                                       | AHA/ACC                                                   | 2014 14                        |
| 2013 AHA/ACC/TOS Guideline for the Management of Overweight and Obesity in Adults                                                                                                                                                                                  | AHA/ACC/TOS                                               | 2014 15                        |
| 2018 AHA/ACC/AACVPR/AAPA/ABC/ACPM/ADA/AGS/AphA/ASPC/NLA/PCNA Guideline on the Manage- ment of Blood Cholesterol                                                                                                                                                    | AHA/ACC/AACVPR/AAPA/ ABC/ACPM/ADA/AGS/ AphA/ASPC/NLA/PCNA | 2019 16                        |
| 2013 ACC/AHA Guideline on the Treatment of Blood Cholesterol to Reduce Atherosclerotic Cardiovascular Risk in Adults                                                                                                                                               | ACC/AHA                                                   | 2014 17                        |
| 2013 ACC/AHA Guideline on the Assessment of Cardiovascular Risk                                                                                                                                                                                                    | ACC/AHA                                                   | 2014 18                        |
| 2013 ACCF/AHA Guideline for the Management of Heart Failure                                                                                                                                                                                                        | ACCF/AHA                                                  | 2013 1                         |
| 2013 ACCF/AHA Guideline for the Management of ST-Elevation Myocardial Infarction                                                                                                                                                                                   | ACCF/AHA                                                  | 2013 19                        |
| 2012 ACCF/AHA/HRS Focused Update of the 2008 Guidelines for Device-Based Therapy of Cardiac Rhythm Abnormalities                                                                                                                                                   | ACCF/AHA/HRS                                              | 2012 20                        |
| 2012 ACCF/AHA/ACP/AATS/PCNA/SCAI/STS Guideline for the Diagnosis and Management of Patients With Stable Ischemic Heart Disease                                                                                                                                     | ACCF/AHA/ACP/AATS/ PCNA/SCAI/STS                          | 2012 21                        |
| Effectiveness-Based Guidelines for the Prevention of Cardiovascular Disease in Women-2011 Update                                                                                                                                                                   | AHA                                                       | 2011 22                        |
| AHA/ACCF Secondary Prevention and Risk Reduction Therapy for Patients With Coronary and Other Atheroscle- rotic Vascular Disease: 2011 Update                                                                                                                      | AHA/ACCF                                                  | 2011 23                        |
| 2010 ACCF/AHA Guideline for Assessment of Cardiovascular Risk in Asymptomatic Adults                                                                                                                                                                               | ACCF/AHA                                                  | 2010 24                        |
| Part 9: Post-Cardiac Arrest Care: 2010 American Heart Association Guidelines for Cardiopulmonary Resuscita- tion and Emergency Cardiovascular Care                                                                                                                 | AHA                                                       | 2010 25                        |
| Seventh Report of the Joint National Committee on Prevention, Detection, Evaluation, and Treatment of High Blood Pressure                                                                                                                                          | NHLBI                                                     | 2003 26                        |
| Statements                                                                                                                                                                                                                                                         |                                                           |                                |
| Cardiac Amyloidosis: Evolving Diagnosis and Management                                                                                                                                                                                                             | AHA                                                       | 2020 27                        |
| Testing of Low-Risk Patients Presenting to the Emergency Department With Chest Pain                                                                                                                                                                                | AHA                                                       | 2010 28                        |
| Primary Prevention of Cardiovascular Diseases in People With Diabetes Mellitus                                                                                                                                                                                     | AHA/ADA                                                   | 2007 29                        |
| Prevention and Control of Influenza                                                                                                                                                                                                                                | CDC                                                       | 2005 30                        |

AATS indicates American Association for Thoracic Surgery; AACVPR, American Association of Cardiovascular and Pulmonary Rehabilitation; AAPA, American Academy of Physician Associates; ABC, Association of Black Cardiologists; ACC, American College of Cardiology; ACCF, American College of Cardiology Foundation; ACPM, American College of Preventive Medicine; ADA, American Diabetes Association; AGS, American Geriatrics Society; AHA, American Heart Association; AphA, American Pharmacists Association; ASH, American Society of Hypertension; ASPC, American Society for Preventive Cardiology; CDC, Centers for Disease Control and Prevention; ESC, European Society of Cardiology; HFSA, Heart Failure Society of America; HRS, Heart Rhythm Society; NHLBI, National Heart, Lung, and Blood Institute; NICE, National Institute for Health and Care Excellence; NMA, National Medical Association; NLA, National Lipid Association; PCNA, Preventive Cardiovascular Nurses Association; SCAI, Society for Cardiovascular Angiography and Interventions; SIHD, stable ischemic heart disease; STS, Society of Thoracic Surgeons; TOS, The Obesity Society; and WHF, World Heart Federation.

*The full SIHD guideline is from 2012. 21  A focused update was published in 2014. 13

Table 2. Applying American College of Cardiology/American Heart Association Class of Recommendation and Level of Evidence to Clinical Strategies, Interventions, Treatments, or Diagnostic Testing in Patient Care (Updated May 2019)*

<!-- image -->

Patients with HF and an LVEF between the HFrEF and HFpEF range have been termed as 'HF with midrange EF, ' 3,4 or 'HF with mildly reduced EF. ' 4  Because of LVEF being lower than normal, these patients are classified in this document as HF with mildly reduced EF  (HFmrEF).  Patients  with  HFmrEF  are  usually  in a dynamic trajectory to improvement from HFrEF or to  deterioration  to  HFrEF  (Figure  3).  Therefore,  for patients whose EF falls into this mildly reduced category, 1 EF measurement at 1 time point may not be adequate,  and  the  trajectory  of  LVEF  over  time  and the cause is important to evaluate (Figure 3). Furthermore, the diagnosis of HFmrEF and HFpEF can be challenging.  Although  the  classic  clinical  signs  and symptoms of HF, together with EF of 41% to 49%

## LEVEL(QUALITY)OFEVIDENCE

## LEVELA

- ·High-quality evidencetfrommore than1RCT
- Meta-analysesofhigh-qualityRCTs
- OneormoreRCTscorroboratedbyhigh-qualityregistrystudies

## LEVELB-R

- Moderate-quality evidencetfrom1ormoreRCTs
- ·Meta-analyses of moderate-quality RCTs

## LEVELB-NR

## (Randomized)

## (Nonrandomized)

- ·Moderate-qualityevidencefrom1ormorewell-designed,well executed nonrandomized studiesobservational studies,orregistry studies
- Meta-analysesof such studies

## LEVELC-LD

## (Limited Data)

- ·Randomized ornonrandomizedobservational orregistry studieswith limitationsofdesign or execution
- ·Meta-analyses of such studies
- ·Physiological ormechanistic studies in human subjects

## LEVELC-EO

## (Expert Opinion)

- Consensus of expert opinionbased on clinical experience

ArecommendationwithLoECdoesnotimplythattherecommendationisweak.Many importantclinicalquestionsaddressedinguidelinesdonotlendthemselvestoclinical trials.AlthoughRCTs areunavailable,theremaybeaveryclear clinical consensus thata particular testortherapyisuseful oreffective.

- Theoutcomeorresultoftheintervention shouldbe specified(animprovedclinical
- For comparative-effectiveness recommendations(CoR1and 2a:LOEAandBonly), studiesthatsupporttheuseofcomparatorverbsshould invalvedirectcomparisons of the treatmentsorstrategiesbeing evaluated.
- Themethod of assessing quality is evolving.including the application of standardizedwidly-uedandpreerablyvaldatedevidencegradingtolsndor systematicreviews,theincorporationofanEvidenceReviewCommittee.

CORindicatesClassofRecommendation:EO,expertopinion:LD,limited data;LOE,Level or ≥ 50%, respectively, are necessary for the diagnosis of the HFmrEF and HFpEF, the requirements for additional objective measures of cardiac dysfunction can improve the diagnostic specificity. The signs and symptoms of HF are frequently nonspecific and overlap with other clinical conditions. Elevated natriuretic peptide  levels  are  supportive  of  the  diagnosis,  but normal levels do not exclude a diagnosis of HFmrEF or  HFpEF.  To  improve  the  specificity  of  diagnosing HFmrEF and HFpEF, the clinical diagnosis of HF in these EF categories should be further supported by objective  measures.  Therefore,  the  writing  committee  proposes  the  addition  of  evidence  of  spontaneous (at rest) or provokable (eg, during exercise, fluid challenge) increased LV filling pressures (eg, elevated

Figure 1. ACC/AHA Stages of HF.

<!-- image -->

The ACC/AHA stages of HF are shown. ACC indicates American College of Cardiology; AHA, American Heart Association; CVD, cardiovascular disease; GDMT, guideline-directed medical therapy; and HF, heart failure.

natriuretic peptide, noninvasive/invasive hemodynamic  measurement)  to  the  classifications  of  HFmrEF and HFpEF (Table 4).

The  '2013  ACCF/AHA  Guideline  for  the  Management  of  Heart  Failure' 1   has  used  the  HFpEFimproved terminology  for  those  whose  EF  improved from a lower level to EF &gt;40% under the subgrouping of patients with HFpEF. Others have proposed a

Table 3. Stages of HF

| Stages                  | Definition and Criteria                                                                                                                                                                                                                                                                                                      |
|-------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Stage A: At Risk for HF | At risk for HF but without symptoms, structural heart disease, or cardiac biomarkers of stretch or injury (eg, patients with hypertension, atherosclerotic CVD, diabetes, metabolic syndrome and obesity, exposure to cardiotoxic agents, genetic variant for cardiomyopathy, or positive family history of cardiomyopathy). |
| Stage B: Pre-HF         | No symptoms or signs of HF and evidence of 1 of the following:                                                                                                                                                                                                                                                               |
| Stage B: Pre-HF         | Structural heart disease * Reduced left or right ventricular systolic function Reduced ejection fraction, reduced strain Ventricular hypertrophy Chamber enlargement Wall motion abnormalities Valvular heart disease                                                                                                        |
| Stage B: Pre-HF         | Evidence for increased filling pressures * By invasive hemodynamic measurements By noninvasive imaging suggesting elevated filling pressures (eg, Doppler echocardiography)                                                                                                                                                  |
| Stage B: Pre-HF         | Patients with risk factors and Increased levels of BNPs * or Persistently elevated cardiac troponin in the absence of competing diagnoses resulting in such biomarker elevations such as acute coronary syndrome, CKD, pulmonary embolus, or myopericarditis                                                                 |
| Stage C: Symptomatic HF | Structural heart disease with current or previous symptoms of HF.                                                                                                                                                                                                                                                            |
| Stage D: Advanced HF    | Marked HF symptoms that interfere with daily life and with recurrent hospitalizations despite attempts to optimize GDMT.                                                                                                                                                                                                     |

BNP indicates B-type natriuretic peptide; CKD, chronic kidney disease; CVD, cardiovascular disease; GDMT, guideline-directed medical therapy; and HF, heart failure. *For thresholds of cardiac structural, functional changes, elevated filling pressures, and biomarker elevations, refer to Appendix 3.

working definition of HF-recovered EF that included a baseline LVEF ≤ 40%, a ≥ 10% increase from baseline LVEF,  and  a  second  measurement  of  LVEF  &gt;40%. 3 Although associated with better outcomes, improvement in LVEF does not mean full myocardial recovery or normalization of LV function. In most patients, cardiac  structural  abnormalities,  such  as  LV  chamber  dilatation  and  ventricular  systolic  and  diastolic

Figure 2. Trajectory of Stage C HF.

<!-- image -->

The trajectory of stage C HF is displayed. Patients whose symptoms and signs of HF are resolved are still stage C and should be treated accordingly. If all HF symptoms, signs, and structural abnormalities resolve, the patient is considered to have HF in remission. HF indicates heart failure; and L V, left ventricular. *Full resolution of structural and functional cardiac abnormalities is uncommon.

dysfunction,  may  persist.  Furthermore,  changes  in LVEF might not be unidirectional; a patient may have improvement  followed  by  a  decrease  in  EF  or  vice versa  depending  on  the  underlying  cause,  duration of  disease,  adherence  to  the  GDMT,  or  reexposure to  cardiotoxicity. 5   Therefore,  the  writing  committee elected  not  to  use  'recovered  EF'  or  HFpEF,  even if  subsequent LVEF was &gt;50% but, rather, 'HF with improved EF' (HFimpEF) as a subgroup of HFrEF to characterize these patients (Table 4, Figure 3). Importantly, EF can decrease after withdrawal of pharmacological treatment in many patients who had improved EF to normal range with GDMT. 5  Trajectory of LVEF can be important, and a significant reduction in LVEF over time is a poor prognostic factor.

Table 4. Classification of HF by LVEF

| Type of HF According to LVEF         | Criteria                                                                                                                                                               |
|--------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| HFrEF (HF with reduced EF)           | LVEF ≤ 40%                                                                                                                                                             |
| HFimpEF (HF with improved EF)        | Previous LVEF ≤ 40% and a follow-up measurement of LVEF >40%                                                                                                           |
| HFmrEF (HF with mildly re- duced EF) | LVEF 41%-49% Evidence of spontaneous or provokable increased LV filling pressures (eg, elevated natriuretic peptide, noninvasive and invasive hemodynamic measurement) |
| HFpEF (HF with preserved EF)         | LVEF ≥ 50% Evidence of spontaneous or provokable increased LV filling pressures (eg, elevated natriuretic peptide, noninvasive and invasive hemodynamic measurement)   |

Please see Appendix 3 for suggested thresholds for structural heart disease and evidence of increased filling pressures.

HF indicates heart failure; LV, left ventricular; and LVEF, left ventricular ejection fraction.

## 2.3. Diagnostic Algorithm for Classification of HF According to LVEF

Structural and functional alterations of the heart as the underlying cause for the clinical presentation support the diagnosis of HFmrEF and HFpEF 1  (Figure 4). The criteria  for  diagnosis  of  HFmrEF  and  HFpEF  require evidence of increased LV filling pressures at rest, exercise, or other provocations. The criteria can be fulfilled with findings of elevated levels of natriuretic peptides, echocardiographic  diastolic  parameters  such  as  an E/e ′ ≥ 15  or  other  evidence  of  elevated  filling  pressures, or invasive hemodynamic measurement at rest or  exercise.  Evidence  of  structural  heart  disease  (eg, LV structural or functional alterations) may be used to further support the diagnosis of HFpEF. Key structural alterations are an increase in left atrial size and volume (left atrial volume index) and/or an increase in LV mass (LV mass index).

Exercise stress testing with echocardiographic evaluation  of  diastolic  parameters  can  be  helpful  if the  diagnosis  remains  uncertain. 2,3 Alternatively,  or  in addition, invasive hemodynamics at rest or with exercise,  with  assessment  of  filling  pressures  (pulmonary capillary wedge pressure or LV end diastolic pressures, pulmonary artery [PA] pressures, stroke volumes, and cardiac output) can be performed to help further establish the diagnosis. 4

The diagnosis of HFpEF is often challenging. A clinical composite score to diagnose HFpEF, the H 2 FPEF score, 5-7 integrates these predictive variables: obesity, atrial  fibrillation  (AF),  age  &gt;60  years,  treatment  with ≥ 2  antihypertensive  medications,  echocardiographic E/e ′ ratio &gt;9, and echocardiographic PA systolic pressure &gt;35 mm Hg. A weighted score based on these

Figure 3. Classification and Trajectories of HF Based on LVEF.

<!-- image -->

See Appendix 3 for suggested thresholds for laboratory findings. The classification for baseline and subsequent L VEF is shown. Patients with HFrEF who improve their LVEF to &gt;40% are considered to have HFimpEF and should continue HFrEF treatment. HF indicates heart failure; HFimpEF, heart failure with improved ejection fraction; HFmrEF, heart failure with mildly reduced ejection fraction; HFpEF, heart failure with preserved ejection fraction; HFrEF, heart failure with reduced ejection fraction; and L VEF, left ventricular ejection fraction. *There is limited evidence to guide treatment for patients who improve their L VEF from mildly reduced (41%-49%) to ≥ 50%. It is unclear whether to treat these patients as HFpEF or HFmrEF.

6  variables  was  used  to  create  the  composite  score ranging from 0 to 9. The odds of HFpEF doubled for each  1-unit  score  increase  (odds  ratio,  1.98;  95% CI: 1.74-2.30; P &lt;0.0001), with a c-statistic of 0.841. Scores  &lt;2  and ≥ 6  reflect  low  and  high  likelihood, respectively, for HFpEF. A score between 2 and 5 may require further evaluation of hemodynamics with exercise echocardiogram or cardiac catheterization to confirm or negate a diagnosis of HFpEF. The use of this H 2 FPEF score may help to facilitate discrimination of HFpEF from noncardiac causes of dyspnea and can assist  in  determination  of  the  need  for  further  diagnostic testing in the evaluation of patients with unexplained exertional dyspnea. 6,7

The European Society of Cardiology has developed a  diagnostic  algorithm. 8 This  involves  a  pretest  that assesses  for  HF  symptoms  and  signs,  typical  clinical  demographics  (obesity,  hypertension,  diabetes, elderly, AF), and diagnostic laboratory tests, ECG, and echocardiography. In the absence of overt noncardiac causes of breathlessness, HFpEF can be suspected if  there  is  a  normal  L VEF,  no  significant  heart  valve disease or cardiac ischemia, and at least 1 typical risk factor. The score used functional, morphological, and biomarker domains. The points score assigns 2 points for  a  major  criterion  or  1  point  for  a  minor  criterion within each domain, with a maximum of 2 points for each domain.

## 3. EPIDEMIOLOGY AND CAUSES OF HF 3.1. Epidemiology of HF Trends in Mortality and Hospitalization for HF

HF  is  a  growing  health  and  economic  burden  for  the United States, in large part because of the aging popula-

Figure 4. Diagnostic Algorithm for HF and EF-Based Classification.

<!-- image -->

The algorithm for a diagnosis of HF and EF-based classification is shown. BNP indicates B-type natriuretic peptide; ECG, electrocardiogram; EF, ejection fraction; HF, heart failure; HFmrEF, heart failure with mildly reduced ejection fraction; HFpEF, heart failure with preserved ejection fraction; HFrEF, heart failure with reduced ejection fraction; L VEF, left ventricular ejection fraction; L V, left ventricular; and NT-proBNP, N-terminal pro-B type natriuretic peptide.

tion. 1,2   Beginning in 2012, the age-adjusted death rate per capita for HF increased for the first time in the United  States. 3 A  recent  US  evaluation  found  total  deaths caused by HF have increased from 275 000 in 2009 to 310 000 in 2014. 3

US hospitalizations  for  HF  decreased  up  until  2012 4 ; however, from 2013 to 2017 , an increase in HF hospitalizations was observed. In 2017 , there were 1.2 million HF hospitalizations in the United States among 924  000 patients with HF. 4 This represents a 26% increase in HF hospitalizations and number of patients hospitalized with HF.

Although  the  absolute  number  of  patients  with  HF has partly grown as a result of the increasing number of older adults, the incidence of HF has decreased. 5  Among US Medicare beneficiaries, HF incidence declined from 36 cases per 1000 beneficiaries in 2011 to 27 cases per  1000  beneficiaries  in  2014  and  remained  stable through 2016. 5  Divergent trends in the incidence of HF have been observed for those with HFrEF (decreasing incidence) and HFpEF (increasing incidence). 6,7  Deaths attributable  to  cardiomyopathies  have  been  increasing globally because of, in part, increased recognition, diagnosis, and documentation of specific cardiomyopathies and cardiotoxicity. 2

## Racial and Ethnic Disparities in Mortality and Hospitalization for HF

Racial and ethnic disparities in death resulting from HF persist,  with  non-Hispanic  Black  patients  having  the highest death rate per capita. 4  A report examining the US  population  found  age-adjusted  mortality  rate  for HF to be 92 per 100 000 individuals for non-Hispanic Black patients, 87 per 100 000 for non-Hispanic White patients,  and  53  per  100 000  for  Hispanic  patients. 4 Among  Medicare  beneficiaries,  non-Hispanic  Black beneficiaries had a slightly greater decrease in HF incidence (38 cases per 1000 to 26 cases per 1000, P =0.009) than non-Hispanic White beneficiaries (36 cases per 1000 to 28 cases per 1000, P =0.003) from 2011 to 2016. 4  Among patients with established HF, non-Hispanic Black patients experienced a higher rate of HF hospitalization and a lower rate of death compared  with  non-Hispanic  White  patients  with  HF. 8-10 Hispanic  patients  with  HF  have  been  found  to  have similar 8 or higher 10 HF hospitalization rates and similar 10 or lower 8   mortality rates compared with non-Hispanic White patients. Asian/Pacific Islander patients with HF have had a similar rate of hospitalization as non-Hispanic White patients but a lower rate of death. 8,10  These racial and ethnic disparities in outcome, for those with HF, warrant studies and health policy changes to address health inequity.

## 3.2. Cause of HF

In the United States, approximately 115 million people have hypertension, 100 million have obesity, 92 million  have  prediabetes,  26  million  have  diabetes, and 125 million have atherosclerotic CVD. 1  These are

Table 5. Other Potential Nonischemic Causes of HF

| Cause                                                                               | Reference   |
|-------------------------------------------------------------------------------------|-------------|
| Chemotherapy and other cardiotoxic medications                                      | 23-25       |
| Rheumatologic or autoimmune                                                         | 26          |
| Endocrine or metabolic (thyroid, acromegaly, pheochromocy- toma, diabetes, obesity) | 27-31       |
| Familial cardiomyopathy or inherited and genetic heart disease                      | 32          |
| Heart rhythm-related (eg, tachycardia-mediated, PVCs, RV pacing)                    | 33          |
| Hypertension                                                                        | 34          |
| Infiltrative cardiac disease (eg, amyloid, sarcoid, hemochro- matosis)              | 21,35,36    |
| Myocarditis (infectious, toxin or medication, immunological, hypersensitivity)      | 37,38       |
| Peripartum cardiomyopathy                                                           | 39          |
| Stress cardiomyopathy (Takotsubo)                                                   | 40,41       |
| Substance abuse (eg, alcohol, cocaine, methamphetamine)                             | 42-44       |

HF indicates heart failure; PVC, premature ventricular contraction; and RV, right ventricular.

known risk factors with high relative risk and population  attributable  risk  for  development  of  HF.  Therefore, a large proportion of the US population can be categorized  as  being  at-risk  for  HF  or  stage  A  HF. The  common  causes  of  HF  include  ischemic  heart disease and myocardial infarction (MI), hypertension, and valvular heart disease (VHD). Other causes can include familial or genetic cardiomyopathies; amyloidosis; cardiotoxicity with cancer or other treatments or substance abuse such as alcohol, cocaine, or methamphetamine; tachycardia, right ventricular (RV) pacing  or  stress-induced  cardiomyopathies;  peripartum cardiomyopathy;  myocarditis;  autoimmune  causes, sarcoidosis; iron overload, including hemochromatosis; and thyroid disease and other endocrine metabolic and nutritional causes (Table 5). Furthermore, with cardiac imaging and biomarkers, myocardial injury or cardiac  maladaptive  structural  changes  can  be  detected at earlier phases with a higher sensitivity, even in the absence of gross LV dysfunction or symptoms. With the coronavirus disease 2019 (COVID-19) pandemic,  investigators  are  gaining  better  insights  into infection  and  inflammation-related  myocardial  injury and myocarditis. With the increasing ability to detect myocardial injury and with an increasing awareness of cardiotoxicity and injury patterns including inflammation, pre-HF or stage B HF will likely continue to increase.  Beyond  classifications  of  EF  and  staging in  HF,  clinicians  should  seek  the  cause  of  HF  because appropriate treatment may be determined by the cause (Table 5).

## 4. INITIAL AND SERIAL EVALUATION

## 4.1. Clinical Assessment: History and Physical Examination

| Recommendations for Clinical Assessment: History and Physical Ex- amination Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Clinical Assessment: History and Physical Ex- amination Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Clinical Assessment: History and Physical Ex- amination Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                       |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                | LOE                                                                                                                                                                                | Recommendations                                                                                                                                                                                                                                                                                        |
| 1                                                                                                                                                                                  | B-NR                                                                                                                                                                               | 1. In patients with HF, vital signs and evidence of clinical congestion should be assessed at each encounter to guide overall management, includ- ing adjustment of diuretics and other medica- tions. 1-6                                                                                             |
| 1                                                                                                                                                                                  | B-NR                                                                                                                                                                               | 2. In patients with symptomatic HF, clinical factors indicating the presence of advanced HF should be sought via the history and physical examina- tion. 7-12                                                                                                                                          |
| 1                                                                                                                                                                                  | B-NR                                                                                                                                                                               | 3. In patients with cardiomyopathy, a 3-generation family history should be obtained or updated when assessing the cause of the cardiomyopa- thy to identify possible inherited disease. 13,14                                                                                                         |
| 1                                                                                                                                                                                  | B-NR                                                                                                                                                                               | 4. In patients presenting with HF, a thorough history and physical examination should direct diagnos- tic strategies to uncover specific causes that may warrant disease-specific management. 15,16                                                                                                    |
| 1                                                                                                                                                                                  | C-EO                                                                                                                                                                               | 5. In patients presenting with HF, a thorough history and physical examination should be obtained and performed to identify cardiac and noncardiac disorders, lifestyle and behavioral factors, and social determinants of health that might cause or accelerate the development or progression of HF. |

## Synopsis

The history and physical examination remain a cornerstone in  the  assessment  of  patients  with  HF.  The  history  and physical examination provide information about the cause of  an  underlying  cardiomyopathy,  including  the  possibility of  an  inherited  cardiomyopathy as ascertained by a family history or a condition requiring disease-specific therapy like amyloid heart disease, as well as reasons why a previously stable patient developed acutely decompensated HF. A critical component of the history and physical examination is to assess for clinical congestion (ie, those signs and symptoms resulting from elevated cardiac filling pressures). Congestion is a target for medication adjustment and is associated with quality of life (QOL) and prognosis. The history and physical examination also allow for the determination of clinical clues that suggest the patient has advanced HF, which may warrant referral to an advanced HF center.

## Recommendation-Specific Supportive Text

1. Clinical  congestion  can  be  assessed  by  various methods, including the presence of jugular venous

distention, 17 orthopnea, 18 bendopnea, 19 a  squarewave response to the Valsalva maneuver, 20  and leg edema. 6  On a practical level, clinicians use extent of clinical congestion to guide titration of pharmacological treatments, including doses of diuretics. Observational  studies  have  shown  that  clinical congestion is an important adverse risk factor in patients with HF. 1-6,17  Recently, the PARADIGM-HF (The Efficacy and Safety of LCZ696 Compared to Enalapril on Morbidity and Mortality of Patients With Chronic Heart Failure) investigators showed that, in patients with chronic HFrEF, changes in markers of  clinical  congestion  were  associated  with  QOL as assessed by the Kansas City Cardiomyopathy Questionnaire and also provided prognostic information independently even of natriuretic peptides or  the  MAGGIC  (Meta-analysis  Global  Group  in Chronic  Heart  Failure)  risk  score. 2   These  data highlight  the  ongoing  relevance  of  clinical  congestion  ascertained  by  the  history  and  physical examination.

2.  Some patients with HF progress to an advanced state, a condition that can be treated with specialized  interventions  such  as  mechanical  circulatory support  (MCS)  or  cardiac  transplantation.  Such patients should be identified before they progress to a state of extremis, at which point they may succumb  to  their  illness  or  suffer  complications  of an intervention as a result of their very advanced state.  Several  'simple  clinical  clues'  are  available to identify advanced HF and should be ascertained via a focused history and physical examination. The recognition  that  a  patient  has  advanced  HF  will allow for earlier referral to an advanced HF center, when appropriate, as will be discussed later in this document (see  Section  8,  'Specialty  Referral  for Advanced HF').
3. Increasingly, familial cardiomyopathy is recognized as  a  more  accurate  diagnosis  in  some  patients previously classified as having an idiopathic dilated cardiomyopathy  (DCM).  A  detailed  family  history may  provide  the  first  clue  of  a  genetic  basis.  A broad array of questions includes whether family members had a weak, enlarged, or thick heart, or HF; muscular dystrophy; a pacemaker or defibrillator; were on a heart transplant list; or died unexpectedly. Periodic updating of the family history in patients with a cardiomyopathy of uncertain origin may lead to a diagnosis of familial cardiomyopathy in the event that a relative subsequently develops a cardiomyopathy or a related complication. A 3-generation family pedigree obtained by genetic health

care professionals improved the rate of detection of  a  familial  process  as  compared  with  routine care. 14 Furthermore, a family history of cardiomyopathy, as determined by a 3-generation pedigree analysis, was associated with findings of gadolinium enhancement on cardiac magnetic resonance imaging (MRI) and increased major adverse cardiac  events. 13 The  possibility  of  an  inherited  cardiomyopathy  provides  the  impetus  for  cascade screening of undiagnosed family members, thereby potentially avoiding preventable adverse events in affected relatives by implementation of GDMT and other  management  that  otherwise  would  not  be initiated.

4. Certain conditions that cause HF require diseasespecific  therapies.  For  example,  in  amyloid  heart disease, whether on the basis of transthyretin 21 or light  chain  deposition, 22 there  are  specific  treatments that otherwise would not be used in patients with  HF.  Hence,  expeditious  and  accurate  diagnosis  of  such  conditions  is  important.  Currently, important delays have been reported in diagnosing amyloid heart disease, 16  perhaps not unexpectedly  given  the  wide  spectrum  of  possible  clinical presentations. 15 Similarly,  HF  attributable  to  sarcoidosis, hemochromatosis, hypothyroidism, hyperthyroidism, acromegaly, connective tissue disease, tachycardia-induced cardiomyopathy, or highoutput  HF  from  an  arteriovenous  fistula,  among others,  requires  specific  therapeutic  approaches. Given that the differential diagnosis of HF is broad, the  history  and  physical  examination  can  provide clues to narrow the number of causes to consider and guide the diagnostic approach to identify such conditions (Table 5).
5. The  history  and  physical  examination  help  to identify the cause of a clinical deterioration. To determine  the  cause  of  a  clinical  deterioration, the clinician assesses for concurrent illness (eg, ongoing myocardial ischemia, pulmonary emboli, or systemic infection), initiation of a medication potentially detrimental in the setting of HF (eg, nonsteroidal anti-inflammatory drugs [NSAIDs]), or  the  possibility  of  chronic  RV  pacing  (eg,  a newly implanted pacemaker or medications such as  amiodarone  that  leads  to  bradycardia  and resultant  chronic  RV  pacing),  nonadherence  to a  medication  or  dietary  regimen,  and  ongoing substance abuse. In addition, an assessment of social determinants of health (eg, housing stability, food security, available transportation) should be made.

## 4.1.1. Initial Laboratory and Electrocardiographic Testing

| Recommendations for Initial Laboratory and Electrocardiographic Test- ing Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Initial Laboratory and Electrocardiographic Test- ing Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Initial Laboratory and Electrocardiographic Test- ing Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                       |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                              | LOE                                                                                                                                                                              | Recommendations                                                                                                                                                                                                                                                                                      |
| 1                                                                                                                                                                                | B-NR                                                                                                                                                                             | 1. For patients presenting with HF, the specific cause of HF should be explored using addi- tional laboratory testing for appropriate man- agement. 1-8                                                                                                                                              |
| 1                                                                                                                                                                                | C-EO                                                                                                                                                                             | 2. For patients who are diagnosed with HF, laboratory evaluation should include com- plete blood count, urinalysis, serum electro- lytes, blood urea nitrogen, serum creatinine, glucose, lipid profile, liver function tests, iron studies, and thyroid-stimulating hormone to optimize management. |
| 1                                                                                                                                                                                | C-EO                                                                                                                                                                             | 3. For all patients presenting with HF, a 12-lead ECG should be performed at the initial encoun- ter to optimize management.                                                                                                                                                                         |

## Synopsis

Laboratory evaluation with complete blood count, urinalysis, serum electrolytes (including sodium, potassium, calcium, and magnesium), blood urea nitrogen, serum creatinine, glucose, fasting lipid profile, liver function tests, iron  studies  (serum  iron,  ferritin,  transferrin  saturation), and  thyroid-stimulating  hormone  level  and  electrocardiography is part of the standard diagnostic evaluation of a patient with HF. In addition to routine assessment, specific diagnostic testing and evaluation is often necessary to identify specific cause and other comorbidities in patients with HF.

## Recommendation-Specific Supportive Text

1. Identifying  the  specific  cause  of  HF  is  important,  because  conditions  that  cause  HF  may require  disease-specific  therapies.  Depending on  the  clinical  suspicion,  additional  diagnostic studies are usually required to diagnose specific causes  (Table  6)  such  as  ischemic  cardiomyopathy,  cardiac  amyloidosis,  sarcoidosis,  hemochromatosis,  infectious  mechanisms  (eg,  HIV, COVID-19,  Chagas),  hypothyroidism,  hyperthyroidism, acromegaly, connective tissue disorders, tachycardia-induced cardiomyopathy, Takotsubo, peripartum  cardiomyopathy,  cardiotoxicity  with cancer  therapies,  or  substance  abuse  would require  specific  management  in  addition  to  or beyond GDMT. 1,2,9-15

Table 6. Selected Potential Causes of Elevated Natriuretic Peptide Levels 50-53

| Cardiac                                                           |
|-------------------------------------------------------------------|
| HF, including RV HF syndromes                                     |
| ACS                                                               |
| Heart muscle disease, including LVH                               |
| VHD                                                               |
| Pericardial disease                                               |
| AF                                                                |
| Myocarditis                                                       |
| Cardiac surgery                                                   |
| Cardioversion                                                     |
| Toxic-metabolic myocardial insults, including cancer chemotherapy |
| Noncardiac                                                        |
| Advancing age                                                     |
| Anemia                                                            |
| Renal failure                                                     |
| Pulmonary: Obstructive sleep apnea, severe pneumonia              |
| Pulmonary embolism, pulmonary arterial hypertension               |
| Critical illness                                                  |
| Bacterial sepsis                                                  |
| Severe burns                                                      |

ACS indicates acute coronary syndromes; AF, atrial fibrillation; HF, heart failure; LVH, left ventricular hypertrophy; RV, right ventricular; and VHD, valvular heart disease.

2.  Laboratory evaluation with complete blood count, urinalysis,  serum  electrolytes,  blood  urea  nitrogen, serum creatinine, glucose, fasting lipid profile,  liver  function  tests,  iron  studies  (serum iron, ferritin, transferrin saturation), and thyroid-stimulating hormone levels provides important information  regarding  patients'  comorbidities,  suitability for  and  adverse  effects  of  treatments,  potential causes or confounders of HF, severity and prognosis  of  HF,  and  is  usually  performed  on  initial evaluation. Pertinent laboratory tests are repeated with  changes  in  clinical  condition  or  treatments (eg, to monitor renal function or electrolytes with diuretics).
3. Electrocardiography is part of the routine evaluation of a patient with HF and provides important information on rhythm, heart rate, QRS morphology  and  duration,  cause,  and  prognosis  of  HF. It is repeated when there is a clinical indication, such as a suspicion for arrhythmia, ischemia or myocardial  injury,  conduction,  or  other  cardiac abnormalities.

## 4.2. Use of Biomarkers for Prevention, Initial Diagnosis, and Risk Stratification

| Recommendations for Use of Biomarkers for Prevention, Initial Diagno- sis, and Risk Stratification Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Use of Biomarkers for Prevention, Initial Diagno- sis, and Risk Stratification Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Use of Biomarkers for Prevention, Initial Diagno- sis, and Risk Stratification Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                           |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                                       | LOE                                                                                                                                                                                                       | Recommendations                                                                                                                                                                                                                   |
| 1                                                                                                                                                                                                         | A                                                                                                                                                                                                         | 1. In patients presenting with dyspnea, measure- ment of B-type natriuretic peptide (BNP) or N-terminal prohormone of B-type natriuretic peptide (NT-proBNP) is useful to support a diagnosis or exclusion of HF. 1-12            |
| 1                                                                                                                                                                                                         | A                                                                                                                                                                                                         | 2. In patients with chronic HF, measurements of BNP or NT-proBNP levels are recommended for risk stratification. 11,13-29                                                                                                         |
| 1                                                                                                                                                                                                         | A                                                                                                                                                                                                         | 3. In patients hospitalized for HF, measurement of BNP or NT-proBNP levels at admission is recommended to establish prognosis. 11,13-19                                                                                           |
| 2a                                                                                                                                                                                                        | B-R                                                                                                                                                                                                       | 4. In patients at risk of developing HF, BNP or NT-proBNP-based screening followed by team-based care, including a cardiovascular specialist, can be useful to prevent the devel- opment of LV dysfunction or new-onset HF. 30,31 |
| 2a                                                                                                                                                                                                        | B-NR                                                                                                                                                                                                      | 5. In patients hospitalized for HF, a predischarge BNP or NT-proBNP level can be useful to inform the trajectory of the patient and estab- lish a postdischarge prognosis. 14,17,20-29                                            |

## Synopsis

Assays  for  BNP  and  NT-proBNP  are  frequently  used to establish the presence and severity of HF. In general, BNP and NT-proBNP levels are similar, and either can be used in patient care settings as long as their respective  absolute  values  and  cut-points  are  not  used  interchangeably. 32-34 Obesity is associated with lower levels of BNP and NT-proBNP thereby reducing their diagnostic sensitivity. 35,36  A substantial evidence base supports the use of natriuretic peptide biomarkers for excluding HF as a cause of symptoms in ambulatory and emergency department settings. Although a reduction in BNP and NT-proBNP has been associated with better outcomes, the  evidence for  treatment  guidance using serial BNP or  NT-proBNP measurements remains insufficient. 37-39 Lastly,  a  widening  array  of  biomarkers  including  markers  of  myocardial  injury,  inflammation,  oxidative  stress, vascular dysfunction, and matrix remodeling have been shown  to  provide  incremental  prognostic  information over natriuretic peptides but remain without evidence of an incremental management benefit. 13,40-49

## Recommendation-Specific Supportive Text

1.  Measurement of BNP and NT-proBNP levels in the ambulatory setting for a suspected cardiac cause of dyspnea provides incremental diagnostic value to clinical judgment when the cause of dyspnea is unclear and the physical examination equivocal. 1-9 In  the  emergency  setting,  BNP  and  NT-proBNP

levels  have  higher  sensitivity  than  specificity  and may be more useful for ruling out HF than ruling in HF. Although lower levels of BNP and NT-proBNP may help exclude the presence of HF, and higher levels have high positive predictive value to diagnose HF, increases in both BNP and NT-proBNP levels have been reported in patients with various cardiac and noncardiac causes (Table 6). 50-53

2.  and 3. Higher levels of BNP and NT-proBNP are associated  with  a  greater  risk  for  adverse  shortand long-term outcomes in patients with HF, including all-cause and cardiovascular death and major cardiovascular  events. 11,13-19 Studies  have  shown incremental  prognostic  value  of  these  biomarkers  to  standard  approaches  of  CVD  risk  assessment. 11,16 Not  all  patients  may  need  biomarker measurement for prognostication, especially if they already have advanced HF with established poor prognosis  or  persistently  elevated  levels  of  biomarkers in former settings.
4.  The STOP-HF (St Vincent's Screening to Prevent Heart  Failure)  study  is  a  large  single-center  trial of patients at risk of HF, defined by the presence of  hypertension, diabetes, or known vascular disease  but  without  established  L V  systolic  dysfunction  or  symptomatic  HF,  who  were  randomly assigned to screening with BNP testing or usual care. 31 Participants in the intervention group with BNP levels ≥ 50 pg/mL underwent echocardiography  and  referral  to  a  cardiovascular  specialist. 31 All patients received coaching by a specialist nurse who provided education on the importance of  adherence  to  medication  and  healthy  lifestyle behaviors. 31   BNP-based  screening  reduced  the composite  endpoint  of  incident  asymptomatic  L V dysfunction  with  or  without  newly  diagnosed  HF. Similarly, accelerated uptitration of renin-angiotensin-aldosterone  system  (RAAS)  antagonists  and beta blockers reduced cardiac events in patients with diabetes and elevated NT-proBNP levels but without cardiac disease at baseline. 30  Standardized screening for HF remains challenging as a result of the heterogeneity of risk factors across different patient populations. Studies are needed to assess the cost-effectiveness and risks of such screening, as well as its impact on QOL and mortality.
5.  Predischarge  BNP  and  NT-proBNP  levels  are strong predictors of the risk  of  death  or  hospital readmission  for  HF. 14,17,20-29 Although  patients  in whom levels of BNP or NT-proBNP decreased with treatment had better outcomes than those without any changes or with a biomarker rise, 14,23,28,29 targeting a certain threshold, value, or relative change in  these  biomarker  levels  during  hospitalization has not been shown to be consistently effective in improving outcomes. 37-39  Patients in which GDMT

Table 7. Examples of Factors Implicating Possible Genetic Cardiomyopathy

| Phenotypic Category     | Patient or Family Member Phenotypic Finding*                                                        | Ask Specifically About Family Members* With                                                                                                                                                                                                        |
|-------------------------|-----------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Cardiac morphology      | Marked LV hypertrophy                                                                               | Any mention of cardiomyopathy, enlarged or weak heart, HF. Document even if attributed to other causes, such as alcohol or peri- partum cardiomyopathy                                                                                             |
| Cardiac morphology      | LV noncompaction                                                                                    | Any mention of cardiomyopathy, enlarged or weak heart, HF. Document even if attributed to other causes, such as alcohol or peri- partum cardiomyopathy                                                                                             |
| Cardiac morphology      | Right ventricular thinning or fatty replacement on imaging or biopsy                                | Any mention of cardiomyopathy, enlarged or weak heart, HF. Document even if attributed to other causes, such as alcohol or peri- partum cardiomyopathy                                                                                             |
| Findings on 12-lead ECG | Abnormal high or low voltage or conduction, and repolar- ization, altered RV forces                 | Long QT or Brugada syndrome                                                                                                                                                                                                                        |
| Dysrhythmias            | Frequent NSVT or very frequent PVCs Sustained ventricular tachycardia or fibrillation               | ICD Recurrent syncope Sudden death attributed to 'massive heart attack' without known CAD Unexplained fatal event such as drowning or single-vehicle crash                                                                                         |
| Dysrhythmias            | Early onset AF                                                                                      | 'Lone' AF before age 65 y                                                                                                                                                                                                                          |
| Dysrhythmias            | Early onset conduction disease                                                                      | Pacemaker before age 65 y                                                                                                                                                                                                                          |
| Extracardiac features   | Skeletal myopathy Neuropathy Cutaneous stigmata Other possible manifestations of systemic syndromes | Any known skeletal muscle disease, including mention of Duchenne and Becker's, Emory-Dreifuss limb-girdle dystrophy Systemic syndromes: Dysmorphic features Mental retardation Congenital deafness Neurofibromatosis Renal failure with neuropathy |

AF indicates atrial fibrillation; CAD, coronary artery disease; LV, left ventricular; NSVT, nonsustained ventricular tachycardia; PVC, premature ventricular contraction; and RV, right ventricular.

*Note that genetic cause is more likely when the person is younger at the onset of events. However, the cardiac morphology and peripheral manifestations of hereditary amyloidosis may present in later life, unlike most other inherited cardiomyopathies.

leads to a reduction in BNP and NT-proBNP levels represent a population with improved long-term outcomes  compared  with  those  with  persistently elevated levels despite appropriate treatment. 37-39 BNP  and  NT-proBNP  levels  and  their  change could help guide discussions on prognosis as well as adherence to, and optimization of, GDMT.

## 4.3. Genetic Evaluation and Testing

| Recommendations for Genetic Evaluation and Testing Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Genetic Evaluation and Testing Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Genetic Evaluation and Testing Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                            |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                       | LOE                                                                                                                                                       | Recommendations                                                                                                                                                                                                                                                    |
| 1                                                                                                                                                         | B-NR                                                                                                                                                      | 1. In first-degree relatives of selected patients with genetic or inherited cardiomyopathies, genetic screening and counseling are recom- mended to detect cardiac disease and prompt consideration of treatments to decrease HF progression and sudden death. 1,2 |
| 2a                                                                                                                                                        | B-NR                                                                                                                                                      | 2. In select patients with nonischemic cardio- myopathy, referral for genetic counseling and testing is reasonable to identify conditions that could guide treatment for patients and family members. 3,4                                                          |

## Synopsis

In patients in whom a genetic or inherited cardiomyopathy is suspected, a family history should be performed,  including  at  least  3  generations  and  ideally diagrammed as a family  tree  pedigree  (see  Section 4.1,  'Clinical  Assessment:  History  and  Physical  Examination'). Genetic variants have been implicated in 25% to 40% of patients with DCM with a positive family history but also in 10% to 30% of patients without a  recognized  family  history. 3,4   Phenotype  and  family history are important for identifying patients in whom genetic testing is most likely to yield clinically actionable information (Table 7). Presentation of DCM with conduction disease or ventricular arrhythmias raises concern  of  sarcoidosis  and  arrhythmogenic  cardiomyopathy, which is of particular concern because of the risk of sudden death in patients and families. 5  No controlled studies have shown clinical benefits of genetic testing for cardiomyopathy, but genetic testing contributes to risk stratification and has implications for  treatment,  currently  most  often  for  decisions  regarding defibrillators for primary prevention of sudden death 5  and regarding exercise limitation for hypertrophic  cardiomyopathy  and  the  desmosomal  variants. Consultation with a trained counselor before and after genetic testing helps patients to understand and weigh  the  implications  of  possible  results  for  their own lives and those of family members, including possible discrimination on the basis of genetic information. Unless shown to be free of the genetic variant(s) implicated in the proband, first-degree relatives of affected  probands  should  undergo  periodic  screening with echocardiography and electrocardiography.

## Recommendation-Specific Supportive Text

1. and 2. Inherited dilated, restrictive, and hypertrophic cardiomyopathies  have  been  identified,  although  1 gene variant may cause different phenotypes in the same family. The most common pathogenic variants identified are truncations in the large structural protein titin, which have been implicated in DCM 3-5 and also in peripartum or alcoholic cardiomyopathies; however, variants that do not cause disease are also common. Pathogenic variants in lamin A/C can be associated with conduction block and atrial arrhythmias as well as ventricular arrhythmias, which may progress more rapidly  than  symptoms  of  HF.  Although  previously linked with the phenotype of arrhythmogenic RV cardiomyopathy,  desmosomal  protein  variants  are  now recognized to affect the left ventricle also with or without the right ventricle, and the term arrhythmogenic cardiomyopathy is now preferred for the phenotype of arrhythmias combined with DCM. Filamin-C mutations have been associated with skeletal myopathies and  with  isolated  cardiomyopathy  with  ventricular arrhythmias. The identification of pathogenic variants associated with increased risk of sudden death may trigger  consideration  of  primary  prevention  implantable cardioverter-defibrillators (ICDs) even in patients who have LVEF &gt;0.35 or &lt;3 months of guidelinerecommended therapies. 6   Evidence  of  desmosomal cardiac disease carries the additional implication of advice to avoid strenuous exercise, which may accelerate ventricular remodeling. 7 Genetic confirmation of symptomatic Fabry's cardiomyopathy is an indication for replacement therapy with the enzyme agalsidase beta, and migalastat was recently approved for this uncommon cardiomyopathy.

## 4.4. Evaluation With Cardiac Imaging

| Recommendations for Evaluation With Cardiac Imaging Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Evaluation With Cardiac Imaging Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Evaluation With Cardiac Imaging Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                                                       |
|------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                        | LOE                                                                                                                                                        | Recommendations                                                                                                                                                                                                                                                                                                |
| 1                                                                                                                                                          | C-LD                                                                                                                                                       | 1. In patients with suspected or new-onset HF, or those presenting with acute decompensated HF, a chest x-ray should be performed to assess heart size and pulmonary congestion and to detect alternative cardiac, pulmonary, and other diseases that may cause or contrib- ute to the patient's symptoms. 1,2 |
| 1                                                                                                                                                          | C-LD                                                                                                                                                       | 2. In patients with suspected or newly diag- nosed HF, transthoracic echocardiography (TTE) should be performed during initial evaluation to assess cardiac structure and function. 3                                                                                                                          |

| Recommendations for Evaluation With Cardiac Imaging (Continued)   | Recommendations for Evaluation With Cardiac Imaging (Continued)   | Recommendations for Evaluation With Cardiac Imaging (Continued)                                                                                                                                                                                                                                                                                            |
|-------------------------------------------------------------------|-------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                               | LOE                                                               | Recommendations                                                                                                                                                                                                                                                                                                                                            |
| 1                                                                 | C-LD                                                              | 3. In patients with HF who have had a significant clinical change, or who have received GDMTand are being considered for invasive procedures or device therapy, repeat measurement of EF, degree of structural remodeling, and valvular function are useful to inform therapeutic interven- tions. 4-7                                                     |
| 1                                                                 | C-LD                                                              | 4. In patients for whom echocardiography is inadequate, alternative imaging (eg, cardiac magnetic resonance [CMR], cardiac computed tomography [CT], radionuclide imaging) is rec- ommended for assessment of LVEF. 8-15                                                                                                                                   |
| 2a                                                                | B-NR                                                              | 5. In patients with HF or cardiomyopathy, CMR can be useful for diagnosis or manage- ment. 16-23                                                                                                                                                                                                                                                           |
| 2a                                                                | B-NR                                                              | 6. In patients with HF, an evaluation for possible ischemic heart disease can be useful to identify the cause and guide management. 24-27                                                                                                                                                                                                                  |
| 2b                                                                | B-NR                                                              | 7. In patients with HF and coronary artery disease (CAD) who are candidates for coronary revas- cularization, noninvasive stress imaging (stress echocardiography, single-photon emission CT [SPECT], CMR, or positron emission tomog- raphy [PET]) may be considered for detection of myocardial ischemia to help guide coronary revascularization. 28-32 |
| 3: No Benefit                                                     | C-EO                                                              | 8. In patients with HF in the absence of: 1) clinical status change, 2) treatment interventions that might have had a significant effect on cardiac function, or 3) candidacy for invasive proce- dures or device therapy, routine repeat assess- ment of LV function is not indicated.                                                                    |

## Synopsis

Cardiac imaging has a key role in the initial evaluation of individuals with suspected HF and, when indicated, in the serial assessment of patients with HF. After a complete  history  and  physical  examination,  a  comprehensive  TTE  is  the  most  useful  initial  diagnostic test given the vast amount of diagnostic and prognostic  information  provided.  The  determination  of  LVEF is  a  fundamental  step  to  classify  HF  and  to  guide evidence-based  pharmacological  and  device-based therapy.  In  certain  situations,  the  echocardiogram  is unable to accurately assess cardiac structure and/or function or more information is needed to determine the cause of the cardiac dysfunction. Other imaging modalities, such as CMR, SPECT or radionuclide ventriculography, PET, or cardiac CT or invasive coronary angiography, can provide additional and complementary  information  to  cardiac  ultrasound. 11 In  general, cardiac imaging tests, including repeat tests, are performed only when the results have a meaningful impact on clinical care.

## Recommendation-Specific Supportive Text

1. The chest x-ray is a useful initial diagnostic test for the evaluation of patients presenting with signs and symptoms of HF because it assesses cardiomegaly, pulmonary venous congestion, and interstitial or alveolar edema and may reveal alternative causes, cardiopulmonary or otherwise, of the patient's symptoms. 1,2 Apart from congestion, other findings on chest x-ray are associated with HF only in the context of clinical presentation. Importantly, cardiomegaly may be absent in acute HF and, although cephalization, interstitial edema, and alveolar edema are modestly specific for HF, these findings are relatively insensitive. 2,33 Considering the limited sensitivity and specificity, the chest x-ray should not be used as the only determinant of the specific cause or presence of HF.
2. TTE provides information regarding cardiac structure and  function and  identifies abnormalities of myocardium,  heart  valves, and  pericardium. Echocardiography reveals structural and functional information that predicts subsequent risk. 34-40 Guidelines  provide  recommendations  for  quantification  of  cardiac  structure  and  function,  including  L VEF  measurements,  ventricular  dimensions and volumes, evaluation of chamber geometry, and regional wall motion. 41 RV size and function, atrial size, and all valves are evaluated for anatomic and flow abnormalities. Guidelines also provide recommendations  for  diastolic  function  and  estimates of  L V  filling  and  left  atrial  pressure. 42 The  tricuspid valve regurgitant gradient, coupled with inferior vena cava diameter and its response during respiration, provides estimates of systolic PA pressure and central venous pressure. Indices of myocardial deformation, such as global longitudinal strain, may identify  subclinical  L V  systolic  dysfunction,  which has been associated with greater risk of developing HF  or  recurrent  HF  hospitalizations. 38,43-46 Given the  widespread  availability,  lack  of  ionizing  radiation, and wealth of provided information, echocardiography is the preferred initial imaging modality for evaluation of patients with suspected HF. Pointof-care  cardiac  ultrasound  is  an  evolving  tool  for assessment of cardiac function and assessment of volume status and pulmonary congestion. 47-52
3.  Serial  echocardiograms  to  assess  changes  in EF,  structural  remodeling,  and  valvular  function, although  not  recommended  routinely  in  stable patients, are useful in various situations. In patients who  have an unexplained, significant change in  clinical  status,  echocardiography  can  provide important  information,  such  as  worsening  ventricular  or  valvular  function.  A  subset  of  patients may  also  have  reverse  remodeling,  improvement

in  LVEF,  and  valvular  function  in  response  to evidence-based medical, revascularization, and device therapies, and repeat assessment of L VEF and remodeling is appropriate in those who have received treatments that might have had a significant effect on cardiac structure and function. 4-7,53-59 Recovery  of  function  appears  more  common  in those with L V systolic dysfunction occurring in the setting  of  adverse  energetic  circumstances  (eg, chronic tachycardia or thyroid disease), dilated cardiomyopathies associated with immune responses (eg,  peripartum  cardiomyopathy,  acute  myocarditis,  systemic inflammatory responses), or in those who have undergone revascularization or devicebased therapies. 60   Reevaluation of EF (&gt;40 days after  MI,  &gt;90  days  after  revascularization,  &gt;90 days after GDMT) is useful to determine candidacy for  implantable  cardioverter-defibrillator  (ICD)  or cardiac  resynchronization  therapy  (CRT).  Finally, repeat  surveillance  of  L V  function  is  appropriate in patients exposed to treatments that potentially damage the myocardium, such as chemotherapy.

4. If  TTE  is  unable  to  accurately  evaluate  cardiac structure and function, additional noninvasive imaging modalities are available to clarify the initial  diagnosis  and  to  provide  information  on  cardiac  structure  and  function.  The  choice  between these modalities depends  on  availability, local expertise,  patient  characteristics,  indication,  and goal of limiting radiation exposure. CMR provides an  accurate  and  highly  reproducible  assessment of cardiac volumes, mass, and EF of the left and right  ventricles. 8-10   CMR  provides  high  anatomic resolution of all aspects of the heart and surrounding  structures  and  is  not  associated  with  ionizing  radiation,  leading  to  its  recommended  use  in known or suspected congenital heart diseases. 11,61 Electrocardiographic-gated  cardiac  CT  can  also accurately  assess  ventricular  size,  EF,  and  wall motion  abnormalities,  but  it  is  accompanied  with ionizing radiation. 13-15 Radionuclide  ventriculography  is  highly  reproducible  for  measurement  of LVEF, although it also exposes the patient to ionizing radiation. 12
5.  CMR provides noninvasive characterization of the myocardium  that  may  provide  insights  into  HF cause. 62   Late-gadolinium  enhancement,  reflecting  fibrosis  and  damaged  myocardium, can identify  acute  and  chronic  MI. 63,64 and  identify  HF caused  by  CAD 65,66 Patterns  of  late-gadolinium enhancement or specific T-1 and T-2 techniques can suggest specific infiltrative  and  inflammatory cardiomyopathies,  such  as  myocarditis,  sarcoidosis,  Fabry  disease,  Chagas  disease,  noncompaction, iron overload, and amyloidosis. 16,20,22,67 T-1  mapping  techniques  allow  for  measurement

of  interstitial  space  characteristics  and  extracellular volume fraction and provides diagnostic and prognostic  information. 19,21-23,68-71   The  presence of  delayed  hyperenhancement  has  been  associated  with  worse  outcomes  and  can  provide  risk stratification. 72-77 Although registry data show that CMR findings commonly impact patient care management  and  provide  diagnostic  information in  patients  with  suspected  myocarditis  or  cardiomyopathy, 17,18 a strategy of routine screening with CMR in patients with nonischemic cardiomyopathy was not shown to yield more specific HF causes than a strategy of selective CMR strategy based on  echocardiographic  and  clinical  findings  in  a recent trial. 78

6. HF is often caused by coronary atherosclerosis, 79 and evaluation for ischemic heart disease can help in determining the presence of significant coronary artery  disease  (CAD).  Noninvasive  stress  imaging with echocardiography or nuclear scintigraphy can be helpful in identifying patients likely to have obstructive CAD. 24,25  Invasive or computed tomography coronary angiography can detect and characterize extent of CAD. 26,27
7. CAD is a leading cause of HF 79  and myocardial ischemia may contribute to new or worsening HF symptoms. Noninvasive testing (ie, stress echocardiography, SPECT, CMR, or PET) may be considered for detection of myocardial ischemia to help guide coronary revascularization decisions. Multiple  nonrandomized,  observational  studies have reported improved survival with revascularization  in  patients  with  viable  but  dysfunctional myocardium. 28,30-32 Despite  these  observational data,  RCTs  have  not  shown  that  viability  imaging improves guidance of revascularization to  a  reduction  of  adverse  cardiovascular  outcomes. 80-82 A prespecified viability substudy of  the  STICH  (Surgical  Treatment  for  Ischemic Heart Failure) trial showed that the presence of myocardial viability did not determine the longterm  benefit  from  surgical  revascularization  in patients  with  ischemic  cardiomyopathy. 81,82 Of note,  a  relatively  small  number  of  individuals enrolled  in  the  STICH  substudy  did  not  have viability, which may limit the power of the study. Although these data do not support the concept of  routine  viability  assessment  before  revascularization,  myocardial viability  is  used  as  one  of the  tools  to  inform  decisions  regarding  revascularization in patients with high surgical risk or with complex medical problems.
8.  Repeat  noninvasive imaging of cardiac structure and function for routine surveillance is rarely appropriate in the absence of a change in clinical status or treatment interventions. 11,83

## 4.5. Invasive Evaluation

| Recommendations for Invasive Evaluation Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Invasive Evaluation Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Invasive Evaluation Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                        |
|------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                            | LOE                                                                                                                                            | Recommendations                                                                                                                                                                                                     |
| 2a                                                                                                                                             | B-NR                                                                                                                                           | 1. In patients with HF, endomyocardial biopsy may be useful when a specific diagnosis is sus- pected that would influence therapy. 1,2                                                                              |
| 2a                                                                                                                                             | C-EO                                                                                                                                           | 2. In selected patients with HF with persistent or worsening symptoms, signs, diagnostic param- eters, and in whom hemodynamics are uncer- tain, invasive hemodynamic monitoring can be useful to guide management. |
| 3: No Benefit                                                                                                                                  | B-R                                                                                                                                            | 3. In patients with HF, routine use of invasive hemodynamic monitoring is not recom- mended. 3,4                                                                                                                    |
| 3: Harm                                                                                                                                        | C-LD                                                                                                                                           | 4. For patients undergoing routine evaluation of HF, endomyocardial biopsy should not be per- formed because of the risk of complications. 5,6                                                                      |

## Synopsis

Invasive  evaluation  of  patients  with  HF  may  provide important clinical  information  to  determine  the  cause of HF and treatment options. Routine right heart catheterization  does  not  provide  sufficient  information  to guide  treatment  decisions. 3,4   However,  hemodynamic evaluation  with  right  heart  catheterization  and  monitoring in the setting of acute respiratory distress, systemic  hypoperfusion  including  cardiogenic  shock,  or when hemodynamics are uncertain,  may  guide  treatment decisions. Coronary angiography may be useful in patients who are candidates for revascularization 7-9 (see Section 4.4, 'Evaluation with Cardiac Imaging,' for recommendations). Endomyocardial biopsy may be advantageous in patients with HF in which a histological diagnosis, such as amyloidosis or myocarditis, may influence treatment decisions. 1,2

## Recommendation-Specific Supportive Text

1.  Endomyocardial biopsy may be useful when seeking a specific diagnosis that would influence treatment, and biopsy should thus be considered in patients with  rapidly  progressive  clinical  HF  or  worsening ventricular dysfunction that persists despite appropriate  medical  treatment.  Endomyocardial  biopsy should  also  be  considered  in  patients  suspected of having acute cardiac rejection status after heart transplantation or having  myocardial  infiltrative processes.  A  specific  example  is  to  determine treatment for light chain (AL) amyloidosis or transthyretin amyloidosis. 5 Additional indications for endomyocardial biopsy include patients with rapidly  progressive  and  unexplained  cardiomyopathy and those in  whom active  myocarditis,  especially giant cell myocarditis, is being considered. 1

2.  Right-heart catherization in patients in acute HF. The ESCAPE  (Evaluation Study of  Congestive  Heart  Failure  and  Pulmonary Artery Catheterization Effectiveness) trial found that  routine  use  of  PA  catheter  monitoring for  patients  with  HF  did  not  provide  benefit. 3 However,  invasive  hemodynamic  evaluation  or monitoring can be useful to guide management in  carefully  selected  patients  with  acute  HF who  have  persistent  symptoms  despite  treatment. This includes patients whose fluid status, perfusion,  or  systemic  or  pulmonary  vascular resistance  is  uncertain  whose  systolic  blood pressure  (SBP)  remains  low,  or  is  associated with symptoms, despite initial treatment; whose renal function is worsening with therapy; or who require parenteral vasoactive agents.
3.  There has been no established role for routine or  periodic  invasive  hemodynamic  measurements  in  the  management  of  HF.  Most  drugs used  to  treat  HF  are  prescribed  on  the  basis of their ability to improve symptoms or survival rather  than  their  effect  on  hemodynamic  variables. The initial and target doses of these drugs are generally selected on the basis of controlled trial  experience  rather  than  changes  produced in cardiac output or pulmonary capillary wedge pressure. 3,4
4. Patients with HF should not undergo routine endomyocardial biopsy because of the risk of complications that include perforation, cardiac tamponade, and  thrombus  formation,  as  well  as  limited  diagnostic yield. 5,6

## 4.6. Wearables and Remote Monitoring (Including Telemonitoring and Device Monitoring)

| Recommendation for Wearables and Remote Monitoring (Including Telemonitoring and Device Monitoring) Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Wearables and Remote Monitoring (Including Telemonitoring and Device Monitoring) Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Wearables and Remote Monitoring (Including Telemonitoring and Device Monitoring) Referenced studies that support the recommendation are summarized in the Online Data Supplements.                                                                                                                                                                                          |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                                     | LOE                                                                                                                                                                                                     | Recommendation                                                                                                                                                                                                                                                                                                                                                                                 |
| 2b                                                                                                                                                                                                      | B-R                                                                                                                                                                                                     | 1. In selected adult patients with NYHA class III HF and history of a HF hospitalization in the past year or elevated natriuretic peptide levels, on maximally tolerated stable doses of GDMT with optimal device therapy, the use- fulness of wireless monitoring of PA pressure by an implanted hemodynamic monitor to reduce the risk of subsequent HF hospitaliza- tions is uncertain. 1-4 |
| Value Statement: Uncertain Value (B-NR)                                                                                                                                                                 | Value Statement: Uncertain Value (B-NR)                                                                                                                                                                 | 2. In patients with NYHA class III HF with a HF hospitalization within the previous year, wireless monitoring of the PA pressure by an implanted hemodynamic monitor provides uncertain value. 4-7                                                                                                                                                                                             |

## Synopsis

HF is a chronic condition punctuated by periods of instability.  Despite  close  longitudinal  monitoring  via  in-person visits, event rates remain high, affording a potential role for remote monitoring strategies to improve clinical outcomes. Strategies tested in randomized trials include an implantable PA pressure sensor (CardioMEMS), noninvasive telemonitoring, or monitoring via existing implanted electronic devices (ICDs or CRT-Ds). Results from a single randomized trial, 1-3 and subsequent observational studies, 8-10 support consideration of an implantable PA sensor in selected patients with HF to reduce the risk of HF hospitalization. In contrast, a recent trial testing a PA pressure sensor did not meet its primary endpoint. 4 Results from previous clinical trials do not support the alternative remote monitoring strategies (eg, noninvasive telemonitoring or remote monitoring of physiological parameters such as patient activity, thoracic impedance, heart rate) for this purpose. 11-18

## Recommendation-Specific Supportive Text

1.  The CHAMPION  (CardioMEMS  Heart Sensor Allows Monitoring of Pressure to Improve Outcomes in  NYHA  Class  III  Heart  Failure  patients)  trial reported a significant 28% reduction of HF-related hospitalizations after 6 months in patients randomized to an implanted PA pressure monitor compared with  a  control  group. 1 Patients  had  to  have  a  HF hospitalization in the previous year and be on stable doses of a beta blocker and angiotensin-converting enzyme inhibitor (ACEi) (or angiotensin (II) receptor  blocker [ARB]) if tolerated. The clinical benefit persisted after longer term follow-up and was seen in both subjects with reduced 3 and preserved 2 L VEF. However, CHAMPION was a nonblinded trial, and there was differential contact of study personnel with patients in the treatment arm, raising methodological concerns about the opportunity for bias to have influenced its results. 19-21  In the recent GUIDE-HF (Haemodynamic-GUIDEed  management  of  Heart Failure)  study,  hemodynamic-guided  management of patients with NYHA class II to IV heart failure did not significantly reduce the composite endpoint rate of mortality and total HF events. 4 The usefulness of noninvasive telemonitoring 11,12,22,23   or remote monitoring  of  physiological  parameters 13-18 (eg,  patient activity, thoracic impedance, heart rate) via implanted electrical devices (ICDs or CRT-Ds) to improve clinical  outcomes  remains  uncertain.  Further  study  of these  approaches  is  needed  before  they  can  be recommended for routine clinical care.
2. Three  model-based  studies 5-7 have  evaluated  the cost-effectiveness of wireless PA pressure monitoring  using  data  from  the  CHAMPION-HF 1 study  of

the  CardioMEMS  device.  All  3  studies  estimated CardioMEMS implantation and monitoring increased survival  and  quality-adjusted  life  year  (QAL Y)  while increasing costs. Primarily  based  on  differences regarding the expected magnitude of clinical benefit, 2 analyses 5,7 estimated the device provided high value while the third 6 estimated intermediate value. These analyses had several important differences detailed in the evidence tables, including the model duration, QOL data, cost estimates, and assumptions regarding mortality. One analysis 6 found the economic value of CardioMEMS implantation was highly dependent on its effect on mortality and duration of treatment benefit, both of which remain unclear. Cost-effectiveness studies  incorporating  data  from  GUIDE-HF 4 have not been published. Additional data regarding clinical outcomes  following  CardioMEMS  implantation  will improve estimates of its economic value.

## 4.7. Exercise and Functional Capacity Testing

| Recommendations for Exercise and Functional Capacity Testing Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Exercise and Functional Capacity Testing Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Exercise and Functional Capacity Testing Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                        |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                 | LOE                                                                                                                                                                 | Recommendations                                                                                                                                                                          |
| 1                                                                                                                                                                   | C-LD                                                                                                                                                                | 1. In patients with HF, assessment and documen- tation of NYHA functional classification are recommended to determine eligibility for treat- ments. 1-3                                  |
| 1                                                                                                                                                                   | C-LD                                                                                                                                                                | 2. In selected ambulatory patients with HF, cardiopulmonary exercise testing (CPET) is recommended to determine appropriateness of advanced treatments (eg, LVAD, heart transplant). 4-8 |
| 2a                                                                                                                                                                  | C-LD                                                                                                                                                                | 3. In ambulatory patients with HF, performing a CPET or 6-minute walk test is reasonable to assess functional capacity. 4,5,9-16                                                         |
| 2a                                                                                                                                                                  | C-LD                                                                                                                                                                | 4. In ambulatory patients with unexplained dys- pnea, CPET is reasonable to evaluate the cause of dyspnea. 17,18                                                                         |

## Synopsis

Functional impairment and exercise intolerance are common in HF. CPET and the 6-minute walk test are standardized, reliable, and reproducible tests to quantify functional capacity. 19-22 The  NYHA functional classification can be used to grade the severity of functional limitation based on patient report of symptoms experienced with activity 1 and is used to define candidates for certain treatments.

## Recommendation-Specific Supportive Text

1. NYHA functional classification is an ordinal, categorical variable (I-IV) that is used to document functional limitation in patients with cardiac disease, including HF. 1 In HF, NYHA functional class I includes patients with no limitations in physical activity resulting from

their HF. NYHA class II includes patients who are comfortable at rest but have slight symptoms resulting from HF (dyspnea, fatigue, lightheadedness) with ordinary  activity.  NYHA  class  III  includes  patients who are comfortable at rest but have symptoms of HF with less than ordinary activity. NYHA class IV includes patients who are unable to carry out any physical activity without symptoms and have symptoms  at  rest.  NYHA  functional  classification  has been widely used in clinical practice, clinical trials, and clinical practice guidelines to determine candidacy for drug and device therapy. Limitations include its ability to be inconsistently assessed from 1 clinician to another, resulting in poor reproducibility. 23

2. Many  CPET  variables  have  been  associated  with prognosis in patients with HF. 4,5,12,14,16,24 Peak exercise  oxygen  consumption/oxygen  uptake  (VO 2 )  is often used to risk stratify patients and make decisions about timing of advanced HF therapies, including  heart  transplantation  and  L VAD.  In  a  landmark article, 7 investigators  divided  patients  referred  for heart transplantation into groups based on their peak VO 2 . 7  Patients with peak VO 2 &lt;14 mL/kg/min were listed for transplant, while those with higher peak VO 2 values were deferred for being too well. Patients with peak VO 2 &gt;14 mL/kg/min who were deferred had 1- and 2-year survival of 94% and 84%, respectively, which was similar to survival after heart transplant. As such, the authors proposed peak VO 2 ≤ 14 mL/ kg/min as a cutoff to distinguish patients who may derive survival benefit from heart transplant. 7 Patients tolerating beta blockers may have improved survival with an equivalent VO 2 compared with patients who do  not  tolerate  beta  blockers. 25,26 For  patients  on beta blockers, a peak VO 2 ≤ 12 mL/kg/min has been suggested as a more appropriate cutoff to consider cardiac transplant listing. 8
3. Objective  assessment  of  exercise  capacity  with CPET  can  be  useful  in  the  clinical  management of  patients  with  HF.  Although  CPET  remains  the gold standard measure of exercise capacity, limitations to more widespread use include need for special  equipment and trained personnel, which leads to lack of availability at many hospitals and clinics. Furthermore, it is not well tolerated by some patients. The 6-minute walk test is an alternative way to measure exercise capacity that is widely available and well  tolerated  by  patients.  It  entails  walking  for  6 minutes on a measured flat course, and patients are allowed to slow down or stop if needed. A systematic  review of 14 studies found that the 6-minute walk  test  results  correlated  moderately  with  peak VO 2 levels  and  were  a  reliable  and  valid  indicator of functional capacity in patients with HF who did not walk &gt;490 m. 8  Distance walked in the 6-minute walk test has been associated with prognosis in HF

across multiple studies. 9-13,15,16,27   A cutoff of &lt;300 m roughly correlates to patients with NYHA class III to IV symptoms and is associated with worse 3-year survival free of heart transplant (62% versus 82% for those walking ≥ 300 m). 27

4. Dyspnea  is  a  complex  symptom  that  can  reflect abnormalities  in  a  number  of  different  systems and can be influenced by psychological and environmental factors. CPET involves having patients perform  a  treadmill  (or  stationary  bicycle)  exercise  test,  while  also  performing  ventilatory  gas exchange  measurements. 28   CPET  enables  the comprehensive assessment of multiple physiological measures that can impact exercise capacity and contribute to dyspnea. It provides analysis of gas exchange and yields measures of oxygen uptake (VO 2 ), carbon dioxide output, and ventilation. These measures can be integrated with standard exercise testing  variables,  such  as  heart  rate,  blood  pressure, electrocardiographic findings, and symptoms to provide insights into the physiologic mechanisms underlying a patient's dyspnea. In particular, CPET can help to distinguish respiratory versus cardiac etiologies of dyspnea. If exercise capacity is diminished but cardiopulmonary responses are normal, other causes of dyspnea, such as metabolic abnormalities and deconditioning, should be considered.

## 4.8. Initial and Serial Evaluation: Clinical Assessment: HF Risk Scoring

| Recommendation for Initial and Serial Evaluation: Clinical Assessment: HF Risk Scoring Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Initial and Serial Evaluation: Clinical Assessment: HF Risk Scoring Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Initial and Serial Evaluation: Clinical Assessment: HF Risk Scoring Referenced studies that support the recommendation are summarized in the Online Data Supplements.   |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                        | LOE                                                                                                                                                                                        | Recommendation                                                                                                                                                                             |
| 2a                                                                                                                                                                                         | B-NR                                                                                                                                                                                       | 1. In ambulatory or hospitalized patients with HF, validated multivariable risk scores can be useful to estimate subsequent risk of mortality. 1-14                                        |

## Synopsis

Clinicians should routinely assess a patient's risk for an adverse  outcome  to  guide  discussions  on  prognosis, goals of care, and treatment decisions. Several predictive models of outcomes of patients with HF have been developed and validated using data from clinical trials, registries, and population-based cohorts. The best performing models have focused on predicting short- and long-term mortality, whereas predictive models for hospitalization or readmission for HF have generally had poor or modest discrimination. Predictive models may also assess the risk of incident HF among the general population and should be considered in the prevention of HF. In the course of standard evaluation, clinicians should routinely assess the patient's potential for adverse outcome, because accurate

Table 8. Selected Multivariable Risk Scores to Predict Outcome in HF

| Risk Score                                               | Reference/Link                                                   | Year Published   |
|----------------------------------------------------------|------------------------------------------------------------------|------------------|
| Chronic HF                                               |                                                                  |                  |
| All Patients With Chronic HF                             |                                                                  |                  |
| Seattle Heart Failure Model                              | 2 https://depts.washing- ton.edu/shfm/?width =1440&height=900 15 | 2006             |
| Heart Failure Survival Score                             | 1                                                                | 1997             |
| MAGGIC                                                   | 3 http://www.heartfailure- risk.org/ 16                          | 2013             |
| CHARM Risk Score                                         | 4                                                                | 2006             |
| CORONA Risk Score                                        | 5                                                                | 2009             |
| Specific to Chronic HFrEF                                |                                                                  |                  |
| PARADIGM-HF                                              | 6                                                                | 2020             |
| HF-ACTION                                                | 7                                                                | 2012             |
| GUIDE-IT                                                 | 8                                                                | 2019             |
| Specific to Chronic HFpEF                                |                                                                  |                  |
| I-PRESERVE Score                                         | 9                                                                | 2011             |
| TOPCAT                                                   | 10                                                               | 2020             |
| Acutely Decompensated HF                                 |                                                                  |                  |
| ADHERE Classification and Re- gression Tree (CART) Model | 11                                                               | 2005             |
| AHA Get With The Guidelines Score                        | 12 https://www.mdcalc. com/gwtg-heart-failure- risk-score 17     | 2010, 2021       |
| EFFECT Risk Score                                        | 13 http://www.ccort.ca/ Research/CHFRisk- Model.aspx 18          | 2003, 2016       |
| ESCAPE Risk Model and Discharge Score                    | 14                                                               | 2010             |

ADHERE indicates Acute Decompensated Heart Failure National Registry; AHA, American  Heart  Association;  ARIC,  Atherosclerosis  Risk  in  Communities; CHARM, Candesartan in Heart failure-Assessment of Reduction in Mortality  and  morbidity;  CORONA,  Controlled  Rosuvastatin  Multinational  Trial  in Heart Failure; EFFECT, Enhanced Feedback for Effective Cardiac Treatment; ESCAPE, Evaluation Study of Congestive Heart Failure and Pulmonary Artery Catheterization  Effectiveness;  GUIDE-ID,  Guiding  Evidence-Based  Therapy Using Biomarker Intensified Treatment; HF, heart failure; HFpEF, heart failure with preserved ejection fraction; HF-ACTION, Heart Failure: A Controlled Trial Investigating  Outcomes  of  Exercise  Training  MAGGIC  Meta-analysis  Global Group in Chronic Heart Failure; I-PRESERVE, Irbesartan in Heart Failure with Preserved Ejection Fraction Study; PCP-HF, Pooled Cohort Equations to Prevent HF; and TOPCAT, Treatment of Preserved Cardiac Function Heart Failure with an Aldosterone Antagonist trial.

risk  stratification  may  help  guide  therapeutic  decisionmaking,  including  a  more  rapid  transition  to  advanced HF  therapies.  Several  methods  objectively  assess  risk (Table 8), including biomarker testing, as well as various multivariable  clinical  risk  scores,  and  some  that  include

machine learning. 1-14 These risk scores are for use in ambulatory, hospitalized patients, and the general population.

## Recommendation-Specific Supportive Text

1.  For HF, there are several clinical models to consider that include the spectrum of HF based on EF and clinical setting. For chronic HF, the Seattle Heart Failure Model, 2 the  Heart  Failure  Survival  score, 1 and  the MAGGIC score 3  have commonly been used to provide estimates of survival. The MAGGIC predictive model may be quite  useful  given  its  derivation  and  validation across multiple clinical trials and cohorts, including more recent studies. For chronic HFrEF, there are additional models that include other clinical variables, including  exercise  capacity 7 and  natriuretic  peptide levels. 8   Likewise, for chronic HFpEF there are more specific predictive models for that population derived from clinical trial data. 9,10 In acute HF, several clinical models may be used to predict short-term survival. 11-13

## 5. STAGE A (PATIENTS AT RISK FOR HF) 5.1. Patients at Risk for HF (Stage A: Primary Prevention)

| Recommendations for Patients at Risk for HF (Stage A: Primary Prevention) Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Patients at Risk for HF (Stage A: Primary Prevention) Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Patients at Risk for HF (Stage A: Primary Prevention) Referenced studies that support the recommendations are summarized in the Online Data Supplements.                                                                                                          |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                            | LOE                                                                                                                                                                            | Recommendations                                                                                                                                                                                                                                                                       |
| 1                                                                                                                                                                              | A                                                                                                                                                                              | 1. In patients with hypertension, blood pressure should be controlled in accordance with GDMT for hypertension to prevent symptomatic HF. 1-9                                                                                                                                         |
| 1                                                                                                                                                                              | A                                                                                                                                                                              | 2. In patients with type 2 diabetes and either established CVD or at high cardiovascular risk, SGLT2i should be used to prevent hospitaliza- tions for HF. 10-12                                                                                                                      |
| 1                                                                                                                                                                              | B-NR                                                                                                                                                                           | 3. In the general population, healthy lifestyle hab- its such as regular physical activity, maintaining normal weight, healthy dietary patterns, and avoiding smoking are helpful to reduce future risk of HF. 13-21                                                                  |
| 2a                                                                                                                                                                             | B-R                                                                                                                                                                            | 4. For patients at risk of developing HF, natriuretic peptide biomarker-based screening followed by team-based care, including a cardiovascular specialist optimizing GDMT, can be useful to prevent the development of LV dysfunction (systolic or diastolic) or new-onset HF. 22,23 |
| 2a                                                                                                                                                                             | B-NR                                                                                                                                                                           | 5. In the general population, validated multivari- able risk scores can be useful to estimate sub- sequent risk of incident HF. 24-26                                                                                                                                                 |

## Synopsis

Healthy lifestyle habits such as maintaining regular physical  activity;  normal  weight,  blood  pressure,  and  blood glucose levels; healthy dietary patterns, and not smoking reduce primordial risk and have been associated with a lower lifetime risk of developing HF. 13-21,27  The AHA/

ACC primary prevention guidelines provide recommendations for diet, physical activity, and weight control, all of  which  have  been  associated  with  the  risk  of  HF. 28 Blood pressure is an important risk factor for HF, and a treatment goal of &lt;130/80 mm Hg is recommended for those with a CVD risk of ≥ 10%. 29,30  Multiple RCTs have found that patients with diabetes and CVD without HF have improved survival and reduced HF hospitalizations with SGLT2i. 31 Patients at risk for HF screened with BNP or NT-proBNP followed by collaborative care, diagnostic evaluation,  and  treatment  in  those  with  elevated  levels can  reduce  combined  rates  of  L V  systolic  dysfunction, diastolic dysfunction, and HF. 22,23  See Figure 5 for COR 1 and 2a for stage A (at risk for HF) and stage B (pre-HF).

## Recommendation-Specific Supportive Text

1. Elevated systolic and diastolic blood pressure are major  risk  factors  for  the  development  of  symptomatic HF. 8,9,32  Many trials have shown that hypertension control reduces the risk of HF. 1-7  Although the  magnitude  of  benefit  varies  with  the  patient population,  target  blood  pressure  reduction,  and HF criteria, effective hypertension treatment invariably reduces HF events. In the SPRINT (Systolic Blood  Pressure  Intervention  Trial)  trial,  control  to an  SBP  goal  &lt;120  mm  Hg  decreased  incident HF by 38% and mortality by 23% compared with an SBP goal of &lt;140 mm Hg 6,7  A meta-analysis showed  that  blood  pressure  control  was  associated with an approximately 40% reduction in HF events. 5  Therefore, SBP and diastolic blood pressure should be controlled in accordance with published clinical practice guidelines. 30
2. Multiple RCTs in patients with type 2 diabetes and at risk for, or with established CVD or at high risk for CVD, have shown that SGL T2i prevent HF hospitalizations compared with placebo. 10-12 The benefit for reducing HF hospitalizations in these trials predominantly reflects primary prevention of symptomatic HF, because only approximately 10% to 14% of participants in these trials had HF at baseline. The mechanisms for the improvement in HF events have not been clearly elucidated but seem to be independent of glucose lowering. Proposed mechanisms include reductions  in  plasma  volume,  cardiac  preload  and afterload, alterations in cardiac metabolism, reduced arterial  stiffness,  and  interaction  with  the  Na + /H + exchanger. 33,34 SGL T2i  are  generally  well  tolerated, but these agents have not been evaluated in those with severe renal impairment (estimated glomerular filtration rate [eGFR] &lt;25 mL/min/1.73 m 2 ). 35
3.  Greater adherence  to healthy lifestyle habits such  as  regular  physical  activity,  avoiding  obesity, maintaining normal blood pressure and

Figure 5. Recommendations (Class 1 and 2a) for Patients at Risk of HF (Stage A) and Those With Pre-HF (Stage B).

<!-- image -->

Colors correspond to COR in Table 2. COR 1 and COR 2a for patients at risk for HF (stage A) and those with pre-HF (stage B) are shown. Management strategies implemented in patients at risk for HF (stage A) should be continued though stage B. ACEi indicates angiotensinconverting enzyme inhibitor; ARB, angiotensin receptor blocker; BP, blood pressure; COR, Class of Recommendation; CVD, cardiovascular disease; HF, heart failure; ICD, implantable cardioverter-defibrillator; L VEF, left ventricular ejection fraction; MI, myocardial infarction; and SGL T2i, sodium glucose cotransporter 2 inhibitor.

blood  glucose,  not  smoking,  and  healthy  dietary patterns have been associated with a lower lifetime risk of HF and greater preservation of cardiac structure. 13-16,27 Healthful  eating  patterns, particularly  those  that  are  based  more  on  consumption  of  foods  derived  from  plants,  such  as the Mediterranean, whole grain, plant-based diet and the DASH (Dietary Approaches to Stop Hypertension) diet,  are  inversely  associated  with incident HF and may offer some protection against HF development. 17-21

4.  A large-scale unblinded single-center study (STOP-HF [The St Vincent's Screening to Prevent Heart Failure]) 22 of  patients at risk of HF (identified by the presence of hypertension, diabetes, or known  vascular  disease)  but  without  established LV systolic dysfunction or symptomatic HF at baseline  found  that  screening  with  BNP  testing  and then intervening on those with levels of ≥ 50 pg/ mL (performing echocardiography and referral to a cardiovascular specialist) reduced the composite endpoint of asymptomatic LV dysfunction (systolic

Table 9. Selected Multivariable Risk Scores to Predict Development of Incident HF

| Risk Score                          |   Reference |   Year Published |
|-------------------------------------|-------------|------------------|
| Framingham Heart Failure Risk Score |          24 |             1999 |
| Health ABC Heart Failure Score      |          25 |             2008 |
| ARIC Risk Score                     |          26 |             2012 |
| PCP-HF                              |          29 |             2019 |

ARIC indicates Atherosclerosis Risk in Communities; HF, heart failure; and PCP-HF, Pooled Cohort Equations to Prevent HF.

or diastolic) with or without newly diagnosed HF. 22 Similarly, in another small, single-center RCT, accelerated  uptitration  of  RAAS  antagonists  and beta blockers reduced cardiac events in patients with diabetes and elevated NT-proBNP levels but without cardiac disease at baseline. 23

5. Incident HF may be predicted from different models, including those derived from diverse populations (Table  9).  The  PCP-HF  (Pooled  Cohort  equations to  Prevent  HF)  model  provides  race-  and  sexspecific 10-year risk equations from 7 communitybased cohorts with at least 12 years of follow-up. 29 Predictors of HF included in the race- and sex-specific  models  were  age,  blood  pressure  (treated  or untreated),  fasting  glucose  (treated  or  untreated), body mass index, cholesterol, smoking status, and QRS duration. Models can be applied to the clinical setting of interest, with clinical trial models potentially less  generalizable to registry- or population-based models.  In  addition,  predictive  models  provide  the average estimate of risk derived from a population, and individual risk may vary. 36 The integration of risk scores  into  clinical  practice  have  shown  improved outcomes. As data generation increases from electronic health records and digital sources, advanced methods with machine learning are expected to proliferate the development of risk prediction models. Machine  learning  models  are  often  not  externally validated, and their performance may vary based on the population and clinical setting. 37 Patient populations change over time, and models may need to be recalibrated periodically.

## 6. STAGE B (PATIENTS WITH PRE-HF)

## 6.1. Management of Stage B: Preventing the Syndrome of Clinical HF in Patients With Pre-HF

| Recommendations for Management of Stage B: Preventing the Syndrome of Clinical HF in Patients With Pre-HF Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Management of Stage B: Preventing the Syndrome of Clinical HF in Patients With Pre-HF Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Management of Stage B: Preventing the Syndrome of Clinical HF in Patients With Pre-HF Referenced studies that support the recommendations are summarized in the Online Data Supplements.   |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                                            | LOE                                                                                                                                                                                                            | Recommendations                                                                                                                                                                                                |
| 1                                                                                                                                                                                                              | A                                                                                                                                                                                                              | 1. In patients with LVEF ≤ 40%, ACEi should be used to prevent symptomatic HF and reduce mortality. 1-4                                                                                                        |

| Recommendations for Management of Stage B: Preventing the Syndrome of Clinical HF in Patients With Pre-HF (Continued)   | Recommendations for Management of Stage B: Preventing the Syndrome of Clinical HF in Patients With Pre-HF (Continued)   | Recommendations for Management of Stage B: Preventing the Syndrome of Clinical HF in Patients With Pre-HF (Continued)                                                                                                                                                                       |
|-------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                     | LOE                                                                                                                     | Recommendations                                                                                                                                                                                                                                                                             |
| 1                                                                                                                       | A                                                                                                                       | 2. In patients with a recent or remote history of MI or ACS, statins should be used to prevent symptomatic HF and adverse cardiovascular events. 5-9                                                                                                                                        |
| 1                                                                                                                       | B-R                                                                                                                     | 3. In patients with a recent MI and LVEF ≤ 40% who are intolerant to ACEi, ARB should be used to prevent symptomatic HF and reduce mortal- ity. 10                                                                                                                                          |
| 1                                                                                                                       | B-R                                                                                                                     | 4. In patients with a recent or remote history of MI or acute coronary syndrome (ACS) and LVEF ≤ 40%, evidence-based beta blockers should be used to reduce mortality. 11-13                                                                                                                |
| 1                                                                                                                       | B-R                                                                                                                     | 5. In patients who are at least 40 days post-MI with LVEF ≤ 30% and NYHA class I symptoms while receiving GDMT and have reasonable expectation of meaningful survival for >1 year, an ICD is recommended for primary prevention of sudden cardiac death (SCD) to reduce total mortality. 14 |
| 1                                                                                                                       | C-LD                                                                                                                    | 6. In patients with LVEF ≤ 40%, beta blockers should be used to prevent symptomatic HF. 12,13                                                                                                                                                                                               |
| 3: Harm                                                                                                                 | B-R                                                                                                                     | 7. In patients with LVEF <50%, thiazolidinediones should not be used because they increase the risk of HF, including hospitalizations. 15                                                                                                                                                   |
| 3: Harm                                                                                                                 | C-LD                                                                                                                    | 8. In patients with LVEF <50%, nondihydropyri- dine calcium channel blockers with negative inotropic effects may be harmful. 16,17                                                                                                                                                          |

## Synopsis

In general, all recommendations for patients with stage A HF also apply to those with stage B HF. Stage B (preHF) represents a phase of clinically asymptomatic structural and functional cardiac abnormalities that increases the  risk  for  symptomatic  HF. 18-21 Identifying  individuals with stage B HF provides an opportunity to initiate lifestyle  modification  and  pharmacological  therapy  that may prevent or delay the transition to symptomatic HF (stage C/D). Several ACC/AHA clinical practice guidelines address appropriate management of patients with stage B HF (Table 10). Although multiple studies highlight the increased HF risk associated with asymptomatic LV systolic 19,20,22-26 and diastolic dysfunction identified by noninvasive  imaging, 19,26-30 beneficial  pharmacotherapy for asymptomatic LV systolic dysfunction, such as inhibitors of the renin-angiotensin system and beta blockers, have  been  predominantly  observed  in  individuals  with depressed LVEF (LVEF &lt;35%-40%). 1-4,11-13  Studies of specific treatments to alter the onset of HF in the setting of asymptomatic cardiac dysfunction with preserved LVEF  (eg,  abnormalities  of  myocardial  deformation  or diastolic dysfunction) have been limited. Several comorbid conditions, including diabetes, obesity, and hypertension,  have  been associated with asymptomatic L V dysfunction 27,28,30,31 and  with  progression  of  asymptomatic LV dysfunction to symptomatic HF. 27  Accordingly, these comorbidities are controlled according to current clinical

Table 10. Other ACC/AHA Clinical Practice Guidelines Addressing Patients With Stage B HF

| Consideration                                                                                                                                             | Reference                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------| |
| Patients with an acute MI who have not developed HF symptoms treated in accordance with GDMT                                                              | 2013 ACCF/AHA Guideline for the Management of ST-Elevation Myocardial Infarction 51 2014 AHA/ACC Guideline for the Management of Patients With Non-ST-Elevation Acute Coro- nary Syndromes 52                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| Coronary revascularization for patients without symptoms of HF in accordance with GDMT                                                                    | 2015 ACC/AHA/SCAI Focused Update on Primary Percutaneous Coronary Intervention for Pa- tients With ST-Elevation Myocardial Infarction: An Update of the 2011 ACCF/AHA/SCAI Guideline for Percutaneous Coronary Intervention and the 2013 ACCF/AHA Guideline for the Management of ST-Elevation Myocardial Infarction 53 (This guideline has been replaced by Lawton, 2021. 54 ) 2014 ACC/AHA/AATS/PCNA/SCAI/STS Focused Update of the Guideline for the Diagnosis and Management of Patients With Stable Ischemic Heart Disease 55 2011 ACCF/AHA Guideline for Coronary Artery Bypass Graft Surgery 56 (This guideline has been replaced by Lawton, 2021. 54 ) |
| Valve replacement or repair for patients with hemodynamically significant valvular stenosis or regurgitation and no symptoms of HF in accordance withGDMT | 2020 ACC/AHA Guideline for the Management of Patients With Valvular Heart Disease. 57,58                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| Patients with congenital heart disease that may increase the risk for the development of HF                                                               | 2018 AHA/ACC Guideline for the Management of Adults With Congenital Heart Disease 59                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |

AATS indicates American Association for Thoracic Surgery; ACC, American College of Cardiology; ACCF, American College of Cardiology Foundation; AHA, American Heart Association; GDMT, guideline-directed medical therapy; HF, heart failure; MI, myocardial infarction; PCNA, Preventive Cardiovascular Nurses Association; SCAI, Society for Cardiovascular Angiography and Interventions; and STS, The Society of Thoracic Surgeons.

practice  guidelines.  The  benefits  of  mineralocorticoid receptor antagonists (MRA) after MI have mostly been shown in patients with symptomatic HFrEF. 32-34

ARNi  have  not  been  well  studied  in  stage  B  HF. The PARADISE-MI (Prospective ARNi vs. ACE inhibitor  trial  to  DetermIne  Superiority  in  reducing  heart failure  Events  after  Myocardial  Infarction)  study 35 will report the efficacy and safety of sacubitril/valsartan in patients after acute MI, with LVEF ≤ 40 and/or pulmonary congestion, plus an additional risk-enhancing factor, compared with ramipril.

## Recommendation-Specific Supportive Text

1. ACEi have been shown to impede maladaptive remodeling after acute MI in patients with reduced L VEF . 36,37 In  survivors  of  acute  MI  with  asymptomatic  L V  dysfunction  (L VEF  &lt;35%-40%),  RCTs  have  shown that ACEi reduced mortality, HF hospitalizations, and progression to severe HF compared with placebo. 2,4 Similarly,  in  those  individuals  with  asymptomatic  L V dysfunction in the SOL VD (Studies of Left Ventricular Systolic Dysfunction) prevention trial, which included approximately  20%  without  ischemic  heart  disease, enalapril was associated with reduced HF hospitalization and mortality compared with placebo. 1,3
2. In multiple RCTs, 42  statins have been shown to prevent adverse CAD events in patients with an MI, ACS, and with high cardiovascular risk. These trials have  also  shown  that  statin  therapy  reduces  the risk of incident HF. 5-9   A meta-analysis of 6 RCTs of  &gt;110  000  patients  with  an  ACS  showed  that intensive  statin  therapy  reduced  hospitalizations for  HF. 5 A  subsequent, larger collaborative metaanalysis of up to 17 major primary and secondary prevention RCTs showed that statins reduced HF

hospitalization. 42 These  data  support  the  use  of statins to prevent symptomatic HF and cardiovascular events in patients with acute MI or ACS.

3. Two major trials have compared ARB with ACEi after MI.  The  VALIANT  (Valsartan  in  Acute  Myocardial Infarction) trial, which included approximately 25% of patients with asymptomatic L V dysfunction, showed that the benefits of valsartan on mortality and other adverse  cardiovascular  outcomes  were  comparable  to  captopril. 10,38 In  the  OPTIMAAL  (Optimal Trial  in  Myocardial  Infarction  with  the  Angiotensin II  Antagonist Losartan) trial, losartan did not meet the noninferiority criteria for mortality compared with captopril. 39 It has been hypothesized that the lower dose of losartan  (50  mg  daily)  in  the  OPTIMAAL trial  may  have  contributed  to  the  greater  difference than those seen with valsartan in VALIANT. 40 No clinical trials have specifically evaluated ARB in patients  with  asymptomatic  reduced  L VEF  in  the absence of previous MI. Although ARB are alternatives  for  patients  with  ACEi-induced  angioedema, caution is advised because some patients have also developed angioedema with ARB.
4.  Current evidence supports the use of beta blockers  to  improve  adverse  cardiac  remodeling  and outcomes in patients with asymptomatic reduced LVEF after MI.  Among patients with a recent MI and reduced LVEF, carvedilol reduced maladaptive remodeling 41  and reduced mortality compared with placebo. 11   Among patients with asymptomatic LV systolic dysfunction in the SOL VD prevention trial (which  included  80%  with  previous  MI)  and  the SAVE (Survival and Ventricular Enlargement) trial, secondary  analyses  showed  that  the  administration of beta blockers in addition to ACEi reduced mortality and hospitalization. 12,13

5.  The  Framingham  studies  have  shown  a  60% increased risk  of  death  in  patients  with  asymptomatic low LVEF compared with those with normal LVEF, and  almost  half  of  these  patients  remained  free of  HF  before  their  death. 25 MADIT-II  (Multicenter Automatic Defibrillator Implantation Trial II) showed a 31% relative risk reduction in all-cause mortality in  patients  with  post-MI  with  L VEF ≤ 30% receiving  a  prophylactic  ICD  compared  with  standard of  care. 14 These findings provided justification  for the broad adoption of ICDs for primary prevention of SCD in the post-MI setting with reduced L VEF, even in the absence of HF symptoms.
6. Although beta blockers have been shown to improve outcomes in patients with symptomatic HFrEF and in patients with reduced L VEF after MI, 11  few data exist regarding the use of beta blockers in asymptomatic patients with depressed L VEF without a history of MI. There is evidence to support the role of beta blockers to prevent adverse L V remodeling in asymptomatic patients with L V systolic dysfunction, including those with nonischemic cause. 43  Also, in a post hoc analysis of the SOL VD prevention trial, which included approximately 20% of participants with  nonischemic  HF  cause,  beta  blockers  were associated with a reduction in the risk of death and in  death  or  hospitalization  for  symptomatic  HF  in those patients randomized to enalapril, a finding that was not seen in the placebo group. 12 Given the longterm benefits of beta blockers to reduce HF hospitalizations  in  patients  with  symptomatic  HFrEF, 44 beta-blocker  therapy  is  recommended  to  prevent symptomatic HF in patients with reduced L VEF.
7. Thiazolidinediones  have  been  associated  with  fluid retention  and  increased  rates  of  HF  in  RCTs  of patients with type 2 diabetes who were predominantly free of symptomatic HF at baseline. 47-49 In a smaller RCT  of  patients  with  more  severely  symptomatic HFrEF,  pioglitazone  was  associated  with  increased rates of HF hospitalization compared with placebo. 50 In  patients  with  more  mild  symptoms  (NYHA class I to II) but with depressed L VEF, 15 rosiglitazone was associated  with  more  fluid-related  events,  including  worsening  edema  and  need  for  increased  HF medications. 15 Given the evidence, thiazolidinediones should be avoided in patients with reduced L VEF.
8. Nondihydropiridine calcium channel blockers diltiazem and verapamil are myocardial depressants and generally not tolerated in HF. In previous studies of patients with HF or reduced L VEF after acute MI, diltiazem was associated with increased risk of HF, 16,17 although  in  a  smaller  study  of  patients  with  nonischemic  cardiomyopathy,  diltiazem  had  no  impact on mortality. 45  Verapamil had no impact on survival or  major  cardiovascular  events  after  acute  MI. 46 Although  not  specifically  tested  in  asymptomatic

patients with low L VEF, nondihydropyridine calcium channel blockers may be harmful in this population because of their negative inotropic effects.

## 7. STAGE C HF

## 7.1. Nonpharmacological Interventions

## 7.1.1. Self-Care Support in HF

| Recommendations for Nonpharmacological Interventions: Self-Care Support in HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Nonpharmacological Interventions: Self-Care Support in HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Nonpharmacological Interventions: Self-Care Support in HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                          |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                  | LOE                                                                                                                                                                                  | Recommendations                                                                                                                                                                                                                             |
| 1                                                                                                                                                                                    | A                                                                                                                                                                                    | 1. Patients with HF should receive care from multidisciplinary teams to facilitate the imple- mentation of GDMT, address potential barriers to self-care, reduce the risk of subsequent rehospitalization for HF, and improve survival. 1-4 |
| 1                                                                                                                                                                                    | B-R                                                                                                                                                                                  | 2. Patients with HF should receive specific edu- cation and support to facilitate HF self-care in a multidisciplinary manner. 2,5-9                                                                                                         |
| 2a                                                                                                                                                                                   | B-NR                                                                                                                                                                                 | 3. In patients with HF, vaccinating against respi- ratory illnesses is reasonable to reduce mor- tality. 10-16                                                                                                                              |
| 2a                                                                                                                                                                                   | B-NR                                                                                                                                                                                 | 4. In adults with HF, screening for depression, 17,18 social isolation, 19-22 frailty, 23,24 and low health literacy 25,26 as risk factors for poor self-care is reasonable to improve management.                                          |

## Synopsis

Because  of  the  complexity  of  HF  management  and coordination  of  other  health  and  social  services  required, HF care is ideally provided by multidisciplinary teams 27-30 that include cardiologists, nurses, and pharmacists  who  specialize  in  HF  as  well  as  dieticians, mental  health  clinicians,  social  workers,  primary  care clinicians,  and  additional  specialists. 31-33 Self-care  in HF comprises treatment adherence and health maintenance behaviors. 34,35  Patients with HF should learn to take medications as prescribed, restrict sodium intake, stay  physically  active,  and  get  vaccinations. 36,37 They also  should  understand  how  to  monitor  for  signs  and symptoms of worsening HF, and what to do in response to  symptoms  when  they  occur. 36,37   Knowledge  alone is  insufficient to improve self-care. 38   Patients with HF need time and support to gain skills and overcome barriers to effective self-care. 37   Measures listed as Class 1 recommendations for patients in stages A and B are recommended where appropriate for patients in stage C. GDMT, as depicted in Figure 6, should be the mainstay of pharmacological therapy for HFrEF.

## Recommendation-Specific Supportive Text

1. In  a  meta-analysis  of  30  RCTs,  multidisciplinary interventions reduced hospital admission and

<!-- image -->

## Figure 6. Treatment of HFrEF Stages C and D.

Colors correspond to COR in Table 2. Treatment recommendations for patients with HFrEF are displayed. Step 1 medications may be started simultaneously at initial (low) doses recommended for HFrEF. Alternatively, these medications may be started sequentially, with sequence guided by clinical or other factors, without need to achieve target dosing before initiating next medication. Medication doses should be increased to target as tolerated. ACEi indicates angiotensin-converting enzyme inhibitor; ARB, angiotensin receptor blocker; ARNi, angiotensin receptor-neprilysin inhibitor; COR, Class of Recommendation; CRT, cardiac resynchronization therapy; GDMT, guideline-directed medical therapy; ICD, implantable cardioverter-defibrillator; hydral-nitrates, hydralazine and isosorbide dinitrate; HFrEF, heart failure with reduced ejection fraction; LBBB, left bundle branch block; MCS, mechanical circulatory support; L VEF, left ventricular ejection fraction; MRA, mineralocorticoid receptor antagonist; NSR, normal sinus rhythm; NYHA, New York Heart Association; and SGLT2i, sodium-glucose cotransporter 2 inhibitor. *Participation in investigational studies is appropriate for stage C, NYHA class II and III HF.

all-cause mortality. 1 In a separate meta-analysis of 22 RCTs, specialized multidisciplinary team followup was associated with reduced HF hospitalizations and  all-cause  hospitalizations. 2 In  a  recent  metaanalysis of 22 RCTs, multidisciplinary interventions that included a pharmacist reduced HF hospitalizations. 3  In a recent Cochrane systematic review and meta-analysis of 43 RCTs, both case management (ie, active management of complex patients by case managers working in integrated care systems) and multidisciplinary interventions (ie, coordinated multidisciplinary health care interventions and communications) were shown to reduce all-cause mortality, all-cause readmission, and readmission for HF. 4

2. Meta-analyses  of  RCTs  have  shown  that  interventions focused on improving HF self-care

significantly  reduce  the  risk  of  HF-related  hospitalization, 2,5-8 all-cause hospitalization, 2,8,9 and all-cause  mortality, 6,9 as  well  as  improve  QOL. 5 Interventions that aim to improve self-care knowledge and skill, 2,5,8  and those that focus on enhancing  medication  adherence 9 or  reinforce  self-care with structured telephone support, 6,7 are  effective in  patients  with  HF.  There  is  uncertainty  whether mobile health-delivered educational interventions  improve  self-care  in  patients  with  HF. 39 In a  single  RCT  involving  rural  patients  with  HF,  an educational  intervention  was  shown  to  improve knowledge and self-care 40  but did not significantly decrease the combined endpoint of cardiac death or HF hospitalization. 41 In a recent pragmatic trial, a transitional care services program that included

self-care education improved discharge preparedness, quality of transition, and QOL but did not significantly improve clinical outcomes compared with usual care. 42

3. In propensity-adjusted models, influenza vaccination  was  associated  with  a  significant  reduction  in  all-cause  mortality  among  participants  in PARADIGM-HF (Prospective Comparison of ARNi with ACEi to Determine Impact on Global Mortality and Morbidity in Heart Failure). 14  In adjusted models, influenza vaccination was associated with significant reductions in all-cause mortality and cardiovascular mortality 12 in  1  registry  study  and  was associated  with  significant  reductions  in  all-cause mortality  and  the  composite  of  all-cause  mortality and cardiovascular hospitalizations in another large cohort study. 11 In a self-controlled case series study of patients with HF, influenza vaccination was associated  with  a  significantly  lower  risk  of  cardiovascular,  respiratory,  and  all-cause  hospitalization. 43 In a meta-analysis of 16 studies of patients with CVD, influenza  vaccination  was  associated  with  a  lower risk of all-cause, cardiovascular mortality, and major adverse cardiovascular events compared with control  patients. 15 In  the  Cardiovascular  Health  Study, pneumococcal vaccination was associated with significant reductions in incident HF, all-cause mortality, and cardiovascular mortality. 16  Patients with HF are  uniquely  susceptible  to  poor  outcomes  in  the setting of SARS-CoV-2 infection 44-47 and should be vaccinated against COVID-19. 10
4. Many health and social factors are associated with poor HF self-care. 36,37 (T able 11) but have also been linked  to  poor  clinical  outcomes  and  fundamentally  change how education and support must be delivered. Depression is a risk factor for poor selfcare, 40 rehospitalization, 17 and all-cause mortality 18 among patients with HF. Interventions that focus on  improving  HF  self-care  have  been  reported to  be  effective  among  patients  with  moderate/ severe  depression  with  reductions  in  hospitalization  and  mortality  risk. 5   Nonrandomized  studies have  provided  evidence  of  a  link  between  social isolation and mortality in patients with HF 19,20 In a recent  meta-analysis  of  29  cohort  studies,  frailty was associated with an increased risk of all-cause mortality and hospitalization. 23 Frailty also has been shown to impair self-care among elderly patients with HF. 24  A recent meta-analysis of observational studies  revealed  social  isolation  to  be  common among adults  with  HF  (ie,  37%)  and  associated with a 55% greater risk of HF-related rehospitalization. 21  Poor social support also has been shown in  nonrandomized  studies  to  be  associated  with lower  HF  self-care. 22 A  recent  meta-analysis  of observational  studies  showed  that  inadequate/

marginal health literacy is common among adults with  HF  (ie,  24%)  and  associated  independently with the risk of mortality and hospitalization. 25  Low literacy also is associated with poor HF self-care, as most interventions depend on both literacy and health literacy/numeracy. 26

## 7.1.2. Dietary Sodium Restriction

| Recommendation for Dietary Sodium Restriction   | Recommendation for Dietary Sodium Restriction   | Recommendation for Dietary Sodium Restriction                                                                        |
|-------------------------------------------------|-------------------------------------------------|----------------------------------------------------------------------------------------------------------------------|
| COR                                             | LOE                                             | Recommendation                                                                                                       |
| 2a                                              | C-LD                                            | 1. For patients with stage C HF, avoiding exces- sive sodium intake is reasonable to reduce congestive symptoms. 1-6 |

## Synopsis

Restricting  dietary  sodium  is  a  common  nonpharmacological treatment for patients with HF symptomatic with congestion,  but  specific  recommendations  have  been based on low-quality evidence. 7  Concerns about the quality of data regarding clinical benefits or harm of sodium restriction in patients with HF include the lack of current pharmacological therapy, small samples without sufficient racial  and  ethnic  diversity,  questions  about  the  correct threshold for clinical benefit, uncertainty about which subgroups benefit most from sodium restriction, 7,8 and serious questions about the validity of several RCTs in this area. 9-11 However, there are promising pilot trials of sodium restriction in patients with HF 3,5,6  The AHA currently recommends  a  reduction  of  sodium  intake  to  &lt;2300 mg/d for general cardiovascular health promotion 12 ; however, there are no trials to support this level of restriction in patients with HF. 13 Sodium restriction can result in poor dietary  quality  with  inadequate  macronutrient  and  micronutrient intake. 14 Nutritional  inadequacies have been associated with clinical instability, 15-17 but routine supplementation of oral iron, 18 thiamine, 19 zinc, 20 vitamin D, 21 or multivitamins has not proven beneficial. 22  The DASH diet is rich in antioxidants and potassium, can achieve sodium restriction  without  compromising  nutritional  adequacy when accompanied by dietary counseling, 5  and may be associated with reduced hospitalizations for HF. 23

## Recommendation-Specific Supportive Text

1.  A  registered  dietitian-  or  nurse-coached  intervention  with  2  to  3  g/d  sodium  restriction  improved NYHA functional class and leg edema in patients with  HFrEF. 1 In  a  nonrandomized  study  (&gt;2.5  g/d versus &lt;2.5 g/d), lower dietary sodium was associated with worse all-cause mortality in patients with HFrEF. 2 In small RCTs, aggressive sodium restriction (0.8  g/d)  during  hospitalization  for  acute  decompensated HF has not reduced weight, congestion, diuretic use, rehospitalization, or all-cause mortality in patients with HFrEF 24 or in patients with HFpEF. 25

Table 11. Potential Barriers to Effective HF Self-Care and Example Interventions

| Potential Barrier                                         | Example Screening Tools                                                                                                                                    | Example Interventions                                                                                                                                                                                                                                  |
|-----------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Medical Barriers                                          |                                                                                                                                                            |                                                                                                                                                                                                                                                        |
| Cognitive impairment 48-50                                | Mini-Cog Mini-Mental State Examination (MMSE) Montreal Cognitive Assessment (MoCA)                                                                         | Home health aide Home meal deliveries Adult day care Geriatric psychiatry referral Memory care support groups                                                                                                                                          |
| Depression 51,52                                          | Hamilton Depression Rating Scale (HAM-D) Beck Depression Inventory-II (BDI-II) Patient Health Questionnaire-9 (PHQ-9)                                      | Psychotherapy Selective serotonin reuptake inhibitors Nurse-led support                                                                                                                                                                                |
| Substance use disorders 53                                | Tobacco, Alcohol, Prescription medication, and other Sub- stance use (TAPS)                                                                                | Referral to social work services and community support partners Referral for addiction psychiatry consultation                                                                                                                                         |
| Frailty 54                                                | Fried frailty phenotype                                                                                                                                    | Cardiac rehabilitation Registered dietitian nutritionist evaluation for malnutrition                                                                                                                                                                   |
| Social Barriers                                           |                                                                                                                                                            |                                                                                                                                                                                                                                                        |
| Financial burden of HF treatments 55                      | COmprehensive Score for financial Toxicity-Functional As- sessment of Chronic Illness Therapy (COST-FACIT)                                                 | PharmD referral to review prescription assistance eligibilities                                                                                                                                                                                        |
| Food insecurity 56,57                                     | Hunger Vital Sign, 2 items US Household Food Security Survey Module, 6 items                                                                               | Determine eligibility for the Supplemental Nutrition Assistance Program (SNAP) Connect patients with community partners such as food pantries/ food banks Home meal deliveries Registered dietitian nutritionist evaluation for potential malnutrition |
| Homelessness or housing insecurity 58-60                  | Homelessness Screening Clinical Reminder (HSCR)                                                                                                            | Referral to local housing services Connect patients with community housing partners                                                                                                                                                                    |
| Intimate partner violence or elder abuse 61,62            | Humiliation, Afraid, Rape, Kick (HARK) questionnaire Partner Violence Screen (PVS) Woman Abuse Screening Tool (WAST)                                       | Referral to social work services and community support partners                                                                                                                                                                                        |
| Limited English proficiency or other language barriers 63 | Routinely inquire in which language the patient is most comfortable conversing                                                                             | Access to interpreter services covering a wide range of languag- es, ideally in person or, alternatively, via video platform Printed educational materials in a range of appropriate languages                                                         |
| Low health literacy 64                                    | Short Assessment of Health Literacy (SAHL) Rapid Estimate of Adult Literacy in Medicine-Short Form (REALM-SF) Brief Health Literacy Screen (BHLS), 3 items | Agency for Healthcare Research and Quality (AHRQ) Health Lit- eracy Universal Precautions Toolkit Written education tools provided at sixth grade reading level or below Graphic educational documents                                                 |
| Social isolation or low social support 65                 | Patient-Reported Outcomes Measurement Information System (PROMIS) Social Isolation Short Form                                                              | Determine eligibility for home care services Support group referral                                                                                                                                                                                    |
| Transport limitations                                     | No validated tools currently available.                                                                                                                    | Referral to social work services Determine eligibility for insurance or state-based transportation, or reduced-cost public transportation Maximize opportunities for telehealth visits and remote monitoring                                           |

HF indicates heart failure.

A  recent  pilot  RCT  N=27)  showed  that  providing patients with 1.5 g/d sodium meals can reduce urinary sodium and improve QOL but not improve clinical outcomes. 3  Another recent pilot RCT (N=38) of 1.5 versus 2.3 g/d sodium resulted in sodium intake and  improvement  in  BNP  levels  and  QOL  in  the 1.5 g/d sodium intake arm 5 ; the full trial is due to be completed in 2022. A third pilot RCT (N=66) of home-delivered 1.5 g/d meals showed favorable but nonsignificant  trends  toward  improvement  in  clinical status and readmission rates. 6 Moreover, results from RCTs have shown that reducing dietary sodium is difficult to achieve in patients with HF, even with prepared meals 3  or home visits. 26

7.1.3. Management of Stage C HF: Activity, Exercise Prescription, and Cardiac Rehabilitation

| Recommendations for Management of Stage C HF: Activity, Exercise Prescription, and Cardiac Rehabilitation Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Management of Stage C HF: Activity, Exercise Prescription, and Cardiac Rehabilitation Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Management of Stage C HF: Activity, Exercise Prescription, and Cardiac Rehabilitation Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                                              | LOE                                                                                                                                                                                                              | Recommendations                                                                                                                                                                                                  |
| 1                                                                                                                                                                                                                | A                                                                                                                                                                                                                | 1. For patients with HF who are able to par- ticipate, exercise training (or regular physical activity) is recommended to improve functional status, exercise performance, and QOL. 1-9                          |
| 2a                                                                                                                                                                                                               | B-NR                                                                                                                                                                                                             | 2. In patients with HF, a cardiac rehabilitation program can be useful to improve functional capacity, exercise tolerance, and health-related QOL. 1,2,5,6,8                                                     |

## Synopsis

Exercise training in patients with HF is safe and has numerous benefits. In a major trial of exercise and HF, exercise  training  was  associated  with  a  reduction  in CVD mortality or hospitalizations in the exercise training group after adjustment for risk factors. 1  Meta-analyses  show  that  cardiac  rehabilitation  improves  functional  capacity,  exercise  duration,  and  health-related QOL.  A  cardiac  rehabilitation  program  for  patients with HF usually includes a medical evaluation, education  regarding the importance of medical adherence, dietary  recommendations,  psychosocial  support,  and an  exercise  training  and  physical  activity  counseling program. Patients with HF on optimal GDMT, who are in stable medical condition and are able to participate in an exercise program, are candidates for an exercise rehabilitation program. 10,11

## Recommendation-Specific Supportive Text

1. Evidence from RCTs indicates that exercise training improves functional status, exercise performance, and  QOL  in  patients  with  HFrEF  and  HFpEF.  In HF-ACTION, the largest randomized trial with exercise  training  in  patients  with  HF, 1 2331  patients with L VEF ≤ 35% (NYHA class II and III) were randomized to usual care versus supervised exercise training plus usual care. There were modest reductions in all-cause mortality and hospitalization rates that did not reach significance by primary analysis but, after prespecified adjustment, were associated with  reductions  in  cardiovascular  mortality  or  HF hospitalizations. 1 Many RCTs of exercise training in HF have been conducted, but the statistical power of most was low. 2-5,9-13  Meta-analyses suggest that exercise  training  is  associated  with  improvement in  functional  capacity,  exercise  duration,  healthrelated QOL, and reduction in HF hospitalizations in patients with HFrEF as well as HFpEF. 2-6,8,11,14,15 Most studies and meta-analyses have not shown significant  changes  in  all-cause  mortality. 2,12,14-22 except  for  a  few  showing  mortality  benefit  with longer follow-up 6,7 Other benefits of exercise training include improved endothelial function, blunted catecholamine spillover, increased peripheral oxygen extraction,  and  improvement in peak oxygen consumption. 2-5,8,10-12,21
2. A  formal  cardiac  rehabilitation  program  usually includes  a  medical  evaluation,  education  regarding the importance of medical adherence, dietary recommendations,  psychosocial  support,  and  an exercise  training  and  physical  activity  counseling program. Exercise-based cardiac rehabilitation has been associated with an improvement in functional capacity, exercise tolerance, the rate of overall  and  HF-specific  hospitalization,  and  improved

QOL. 3,4,6,7,11,16,17 In  a  diverse  population  of  older patients who were hospitalized for acute decompensated  HF,  an  early,  transitional,  tailored,  progressive  rehabilitation  intervention  that  included multiple  physical-function  domains  (strength,  balance, mobility, and endurance) initiated during, or early  after  hospitalization  for  HF,  and  continued after discharge, resulted in greater improvement in physical function than usual care. 9

## 7.2. Diuretics and Decongestion Strategies in Patients With HF

| Recommendations for Diuretics and Decongestion Strategies in Patients With HF Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Diuretics and Decongestion Strategies in Patients With HF Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Diuretics and Decongestion Strategies in Patients With HF Referenced studies that support the recommendations are summarized in the Online Data Supplements.                                                                                    |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                | LOE                                                                                                                                                                                | Recommendations                                                                                                                                                                                                                                                     |
| 1                                                                                                                                                                                  | B-NR                                                                                                                                                                               | 1. In patients with HF who have fluid retention, diuretics are recommended to relieve conges- tion, improve symptoms, and prevent worsen- ing HF. 1-5                                                                                                               |
| 1                                                                                                                                                                                  | B-NR                                                                                                                                                                               | 2. For patients with HF and congestive symptoms, addition of a thiazide (eg, metolazone) to treat- ment with a loop diuretic should be reserved for patients who do not respond to moderate- or high-dose loop diuretics to minimize electro- lyte abnormalities. 6 |

## Synopsis

Bumetanide, furosemide, and torsemide inhibit reabsorption of sodium or chloride at the loop of Henle, whereas thiazide and thiazide-like diuretics act in the distal convoluting tubule and potassium-sparing diuretics (eg, spironolactone) in the collecting duct. 7,8 Loop diuretics are the  preferred  diuretic  agents  for  use  in  most  patients with  HF.  Thiazide  diuretics  such  as  chlorthalidone  or hydrochlorothiazide may be considered in patients with hypertension  and  HF  and  mild  fluid  retention.  Metolazone or chlorothiazide may be added to loop diuretics in patients with refractory edema unresponsive to loop diuretics alone. Diuretics should be prescribed to patients who have evidence of congestion or fluid  retention.  In any  patient  with  a  history  of  congestion,  maintenance diuretics should be considered to avoid recurrent symptoms. The treatment goal of diuretic use is to eliminate clinical evidence of fluid retention, using the lowest dose possible  to  maintain  euvolemia.  With  the  exception  of MRAs, the effects of diuretics on morbidity and mortality are uncertain. 1-5 As  such, diuretics should not be used in  isolation  but  always  combined  with  other  GDMT  for HF that reduces hospitalizations and prolongs survival. Table 12 lists oral diuretics recommended for use in the treatment of chronic HF. Hyponatremia complicates HF management. If reversing potential causes and free water restriction do not improve hyponatremia, vasopressin antagonists may be helpful in the acute management of

Table 12. Commonly Used Oral Diuretics in Treatment of Congestion for Chronic HF

| Drug                | Initial Daily Dose       | Maximum Total Daily Dose   | Duration of Action   |
|---------------------|--------------------------|----------------------------|----------------------|
| Loop diuretics      | Loop diuretics           | Loop diuretics             | Loop diuretics       |
| Bumetanide          | 0.5-1.0 mg once or twice | 10 mg                      | 4-6 h                |
| Furosemide          | 20-40 mg once or twice   | 600 mg                     | 6-8 h                |
| Torsemide           | 10-20 mg once            | 200 mg                     | 12-16 h              |
| Thiazide diuretics  | Thiazide diuretics       | Thiazide diuretics         | Thiazide diuretics   |
| Chlorthiazide       | 250-500 mg once or twice | 1000 mg                    | 6-12 h               |
| Chlorthalidone      | 12.5-25 mg once          | 100 mg                     | 24-72 h              |
| Hydrochlorothiazide | 25 mg once or twice      | 200 mg                     | 6-12 h               |
| Indapamide          | 2.5 mg once              | 5 mg                       | 36 h                 |
| Metolazone          | 2.5 mg once              | 20 mg                      | 12-24 h              |

HF indicates heart failure.

volume overload to decrease congestion while maintaining serum sodium.

## Recommendation-Specific Supportive Text

1. Controlled trials with diuretics showed their effects to  increase  urinary  sodium  excretion,  decrease physical signs of fluid retention,  and  improve symptoms, QOL, and exercise tolerance. 1-5  Recent data from the nonrandomized OPTIMIZE-HF (Organized Program to Initiate Lifesaving Treatment in Hospitalized Patients with Heart Failure) registry  revealed  reduced  30-day  all-cause  mortality and hospitalization for HF with diuretic use compared with no diuretic use after hospital discharge for  HF. 9 The  most  commonly  used  loop  diuretic for  the  treatment  of  HF  is  furosemide,  but  some patients respond more favorably to other agents in this category (eg, bumetanide, torsemide), potentially  because  of  their  increased  oral  bioavailability. 10-12 In  outpatients  with  HF,  diuretic  therapy  is commonly initiated with low doses, and the dose is increased until urine output  increases  and weight decreases, generally by 0.5 to 1.0 kg daily. Patients may become unresponsive to high doses of diuretic drugs if they consume large amounts of dietary  sodium,  are  taking  agents  that  can  block the effects of diuretics (eg, NSAIDs), or have significant impairment of renal function or perfusion.
2. Diuretic  resistance  can  be  overcome  in  several ways,  including  escalation  of  loop  diuretic  dose, intravenous  administration  of  diuretics  (bolus  or continuous infusion), 6 or  combination  of  different diuretic classes. 13-16 The use of a thiazide or thiazide-like  diuretic  (eg,  metolazone)  in  combination with  a  loop  diuretic  inhibits  compensatory  distal tubular sodium reabsorption, leading to enhanced

natriuresis. However, in a propensity-score matched analysis in patients with hospitalized HF, the  addition  of  metolazone  to  loop  diuretics  was found to increase the risk for hypokalemia, hyponatremia,  worsening  renal  function,  and  mortality, whereas use of higher doses of loop diuretics was not  found  to  adversely  affect  survival. 17 Although randomized data comparing the 2 diuretic strategies are limited, the DOSE (Diuretic Optimization Strategies  Evaluation)  trial  lends  support  for  the use of high-dose intravenous loop diuretics. 18

## 7.3. Pharmacological Treatment* for HFrEF

## 7.3.1. Renin-Angiotensin System Inhibition With ACEi or ARB or ARNi

| Recommendations for Renin-Angiotensin System Inhibition With ACEi or ARB or ARNi Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Renin-Angiotensin System Inhibition With ACEi or ARB or ARNi Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Renin-Angiotensin System Inhibition With ACEi or ARB or ARNi Referenced studies that support the recommendations are summarized in the Online Data Supplements.                                                            |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                   | LOE                                                                                                                                                                                   | Recommendations                                                                                                                                                                                                                                |
| 1                                                                                                                                                                                     | A                                                                                                                                                                                     | 1. In patients with HFrEF and NYHA class II to III symptoms, the use of ARNi is recommended to reduce morbidity and mortality. 1-5                                                                                                             |
| 1                                                                                                                                                                                     | A                                                                                                                                                                                     | 2. In patients with previous or current symptoms of chronic HFrEF, the use of ACEi is beneficial to reduce morbidity and mortality when the use of ARNi is not feasible. 6-13                                                                  |
| 1                                                                                                                                                                                     | A                                                                                                                                                                                     | 3. In patients with previous or current symptoms of chronic HFrEF who are intolerant to ACEi because of cough or angioedema and when the use of ARNi is not feasible, the use of ARB is rec- ommended to reduce morbidity and mortality. 14-18 |
| Value Statement: High Value (A)                                                                                                                                                       | Value Statement: High Value (A)                                                                                                                                                       | 4. In patients with previous or current symptoms of chronic HFrEF, in whom ARNi is not feasible, treatment with an ACEi or ARB provides high economic value. 19-25                                                                             |
| 1                                                                                                                                                                                     | B-R                                                                                                                                                                                   | 5. In patients with chronic symptomatic HFrEF NYHA class II or III who tolerate an ACEi or ARB, replacement by an ARNi is recommended to further reduce morbidity and mortality. 1-5                                                           |
| Value Statement: High Value (A)                                                                                                                                                       | Value Statement: High Value (A)                                                                                                                                                       | 6. In patients with chronic symptomatic HFrEF, treatment with an ARNi instead of an ACEi pro- vides high economic value. 26-29                                                                                                                 |
| 3: Harm                                                                                                                                                                               | B-R                                                                                                                                                                                   | 7. ARNi should not be administered concomi- tantly with ACEi or within 36 hours of the last dose of an ACEi. 30,31                                                                                                                             |
| 3: Harm                                                                                                                                                                               | C-LD                                                                                                                                                                                  | 8. ARNi should not be administered to patients with any history of angioedema. 32-35                                                                                                                                                           |
| 3: Harm                                                                                                                                                                               | C-LD                                                                                                                                                                                  | 9. ACEi should not be administered to patients with any history of angioedema. 36-39                                                                                                                                                           |

*See Section 7.2, 'Diuretics and Decongestion Strategies in Patients with HF, ' for diuretic recommendations.

## Synopsis

Inhibition of the renin-angiotensin system is recommended  to  reduce  morbidity  and  mortality  for  patients  with HFrEF, and ARNi, ACEi, or ARB are recommended as first-line therapy. 1-18 If patients have chronic symptomatic

HFrEF with NYHA class II or III symptoms and they tolerate an ACEi or ARB, they should be switched to an ARNi because of improvement in morbidity and mortality. 1-5  An ARNi is recommended as de novo treatment in hospitalized patients with acute HF before discharge given improvement in health status, reduction in the prognostic biomarker NT-proBNP, and improvement of LV remodeling parameters compared with ACEi/ARB. Although data are limited,  the  use  of  an  ARNi  may  be  efficacious  as de novo treatment in patients with symptomatic chronic HFrEF to simplify management. ARB may be used as an alternative to ACEi in the setting of intolerable cough, or as alternatives to ACEi and ARNi in patients with a history of angioedema. If patients are switched from an ACEi to an ARNi or vice versa, there should be at least 36 hours between ACEi and ARNi doses.

## Recommendation-Specific Supportive Text

1.  An ARNi is composed of an ARB and an inhibitor  of  neprilysin,  an  enzyme  that  degrades  natriuretic  peptides,  bradykinin,  adrenomedullin,  and other vasoactive peptides. In  PARADIGM-HF (Prospective Comparison of ARNi  with ACEi to  Determine  Impact  on  Global  Mortality  and Morbidity in Heart Failure), an RCT that compared the  first  approved  ARNi,  sacubitril-valsartan,  with enalapril in symptomatic patients with HFrEF tolerating an adequate dose of either ACEi or ARB, sacubitril-valsartan significantly reduced the composite  endpoint  of  cardiovascular  death  or  HF hospitalization  by  20%  relative  to  enalapril. 1 The benefit was observed to a similar extent for death and HF hospitalization and was consistent across prespecified subgroups. 1  Use of an ARNi is more frequently  associated  with  symptomatic  hypotension and a comparable incidence of angioedema when compared with enalapril. 1 Sacubitril-valsartan has been approved for patients with symptomatic HF.  HF  effects  and  potential  off-target  effects may  be  complex  with  inhibition  of  the  neprilysin enzyme, which has multiple biological targets. Trial data have included ACEi/ARB-naïve patients before ARNi initiation (53% in the PIONEER-HF [Comparison of Sacubitril-Valsartan versus Enalapril  on  Effect  on  NT-proBNP  in  Patients Stabilized  from  an  Acute  Heart  Failure  Episode] trial  and  24%  in  the  TRANSITION  [Comparison of Pre- and Post-discharge Initiation of Sacubitril/ Valsartan  Therapy  in  HFrEF  Patients  After  an Acute  Decompensation  Event]  trial)  and  have shown  similar  efficacy  and  safety  in  treatmentnaïve  patients. 2,3   The  PIONEER-HF  trial  showed that ARNi reduced NT-proBNP levels in patients hospitalized for acute decompensated HF without increased rates of adverse events (worsening renal

function,  hyperkalemia,  symptomatic  hypotension, angioedema) when compared with enalapril. 3 Additional outcome analyses suggested reduction in all-cause mortality and rehospitalization for HF but were only hypothesis-generating as exploratory study  endpoints.  In  the  open-label  TRANSITION trial,  patients  with  HFrEF  hospitalized  with  worsening  HF  were  randomized  to  start  ARNi  either before or after discharge. 2  Safety outcomes were similar for both arms, suggesting that early initiation may simplify management (rather than initiating and uptitrating ACEi first and then switching to ARNi). 2 ARNi should be initiated de novo in patients hospitalized with acute HFrEF before discharge in the absence of contraindications. ARNi may be initiated de novo in patients with chronic symptomatic HFrEF to simplify management, although data are limited. The PARADISE-MI (Prospective ARNi vs ACE Inhibitor Trial to DetermIne Superiority in Reducing Heart Failure Events After MI) trial 40 will provide information on whether sacubitril-valsartan will significantly reduce the rate of cardiovascular death, HF hospitalization or outpatient HF requiring treatment in patients after acute MI, with L VEF ≤ 40% and/or pulmonary congestion, and 1 of 8 additional risk-enhancing factors like AF, previous MI, diabetes, compared with the ACEi ramipril; and whether the safety and tolerability of sacubitril-valsartan was comparable to that of ramipril. Thus, at the present time, the efficacy of ARNi in patients with LV dysfunction, and HF in the early post-MI period, remains uncertain.

2. ACEi reduce morbidity and mortality in HFrEF. RCTs clearly  establish  the  benefits  of  ACE  inhibition  in patients with mild, moderate, or severe symptoms of HF and in patients with or without CAD. 6-11 Data suggest that there are no differences among available ACEi in their effects on symptoms or survival. 12 ACEi should be started at low doses and titrated upward to doses shown to reduce the risk of cardiovascular events in clinical trials.  ACEi can produce angioedema and should be given with caution to patients with low systemic blood pressures, renal insufficiency,  or  elevated  serum  potassium  (&gt;5.0 mEq/L). If maximal doses are not tolerated, intermediate doses should be tried; abrupt withdrawal of ACE inhibition can lead to clinical deterioration and should be avoided. Although the use of an ARNi in lieu of an ACEi for HFrEF has been found to be superior, for those patients for whom ARNi is inappropriate, continued use of an ACEi for all classes of HFrEF remains strongly advised.
3. ARB  have  been  shown  to  reduce  mortality  and HF  hospitalizations  in  patients  with  HFrEF  in large  RCTs. 14-16   Long-term  treatment  with  ARB in  patients  with  HFrEF  produces  hemodynamic,

neurohormonal, and clinical effects consistent with  those  expected  after  interference  with  the renin-angiotensin  system. 17,18   Unlike  ACEi,  ARB do not inhibit kininase and are associated with a much lower incidence of cough and angioedema, although kininase inhibition by ACEi may produce beneficial  vasodilatory  effects.  Patients  who  are intolerant  to  ACEi  because  of  cough  or  angioedema should be started on an ARB. ARB should be started at low doses and titrated upward, with an attempt to use doses shown to reduce the risk of cardiovascular events in clinical trials. ARB should be given with caution to patients with low systemic blood  pressure,  renal  insufficiency,  or  elevated serum potassium (&gt;5.0 mEq/L). Although ARB are alternatives for patients with ACEi-induced angioedema, caution is advised because some patients have  also  developed  angioedema  with  ARB.  For those patients for whom an ACEi or ARNi is inappropriate, use of an ARB remains advised.

4. Several  cost-effectiveness  analyses  consistently found  that  ACEi  therapy  provides  high  value  for patients with chronic HF. A model-based analysis, using generic ACEi costs, found ACEi therapy was high  value. 19 Previous  analyses  also  found  ACEi therapy was high value despite previously higher ACEi  costs. 19,21,22,24,25 This  includes  a  trial-based analysis  of  SOL VD  (Studies  of  Left  Ventricular Dysfunction) that modeled long-term outcomes. 21 Previous analyses included a range of clinical scenarios  including  asymptomatic  L V  dysfunction 24 and LV dysfunction after MI, 25 with  ACEi  therapy providing high value in each. There are limited data on the cost-effectiveness of ARBs from 2 clinical trials-a within-trial analysis of Val-HeFT (Valsartan Heart Failure Trial) 23  and an analysis of the ELITE (Evaluation  of  Losartan  in  the  Elderly)  study 20 which both suggested ARB therapy is high value. The high value of ARB therapy is also supported by  its  similar  efficacy  as  ACEi  therapy  and  the low-cost  generic  availability  for  both  medication classes.
5. Patients  with  chronic  stable  HFrEF  who  tolerate  ACEi  and  ARB should be switched to ARNi. In  patients  with  mild-to-moderate  HF  who  were able to tolerate both a target dose of enalapril (10 mg twice  daily)  and  then  subsequently  an  ARNi (sacubitril-valsartan;  200  mg twice daily, with the ARB component equivalent to valsartan 160 mg), hospitalizations  and  mortality  were  significantly decreased with the valsartan-sacubitril compound compared with enalapril. 1  Another RCT and metaanalysis  showed  improvement  in  L V  remodeling parameters with ARNi compared with enalapril. 4,5
6.  Multiple model-based analyses evaluated the economic value of ARNi therapy compared with ACEi

therapy using the results of PARADIGM-HF. 26-29,41 Three high-quality analyses 26,28,29 consistently found costs per QAL Y &lt;$60 000, which provides high value according to the benchmarks adopted for  the  current  clinical  practice  guideline.  These results were robust to the range of sacubitril-valsartan costs currently seen in care. These results were  sensitive  to  the  estimated  mortality  reduction and duration of treatment effectiveness. ARNi would need to maintain effectiveness beyond the PARADIGM-HF study period (mean, 27 months) to  be  considered  high  value. 29 If  clinical  benefit were limited to 27 months, ARNi would be intermediate value.  One  additional  analysis,  based  on the PIONEER-HF trial, found that inpatient initiation  of  ARNi  was also high value compared with delayed initiation postdischarge. 27

7. Oral neprilysin inhibitors, used in combination with ACEi,  can  lead  to  angioedema,  and  concomitant use  is  contraindicated  and  should  be  avoided.  A medication that represented a neprilysin inhibitor and  an  ACEi-omapatrilat-was  studied  in  hypertension  and  HF,  but  its  development  was  terminated  because  of  an  unacceptable  incidence  of angioedema. 30,31 and  associated  significant  morbidity.  This  adverse  effect  was  thought  to  occur because  ACEi  and  neprilysin  break  down  bradykinin, which can directly or indirectly cause angioedema 31,32 An  ARNi  should  not  be  administered within 36 hours of switching from or to an ACEi.
8. Omapatrilat,  a  neprilysin  inhibitor  (as  well  as  an ACEi and aminopeptidase P inhibitor), was associated  with  a  higher  frequency  of  angioedema than that seen with enalapril in an RCT of patients with  HFrEF. 30 In  a  very  large  RCT  of  hypertensive  patients,  omapatrilat  was  associated  with  a 3-fold  increased  risk  of  angioedema  compared with  enalapril. 31 Black  patients  and  patients  who smoked  were  particularly  at  risk.  The  high  incidence of angioedema ultimately led to cessation of the clinical development  of  omapatrilat. 33,34 Because of these observations, angioedema was an exclusion criterion in the first large trial assessing  ARNi  therapy  in  patients  with  hypertension 35 and then in the large trial that showed clinical benefit of ARNi therapy in HFrEF. 1 The rates of angioedema were numerically higher in patients treated with  ARNi  than  in  patients  treated  with  ACEi  in PARADIGM-HF,  although  this  difference  did  not reach  significance. 1 ARNi  therapy  should  not  be administered  in  patients  with  a  history  of  angioedema because of the concern that it will increase the risk of a recurrence of angioedema.
9. Angioedema  attributable  to  ACEi  is  thought  to result from defective degradation of the vasoactive peptides  bradykinin,  des-Arg9-BK  (a  metabolite

of  bradykinin),  and  substance  P. 36,37 ACEi  should not be administered to patients with any history of angioedema, but ARB do not interfere as directly with bradykinin metabolism and have been associated with low rates of angioedema. 38,39

## 7.3.2. Beta Blockers

| Recommendation for Beta Blockers Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Beta Blockers Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Beta Blockers Referenced studies that support the recommendation are summarized in the Online Data Supplements.                                                                                                                             |
|--------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                  | LOE                                                                                                                                  | Recommendation                                                                                                                                                                                                                                                 |
| 1                                                                                                                                    | A                                                                                                                                    | 1. In patients with HFrEF, with current or previ- ous symptoms, use of 1 of the 3 beta blockers proven to reduce mortality (eg, bisoprolol, carvedilol, sustained-release metoprolol succi- nate) is recommended to reduce mortality and hospitalizations. 1-3 |
| Value Statement: High Value (A)                                                                                                      | Value Statement: High Value (A)                                                                                                      | 2. In patients with HFrEF, with current or previous symptoms, beta-blocker therapy provides high economic value. 4-8                                                                                                                                           |

## Synopsis

Treatment with beta blockers reduces the risk of death and the combined risk of death or hospitalization in patients with HFrEF. 1-3 In  addition, this treatment can improve  L VEF,  lessen  the  symptoms  of  HF,  and  improve clinical status. 1-3,9-11 Clinical trials  have  shown  that beta blockers should be prescribed to all patients when HFrEF is diagnosed, including in-hospital, unless contraindicated or not tolerated. 1-3,9-11 These benefits of beta blockers were observed in patients with or without CAD, and in patients with or without diabetes, older patients, as well as in women and across racial and ethnic groups but not in patients with AF. 1-3,10-12  Even if symptoms do not improve, long-term treatment should be maintained to reduce the risk of major cardiovascular events. Beta blockers should be initiated at low doses, and every effort should be made to achieve the target doses of the beta blockers shown to be effective in major clinical trials, as tolerated 1-3,9,10 (see Section 7 .3.8, 'GDMT Dosing, Sequencing and Uptitration').

## Recommendation-Specific Supportive Text

1.  Three beta blockers have been shown to be effective in reducing the risk of death in patients with HFrEF:  bisoprolol,  sustained-release  metoprolol (succinate),  and  carvedilol. 1-3 The  favorable  findings with these 3 agents, however, should not be considered a beta-blocker class effect  in  HFrEF. Other beta blockers are not included in this recommendation for use. 13-15  Even when asymptomatic,  or  when  symptoms are mild or improve with other therapies, beta-blocker therapy is important and should not be delayed until symptoms return or disease progression is documented. 16  Data show that  beta  blockers  can  be  safely  initiated  before

hospital discharge, provided patients are clinically stabilized and do not require intravenous inotropic therapy  for  HF. 17 If  a  contraindication  or  intolerance are noted, they should be documented, and the patient restarted on beta-blocker therapy in the future, so long as an absolute contraindication is not  present.  Even  if  symptoms  or  L VEF  improve, long-term treatment with beta blockers and use of target doses should be maintained to reduce the risk of progression in L V dysfunction or major cardiovascular events. 18,19  Abrupt withdrawal of betablocker  therapy  can  lead  to  clinical  deterioration and should be avoided unless indicated. 18

2. Multiple  analyses  have  shown  the  high  value  of beta-blocker therapy among HF patients. A modelbased analysis, using generic beta-blocker costs, found beta-blocker therapy was high value. 4  These results  were  consistent  with  earlier  model-based cost-effectiveness  analyses 5-7 and  a  trial-based economic  analysis  of  the  US  Carvedilol  Heart Failure (CHF) Trials Program. 8  Each of these studies also found treatment with a beta blocker was high  value  despite  using  previously  higher  betablocker costs.

## 7.3.3. Mineralocorticoid Receptor Antagonists (MRAs)

| Recommendations for Mineralocorticoid Receptor Antagonists (MRAs) Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Mineralocorticoid Receptor Antagonists (MRAs) Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Mineralocorticoid Receptor Antagonists (MRAs) Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                                                                                                                                                          |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                      | LOE                                                                                                                                                                      | Recommendations                                                                                                                                                                                                                                                                                                                                                                                                                 |
| 1                                                                                                                                                                        | A                                                                                                                                                                        | 1. In patients with HFrEF and NYHA class II to IV symptoms, an MRA (spironolactone or eplere- none) is recommended to reduce morbidity and mortality, if eGFR is >30 mL/min/1.73 m 2 and serum potassium is <5.0 mEq/L. Careful moni- toring of potassium, renal function, and diuretic dosing should be performed at initiation and closely monitored thereafter to minimize risk of hyperkalemia and renal insufficiency. 1-3 |
| Value Statement: High Value (A)                                                                                                                                          | Value Statement: High Value (A)                                                                                                                                          | 2. In patients with HFrEF and NYHA class II to IV symptoms, MRA therapy provides high eco- nomic value. 4-7                                                                                                                                                                                                                                                                                                                     |
| 3: Harm                                                                                                                                                                  | B-NR                                                                                                                                                                     | 3. In patients taking MRA whose serum potas- sium cannot be maintained at <5.5 mEq/L, MRA should be discontinued to avoid life- threatening hyperkalemia. 8,9                                                                                                                                                                                                                                                                   |

## Synopsis

MRA (also known as aldosterone antagonists or anti-mineralocorticoids) show consistent improvements in all-cause mortality, HF hospitalizations, and SCD across a wide range of patients with HFrEF. 1-3 Patients at risk for renal dysfunction  or  hyperkalemia require close monitoring, and eGFR ≤ 30  mL/min/1.73  m 2   or  serum  potassium ≥ 5.0  mEq/L are contraindications to MRA initiation. 10,11  Because of the higher selectivity of eplerenone for the aldosterone receptor, adverse effects such as gynecomastia and vaginal bleeding

are observed less often in patients who take eplerenone than in those who take spironolactone.

## Recommendation-Specific Supportive Text

1.  Clinical  trials  taken  on  MRA  together-RALES (Randomized  Aldactone  Evaluation  Study) 1   randomized  highly  symptomatic  patients  with  L VEF ≤ 35%; EPHESUS (Eplerenone Post-Acute Myocardial  Infarction  Heart  Failure  Efficacy  and Survival Study) 2  randomized patients post-MI with LVEF ≤ 40%; and EMPHASIS-HF (Eplerenone in Mild  Patients  Hospitalization  and  Survival  Study in  Heart  Failure) 3 randomized  patients  with  mild symptoms and LVEF ≤ 30%-suggest a benefit of MRA across the spectrum of HFrEF, inclusive of a wide range of etiologies and disease severities. Initiation  in  the  ambulatory  or  hospital  setting  is appropriate. 12  The starting dose of spironolactone and eplerenone is 25 mg orally daily, increased to 50 mg daily orally after a month; for eGFR 31 to 49  mL/min/1.73  m 2 ,  dosing  should  be  reduced by half. Regular checks of serum potassium levels and  renal  function  should  be  performed  according to clinical status, approximately 1 week, then 4 weeks, then every 6 months after initiating or intensifying MRA, with more frequent testing for clinical instability. We elected to remove the 2013 recommendation 'Aldosterone  receptor  antagonists  are recommended  to  reduce  morbidity  and  mortality following an acute MI in patients who have L VEF of 40% or less who develop symptoms of HF or who have a history of diabetes mellitus, unless contraindicated' because the new recommendation covers the spectrum of symptomatic patients with HF.
2.  The economic value of MRA therapy was assessed by  both  RCTs  (RALES 5   and  EPHESUS 6,7 )  and  a model-based analysis. 4  The model-based analysis used generic MRA costs and found therapy was high value with a cost per QAL Y of under $1000. 4 The earlier trial-based economic analyses of MRAs from RALES and EPHESUS also found MRA therapy was high value despite using previously higher MRA costs. 5-7
3. Spironolactone and eplerenone are partially excreted  through  the  kidneys,  raising  concerns about  safety  when  eGFR  is ≤ 30  mL/min/1.73 m 2 . 10,11   Spironolactone  and  eplerenone  decrease renal potassium excretion, raising the risk of hyperkalemia,  particularly  when  MRA  is  initiated at  serum  potassium ≥ 5.0  mEq/L  and  continued ≥ 5.5 mEq/L. The incidence of clinically significant hyperkalemia events was &lt;1% in EPHESUS and EMPHASIS-HF,  without  a  significant  difference between eplerenone and placebo. 2,3  however, in the closely monitored setting of a RCT with enrollment

of  younger  patients  with  fewer  multiple  chronic conditions than seen in the general HFrEF population, safety may be overstated. Observational data have  raised  concerns  about  less  favorable  outcomes of MRA use for HFrEF during usual care. 8,9 Coadministration of MRA with ACEi or ARB mildly increases  the  risk  of  hyperkalemia.  Hyperkalemia risk was lower with ARNi in patients with chronic HF in the PARADIGM-HF trial 13  but not different in patients with HF who were decompensated in the PIONEER-HF  trial 14   when  compared  with  ACEi. Diarrhea causing dehydration or loop diuretic therapy interruption, because of worsening renal function or hyperkalemia, should be a consideration for temporarily holding the MRA. The development of worsening renal function or hyperkalemia is often a reflection of acute clinical change or progressive disease, prompting careful evaluation of the entire medical regimen and other causes of hyperkalemia, in addition to holding the MRA. The efficacy of the use of potassium binders (eg, patiromer, sodium zirconium cyclosilicate) to improve outcomes by facilitating continuation of MRA is uncertain 15,16 and is addressed in Section 7 .3.6, 'Other Drug Treatment.'

## 7.3.4. Sodium-Glucose Cotransporter 2 Inhibitors

| Recommendation for SGLT2i Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for SGLT2i Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for SGLT2i Referenced studies that support the recommendation are summarized in the Online Data Supplements.                                                                   |
|-------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                           | LOE                                                                                                                           | Recommendation                                                                                                                                                                                |
| 1                                                                                                                             | A                                                                                                                             | 1. In patients with symptomatic chronic HFrEF, SGLT2i are recommended to reduce hospital- ization for HF and cardiovascular mortality, irre- spective of the presence of type 2 diabetes. 1,2 |
| Value Statement: Intermediate Value (A)                                                                                       | Value Statement: Intermediate Value (A)                                                                                       | 2. In patients with symptomatic chronic HFrEF, SGLT2i therapy provides intermediate eco- nomic value. 3,4                                                                                     |

## Synopsis

Several  RCTs  in  patients  with  type  2  diabetes  and  either established CVD or high risk for CVD have shown that SGLT2i prevent HF hospitalizations compared with placebo. 5-7  The overall 31% reduction in HF hospitalizations was noted irrespective of the presence or absence of  preexisting  HF,  although  only  10%  to  14%  of  participants  had  HF  at  baseline.  The  benefit  appears  independent of the glucose-lowering effects. 8  Therefore, several trials were launched to examine the efficacy of SGLT2i on outcomes in patients with HF, irrespective of the presence of type 2 diabetes. The DAPA-HF (Dapagliflozin  and Prevention of Adverse Outcomes in Heart Failure)  trial  and  EMPEROR-Reduced  (EMPagliflozin outcomE  tRial  in  Patients  With  chrOnic  heaRt  Failure With Reduced Ejection Fraction) showed the benefit of SGLT2i  (dapagliflozin  and  empagliflozin,  respectively) versus placebo on outcomes (median follow-up, 16-18

months). 1,2 Patients  enrolled  had  symptomatic  chronic HFrEF (LVEF ≤ 40%, NYHA class II to IV, and elevated natriuretic peptides) and were already on GDMT. Important exclusions were eGFR &lt;20 (EMPEROR-Reduced) or &lt;30 mL/min/1.73 m 2  (DAPA-HF), type 1 diabetes, or lower SBP &lt;95 to 100 mm Hg.

## Recommendation-Specific Supportive Text

1.  In  the  DAPA-HF  and  EMPEROR-Reduced  trials,  SGL T2i  compared  with  placebo  reduced  the composite  of  cardiovascular  death  or  HF  hospitalization by approximately 25%. 1,2,9 The benefit in reduction of HF hospitalization was greater (30%) in  both  trials. 9 Risk  of  cardiovascular  death  was significantly  lowered  (18%)  with  dapagliflozin,  as was  risk  of  all-cause  mortality  (17%).  Although no significant cardiovascular mortality benefit was observed  with  empagliflozin  in  a  meta-analysis of DAPA-HF and EMPEROR-Reduced  trials, SGLT2i therapy was associated with a reduction in  all-cause  mortality  and  cardiovascular  death. 9 The benefits in both trials were seen irrespective of  baseline  diabetes  status.  Furthermore,  serious renal  outcomes  were  less  frequent,  and  the  rate of decline in eGFR was slower in patients treated with  SGLT2i. 1,2,9 In  the  SOLOIST-WHF  (Effect  of Sotagliflozin on Cardiovascular Events in Patients With T ype 2 Diabetes And Worsening Heart Failure) trial, patients with diabetes and HF hospitalization (79%:  LVEF,  &lt;50%)  were  enrolled  before  discharge or within 3 days of discharge. Sotagliflozin, a dual inhibitor of sodium-glucose co-transporters 1 and 2, reduced the combined endpoint of cardiovascular  death,  HF  hospitalization,  or  urgent HF visits by 33% 10  but has not been approved by the US Food and Drug Administration (FDA) as of 2021. Although SGLT2i increased risk for genital infections, they were otherwise well tolerated in the trials. As the use of SGL T2i is translated into clinical  practice,  caution  is  warranted  for  euglycemic ketoacidosis, genital and soft tissue infections, and adjustment of diuretics, if needed, to prevent volume depletion. 11
2.  Two model-based analyses evaluated the economic value of dapagliflozin therapy compared with usual care based on the results of the DAPA-HF trial. 3,4 Both  analyses  found  costs  per  QAL Y  between $60 000  and  $90 000,  which  is  consistent  with intermediate  value  according  to  the  benchmarks adopted for the current guideline. The results were most sensitive to the magnitude of cardiovascular mortality reduction, with a ≥ 8% reduction in cardiovascular mortality necessary for a cost per QAL Y below  $150 000  in  1  study. 3 There  are  a  wide range  of  costs  currently  seen  with  dapagliflozin.

These 2 analyses estimated a cost per QAL Y below $50 000 with annual dapagliflozin costs of $3240 (43%  reduction  from  main  analysis)  and  $2500 (40% reduction from main analysis), respectively. 3,4 A smaller reduction in drug cost would lead to a cost per QAL Y of under $60  000, the threshold for high value in this guideline.

## 7.3.5. Hydralazine and Isosorbide Dinitrate

| Recommendations for Hydralazine and Isosorbide Dinitrate Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Hydralazine and Isosorbide Dinitrate Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Hydralazine and Isosorbide Dinitrate Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                                         |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                             | LOE                                                                                                                                                             | Recommendations                                                                                                                                                                                                                                                                                       |
| 1                                                                                                                                                               | A                                                                                                                                                               | 1. For patients self-identified as African American with NYHA class III-IV HFrEF who are receiv- ing optimal medical therapy, the combination of hydralazine and isosorbide dinitrate is rec- ommended to improve symptoms and reduce morbidity and mortality. 1,2                                    |
| Value Statement: High Value (B-NR)                                                                                                                              | Value Statement: High Value (B-NR)                                                                                                                              | 2. For patients self-identified as African Ameri- can with NYHA class III to IV HFrEF who are receiving optimal medical therapy with ACEi or ARB, beta blockers, and MRA, the combination of hydralazine and isosorbide dinitrate provides high economic value. 3                                     |
| 2b                                                                                                                                                              | C-LD                                                                                                                                                            | 3. In patients with current or previous symp- tomatic HFrEF who cannot be given first-line agents, such as ARNi, ACEi, or ARB, because of drug intolerance or renal insufficiency, a combination of hydralazine and isosorbide dini- trate might be considered to reduce morbidity and mortality. 4,5 |

## Synopsis

Two  RCTs,  V-HeFT  I  (Vasodilator  Heart  Failure  Trial) and A-HeFT (African-American Heart Failure Trial), established benefit of the combination of hydralazine-isosorbide  dinitrate  in  self-identified  African  Americans. 2,4 A-HeFT was terminated  early  because  of  evidence  of remarkable benefit, but the result is vulnerable to a small number of events and the exigencies of early cessation of RCTs. 2 The benefit in both trials was seen only at doses achieved in those trials that are higher than doses typically used in clinical practice and with short-acting nitrate therapy. 2,4  Uptake of this regimen has been modest as a result of the complexity of the medical regimen and the array of drug-related adverse effects. 5   Even when prescribed, there is marked underusage based on very low prescription refill rates. Race-based medical therapy remains a challenging issue, as well, with ongoing research now focused on biological  hypotheses,  particularly  absence of European ancestry, which may be associated with responsiveness to this combination. There are insufficient  data  to  guide  the  use  of  hydralazine-isosorbide dinitrate with ARNi. In patients with HFrEF who cannot receive first-line agents such as ARNi, ACEi, or ARB, referral to a HF specialist can provide guidance for further management because the use of hydralazine and isosorbide dinitrate in these patients is uncertain.

## Recommendation-Specific Supportive Text

1. In  a  large-scale  trial  that  compared  the  vasodilator combination with placebo, the use of hydralazine  and  isosorbide  dinitrate  reduced  mortality  in patients with HF treated with digoxin and diuretics but  not  an  ACEi  or  beta  blocker. 4 However,  in  2 other trials that compared the vasodilator combination with an ACEi, the ACEi produced more favorable effects on survival. 6,7 A post hoc retrospective analysis of these vasodilator trials showed particular efficacy of isosorbide dinitrate and hydralazine in  the  African  American cohort. 1 In  a  subsequent trial,  which  was  limited  to  patients  self-identified as African American, the addition of a fixed-dose combination  of  hydralazine  and  isosorbide  dinitrate to standard therapy with an ACEi or ARB, a beta blocker, and MRA offered significant benefit. 2 Thus,  the  combination  of  hydralazine  and  isosorbide dinitrate is appropriate for African Americans with HFrEF who remain symptomatic despite concomitant use of ACEi (or ARB), beta blockers, and MRA. There are insufficient data for concomitant use with ARNi.
2.  The economic value of hydralazine and isosorbide nitrate therapy was assessed by the A-HeFT trial. 3 This  analysis  found  hydralazine  and  isosorbide dinitrate  increased  survival  and  reduced  health care costs over the 12.8-month trial. Extrapolating beyond the trial, the analysis found hydralazine and isosorbide dinitrate remained high value over a lifetime  with  a  cost  per  life-year  &lt;$60  000  despite conservative  assumptions  regarding  the  durability  of  therapy effectiveness and previously higher hydralazine and isosorbide dinitrate costs.
3. It is unclear if a benefit of hydralazine-isosorbide dinitrate  (suggested  in  a  trial  before  the  use  of ACEi) 4   exists  for  non-African  Americans  with HFrEF.  Despite  the  lack  of  data  with  the  vasodilator  combination  in  patients  who  are  intolerant  of  ACEi  or  ARB,  especially  those  with  renal insufficiency,  the  combined  use  of  hydralazine and  isosorbide  dinitrate  might  be  considered  as a  therapeutic  option  in  such  patients.  Although the  potential  benefit  is  unknown  and  has  not been shown in recent observational datasets, 5  in V-HeFT I,  the  use  of  hydralazine  and  isosorbide dinitrate  reduced  mortality  in  patients  with  HF treated with digoxin and diuretics, compared with placebo. 4 If  patients  are  unable  to  tolerate  firstline agents, such as ARNi, ACEi, or ARB, because of  drug  intolerance,  hypotension,  or  renal  insufficiency,  referral  to  a  HF  specialist  can  provide guidance  for  further  management,  and  the  use of  hydralazine  and  isosorbide  dinitrate  in  these patients might be considered.

## 7.3.6. Other Drug Treatment

| Recommendations for Other Drug Treatment Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Other Drug Treatment Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Other Drug Treatment Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                                                                                                |
|-------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                             | LOE                                                                                                                                             | Recommendations                                                                                                                                                                                                                                                                                                                              |
| 2b                                                                                                                                              | B-R                                                                                                                                             | 1. In patients with HF class II to IV symptoms, omega-3 polyunsaturated fatty acid (PUFA) supplementation may be reasonable to use as adjunctive therapy to reduce mortality and car- diovascular hospitalizations. 1-4                                                                                                                      |
| 2b                                                                                                                                              | B-R                                                                                                                                             | 2. In patients with HF who experience hyperkale- mia (serum potassium level ≥ 5.5 mEq/L) while taking a renin-angiotensin-aldosterone system inhibitor (RAASi), the effectiveness of potas- sium binders (patiromer, sodium zirconium cyclosilicate) to improve outcomes by facilitat- ing continuation of RAASi therapy is uncer- tain. 5,6 |
| 3: No Benefit                                                                                                                                   | B-R                                                                                                                                             | 3. In patients with chronic HFrEF without a spe- cific indication (eg, venous thromboembolism [VTE], AF, a previous thromboembolic event, or a cardioembolic source), anticoagulation is not recommended. 7-9                                                                                                                                |

## Synopsis

Trials  in  prevention  of  CVD,  including  HF,  showed  that omega-3  PUFA  supplementation  results  in  a  10%  to 20% risk reduction in fatal and nonfatal cardiovascular events  when  used  with  other  evidence-based  therapies. 2,3,10   Hyperkalemia is common in HF and can lead to  arrhythmias  and  underuse  of  GDMT. 11,12 Two  newer gastrointestinal potassium-binding agents-patiromer and  sodium  zirconium  cyclosilicate-have  been  shown to  lower  potassium levels and enable treatment with a RAASi in patients with HF. 5,6,13

## Recommendation-Specific Supportive Text

1.  Supplementation  with  omega-3  PUFA  has  been evaluated  as  an  adjunctive  therapy  for  CVD  and HF. 14  The GISSI-HF (Effect of n-3 polyunsaturated fatty  acids  in  patients  with  chronic  heart  failure) trial  showed a reduction in death among post-MI patients taking 1 g of omega-3 PUFA (850-882 mg of eicosapentaenoic acid  [EPA]  and  docosahexaenoic acid [DHA] as ethyl esters in the ratio of 1:1.2). 10  A post hoc subgroup analysis revealed that this reduction in mortality and SCD was concentrated in the approximately 2000 patients with reduced LVEF. 10  The GISSI-HF investigators randomized symptomatic patients with HF to 1 g daily of  omega-3  PUFA  (850-882  mg  of  EPA-DHA) or  placebo.  Death  from  any  cause  was  reduced from 29% with placebo to 27% in those treated with  omega-3  PUFA. 2   The  outcome  of  death  or admission  to  hospital  for  a  cardiovascular  event was  also  significantly  reduced.  The  REDUCE-IT trial  randomized  patients  with  established  CVD

or  diabetes  with  risk  factors  to  2  g  of  icosapent ethyl (a highly purified EPA) twice daily or placebo and showed a reduced risk for the composite of cardiovascular death, nonfatal MI, nonfatal stroke, coronary revascularization, or unstable angina. 3 In reported studies, omega-3 PUFA therapy has been well  tolerated.  Recent  studies  have  reported  that in  patients  with  cardiovascular  risk  treated  with omega-3 fatty acid, there may be a dose-related risk of AF. 3,15,16

2. Hyperkalemia  is  common  in  HF  as  a  result  of the syndrome itself, comorbidities (diabetes, CKD), and use of RAASi, and can increase the risk  for  ventricular  arrhythmias  and  mortality. 11 Hyperkalemia  results  in  dose  reductions  or  discontinuation of RAASi, compromising their cardiorenal benefit in HF. 12   Two newer gastrointestinal potassium binders-patiromer (RLY5016) and sodium zirconium cyclosilicate (SZC)-remove potassium by exchanging cations (calcium for patiromer, and sodium and hydrogen for SZC), leading to increased fecal excretion. Both agents have been FDA approved for treatment of hyperkalemia for  patients  receiving  RAASi.  In  the  PEARL-HF (Evaluation of the efficacy and safety of RL Y5016, a  polymeric  potassium  binder  in  patients  with chronic heart failure) trial, patiromer led to lower potassium levels, less hyperkalemia, and a higher proportion of patients able to increase spironolactone dose to 50 mg daily compared with placebo. 5 The  HARMONIZE  (Hyperkalemia  Randomized Intervention  Multidose  ZS-9  Maintenance)  trial included 94 patients (out of 258 total) with HF (87 of whom entered the double-blind phase). 6,13 The  SZC  groups  achieved  lower  potassium  levels overall compared with placebo, and a higher proportion  maintained  normokalemia  (potassium levels,  &lt;5.1  mEq/L).  Whether patiromer or SZC improve clinical outcomes is under investigation. Adverse  effects  for  the  newer  potassium  binders include hypomagnesemia (for patiromer) and edema (for SZC).
3. In several retrospective analyses, the risk of thromboembolic events was not lower in patients  with HF taking warfarin than in patients not treated with antithrombotic drugs. 17-19  The use of warfarin was associated with a reduction in major cardiovascular events and death in patients with HF in some studies but not in others. 20-22   An RCT that compared the  outcome  of  patients  with  HFrEF  assigned to  aspirin,  warfarin,  or  clopidogrel  found  that  no therapy was superior. 7 Another trial that compared aspirin with warfarin in patients with reduced L VEF, sinus rhythm, and no cardioembolic source showed no  difference  in  either  the  primary  outcome  of death, stroke, or intracerebral hemorrhage, and no

difference in the combined outcome of death, ischemic stroke, intracerebral hemorrhage, MI, or HF hospitalization. 8 There  was  a  significant  increase in major bleeding with warfarin. A trial of rivaroxaban in patients with HFrEF, CAD, and normal sinus rhythm showed no difference in mortality, MI, and stroke compared with placebo. 9  Therefore, there is no  evidence  of  benefit  for  anticoagulation  in  HF patients without a specific indication (eg, VTE, AF, a previous thromboembolic event, or a cardioembolic source).

## 7.3.7. Drugs of Unproven Value or That May Worsen HF

| Recommendations for Drugs of Unproven Value or Drugs That May Worsen HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Drugs of Unproven Value or Drugs That May Worsen HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Drugs of Unproven Value or Drugs That May Worsen HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                            |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                            | LOE                                                                                                                                                                            | Recommendations                                                                                                                                                                                                                         |
| 3: No Benefit                                                                                                                                                                  | A                                                                                                                                                                              | 1. In patients with HFrEF, dihydropyridine calcium channel-blocking drugs are not recommended treatment for HF. 1,2                                                                                                                     |
| 3: No Benefit                                                                                                                                                                  | B-R                                                                                                                                                                            | 2. In patients with HFrEF, vitamins, nutritional supplements, and hormonal therapy are not recommended other than to correct specific deficiencies. 3-9                                                                                 |
| 3: Harm                                                                                                                                                                        | A                                                                                                                                                                              | 3. In patients with HFrEF, nondihydropyridine calcium channel-blocking drugs are not recom- mended. 10-13                                                                                                                               |
| 3: Harm                                                                                                                                                                        | A                                                                                                                                                                              | 4. In patients with HFrEF, class IC antiarrhythmic medications and dronedarone may increase the risk of mortality. 14-16                                                                                                                |
| 3: Harm                                                                                                                                                                        | A                                                                                                                                                                              | 5. In patients with HFrEF, thiazolidinediones increase the risk of worsening HF symptoms and hospitalizations. 17-21                                                                                                                    |
| 3: Harm                                                                                                                                                                        | B-R                                                                                                                                                                            | 6. In patients with type 2 diabetes and high cardiovascular risk, the dipeptidyl pepti- dase-4 (DPP-4) inhibitors saxagliptin and alogliptin increase the risk of HF hospitaliza- tion and should be avoided in patients with HF. 22-24 |
| 3: Harm                                                                                                                                                                        | B-NR                                                                                                                                                                           | 7. In patients with HFrEF, NSAIDs worsen HF symptoms and should be avoided or withdrawn whenever possible. 25-28                                                                                                                        |

## Synopsis

Although there is strong evidence for benefit with selected medications for HFrEF as outlined in Section 7.3, 'Pharmacological Treatment for HF With Reduced Ejection Fraction (HFrEF),' there remain several classes of medications that have either unproven value or potential  for  harm  (Table  13).  These  recommendations  are not exhaustive but focus on the most relevant and commonly encountered medications in the management of patients with HFrEF: calcium channel blockers; antiarrhythmic agents; NSAIDs; medications for treatment of type 2 diabetes including thiazolidinediones and DPP-4 inhibitors; and vitamins, hormones, and nutritional supplements.

Table 13. Selected Prescription Medications That May Cause or Exacerbate HF

|                                              | Associated With HF                | Associated With HF                            | Magnitude of HF Induction or   | LOE for HF Induction or   |                                                                                                                                           |                           |
|----------------------------------------------|-----------------------------------|-----------------------------------------------|--------------------------------|---------------------------|-------------------------------------------------------------------------------------------------------------------------------------------|---------------------------|
| Drug or Therapeutic Class                    | Causes Direct Myocardial Toxicity | Exacerbates Underlying Myocardial Dysfunction | Precipitation                  | Precipitation             | Possible Mechanism(s)                                                                                                                     | Onset                     |
| COX, nonselective inhibi- tors (NSAIDs)      |                                   | X                                             | Major                          | B                         | Prostaglandin inhibition leading to sodium and water retention, increased systemic vascular resistance, and blunted response to diuretics | Immediate                 |
| COX, selective inhibitors (COX-2 inhibitors) |                                   | X                                             | Major                          | B                         | Prostaglandin inhibition leading to sodium and water retention, increased systemic vascular resistance, and blunted response to diuretics | Immediate                 |
| Thiazolidinediones                           |                                   | X                                             | Major                          | A                         | Possible calcium channel blockade                                                                                                         | Intermediate              |
| Saxagliptin                                  |                                   | X                                             | Major                          | A                         | Unknown                                                                                                                                   | Intermediate to delayed   |
| Alogliptin                                   |                                   | X                                             | Major                          | A                         | Unknown                                                                                                                                   | Intermediate to delayed   |
| Flecainide                                   |                                   | X                                             | Major                          | A                         | Negative inotrope, proarrhythmic effects                                                                                                  | Immediate to intermediate |
| Disopyramide                                 |                                   | X                                             | Major                          | B                         |                                                                                                                                           |                           |
| Sotalol                                      |                                   | X                                             | Major                          | A                         | Proarrhythmic properties, beta blockade                                                                                                   | Immediate to intermediate |
| Dronedarone                                  |                                   | X                                             | Major                          | A                         | Negative inotrope                                                                                                                         |                           |
| Alpha-1 blockers                             | Alpha-1 blockers                  | Alpha-1 blockers                              | Alpha-1 blockers               | Alpha-1 blockers          | Alpha-1 blockers                                                                                                                          | Alpha-1 blockers          |
| Doxazosin                                    |                                   | X                                             | Moderate                       | B                         | Beta-1-receptor stimulation with increas- es in renin and aldosterone                                                                     | Intermediate to delayed   |
| Diltiazem                                    |                                   | X                                             | Major                          | B                         | Negative inotrope                                                                                                                         | Immediate to intermediate |
| Verapamil                                    |                                   | X                                             | Major                          | B                         | Negative inotrope                                                                                                                         | Immediate to intermediate |
| Nifedipine                                   |                                   | X                                             | Moderate                       | C                         | Negative inotrope                                                                                                                         | Immediate to intermediate |

COX indicates cyclo-oxygenase; HF, heart failure; LOE, Level of Evidence; and NSAID, nonsteroidal anti-inflammatory drug. Adapted from Page RL 2nd et al. 57  Copyright 2016 American Heart Association Inc.

## Recommendation-Specific Supportive Text

1.  Second-generation dihydropyridine calcium channel blockers, including amlodipine and felodipine,  have  greater  selectivity  for  calcium channels  in  vascular  smooth  muscle  cells  and less  myocardial  depressant  activity.  By  reducing peripheral vasoconstriction and LV afterload, calcium channel blockers were thought to have a  potential  role  in  the  management  of  chronic HF.  The  PRAISE-1  (Prospective  Randomized Amlodipine Survival Evaluation-1) study showed a reduction in mortality in  the  subgroup  of patients  with  nonischemic  cardiomyopathy  who received amlodipine. 1  However, in the PRAISE-2 (Prospective Randomized  Amlodipine  Survival Evaluation  2)  trial,  which  enrolled  only  patients with  nonischemic  cardiomyopathy,  no  survival benefit  was  observed,  indicating  the  limitations of conclusions derived from subgroup analyses. 29 However, dihydropyridine calcium channel blockers  may  be  used  for  treatment  of  hypertension in  patients  who  have  elevated  blood  pressure despite optimization of GDMT.
2.  Many nutritional supplements and hormonal therapies  have  been  proposed  for  the  treatment of  HF. 3-9,30,31 Ultimately,  most  studies  are  limited by  small  sample  sizes,  surrogate  endpoints,  or

nonrandomized design. 32,33 In addition, adverse effects  and  drug-nutraceutical  interactions  remain unresolved. There is a lack of evidence of benefit from  vitamin  D, 3-5 thiamine, 34-36 carnitine, 37 and taurine 38,39 and  potential  harm  from  vitamin  E. 6,7 The  largest  RCT  of  coenzyme  Q10-Q-SYMBIO (Coenzyme Q10 as adjunctive treatment of chronic heart  failure  with  focus  on  SYMptoms,  BIomarker status  [Brain-Natriuretic  Peptide],  and  long-term Outcome  [hospitalisations/mortality])-showed  no changes  in  NYHA  functional  classification  at  16 weeks,  although  the  incidence  of  major  adverse cardiovascular  events  at  2  years  was  significantly reduced  (hazard  ratio,  0.50;  95%  CI,  0.32-0.80; P =0.003). 8  Despite these findings, concerns about slow recruitment in this trial have tempered enthusiasm for coenzyme Q10 supplementation in clinical practice. 9,31   Hormonal therapies have been proposed for the treatment of HF, but trials have shown a neutral effect of testosterone, 40,41 growth hormone, 30,42 and thyroid hormone 43-45  in HF outcomes.

3.  Nondihydropyridine calcium channel blockers-diltiazem and verapamil-are myocardial depressants and generally not well tolerated in HF. Verapamil had no impact of survival or major cardiac events post-MI,  including  in  those  patients  with  HFrEF after  acute  MI. 10 In  patients  with  nonischemic

cardiomyopathy, diltiazem had no impact on mortality 13 but, in HFrEF after acute MI, diltiazem was associated with a higher risk of recurrent HF. 11,12

4. In  the  CAST  (Cardiac  Arrhythmia  Suppression) trial, patients with asymptomatic ventricular arrhythmias  post-MI  on  the  class  IC  antiarrhythmics encainide or flecainide had increased mortality. 14 The applicability of CAST to patients without recent MI or to other class I antiarrhythmic drugs is  uncertain,  but  class  IC  antiarrhythmic  agents are  generally  avoided  in  patients  with  structural heart  disease.  In  ANDROMEDA  (Antiarrhythmic Trial  with  Dronedarone  in  Moderate  to  Severe CHF  Evaluating  Morbidity  Decrease  Study),  for the  class  III  antiarrhythmic  dronedarone,  patients with HFrEF who were hospitalized had increased mortality. 16   In  the  SWORD  (Survival  With  ORal D-sotalol) trial of the class III antiarrhythmic sotalol, patients with HF post-MI had increased mortality. 15 However,  SWORD  was  published  in  1996,  and whether  sotalol  would  be  harmful  in  the  current era of GDMT and ICDs is uncertain; sotalol may be  used  for  refractory  atrial-ventricular  arrhythmias  with  close  monitoring  for  decompensation. Amiodarone 46,47 and dofetilide 48,49 are the only antiarrhythmic agents with neutral effects on mortality in clinical trials of patients with HFrEF. Class IA antiarrhythmic agents such as quinidine and class IB agents such as mexiletine have not been studied and may be indicated for the management of refractory ventricular arrhythmias in the context of the individual patient's risk benefit calculus and in conjunction with electrophysiology consultation.
5. Thiazolidinediones  increase  insulin  sensitivity  by activating nuclear peroxisome proliferator-activated  receptor  gamma  (PPARγ ).  Expressed  in virtually all tissues, PPARγ also regulates sodium reabsorption in the collecting ducts of the kidney. In  observational  cohort  studies, 17 meta-analysis, 18 and clinical trials, 19-21  thiazolidinediones have been associated with increased incidence of fluid retention  and  HF  events  in  those  patients  with 19,21 or without 18,20 a previous history of HF.
6.  DPP-4 is a cell-surface enzyme that deactivates several peptides include glucose-dependent insulinotropic polypeptide and glucagon-like peptide  1.  DPP-4  inhibitors  affect  glucose  regulation through multiple mechanisms, including  enhancement  of  glucose-dependent  insulin secretion, slowed gastric emptying, and reduction of postprandial glucagon and of food intake. The impact of DPP-4 inhibitors on cardiovascular outcomes in patients with diabetes and high cardiovascular risk has been assessed in multiple RCTs. Saxagliptin  increased  the  risk  of  hospitalization for  HF, 22 as  did  alogliptin  in  a  post  hoc  analysis

including only patients with no HF history, 23,50 but sitagliptin 51,52 and  linagliptin 53-55 did not;  these findings may have been a result of baseline differences in the use of metformin, thiazolidinediones,  and  insulin,  which  also  affect  HF  risk.  The FDA recommends discontinuation specifically of saxagliptin and alogliptin in patients who develop HF, 56  and whether the risk of worsening HF is a class effect of DPP-4 inhibitors is unclear.

7. NSAIDs  inhibit  the  synthesis  of  renal  prostaglandins,  which  mediate  vasodilation  in  the  kidneys and directly inhibit sodium resorption in the thick  ascending  loop  of  Henle  and  collecting tubule.  Hence,  NSAIDs  can  cause  sodium  and water  retention  and  blunt  the  effects  of  diuretics.  Several  observational  cohort  studies  have revealed  increased  morbidity  and  mortality  in patients  with  HF  using  either  nonselective  or selective NSAIDs. 25-28

## 7.3.8. GDMT Dosing: Sequencing and Uptitration

| Recommendations for GDMT Dosing: Sequencing and Uptitration Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for GDMT Dosing: Sequencing and Uptitration Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for GDMT Dosing: Sequencing and Uptitration Referenced studies that support the recommendations are summarized in the Online Data Supplements.                                                                                         |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                              | LOE                                                                                                                                                              | Recommendations                                                                                                                                                                                                                                        |
| 1                                                                                                                                                                | A                                                                                                                                                                | 1. In patients with HFrEF, titration of guideline- directed medication dosing to achieve target doses showed to be efficacious in RCTs is rec- ommended, to reduce cardiovascular mortality and HF hospitalizations, unless not well toler- ated. 1-10 |
| 2a                                                                                                                                                               | C-EO                                                                                                                                                             | 2. In patients with HFrEF, titration and optimiza- tion of guideline-directed medications as frequently as every 1 to 2 weeks depending on the patient's symptoms, vital signs, and labora- tory findings can be useful to optimize manage- ment.      |

## Synopsis

Clinical  trials  of  ACEi,  ARB,  ARNi,  beta  blockers,  and most other HFrEF medications had therapy initiated at low dose by trial protocol. 1-9,11-14 If the initial dose was tolerated, the protocol would then direct the uptitration of medication dose over time to a specified target dose (Table 14), unless not well tolerated. Even if symptoms improved or other indicators of response were shown at lower doses, the medication dose would still be increased  to  the  trial-defined  target  doses.  Because these target doses were the ones that established the efficacy and safety of these medications in HFrEF and serve  as  the  basis  of  the  guideline  recommendations (Table 15), use of these target doses is recommended, if tolerated. 1-9,11-14  Use of all 4 drug classes has been estimated to reduce all-cause mortality by 73% compared with no treatment. 15

If the target dose cannot be achieved or is not well tolerated, then the highest tolerated dose is recommended.

Table 14. Drugs Commonly Used for HFrEF (Stage C HF)

| Drug                                                     | Initial Daily Dose(s)                                                                                                             | Target Doses(s)                                                                                                | Mean Doses Achieved in Clinical Trials                          | References   |
|----------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------|--------------|
| ACEi                                                     |                                                                                                                                   |                                                                                                                |                                                                 |              |
| Captopril                                                | 6.25 mg 3 times daily                                                                                                             | 50 mg 3 times daily                                                                                            | 122.7 mg total daily                                            | 19           |
| Enalapril                                                | 2.5 mg twice daily                                                                                                                | 10-20 mg twice daily                                                                                           | 16.6 mg total daily                                             | 3            |
| Fosinopril                                               | 5-10 mg once daily                                                                                                                | 40 mg once daily                                                                                               | NA                                                              | …            |
| Lisinopril                                               | 2.5-5 mg once daily                                                                                                               | 20-40 mg once daily                                                                                            | 32.5-35.0 mg total daily                                        | 17           |
| Perindopril                                              | 2 mg once daily                                                                                                                   | 8-16 mg once daily                                                                                             | NA                                                              | …            |
| Quinapril                                                | 5 mg twice daily                                                                                                                  | 20 mg twice daily                                                                                              | NA                                                              | …            |
| Ramipril                                                 | 1.25-2.5 mg once daily                                                                                                            | 10 mg once daily                                                                                               | NA                                                              | …            |
| Trandolapril                                             | 1 mg once daily                                                                                                                   | 4 mg once daily                                                                                                | NA                                                              | …            |
| ARB                                                      |                                                                                                                                   |                                                                                                                |                                                                 |              |
| Candesartan                                              | 4-8 mg once daily                                                                                                                 | 32 mg once daily                                                                                               | 24 mg total daily                                               | 20           |
| Losartan                                                 | 25-50 mg once daily                                                                                                               | 50-150 mg once daily                                                                                           | 129 mg total daily                                              | 18           |
| Valsartan                                                | 20-40 mg once daily                                                                                                               | 160 mg twice daily                                                                                             | 254 mg total daily                                              | 21           |
| ARNi                                                     |                                                                                                                                   |                                                                                                                |                                                                 |              |
| Sacubitril-valsartan                                     | 49 mg sacubitril and 51 mg val- sartan twice daily (therapy may be initiated at 24 mg sacubitril and 26 mg valsartan twice daily) | 97 mg sacubitril and 103 mg val- sartan twice daily                                                            | 182 mg sacubitril and 193 mg valsartan total daily              | 22           |
| Beta blockers                                            |                                                                                                                                   |                                                                                                                |                                                                 |              |
| Bisoprolol                                               | 1.25 mg once daily                                                                                                                | 10 mg once daily                                                                                               | 8.6 mg total daily                                              | 1            |
| Carvedilol                                               | 3.125 mg twice daily                                                                                                              | 25-50 mg twice daily                                                                                           | 37 mg total daily                                               | 23           |
| Carvedilol CR                                            | 10 mg once daily                                                                                                                  | 80 mg once daily                                                                                               | NA                                                              | …            |
| Metoprolol succinate extended release (metoprolol CR/XL) | 12.5-25 mg once daily                                                                                                             | 200 mg once daily                                                                                              | 159 mg total daily                                              | 11           |
| Mineralocorticoid receptor antagonists                   | Mineralocorticoid receptor antagonists                                                                                            |                                                                                                                |                                                                 |              |
| Spironolactone                                           | 12.5-25 mg once daily                                                                                                             | 25-50 mg once daily                                                                                            | 26 mg total daily                                               | 6            |
| Eplerenone                                               | 25 mg once daily                                                                                                                  | 50 mg once daily                                                                                               | 42.6 mg total daily                                             | 13           |
| SGLT2i                                                   |                                                                                                                                   |                                                                                                                |                                                                 |              |
| Dapagliflozin                                            | 10 mg once daily                                                                                                                  | 10 mg once daily                                                                                               | 9.8 mg total daily                                              | 8            |
| Empagliflozin                                            | 10 mg once daily                                                                                                                  | 10 mg once daily                                                                                               | NR                                                              | 9            |
| Isosorbide dinitrate and hydralazine                     | Isosorbide dinitrate and hydralazine                                                                                              |                                                                                                                |                                                                 |              |
| Fixed dose combination                                   | 20 mg isosorbide dinitrate and 37.5 mg hydralazine 3 times daily                                                                  | 40 mg isosorbide dinitrate and 75 mg hydralazine 3 times daily                                                 | 90 mg isosorbide dinitrate and ∼ 175 mg hydralazine total daily | 10           |
| Isosorbide dinitrate and hydrala- zine                   | 20-30 mg isosorbide dinitrate and 25-50 mg hydralazine 3-4 times daily                                                            | 120 mg isosorbide dinitrate total daily in divided doses and 300 mg hydralazine total daily in di- vided doses | NA                                                              | 24           |
| I f Channel inhibitor                                    |                                                                                                                                   |                                                                                                                |                                                                 |              |
| Ivabradine                                               | 5 mg twice daily                                                                                                                  | 7.5 mg twice daily                                                                                             | 12.8 total daily                                                | 25-27        |
| Soluble guanylate cyclase stimulator                     | Soluble guanylate cyclase stimulator                                                                                              |                                                                                                                |                                                                 |              |
| Vericiguat                                               | 2.5 mg once daily                                                                                                                 | 10 mg once daily                                                                                               | 9.2 mg total daily                                              | 28           |
| Cardiac glycoside                                        | Cardiac glycoside                                                                                                                 |                                                                                                                |                                                                 |              |
| Digoxin                                                  | 0.125-0.25 mg daily (modified according to monogram)                                                                              | Individualized variable dose to achieve serum digoxin concentra- tion 0.5-<0.9 ng/mL                           | NA                                                              | 29,30        |

ACE indicates angiotensin-converting enzyme; ARB, angiotensin receptor blocker; CR, controlled release; CR/XL, controlled release/extended release; HF, heart failure; HFrEF, heart failure with reduced ejection fraction; NA, not applicable; NR, not reported; and SGLT2i, sodium glucose cotransporter 2 inhibitor.

There are no direct data showing that use of lower doses of HFrEF medications among patients, where higher target doses could be tolerated, would produce the same or simi- lar degree of clinical benefit. In trials that have evaluated dose response for outcomes, composite event rates were lower with target doses compared with lower dose. 16-18

Table 15. Benefits of Evidence-Based Therapies for Patients With HFrEF 3-6,8,10-14,23,31-42

| Evidence-Based Therapy                |   Relative Risk Reduction in All-Cause Mortality in Pivotal RCTs,% | NNT to Prevent All-Cause Mortality Over Time*   |   NNT for All-Cause Mortality (Standardized to 12 mo) |   NNT for All- Cause Mortality (Standardized to 36 mo) |
|---------------------------------------|--------------------------------------------------------------------|-------------------------------------------------|-------------------------------------------------------|--------------------------------------------------------|
| ACEi or ARB                           |                                                                 17 | 22 over 42 mo                                   |                                                    77 |                                                     26 |
| ARNi†                                 |                                                                 16 | 36 over 27 mo                                   |                                                    80 |                                                     27 |
| Beta blocker                          |                                                                 34 | 28 over 12 mo                                   |                                                    28 |                                                      9 |
| Mineralocorticoid receptor antagonist |                                                                 30 | 9 over 24 mo                                    |                                                    18 |                                                      6 |
| SGLT2i                                |                                                                 17 | 43 over 18 mo                                   |                                                    63 |                                                     22 |
| Hydralazine or nitrate‡               |                                                                 43 | 25 over 10 mo                                   |                                                    21 |                                                      7 |
| CRT                                   |                                                                 36 | 12 over 24 mo                                   |                                                    24 |                                                      8 |
| ICD                                   |                                                                 23 | 14 over 60 mo                                   |                                                    70 |                                                     23 |

ACEi indicates angiotensin-converting enzyme inhibitor; ARB, angiotensin receptor blocker; ARNi, angiotensin receptor neprilysin inhibitor; CRT, cardiac resynchronization therapy; HFrEF, heart failure with reduced ejection fraction; ICD, implantable cardioverter-defibrillator; NNT, number needed to treat; RCT, randomized controlled trial; and SGLT2i, sodium-glucose cotransporter-2 inhibitor.

*Median duration follow-up in the respective clinical trial.

†Benefit of ARNi therapy incremental to that achieved with ACEi therapy. For the other medications shown, the benefits are based on comparisons to placebo control.

‡Benefit of hydralazine-nitrate therapy was limited to African American patients in this trial.

## Recommendation-Specific Supportive Text

1.  The use of these specific medications for HFrEF should  involve  initiation  at  low-starting  doses, uptitration at specified intervals as tolerated, and achieving-maintaining the target doses shown to be  effective  in  major  clinical  trials.  Every  effort should be made by clinicians to achieve and maintain the clinical trial-defined target doses (Table 13) of guideline-directed medications, as long as they  are  well  tolerated  by  the  patient.  Patients should  be  monitored  for  changes  in  heart  rate, blood  pressure,  electrolytes,  renal  function,  and symptoms during this uptitration period. Planned uptitration of a HF medication should be delayed until  any  adverse  effects  observed  with  lower doses  have  resolved.  When  such  a  strategy  is used  for  dose  titration,  most  patients  (approximately 70%-85%) enrolled in clinical trials who received these medications were able to tolerate short-,  intermediate-,  and  long-term  treatment with  these  agents  and  achieve  and  maintain the  trial  defined  target  dose. 1-9,11-14   Repeated attempts at uptitration can result in optimization, even if initial  attempts may fail. In patients with HFrEF,  beta  blockers  provide  dose-dependent improvements  in  LVEF,  reduction  in  HF  hospitalizations, and reduction in all-cause mortality. 17 Trials  of  lower  versus  higher  dose  of  ACEi  and ARB  have  shown  lower  risk  of  cardiovascular death  or  HF  hospitalization  with  higher  doses, with similar safety and tolerability. 17,18
2. Initiation and titration should be individualized and optimized  without  delay  according  to  patient's symptoms, vital signs, functional status, tolerance, renal function, electrolytes, comorbidities, specific

cause  of  HF,  and  ability  of  follow-up.  In  patients with HFrEF, simultaneous initiation or sequencing, and  order  of  guideline-directed  medications  are usually individualized according to patient's symptoms, vital signs, functional status, tolerance, renal function, electrolytes, comorbidities, specific cause of HF, and ability of follow-up, and does not necessarily need to be done according to the sequence of trial publications and should not be delayed.

## 7.3.9. Additional Medical Therapies

7.3.9.1. Management of Stage C HF: Ivabradine

| Recommendation for the Management of Stage C HF: Ivabradine Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for the Management of Stage C HF: Ivabradine Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for the Management of Stage C HF: Ivabradine Referenced studies that support the recommendation are summarized in the Online Data Supplements.                                                                                                                                                                     |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                             | LOE                                                                                                                                                             | Recommendation                                                                                                                                                                                                                                                                                                                    |
| 2a                                                                                                                                                              | B-R                                                                                                                                                             | 1. For patients with symptomatic (NYHA class II to III) stable chronic HFrEF (LVEF ≤ 35%) who are receiving GDMT, including a beta blocker at maximum tolerated dose, and who are in sinus rhythm with a heart rate of ≥ 70 bpm at rest, ivabradine can be beneficial to reduce HF hospitalizations and cardiovascular death. 1,2 |

## Synopsis

Heart  rate  is  a  strong  predictor  of  cardiovascular  outcomes  in  the  general  population  and  in  patients  with CVD, including HF. The SHIFT (Ivabradine and Outcomes in Chronic Heart Failure) trial tested the hypothesis that reducing heart rate in patients with HF improves cardiovascular outcomes. 1  SHIFT demonstrated the efficacy of ivabradine,  a  sinoatrial  node  modulator  that  selectively inhibits the I f current, in reducing the composite endpoint of cardiovascular death or HF hospitalization in patients with HF. See Figure 7 for a summary of additional medical therapy recommendations.

Figure 7. Additional Medical Therapies for Patients With HFrEF.

<!-- image -->

Colors correspond to COR in Table 2. Recommendations for additional medical therapies that may be considered for patients with HF are shown. GDMT indicates guideline-directed medical therapy; HF, heart failure; HFH, heart failure hospitalization; HFrEF, heart failure with reduced ejection fraction; IV, intravenous; L VEF, left ventricular ejection fraction; L VESD, left ventricular end systolic dimension; MV, mitral valve; MR, mitral regurgitation; NP, natriuretic peptide; NSR, normal sinus rhythm; NYHA, New York Heart Association; and RAASi, renin-angiotensin-aldosterone system inhibitors.

## Recommendation-Specific Supportive Text

1.  Although the primary outcome in SHIFT was a composite  of  hospitalization  and  cardiovascular  death, the greatest benefit was a reduction in HF hospitalization. SHIFT included patients with HFrEF and LVEF ≤ 35% who were in sinus rhythm with a resting heart rate of ≥ 70 bpm. Participants were predominantly NYHA class II and III. Participants had been hospitalized for HF in the preceding 12 months and were on stable GDMT for 4 weeks before initiation of  ivabradine  therapy. 1-4 The  target  of  ivabradine is  heart rate, and the benefit of ivabradine results from a reduction in heart rate. However, only 25% of patients studied in SHIFT were on optimal doses of beta-blocker therapy. Given the well-proven mortality benefits of beta-blocker therapy, these agents should be initiated and uptitrated to target doses, as tolerated, before assessing the resting heart rate for consideration of ivabradine initiation. 5,6

7.3.9.2. Pharmacological Treatment for Stage C HFrEF: Digoxin

| Recommendation for the Pharmacological Treatment for Stage C HFrEF: Digoxin Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for the Pharmacological Treatment for Stage C HFrEF: Digoxin Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for the Pharmacological Treatment for Stage C HFrEF: Digoxin Referenced studies that support the recommendation are summarized in the Online Data Supplements.   |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                             | LOE                                                                                                                                                                             | Recommendation                                                                                                                                                                  |
| 2b                                                                                                                                                                              | B-R                                                                                                                                                                             | 1. In patients with symptomatic HFrEF despite GDMT (or who are unable to tolerate GDMT), digoxin might be considered to decrease hospi- talizations for HF. 1,2                 |

## Synopsis

To date, there has been only 1 large-scale, RCT of digoxin in patients with HF. 1 This trial, which predated current GDMT, primarily enrolled patients with NYHA class II to III HF and showed that treatment with digoxin for 2 to 5 years had no effect on mortality but modestly reduced the combined risk of death and hospitalization. The trial also found no significant effect on health-related QOL in  a  subset  of  the  trial  patients. 3 The  effect  of  digoxin on hospitalizations has been supported by retrospective analyses  and  meta-analyses. 2,4-6 Additionally,  observational  studies  and  retrospective  analyses  have  shown improvement in symptoms and exercise tolerance in mild to moderate HF; however, they have mostly shown either lack of mortality benefit or increased mortality associated with digoxin. 7   The benefit in patients on current GDMT is unclear because most trials preceded current GDMT. Thus, use of digoxin requires caution in patients with HF and is reserved for those who remain symptomatic despite optimization of GDMT.

## Recommendation-Specific Supportive Text

1.  Digoxin is usually initiated at a low dose because higher doses are rarely required in the management of  HF  and  are  potentially  detrimental.  Two  retrospective analyses of large-scale clinical trials have shown a linear relationship between mortality and digoxin  serum  concentration  in  patients  with  AF and at risk for stroke, including those with HF, and in patients with HF. The risk of death was independently associated with serum digoxin concentration, with a significantly higher risk observed in those with concentrations ≥ 1.2 ng/mL and ≥ 1.6 ng/mL. 8,9  The benefit of digoxin in patients with HF remains controversial. GDMT is expected to be optimized before considering the addition of digoxin. Clinical worsening after withdrawal of digoxin has been shown. 10 Therapy with digoxin may either be continued in the absence of a contraindication or discontinued with caution. 11 Therapy  with  digoxin  is  commonly  initiated and maintained at a dose of 0.125 to 0.25 mg daily. Low doses (0.125 mg daily or every other day) should be used initially if the patient is &gt;70 years of

age, has impaired renal function, or has a low lean body mass. Higher doses (eg, digoxin 0.375 to 0.50 mg daily) are rarely used or needed in the management of patients with HF.

## 7.3.9.3. Pharmacological Treatment for Stage C HFrEF: Soluble Guanylyl Cyclase Stimulators

| Recommendation for Pharmacological Treatment for Stage C HFrEF: Soluble Guanylyl Cyclase Stimulators Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Pharmacological Treatment for Stage C HFrEF: Soluble Guanylyl Cyclase Stimulators Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Pharmacological Treatment for Stage C HFrEF: Soluble Guanylyl Cyclase Stimulators Referenced studies that support the recommendation are summarized in the Online Data Supplements.                        |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                                      | LOE                                                                                                                                                                                                      | Recommendation                                                                                                                                                                                                                |
| 2b                                                                                                                                                                                                       | B-R                                                                                                                                                                                                      | 1. In selected high-risk patients with HFrEF and recent worsening of HF already on GDMT, an oral soluble guanylate cyclase stimulator (vericiguat) may be considered to reduce HF hospitalization and cardiovascular death. 1 |

## Synopsis

In  patients  with  progression  of  HFrEF  despite  GDMT, there  may be a role for novel therapeutic agents. Oral soluble  guanylyl  cyclase  stimulator  (eg,  vericiguat)  directly  binds  and  stimulates  sGC  and  increases  cGMP production. cGMP  has  several  potentially  beneficial effects  in  patients  with  HF,  including  vasodilation,  improvement in endothelial function, as well as decrease in fibrosis and remodeling of the heart. 2-7  The VICTORIA (Vericiguat Global Study in Subjects with Heart Failure with Reduced Ejection Fraction) trial randomized 5050 higher-risk patients with worsening HFrEF to vericiguat versus placebo. 1

## Recommendation-Specific Supportive Text

1.  Patients with HFrEF in the VICTORIA trial had L VEF &lt;45%, NYHA class II to IV, were on GDMT, with elevated  natriuretic  peptides  (BNP ≥ 300  pg/mL or  NT-proBNP ≥ 1000  pg/mL  if  in  sinus  rhythm; higher cutoffs with AF), and recent HF worsening (hospitalized within 6 months or recently received intravenous  diuretic  therapy  without  hospitalization).  Patients  on  long-acting  nitrates,  with  SBP &lt;100 mm Hg, or eGFR &lt;15 mL/min/1.73 m 2  were excluded. 1  Over a median follow-up of 10.8 months, the  primary  outcome,  cardiovascular  death  or  HF hospitalization,  occurred  in  35.5%  with  vericiguat compared  with  38.5%  with  placebo  (HR,  0.90; P =0.019).  All-cause  mortality  occurred  in  20.3% in  the  vericiguat group and 21.2% in the placebo group (HR, 0.95; 95% CI, 0.84-1.07; P =0.38) and composite  of  any-cause  death  or  HF  hospitalization was also lower in the vericiguat group versus placebo  group  (HR,  0.90;  95%  CI,  0.83-0.98; P =0.02). The relative risk reduction of 10% in the primary outcome was lower than expected, even in

a  higher  risk  population.  Although  not  statistically significant, symptomatic hypotension (9.1% versus 7.9%; P =0.12)  and  syncope  (4.0%  versus  3.5%; P =0.30) were numerically higher in the vericiguat group  versus  placebo.  There  was  heterogeneity by  subgroup  analysis,  and  patients  in  the  highest quartile of NT-proBNP subgroup (NT proBNP level &gt;5314 pg/mL) did not have benefit from vericiguat when compared with placebo.

## 7.4. Device and Interventional Therapies for HFrEF

## 7.4.1. ICDs and CRTs

| Recommendations for ICDs and CRTs Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for ICDs and CRTs Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for ICDs and CRTs Referenced studies that support the recommendations are summarized in the Online Data Supplements.                                                                                                                                                                                                           |
|----------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                    | LOE                                                                                                                                    | Recommendations                                                                                                                                                                                                                                                                                                                                |
| 1                                                                                                                                      | A                                                                                                                                      | 1. In patients with nonischemic DCM or ischemic heart disease at least 40 days post-MI with LVEF ≤ 35% and NYHA class II or III symp- toms on chronic GDMT, who have reasonable expectation of meaningful survival for >1 year, ICD therapy is recommended for primary pre- vention of SCD to reduce total mortality. 1-9                      |
| Value Statement: High Value (A)                                                                                                        | Value Statement: High Value (A)                                                                                                        | 2. A transvenous ICD provides high economic value in the primary prevention of SCD particularly when the patient's risk of death caused by ventricular arrythmia is deemed high and the risk of nonarrhythmic death (either cardiac or noncardiac) is deemed low based on the patient's burden of comorbidi- ties and functional status. 10-15 |
| 1                                                                                                                                      | B-R                                                                                                                                    | 3. In patients at least 40 days post-MI with LVEF ≤ 30% and NYHA class I symptoms while receiving GDMT, who have reasonable expec- tation of meaningful survival for >1 year, ICD therapy is recommended for primary prevention of SCD to reduce total mortality. 6                                                                            |
| 1                                                                                                                                      | B-R                                                                                                                                    | 4. For patients who have LVEF ≤ 35%, sinus rhythm, left bundle branch block (LBBB) withaQRS duration ≥ 150 ms, and NYHA class II, III, or ambulatory IV symptoms on GDMT, CRT is indicated to reduce total mortality, reduce hospi- talizations, and improve symptoms and QOL. 16-21                                                           |
| Value Statement: High Value (B-NR)                                                                                                     | Value Statement: High Value (B-NR)                                                                                                     | 5. For patients who have LVEF ≤ 35%, sinus rhythm, LBBB with a QRS duration of ≥ 150 ms, and NYHA class II, III, or ambulatory IV symptoms on GDMT, CRT implantation pro- vides high economic value. 22-27                                                                                                                                     |
| 2a                                                                                                                                     | B-R                                                                                                                                    | 6. For patients who have LVEF ≤ 35%, sinus rhythm, a non-LBBB pattern with a QRS duration ≥ 150 ms, and NYHA class II, III, or ambulatory class IV symptoms on GDMT, CRT can be useful to reduce total mortality, reduce hospitalizations, and improve symp- toms and QOL. 16-21,28-33                                                         |
| 2a                                                                                                                                     | B-R                                                                                                                                    | 7. In patients with high-degree or complete heart block and LVEF of 36% to 50%, CRT is reasonable to reduce total mortality, reduce hospitalizations, and improve symptoms and QOL. 34,35                                                                                                                                                      |

| Recommendations for ICDs and CRTs (Continued)   | Recommendations for ICDs and CRTs (Continued)   | Recommendations for ICDs and CRTs (Continued)                                                                                                                                                                                                                                                                                                                      |
|-------------------------------------------------|-------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                             | LOE                                             | Recommendations                                                                                                                                                                                                                                                                                                                                                    |
| 2a                                              | B-NR                                            | 8. For patients who have LVEF ≤ 35%, sinus rhythm, LBBB with a QRS duration of 120 to 149 ms, and NYHA class II, III, or ambu- latory IV symptoms on GDMT, CRT can be useful to reduce total mortality, reduce hospitalizations, and improve symptoms and QOL. 16-21,28-33                                                                                         |
| 2a                                              | B-NR                                            | 9. In patients with AF and LVEF ≤ 35% on GDMT, CRT can be useful to reduce total mortality, improve symptoms and QOL, and increase LVEF, if: a) the patient requires ventricular pac- ing or otherwise meets CRT criteria and b) atrioventricular nodal ablation or pharmacologi- cal rate control will allow near 100% ventricu- lar pacing with CRT. 16-21,28-33 |
| 2a                                              | B-NR                                            | 10. For patients on GDMT who have LVEF ≤ 35% and are undergoing placement of a new or replacement device implantation with anticipated requirement for significant (>40%) ventricular pacing, CRT can be useful to reduce total mortality, reduce hospitalizations, and improve symptoms and QOL. 16-21,28-33                                                      |
| 2a                                              | B-NR                                            | 11. In patients with genetic arrhythmogenic car- diomyopathy with high-risk features of sudden death, with EF ≤ 45%, implantation of ICD is reasonable to decrease sudden death. 36,37                                                                                                                                                                             |
| 2b                                              | B-NR                                            | 12. For patients who have LVEF ≤ 35%, sinus rhythm, a non-LBBB pattern with QRS dura- tion of 120 to 149 ms, and NYHA class III or ambulatory class IV on GDMT, CRT may be considered to reduce total mortality, reduce hospitalizations, and improve symptoms and QOL. 16-21,28-33                                                                                |
| 2b                                              | B-NR                                            | 13. For patients who have LVEF ≤ 30%, ischemic cause of HF, sinus rhythm, LBBB with a QRS duration ≥ 150 ms, and NYHA class I symp- toms on GDMT, CRT may be considered to reduce hospitalizations and improve symptoms and QOL. 16-21,28-33                                                                                                                       |
| 3: No Benefit                                   | B-R                                             | 14. In patients with QRS duration <120 ms, CRT is not recommended. 36-41                                                                                                                                                                                                                                                                                           |
| 3: No Benefit                                   | B-NR                                            | 15. For patients with NYHA class I or II symptoms and non-LBBB pattern with QRS duration <150 ms, CRT is not recommended. 16-21,28-33                                                                                                                                                                                                                              |
| 3: No Benefit                                   | C-LD                                            | 16. For patients whose comorbidities or frailty limit survival with good functional capacity to <1 year, ICD and cardiac resynchronization therapy with defibrillation (CRT-D) are not indi- cated. 1-9,16-21                                                                                                                                                      |

## Synopsis

RCTs  have  informed  the  decisions  regarding  cardiac implantable devices (ICDs and CRTs) over the past 20 years. In fact, the seminal RCTs for ICDs and CRTs are unlikely to be repeated. Subgroup analyses of these trials have also informed decisions, but these were not the primary endpoints of these studies and thus should be interpreted with caution. GDMT is optimized before ICD and CRT implantation to assess whether the LVEF improves. Figures 8 and 9 summarize device and interventional therapy recommendations.

## Recommendation-Specific Supportive Text

1. ICDs  were  first  assessed  in  patients  who  had been resuscitated from a cardiac arrest.  In  AVID (Antiarrhythmics  versus  Implantable  Defibrillators trial),  CASH  (Cardiac  Arrest  Study  Hamburg), and CIDS (Canadian Implantable Defibrillator StudyS), benefit was observed in those who were randomized  to  ICDs. 1-3 Extension  of  benefit  was then shown  in  other patient populations that were at perceived risk of SCD. In the first MADIT (Multicenter  Automated  Defibrillator  Implantation Trial)  trial,  patients  with  previous  MI,  L VEF ≤ 35% with nonsustained VT had a mortality benefit with ICD. 4 Similar  populations  in  MUSTT  (Multicenter UnSustained Tachycardia Trial) also showed benefit. 5 In MADIT-II (Multicenter Automatic Defibrillator Implantation  Trial  II),  patients  with  no  arrhythmia  qualifier  but  with  previous  MIs  and  L VEF ≤ 30% derived benefit from ICD. 6   The  DEFINITE (Defibrillators  in  Non-Ischemic  Cardiomyopathy Treatment  Evaluation)  study  included  only  nonischemic patients with L VEF ≤ 35% and frequent premature ventricular contractions (PVCs) or nonsustained ventricular tachycardia (VT). 7  There was a  trend  to  mortality  benefit,  but  it  ultimately  did not  achieve  significance.  In  SCD-HEFT  (Sudden Cardiac Death in Heart Failure Trial), patients with ischemic  and  nonischemic  cardiomyopathy,  L VEF ≤ 35%, and HF class II to III showed benefit with an ICD compared with either amiodarone or placebo. 8 More  recently,  the  DANISH  (Defibrillator Implantation in Patients with Nonischemic Systolic Heart Failure) trial enrolled patients with nonischemic cardiomyopathy and LVEF ≤ 35% to ICD or standard care. 9  There was no reduction in the primary endpoint of  total  mortality,  but  there  was  a reduction in SCD risk. In the DANISH trial, 58% of patients in each limb received CRT, possibly mitigating the benefit of an ICD.
2. Economic  outcomes  of  ICD  implantation  for  primary prevention of SCD were assessed in 3 RCTs (MADIT-I, 13 MADIT-II, 15  and SCD-HeFT, 12  1 observational study, 10 and 3 simulation models, 11,14,42 all of which had generally consistent results. All studies reported increased survival and life expectancy and higher lifetime costs of medical care with an ICD  than  without  an  ICD.  The  incremental  costeffectiveness ratios were generally &lt;$60  000 per year of life added by an ICD, which provides high value according to the benchmarks adopted for the current  guideline.  The  value  provided  by  an  ICD was  consistently  high  when  life  expectancy  was projected to increase by &gt;1.4 years. 14 In contrast, when survival was not increased by ICD implantation, as in the coronary artery bypass graft (CABG) Patch trial, 43 the ICD did not provide value, because

Figure 8. Algorithm for CRT Indications in Patients With Cardiomyopathy or HFrEF.

<!-- image -->

Colors correspond to COR in Table 2. Recommendations for cardiac resynchronization therapy (CRT) are displayed. AF indicates atrial fibrillation; Amb, ambulatory; CM, cardiomyopathy; GDMT, guideline-directed medical therapy; HB, heart block; HF, heart failure; HFrEF, heart failure with reduced ejection fraction; LBBB, left bundle branch block; L V, left ventricular; L VEF, left ventricular ejection fraction; NSR, normal sinus rhythm; NYHA, New York Heart Association; and RV, right ventricular.

the higher costs were unaccompanied by a gain in life expectancy. 14

3. The MADIT-II trial randomized patients with previous MI and LVEF &lt;30%, without any limitation of HF class, to ICDs or not. 6 Thirty-seven percent of the patients were in class I congestive heart failure (CHF). Mortality was reduced with an ICD.
4. Most  of  the  relevant  data  for  the  guidelines  of CRT  in  HF  come  from  seminal  trials  published from  2002  to  2010.  The  first  of  these  was  the MIRACLE (Multicenter InSync Randomized Clinical Evaluation)  trial,  which  took  patients  with  L VEF ≤ 35%, moderate to severe HF, and QRS duration ≥ 130 ms. 16   There  was  a  benefit  in  the  6-minute walk  test,  QOL,  functional  HF  classification,  and LVEF. The COMPANION (Comparison of Medical Therapy, Pacing and Defibrillation in Heart Failure) trial,  which enrolled NYHA class III to IV patients with QRS ≥ 120 ms, included 3 arms: GDMT, CRT-D, and CRT pacemaker (CRT-P). 17  The primary endpoint  of  death  or  hospitalization  was  decreased

with  CRT-P  and  CRT-D.  The  CARE-HF  (Cardiac Resynchronization Heart Failure) trial included a  similar  group  with  NYHA  class  III  to  IV,  L VEF ≤ 35%, QRS &gt;120 ms, and showed a significant reduction in primary and endpoint of death or hospitalization. 18  In the REVERSE (Resynchronization Reverses Remodeling in Systolic  Left  Ventricular Dysfunction) trial, patients with NYHA class I to II and LVEF ≤ 40% were randomized to CRT-D on for 1 year and CRT-D off for 1 year or vice versa. 19 A HF composite endpoint  was  less  common  when CRT  was  activated.  MADIT-CRT  enrolled  NYHA class I and II HF with L VEF ≤ 30% and QRS ≥ 130 ms and compared CRT-D with ICD. 20  The primary endpoint of death or HF was reduced by CRT-D. The RAFT  (Resynchronization-Defibrillation for Ambulatory Heart Failure) trial randomized patients with  NYHA  class  II  to  III  HF,  L VEF ≤ 30%,  QRS &gt;120 ms, or paced QRS ≥ 200 ms and compared CRT-D with ICD. 21  Again, there was a reduction in the primary endpoint of death or HF hospitalization.

Figure 9. Additional Device Therapies.

<!-- image -->

Colors correspond to COR in Table 2. Recommendations for additional nonpharmaceutical interventions that may be considered for patients with HF are shown. GDMT indicates guideline-directed medical therapy; HF, heart failure; HFH, heart failure hospitalization; HFrEF, heart failure with reduced ejection fraction; IV, intravenous; LVEF, left ventricular ejection fraction; L VESD, left ventricular end systolic dimension; MV, mitral valve; MR, mitral regurgitation; NP, natriuretic peptide; NSR, normal sinus rhythm; NYHA, New York Heart Association; and PASP, pulmonary artery systolic pressure.

5. The  economic  value  of  CRT  has  been  evaluated by  3  RCTs  (COMPANION, 22   MADIT-CRT, 26   and REVERSE 23 ),  2  model-based  analyses, 25,27 and  1 observational  study. 24 These  analyses  consistently found CRT increased survival and QOL in addition to increasing health care costs. However, the economic value of CRT likely varies as a result of the shown variation in treatment effect. 26  Among populations with larger expected mortality reduction and improvement in QOL, such as patients with a LBBB with QRS duration &gt;150 ms, the cost per QAL Y is &lt;$60 000. 22,26,27  Among other populations expected to  have  smaller  treatment  benefit,  the  economic value  is  more  uncertain.  However,  a  model-based analysis of patients with NYHA class I to II found the  incremental  cost-effectiveness  ratio  remained &lt;$150 000 per QAL Y with even small reductions in all-cause mortality. 27 Therefore, CRT likely provides at  least  intermediate  value  for  patients  with  other guideline-indicated recommendations in which CRT is expected to reduce mortality.
6. Subgroup analysis of the previously mentioned trials  has  informed  us  of  the  predictors  of  benefit,

including longer QRS duration, and LBBB versus non-LBBB. 28   The  most  benefit  was  gained  with wider  QRS  durations  and  with  LBBB.  This  was true  in  COMPANION,  CARE-HF,  MADIT-CRT, REVERSE, and RAFT. 17,29-32  A QRS duration &gt;150 ms was also a predictor of response, and in those with non-LBBB, a prolonged PR predicted benefit in MADIT-CRT but not in REVERSE. 33

7. Extension of benefit to those with LVEF between 35% and 50% has been seen. In the BLOCK-HF (Biventricular  versus  Right  Ventricular  Pacing  in Heart  Failure)  trial,  patients  with  NYHA  class  I to III  HF,  L VEF ≤ 50%, and atrioventricular block randomized to RV pacing or CRT, there was benefit to CRT in reduction in the primary outcome of death, urgent HF visit, or 15% increase in LV end systolic volume. 34
8. In the previously mentioned CRT trials, there was some benefit for those with LBBB and QRS durations between 120 and 149, but not as much benefit as those with LBBB ≥ 150 ms. 17,28-32
9. Several  trials have  included  patients with AF. In the MUSTIC  AF (Multisite Stimulation in Cardiomyopathies), 44 RAFT, 45 and the  SPARE (Spanish Atrial Fibrillation and Resynchronization) 46 trials,  there  were  benefits  in  patients  with  AF, while  in  COMPANION, 47  AF attenuated the benefit of CRT. In the PAVE (Post AV Nodal Ablation Evaluation) study, patients with NYHA class II to III, mean LVEF of 46%, and AF undergoing atrioventricular node ablation, CRT improved the 6-minute walk test and L VEF compared with those who were RV paced. 35
10. In patients in whom there is an expected high burden of ventricular pacing, especially if &gt;40%, CRT may be used to reduce mortality, reduce hospitalizations, and improve symptoms and QOL. 35,48
11. Identification  of  specific  arrhythmogenic  genetic variants  such  as LMNA/C ,  desmosomal  proteins, phospholamban, and Filamin-C carry implications for  implantation  of  ICDs  for  primary  prevention of sudden death even in patients who have LVEF &gt;35%, or &lt;3 months of GDMT. Most patients with LMNA/C cardiomyopathy will progress to cardiac transplantation, sometimes precipitated by refractory arrhythmias more than by pump failure. 36-38,49
12. Subgroup  analysis  of  the  CRT  RCTs  has  shown that  patients  with  L VEFs ≤ 35%,  non-LBBB,  and QRS duration of 120 to 149 ms and NYHA class III  to  ambulatory  class  IV  did  not  derive  as  much benefit as those with LBBB ≥ 120 ms. 17,28-32
13.  The MADIT-CRT trial included NYHA class I (and class II) patients with ischemic heart disease, L VEF ≤ 30%,  and  QRS  &gt;130  ms. 39   Patients  with  nonischemic cardiomyopathy were enrolled if they had NYHA class II HF.

14.  Extension of benefit to patients with narrow QRS has been attempted but has generally failed. In the RETHINQ (Cardiac Resynchronization Therapy in Patients with Heart Failure and Narrow QRS) trial, patients  with  QRS  duration  &lt;130  ms  were  randomized to CRT or not. 40 There was no benefit from CRT, but subgroup analysis showed there was a benefit with QRS durations between 120 and 130 ms. In the ECHO-CRT (Echocardiography Guided Cardiac Resynchronization Therapy) trial, patients with NYHA class III to IV HF, L VEF ≤ 35% and a QRS  duration ≤ 130  ms,  and  mechanical  dysynchrony  on  echocardiography  underwent  randomization to CRT. 50   There was no benefit to CRT in this trial. And in the LESSER-EARTH (Evaluation of  Resynchronization  Therapy  for  Heart  Failure) trial, patients with severe L V dysfunction and QRS &lt;120  ms  derived  no  benefit  from  CRT. 51   The NARROW-CRT  (Narrow  QRS  Ischemic  Patients Treated With Cardiac Resynchronization Therapy) was the only trial that showed a benefit in a clinical composite score in patients with an indication for an ICD and QRS &lt;120 ms. 52
15.  Subgroup analysis of the CRT trials has shown no benefit for those with L VEF ≤ 35%, non-LBBB 120 to 149, and NYHA class I-II HF. 17,28-32
16. The 1-year survival is a standard inclusion for ICD and CRT trials. 1-9,16-21

## 7.4.2. Other Implantable Electrical Interventions

Autonomic nervous system modulation is intriguing as a treatment  for  HFrEF  because  of  the  heightened  sympathetic  response  and  decreased  parasympathetic  response in HF. 1 Trials of device stimulation of the vagus nerve,  spinal  cord,  and  baroreceptors  have  had  mixed responses. 2 An implantable device that electrically stimulates  the  baroreceptors  of  the  carotid  artery  has  been approved by the FDA for the improvement of symptoms in patients with advanced HF who are unsuited for treatment with other HF devices including CRT. In a prospective,  multicenter,  RCT with a total of 408 patients with current or recent NYHA class III HF, L VEF ≤ 35%, baroreceptor stimulation was associated with improvements in  QOL,  exercise  capacity,  and  NT-proBNP  levels. 3 T o date, there are no mortality or hospitalization rates results available with this device. Although early trials of vagus nerve stimulation were positive, the largest and latest trial did not show a reduction in mortality and HF hospitalizations. 4 Multisite L V pacing studies initially were promising. 5,6   However, more recent data have not confirmed benefit, and the larger phase 2 trial was terminated early for low probability of benefit. 7 His bundle and left bundle pacing are attractive because they use the intrinsic conduction system. In observational data, there does appear to be a benefit over RV pacing 8 ; however, comparisons to  CRT  are  limited. 9,10 Cardiac  contractility  modulation

(CCM),  a  device-based  therapy  that  involves  applying relatively  high-voltage,  long-duration  electric  signals  to the RV septal wall during the absolute myocardial refractory  period,  has  been  associated  with  augmentation of LV  contractile  performance.  CCM  is  FDA-approved  for patients with NYHA class III with L VEF of 25% to 45% who are not candidates for CRT. Four RCTs have shown benefits in exercise capacity and QOL but, as of yet, no benefits in death or hospitalizations. 11-14 Most patients in these trials were class III CHF. 3

## 7.4.3. Revascularization for CAD

| Recommendation for Revascularization for CAD Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Revascularization for CAD Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Revascularization for CAD Referenced studies that support the recommendation are summarized in the Online Data Supplements.                                                                                           |
|--------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                              | LOE                                                                                                                                              | Recommendation                                                                                                                                                                                                                           |
| 1                                                                                                                                                | B-R                                                                                                                                              | 1. In selected patients with HF, reduced EF (EF ≤ 35%), and suitable coronary anatomy, surgical revascularization plus GDMT is beneficial to improve symptoms, cardiovascular hospitaliza- tions, and long-term all-cause mortality. 1-8 |

## Synopsis

CAD is commonly associated with HF, necessitating revascularization  in  selected  patients  with  angina  or  HF symptoms. Data from the STICH Trial showed that, compared with  optimal  medical  management  alone,  CABG surgery plus GDMT did not reduce the primary endpoint of  all-cause  mortality  at  a  median  of  56  months;  however,  at  10  years'  follow-up,  CABG+GDMT  resulted  in significant  reductions  in  all-cause  mortality,  cardiovascular mortality, and death from any cause or cardiovascular  hospitalization  in  patients  with  L VEF ≤ 35%  and ischemic cardiomyopathy. 7,8 Furthermore, a retrospective analysis showed significant reductions in first and recurrent all-cause, cardiovascular, and HF hospitalizations at 10 years in patients receiving CABG+ optimal medical therapy compared with optimal medical therapy alone. 2 Similar benefits from percutaneous coronary intervention revascularization, in this cohort, have not yet been shown in an RCT, although the REVIVED-BCIS2 (Study of Efficacy and Safety of Percutaneous Coronary Intervention to  Improve  Survival  in  Heart  Failure)  trial,  which  compares percutaneous coronary intervention with medical therapy in a similar population, is ongoing. 9  Recent data continue to show a benefit of CABG over percutaneous coronary intervention in patients with diabetes, CAD, and LV dysfunction and in patients with left main CAD and moderate or  severe  L V  dysfunction. 4,6,10 Figure  9  summarizes revascularization  and  additional  device  therapy recommendations.

## Recommendation-Specific Supportive Text

1.  CABG  has  been  shown  to  improve  outcomes in  patients  with  left  main  or  left  main  equivalent

disease and HF. 1,4,10-14  Long-term follow-up shows a  reduction  in  all-cause,  cardiovascular,  and  HF hospitalizations  and  in  all-cause  and  cardiovascular  mortality  in  patients  with  L V  dysfunction  who receive  CABG  and  GDMT  compared  with  GDMT alone. 2,7 The long-term survival benefit is greater in those with more advanced ischemic cardiomyopathy (lower EF or 3-vessel disease) and diminishes with  increasing  age. 5,7   CABG  also  improves  QOL compared  with  GDMT  alone. 3   An  RCT  of  CABG combined with surgical ventricular remodeling compared with CABG alone did not show a reduction in death  or  hospitalization,  or  improvement  in  symptoms with surgical ventricular remodeling. 15 Surgical ventricular  remodeling  performed  at  the  time  of CABG may be useful in patients with intractable HF, large thrombus, or persistent arrhythmias resulting from well-defined aneurysm or scar, if other therapies are ineffective or contraindicated. 15,16

## 7.5. Valvular Heart Disease

| Recommendations for Valvular Heart Disease Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Valvular Heart Disease Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Valvular Heart Disease Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                        |
|---------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                               | LOE                                                                                                                                               | Recommendations                                                                                                                                                                                        |
| 1                                                                                                                                                 | B-R                                                                                                                                               | 1. In patients with HF, VHD should be managed in a multidisciplinary manner in accordance with clini- cal practice guidelines for VHD to prevent wors- ening of HF and adverse clinical outcomes. 1-11 |
| 1                                                                                                                                                 | C-LD                                                                                                                                              | 2. In patients with chronic severe secondary MR and HFrEF, optimization of GDMT is recom- mended before any intervention for secondary MR related to LV dysfunction. 3-5,12-14                         |

## Synopsis

GDMT applies to all patients with HFrEF, irrespective of the presence of VHD. Significant valve disease warrants evaluation by a multidisciplinary  team  with  expertise  in VHD, and management should proceed in accordance with the VHD guidelines. 15

## Mitral Regurgitation

Optimization of GDMT can improve secondary MR associated with LV dysfunction and obviate the need for intervention. 14,16,17  Therefore, optimizing GDMT and reassessing MR before MV interventions are important. Patients with persistent severe secondary MR despite GDMT may benefit from either surgical or transcatheter repair,  depending  on  clinical  scenario.  Thus,  patientcentric conversation with a multidisciplinary cardiovascular  team  that  includes  a  cardiologist  with  expertise in HF is essential when considering MV intervention. 15 Two  RCTs  of  transcatheter  mitral  valve  edge-to-edge repair (TEER) in patients with HFrEF and severe secondary  MR  have  been  performed.  The  COAPT  trial showed significant reduction in HF and all-cause mor- tality  in  patients  treated  with  TEER  and  GDMT  compared with GDMT alone, while MITRA-FR (Multicentre Study  of  Percutaneous  Mitral  Valve  Repair  MitraClip Device  in  Patients  With  Severe  Secondary  Mitral  Regurgitation) showed no benefit of TEER over GDMT in reducing  death  or  hospitalization. 6 Specifically,  transcatheter edge-to-edge MV repair has been shown to be beneficial in patients with persistent symptoms despite GDMT, appropriate anatomy on transesophageal echocardiography and with LVEF between 20% and 50%, LVESD ≤ 70 mm, and pulmonary artery systolic pressure ≤ 70 mm Hg 6  (Figure 10). Optimal management of secondary MR may depend on the degree of MR relative to L V remodeling. 4,5,14,18-22  Disproportionate MR (MR out of proportion to LV remodeling) may respond better to procedural interventions that reduce MR, such as CRT, TEER, and MV surgery. Proportionate MR may respond to measures that reverse LV remodeling and reduce LV volumes, such as GDMT and CRT.

## Aortic Stenosis

In patients with symptomatic aortic stenosis, transcatheter and surgical aortic valve repair can improve survival, symptoms,  and  LV  function. 15 However,  the  choice  of transcatheter  aortic  valve  implantation  versus  surgical aortic  valve  replacement  is  based  on  shared  decisionmaking, indications, and assessment of the risk-benefit profile. 23,24  The benefit of GDMT in nonsevere aortic stenosis and HFrEF is being evaluated in the TAVR UNLOAD (Transcatheter Aortic Valve Replacement to Unload the Left Ventricle in Patients With Advanced Heart Failure) trial. 25 GDMT  is  usually  continued  in  conjunction  with clinical surveillance and imaging in patients with nonsevere aortic stenosis and reduced EF.

## Tricuspid Regurgitation

The  severity  of  secondary  tricuspid  regurgitation  may be dynamic, depending on RV function and pulmonary hypertension,  and  management  entails  focusing  on underlying  causes,  such  as  pulmonary  hypertension, RV failure,  and  HFrEF.  Referral  to  the  multidisciplinary team for consideration of intervention might be helpful in patients with refractory tricuspid regurgitation.

## Recommendation-Specific Supportive Text

1. VHD is a significant cause of HF. In patients with HF, management of VHD should be performed by a  multidisciplinary  team  with  expertise  in  HF  and VHD,  in  accordance  with  the  VHD  guidelines. 15 Cardiologists with expertise in the management of HF are integral to the multidisciplinary team and to guiding the optimization of GDMT in patients with HF and coexisting valve disease. Severe aortic stenosis, aortic regurgitation, MR, and tricuspid regurgitation are associated with adverse outcomes and require timely assessment, optimization of medical

Figure 10. Treatment Approach in Secondary Mitral Regurgitation.

<!-- image -->

Colors correspond to Table 2. AF indicates atrial fibrillation; CABG, coronary artery bypass graft; ERO, effective regurgitant orifice; GDMT, guideline-directed medical therapy; HF, heart failure; L VEF, left ventricular ejection fraction; L VESD, left ventricular end-systolic diameter; MR, mitral regurgitation; MV, mitral valve; PASP, pulmonary artery systolic pressure; RF, regurgitant fraction; RVol, regurgitant volume; and Rx, medication. *Chordal-sparing MV replacement may be reasonable to choose over downsized annuloplasty repair. Adapted from Otto CM, et al. 15 Copyright 2021 American College of Cardiology Foundation and American Heart Association, Inc.

therapies, and consideration of surgical or transcatheter interventions accordingly to prevent worsening of HF and other adverse outcomes. 1-10,12-20,22-35

2. GDMT, including  RAAS  inhibition,  beta  blockers, and  biventricular  pacing,  improves  MR  and  L V dimensions  in  patients  with  HFrEF  and  secondary MR, particularly MR that is proportionate to L V dilatation. 1-5,12,13,17 In a small RCT, sacubitril-valsartan resulted in a significant reduction in effective regurgitant area and in regurgitant volume when compared with valsartan. The COAPT trial showed a  mortality  benefit  with  TEER  in  patients  with

severe  secondary  MR,  LVEF  between  20%  and 50%, LV end-systolic diameter ≤ 70 mm, PA systolic pressure ≤ 70  mm  Hg,  and  persistent  symptoms (NYHA class II  to  IV)  while  on  optimal  GDMT, 28 and these criteria apply when considering TEER. A cardiologist with expertise in the management of  HF  is  integral  to  shared  decision-making  for valve intervention and should guide optimization of GDMT to ensure that medical options for HF and secondary  MR  have  been  effectively  applied  for an appropriate time period and exhausted before considering intervention.

Figure 11. Recommendations for Patients With Mildly Reduced LVEF (41%-49%).

<!-- image -->

Colors correspond to COR in Table 2. Medication recommendations for HFmrEF are displayed. ACEi indicates angiotensin-converting enzyme inhibitor; ARB, angiotensin receptor blocker; ARNi, angiotensin receptor-neprilysin inhibitor; HFmrEF, heart failure with mildly reduced ejection fraction; HFrEF, heart failure with reduced ejection fraction; LVEF, left ventricular ejection fraction; MRA, mineralocorticoid receptor antagonist; and SGL T2i, sodium-glucose cotransporter 2 inhibitor.

## 7.6. Heart Failure With Mildly Reduced EF (HFmrEF) and Improved EF (HFimpHF)

## 7.6.1. HF With Mildly Reduced Ejection Fraction

| Recommendations for HF With Mildly Reduced Ejection Fraction Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for HF With Mildly Reduced Ejection Fraction Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for HF With Mildly Reduced Ejection Fraction Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                                                                  |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                 | LOE                                                                                                                                                                 | Recommendations                                                                                                                                                                                                                                                                                                                    |
| 2a                                                                                                                                                                  | B-R                                                                                                                                                                 | 1. In patients with HFmrEF, SGLT2i can be ben- eficial in decreasing HF hospitalizations and cardiovascular mortality. 1                                                                                                                                                                                                           |
| 2b                                                                                                                                                                  | B-NR                                                                                                                                                                | 2. Among patients with current or previous symp- tomatic HFmrEF (LVEF, 41%-49%), use of evidence-based beta blockers for HFrEF, ARNi, ACEi, or ARB, and MRAs may be considered to reduce the risk of HF hospitalization and cardiovascular mortality, particularly among patients with LVEF on the lower end of this spectrum. 2-9 |

## Synopsis

There are no prospective RCTs for patients specifically with HFmrEF (LVEF, 41%-49%). All data for HFmrEF are from post hoc or subsets of analyses from previous HF trials with patients now classified as HFmrEF. L VEF is a spectrum, and among patients with L VEF 41% to 49%, patients with L VEF on the lower end of this spectrum ap- pear to respond to medical therapies similarly to patients with HFrEF. Thus, it may be reasonable to treat these patients with GDMT used for treatment of HFrEF. Patients with HFmrEF should have repeat evaluation of LVEF to determine the trajectory of their disease process. Future prospective studies are needed to further clarify treatment recommendations for patients with HFmrEF. Figure 11 summarizes COR 1, 2a, and 2b for HFmrEF.

## Recommendation-Specific Supportive Text

1.  EMPEROR-Preserved (Empagliflozin Outcome Trial in Patients with Chronic Heart Failure with Preserved Ejection  Fraction)  showed  a  significant  benefit  of the SGLT2i, empagliflozin, in patients with symptomatic HF, with L VEF &gt;40% and elevated natriuretic peptides. 1  The 21% reduction in the primary composite endpoint of time to HF hospitalization or cardiovascular death was driven mostly by a significant 29% reduction in time to HF hospitalization (nonsignificant lower cardiovascular death [HR, 0.91; 95% CI, 0.76-1.0]), with no benefit on all-cause mortality. Empagliflozin also resulted in a significant reduction in  total  HF  hospitalizations,  decrease  in  the  slope of the eGFR decline, and a modest improvement in QOL at 52 weeks. Of note, the benefit was similar irrespective of the presence or absence of diabetes at baseline. In a subgroup of 1983 patients with L VEF 41% to 49% in EMPEROR-Preserved, empagliflozin, a SGL T2i, reduced the risk of the primary composite endpoint of cardiovascular death or hospitalization for HF. 1 Although the benefit in the primary endpoint did not have a significant interaction by L VEF subgroups (41%-49%, 50%-&lt;60%, and  &gt;60%), 1   in  a  subgroup  analysis  by  EF,  there was a signal for lower benefit on the primary composite endpoint, first and recurrent hospitalizations for HF at higher L VEFs &gt;62.5%. 10
2.  Post hoc and subsets of analyses of HFrEF trials that  included  HFmrEF  (L VEF  41%-49%)  have suggested benefit from use of GDMT for HFrEF (ie, beta blockers, ARNi, ACEi or ARB, and spironolactone). 2,3,5-8  The BBmeta-HF (Beta-blockers in Heart Failure Collaborative Group) performed a meta-analysis of 11 HF trials; in a subgroup of 575 patients with  L VEF  40%  to  49%  in  sinus  rhythm,  beta blockers reduced the primary outcome of all-cause and cardiovascular  mortality. 2 A  subgroup  analysis of  the  PARAGON-HF  (Prospective  Comparison of  ARNi  with  ARB  Global  Outcomes  in  HF  with Preserved Ejection  Fraction)  trial  for  patients  with LVEF 45% to 57% (lower range of EFs in the trial) suggested benefit of sacubitril-valsartan versus valsartan alone (rate ratio, 0.78; 95% CI, 0.64-0.95). 3 In a subgroup of 1322 patients with L VEF 41% to 49% in a post hoc analysis of pooled data from the

CHARM (Candesartan in Heart failure-Assessment of Reduction in Mortality and morbidity) trials, candesartan reduced risk of cardiovascular death and HF hospitalization, the risk of first HF hospitalization,  and  the  risk  of  recurrent  HF  hospitalization. 5 In  a  subgroup of 520 patients with L VEF 44% to 49% in a post hoc analysis of TOPCAT (Treatment of  Preserved  Cardiac  Function  Heart  Failure  With an Aldosterone Antagonist), spironolactone reduced the risk of the primary composite endpoint of cardiovascular  death,  HF  hospitalization,  or  resuscitated sudden death, which was mostly caused by a reduction  in  cardiovascular  mortality  with  spironolactone and among patients enrolled in North and South America. 6  Spironolactone is preferred among HFmrEF patients with  poorly  controlled  hypertension  given  previous  evidence  supporting  its  use for blood pressure management. 1 Continuation of  GDMT  for  patients  with  improved  HFrEF  and HFmrEF is important to reduce risk of recrudescent HF. 4 Meta-analyses report diverse findings with neurohormonal  antagonism  in  patients  with  HFmrEF, specifying benefit in certain subgroups, underlining the heterogeneity of this phenotype. 2,9 Patients with HFmrEF should have repeat evaluation of L VEF to determine  the  trajectory  of  their  disease  process and  should  undergo  testing  as  clinically  indicated to diagnose conditions warranting disease-specific therapy (eg, CAD, sarcoidosis, amyloidosis).

## 7.6.2. HF With Improved Ejection Fraction

| Recommendation for HF With Improved Ejection Fraction Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for HF With Improved Ejection Fraction Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for HF With Improved Ejection Fraction Referenced studies that support the recommendation are summarized in the Online Data Supplements.            |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                       | LOE                                                                                                                                                       | Recommendation                                                                                                                                                     |
| 1                                                                                                                                                         | B-R                                                                                                                                                       | 1. In patients with HFimpEF after treatment, GDMT should be continued to prevent relapse of HF and LV dysfunction, even in patients who may become asymptomatic. 1 |

## Synopsis

Although GDMT can result in improvement in symptoms, functional  capacity,  L VEF,  and  reverse  remodeling  in patients with HFrEF, 2 in  most patients, L V function and structural abnormalities do not fully normalize, and symptoms and biomarker abnormalities may persist or reoccur. Many patients deemed to have recovered from HF with resolution of symptoms and improvement of LVEF and natriuretic peptide levels will relapse after withdrawal of GDMT. 1  Resolution of symptoms and improvement in cardiac function and biomarkers after treatment does not reflect full and sustained recovery but, rather, remission, which requires treatment to be maintained. 3  Stage C HF patients are defined as patients with structural heart disease with previous or current symptoms of HF. In those patients  who  do  not  improve  (ie,  patients  who  remain symptomatic or with LV dysfunction), GDMT should not only be continued but also optimized.

## Recommendation-Specific Supportive Text

1.  In  an  open-label  RCT, 1 phased  withdrawal  of  HF medications  in  patients  with  previous  DCM-who were now asymptomatic, whose LVEF had improved from &lt;40% to ≥ 50%, whose left ventricular enddiastolic volume (L VEDV) had normalized, and who had  an  NT-proBNP  concentration  &lt;250  ng/Lresulted  in  relapse  of  cardiomyopathy  and  HF in  40%  of  the  patients  within  6  months.  Relapse was defined by at least 1 of these: 1) a reduction in  L VEF  by  &gt;10%  and  &lt;50%;  2)  an  increase  in LVEDV  by  &gt;10%  and  to  higher  than  the  normal range; 3) a 2-fold rise in NT-proBNP concentration and to &gt;400 ng/L; or 4) clinical evidence of HF. Treatment was withdrawn successfully in only 50% of patients. 1  Secondary analyses showed worsening Kansas City Cardiomyopathy Questionnaire scores, a substantial reduction in L VEF, and nonsignificant increases in NT-proBNP and LV volumes with withdrawal of HF medications.

## 7.7 . Preserved EF (HFpEF)

## 7.7.1. HF With Preserved Ejection Fraction

| Recommendations for HF With Preserved Ejection Fraction* Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for HF With Preserved Ejection Fraction* Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for HF With Preserved Ejection Fraction* Referenced studies that support the recommendations are summarized in the Online Data Supplements.                                      |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                           | LOE                                                                                                                                                           | Recommendations                                                                                                                                                                                  |
| 1                                                                                                                                                             | C-LD                                                                                                                                                          | 1. Patients with HFpEF and hypertension should have medication titrated to attain blood pres- sure targets in accordance with published clini- cal practice guidelines to prevent morbidity. 1-3 |
| 2a                                                                                                                                                            | B-R                                                                                                                                                           | 2. In patients with HFpEF, SGLT2i can be ben- eficial in decreasing HF hospitalizations and cardiovascular mortality. 4                                                                          |
| 2a                                                                                                                                                            | C-EO                                                                                                                                                          | 3. In patients with HFpEF, management of AF can be useful to improve symptoms.                                                                                                                   |
| 2b                                                                                                                                                            | B-R                                                                                                                                                           | 4. In selected patients with HFpEF, MRAs may be considered to decrease hospitalizations, par- ticularly among patients with LVEF on the lower end of this spectrum. 5-7                          |
| 2b                                                                                                                                                            | B-R                                                                                                                                                           | 5. In selected patients with HFpEF, the use of ARB may be considered to decrease hospital- izations, particularly among patients with LVEF on the lower end of this spectrum. 8,9                |
| 2b                                                                                                                                                            | B-R                                                                                                                                                           | 6. In selected patients with HFpEF, ARNi may be considered to decrease hospitalizations, par- ticularly among patients with LVEF on the lower end of this spectrum. 10,11                        |
| 3: No- Benefit                                                                                                                                                | B-R                                                                                                                                                           | 7. In patients with HFpEF, routine use of nitrates or phosphodiesterase-5 inhibitors to increase activity or QOL is ineffective. 12,13                                                           |

*See Section 7.2, 'Diuretics and Decongestion Strategies in Patients with HF, ' and Section 10.2, 'Management of Atrial Fibrillation (AF) in HF' for recommendations for use of diuretics and management of AF in HF.

Figure 12. Recommendations for Patients With Preserved LVEF ( ≥ 50%).

<!-- image -->

Colors correspond to COR in Table 2. Medication recommendations for HFpEF are displayed. ARB indicates angiotensin receptor blocker; ARNi, angiotensin receptor-neprilysin inhibitor; HF, heart failure; HFpEF, heart failure with preserved ejection fraction; L VEF, left ventricular ejection fraction; MRA, mineralocorticoid receptor antagonist; and SGLT2i, sodium-glucose cotransporter-2 inhibitor. *Greater benefit in patients with L VEF closer to 50%.

## Synopsis

HFpEF (LVEF ≥ 50%) is highly prevalent, accounting for up to 50% of all patients with HF, and is associated with significant morbidity and mortality. 14  HFpEF is a heterogenous disorder, contributed to by comorbidities  that  include  hypertension,  diabetes,  obesity, CAD, CKD, and specific causes such as cardiac amyloidosis. 15-17 Clinical trials have used variable definitions of HFpEF (eg, LVEF ≥ 40%, 45%, or 50%, and the varying need for accompanying evidence of structural  heart  disease  or  elevated  levels  of  natriuretic peptides). 18 Until  recently,  clinical  trials  had  been generally disappointing, with no benefit on mortality and marginal benefits on HF hospitalizations. 5,8,11,19,20 Currently,  recommended  management  is  that  used for  HF  in  general  with  use  of  diuretics  to  reduce congestion  and  improve  symptoms  (see  Section 7.1.1  for  recommendations  for  nonpharmacological management  and  Section  7.2  for  recommendations for  diuretics),  identification  and  treatment  of  specific  causes  such  as  amyloidosis,  and  management of  contributing  comorbidities  such  as  hypertension, CAD, and AF (see Section 10.2 for recommendations on management of AF). Figure 12 summarizes COR 1, 2a, and 2b for HFpEF.

## Recommendation-Specific Supportive Text

1. The role of blood pressure control is well established for the prevention of HF, as well as for reduction of other cardiovascular events and HF mortality in patients without prevalent baseline HF. 1-3,21-24  The SPRINT  (Systolic  Blood  Pressure  Intervention) trial  and  meta-analyses  established  that  more intensive  blood  pressure  control  in  patients  with high  cardiovascular  risk  significantly  reduces  HF and other  cardiovascular  outcomes. 2,3,25 In  recent clinical practice guidelines for hypertension, blood pressure targets in HFpEF are extrapolated from those for treatment of patients with hypertension in general. 26  However, the optimal blood pressure goal and antihypertensive regimens are not known for patients with HFpEF. RAAS antagonists including ACEi, ARB, MRA, and possibly ARNi, could be first-line agents given experience with their use in HFpEF trials. 8,10,16,20,27,28  Beta blockers may be used to treat hypertension in patients with a history of MI, 27 symptomatic CAD, or AF with rapid ventricular response. These effects need to be balanced with the potential contribution of chronotropic incompetence to exercise intolerance in some patients. 29
2.  EMPEROR-Preserved (Empagliflozin Outcome Trial  in  Patients  with  Chronic  Heart  Failure  with Preserved Ejection Fraction) showed a significant benefit of the SGL T2i, empagliflozin, in symptomatic  patients  with  HF  with  L VEF  &gt;40%  and  elevated  natriuretic  peptides. 30   The  21%  reduction in  the  primary  composite  endpoint  of  time  to  HF hospitalization  or  cardiovascular  death  was  driven mostly by a significant 29% reduction in time to HF hospitalization (nonsignificant lower cardiovascular death [HR, 0.91; 95% CI, 0.76-1.0]), with no benefit on all-cause mortality. Empagliflozin also resulted in a significant reduction in total HF hospitalizations, decrease in the slope of the eGFR decline, and a modest improvement in QOL at 52 weeks. Of note, the  benefit  was  similar  irrespective  of  the  presence or absence of diabetes at baseline. Although the benefit in the primary endpoint did not have a significant interaction by L VEF subgroups (&lt;50%, 50%-&lt;60%, and &gt;60%), 30  in a subgroup analysis by EF, there was a signal for lower benefit on the primary composite endpoint, first and recurrent HF hospitalizations at higher L VEFs &gt;62.5%. 31
3. Large,  randomized  clinical  trial  data  are  unavailable to specifically guide therapy in patients with HFpEF and AF. Currently, the comprehensive care of AF can be extrapolated from the clinical practice guidelines for AF, with individualization of strategies for rate or rhythm control in patients with HFpEF (see  also  Section  10.2,  'Management  of  Atrial

Fibrillation (AF) in HF,' for HF specific recommendations for AF). Although beta blockers and nondihydropyridine calcium channel blockers are often considered as first-line agents for heart rate control in patients with HFpEF, a recent smaller openlabel  trial,  RATE-AF  in  elderly  patients  with  AF and symptoms of HF (most with preserved LVEF), compared the use of the beta blocker, bisoprolol, to digoxin. 32 At 6 months, the primary endpoint of QOL was similar between the 2 groups. However, several secondary QOL endpoints, functional capacity, and reduction in NT-proBNP favored digoxin at 12 months. There was a similar heart rate reduction in both groups. Of note, more adverse events such as higher rates of dizziness, lethargy, and hypotension occurred with beta blockers than digoxin. The comprehensive care of AF is beyond the scope of these  guidelines.  AF-specific  care  recommendations can be found in separate ACC/AHA clinical practice guidelines. 33,34

4. MRAs improve diastolic  function  in  patients  with HFpEF. 35 The TOPCAT trial investigated the effects of spironolactone in patients with HFpEF. The small reduction (HR, 0.89) in the composite of death, aborted cardiac death, and HF hospitalization  was  not  statistically  significant,  although  HF hospitalization  was  reduced  (HR,  0.83);  adverse effects  of  hyperkalemia  and  increasing  creatinine  levels  were  more  common  in  the  treatment group. 5 A  post  hoc  analysis 6 showed  efficacy  in the Americas (HR 0.83) but not in Russia-Georgia (HR 1.10). A sample of the Russia-Georgia population in the active treatment arm had nondetectable levels of a spironolactone metabolite. Post hoc analyses have limitations, but they suggest a possibility of benefit in appropriately selected patients with  symptomatic  HFpEF  (L VEF ≥ 45%, elevated BNP level or HF admission within 1 year, eGFR &gt;30 mL/min/1.73 m 2 , creatinine &lt;2.5 mg/dL, and potassium  &lt;5.0  mEq/L).  Furthermore,  another post hoc analysis suggested that the potential efficacy of spironolactone was greatest at the lower end of the LVEF spectrum. 7  Careful monitoring of potassium,  renal  function,  and  diuretic  dosing  at initiation  and  follow-up  are  key  to  minimizing  the risk of hyperkalemia and worsening renal function.
5. Although  RAAS  inhibition  strategies  have  been successful in the treatment of HFrEF, and RAAS activation  is  suggested  in  HFpEF, 36,37 clinical  trials  with  RAAS  inhibition  have  not  showed  much benefit in patients HFpEF. In  the  CHARMPreserved  (Candesartan  in  patients  with  chronic HF  and  preserved  left-ventricular  ejection  fraction)  trial,  patients  with  L VEF  &gt;40%  were  randomized to an ARB, candesartan, or to placebo. 38 The  primary  endpoint  (cardiovascular  death  or
3. HF  hospitalization)  was  not  significantly  different  between  the  2  groups  (HR,  0.89;  95%  CI, 0.77-1.03, P =0.118; covariate-adjusted HR, 0.86; P =0.051). Cardiovascular mortality was identical in the 2 groups; HF hospitalizations were lower in the candesartan arm, with borderline statistical significance on the covariate-adjusted analysis only (HR, 0.84;  95%  CI,  0.70-1.00; P =0.047;  unadjusted P =0.072). The number of individuals hospitalized for HF (reported by the investigator) was lower in the candesartan group than placebo (230 versus 279; P =0.017). A post hoc analysis of the CHARM trials showed that improvement in outcomes with candesartan was greater at the lower end the L VEF spectrum. 39 In  a  meta-analysis  of  7694  patients with HFpEF in 4 trials evaluating ARB, there was no  signal  for  benefit  on  cardiovascular  mortality (HR,  1.02),  all-cause  mortality  (HR,  1.02),  or  HF hospitalization (HR, 0.92; 95% CI, 0.83-1.02). 40,41
6.  In the PARAMOUNT-HF (Prospective Comparison of  ARNi  With  ARB  on  Management  of  Heart Failure  With  Preserved  Ejection  Fraction)  trial,  a phase II RCT in patients with HFpEF (L VEF ≥ 45%), sacubitril-valsartan  resulted  in  a  lower  level  of NT-proBNP after 12 weeks of treatment compared with  the  ARB,  valsartan. 42   In  the  PARAGON-HF (Prospective Comparison of Angiotensin Receptor Neprilysin Inhibitor With Angiotensin  Receptor Blocker  Global  Outcomes  in  Heart  Failure  and Preserved Left Ventricular Ejection Fraction) trial,  in  4822  patients  with  HFpEF  (L VEF ≥ 45%, HF admission within 9 months or elevated natriuretic peptide levels, and eGFR ≥ 30 mL/min/m 2 ), sacubitril-valsartan  compared  with  valsartan  did not achieve a significant reduction in the primary composite  endpoint  of  cardiovascular  death  or total (first and recurrent) HF hospitalizations (rate ratio,  0.87;  95%  CI,  0.75-1.01; P =0.06). 10 Given the primary outcome was not met, other analyses are exploratory. There was no benefit of sacubitrilvalsartan  on  cardiovascular  death  (HR,  0.95)  or total  mortality  (HR,  0.97).  There  was  a  signal  of benefit for the ARNi for HF hospitalizations (rate ratio,  0.85;  95%  CI,  0.72-1.00; P =0.056).  The occurrence  of  hyperkalemia  and  the  composite outcome of decline in renal function favored sacubitril-valsartan, but it was associated with a higher incidence of hypotension and angioedema. In prespecified  subgroup  analyses,  a  differential  effect by LVEF and sex was noted. A benefit of sacubitrilvalsartan compared with valsartan was observed in patients with L VEF below the median (45%-57%; rate ratio, 0.78; 95% CI, 0.64-0.95), and in women (rate ratio, 0.73; 95% CI, 0.59-0.90). 10,43,44
7. Nitrate  therapy  can  reduce  pulmonary  congestion  and  improve  exercise  tolerance  in  patients

with HFrEF. However, the NEAT-HFpEF (Nitrate's Effect on Activity Tolerance in Heart Failure With Preserved  Ejection  Fraction)  trial 45   randomized 110 patients with EF ≥ 50% on stable HF therapy, not  including  nitrates,  and  with  activity  limited  by dyspnea, fatigue, or chest pain, to either isosorbide mononitrate  or  placebo  and  found  no  beneficial effects on activity levels, QOL, exercise tolerance, or NT-proBNP levels. Although the routine use of nitrates  in  patients  with  HFpEF  does  not  appear beneficial,  patients  with  HFpEF  and  symptomatic CAD may still receive symptomatic relief with nitrates. Phosphodiesterase-5 inhibition augments the nitric oxide system by upregulating cGMP activity.  The  RELAX  (Phosphodiesterase-5  Inhibition to  Improve  Clinical  Status  and  Exercise  Capacity in Heart Failure with Preserved Ejection Fraction) trial 13  randomized 216 patients with EF ≥ 50% on stable HF therapy and with reduced exercise tolerance (peak observed VO 2 ,  &lt;60% of predicted) to phosphodiesterase-5 inhibition with sildenafil or placebo. This study did not show improvement in oxygen consumption or exercise tolerance.

## 7.8. Cardiac Amyloidosis

## 7.8.1. Diagnosis of Cardiac Amyloidosis

| Recommendations for Diagnosis of Cardiac Amyloidosis Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Diagnosis of Cardiac Amyloidosis Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Diagnosis of Cardiac Amyloidosis Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                    |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                         | LOE                                                                                                                                                         | Recommendations                                                                                                                                                                                                                              |
| 1                                                                                                                                                           | B-NR                                                                                                                                                        | 1. Patients for whom there is a clinical suspi- cion for cardiac amyloidosis* 1-5 should have screening for serum and urine monoclonal light chains with serum and urine immuno- fixation electrophoresis and serum free light chains. 6     |
| 1                                                                                                                                                           | B-NR                                                                                                                                                        | 2. In patients with high clinical suspicion for car- diac amyloidosis, without evidence of serum or urine monoclonal light chains, bone scintigra- phy should be performed to confirm the pres- ence of transthyretin cardiac amyloidosis. 7 |
| 1                                                                                                                                                           | B-NR                                                                                                                                                        | 3. In patients for whom a diagnosis of transthyre- tin cardiac amyloidosis is made, genetic testing with TTR gene sequencing is recommended to differentiate hereditary variant from wild-type transthyretin cardiac amyloidosis. 8          |

*LV  wall  thickness ≥ 14  mm  in  conjunction  with  fatigue,  dyspnea,  or edema, especially in the context of discordance between wall thickness on echocardiogram and QRS voltage on ECG, and in the context of aortic stenosis,  HFpEF,  carpal  tunnel  syndrome,  spinal  stenosis,  and  autonomic  or sensory polyneuropathy.

## Synopsis

Cardiac amyloidosis is a restrictive cardiomyopathy with extracellular  myocardial  protein  deposition,  most  commonly monoclonal immunoglobulin light chains (amyloid cardiomyopathy  [AL-CM])  or  transthyretin  amyloidosis (ATTR-CM).  ATTR  can  be  caused  by  pathogenic  variants in the transthyretin gene TTR (variant transthyretin amyloidosis, ATTRv) or wild-type transthyretin (wild-type transthyretin  amyloidosis,  ATTRwt).  A  diagnostic  approach is outlined in Figure 13. 9

## Recommendation-Specific Supportive Text

1. Diagnosis  of  ATTR-CM  requires  a  high  index  of suspicion. L V thickening (wall thickness ≥ 14 mm) along with fatigue, dyspnea, or edema should trigger consideration of ATTR-CM, especially with discordance between wall thickness on echocardiogram and QRS voltage on ECG, 10  or other findings such as apical sparing of L V longitudinal strain impairment on echocardiography and diffuse late-gadolinium enhancement on cardiac MRI. ATTR-CM is prevalent in severe aortic stenosis, 1 HFpEF, 2 carpal tunnel syndrome, 3 lumbar spinal stenosis, 4  and autonomic or sensory polyneuropathy. 5  Practically, screening for the presence of a monoclonal light chain and technetium pyrophosphate ( 99m Tc-PYP) scan  can  be  ordered  at  the  same  time  for  convenience,  but  the  results  of  the 99m Tc-PYP  scan are  interpreted  only  on  the  context  of  a  negative monoclonal  light chain screen. 99m Tc-PYP scans may be positive even in AL amyloidosis 7 and, thus, a bone scintigraphy scan alone, without concomitant testing for light chains, cannot distinguish ATTR-CM  from  AL-CM.  Serum  free  light  chain (FLC)  concentration  and  serum  and  urine  immunofixation  electrophoresis  (IFE)  are  assessed  to rule  out  AL-CM.  IFE  is  preferred  because  serum plasma electrophoresis and urine plasma electrophoresis are less sensitive. Together, measurement of serum IFE, urine IFE, and serum FLC is &gt;99% sensitive for AL amyloidosis. 6,11
2. The use of  99m Tc  bone-avid  compounds for bone scintigraphy allows for noninvasive diagnosis of ATTR-CM. 7 99m Tc compounds  include PYP, 3,3-diphosphono-1,2-propanodicarboxylic acid, and hydromethylene diphosphonate, and  PYP is used in the United States. In the absence of a light-chain abnormality, the 99m Tc-PYP scan is diagnostic of ATTR-CM if there is grade 2/3 cardiac uptake or an H/CL ratio of &gt;1.5. In fact, the presence of grade 2/3 cardiac uptake in the absence of  a  monoclonal  protein  in  serum  or  urine  has  a very  high  specificity  and  positive  predictive  value for  ATTR-CM. 7   SPECT is assessed in all positive scans to confirm that uptake represents myocardial retention of the tracer and not blood pool or rib uptake signal. 12

Figure 13. Diagnostic and Treatment of Transthyretin Cardiac Amyloidosis Algorithm.

<!-- image -->

Colors correspond to COR in Table 2. AF indicates atrial fibrillation; AL-CM, amyloid cardiomyopathy; ATTR-CM, transthyretin amyloid cardiomyopathy; ATTRv, variant transthyretin amyloidosis; ATTRwt, wild-type transthyretin amyloidosis; CHA 2 DS 2 -VASc, congestive heart failure, hypertension, age ≥ 75 years, diabetes mellitus, stroke or transient ischemic attack (TIA), vascular disease, age 65 to 74 years, sex category; ECG, electrocardiogram; H/CL, heart to contralateral chest; HFrEF, heart failure with reduced ejection fraction; IFE, immunofixation electrophoresis; MRI, magnetic resonance imaging; NYHA, New York Heart Association; PYP, pyrophosphate; Tc, technetium; and TTR, transthyretin.

3.  If ATTR-CM is identified, then genetic sequencing of the TTR gene will determine if the patient has a pathological variant (ATTRv) or wild-type (ATTRwt) disease. 12  Differentiating ATTRv from ATTRwt is important because confirmation

of ATTRv  would  trigger genetic counseling and potential screening of  family  members and  therapies,  inotersen  and  patisiran,  which are  presently  approved  only  for  ATTRv  with polyneuropathy. 13,14

## 7.8.2. Treatment of Cardiac Amyloidosis

| Recommendations for Treatment of Cardiac Amyloidosis Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Treatment of Cardiac Amyloidosis Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Treatment of Cardiac Amyloidosis Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                                                                           |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                         | LOE                                                                                                                                                         | Recommendations                                                                                                                                                                                                                                                                                                                     |
| 1                                                                                                                                                           | B-R                                                                                                                                                         | 1. In select patients with wild-type or variant trans- thyretin cardiac amyloidosis and NYHA class I to III HF symptoms, transthyretin tetramer sta- bilizer therapy (tafamidis) is indicated to reduce cardiovascular morbidity and mortality. 1                                                                                   |
| Value Statement: Low Value (B-NR)                                                                                                                           | Value Statement: Low Value (B-NR)                                                                                                                           | 2. At 2020 list prices, tafamidis provides low economic value (>$180000 per QALY gained) in patients with HF with wild-type or variant transthyretin cardiac amyloidosis. 2                                                                                                                                                         |
| 2a                                                                                                                                                          | C-LD                                                                                                                                                        | 3. In patients with cardiac amyloidosis and AF, anticoagulation is reasonable to reduce the risk of stroke regardless of the CHA 2 DS 2 -VASc (congestive heart failure, hypertension, age ≥ 75 years, diabetes mellitus, stroke or transient ischemic attack [TIA], vascular disease, age 65 to 74 years, sex category) score. 3,4 |

## Synopsis

For patients with ATTR-CM and EF ≤ 40%, GDMT may be  poorly  tolerated.  The  vasodilating  effects  of  ARNi, ACEi, and ARB may exacerbate hypotension, especially with  amyloid-associated  autonomic  dysfunction.  Beta blockers may worsen HF symptoms as patients with ATTR-CM rely on heart rate response to maintain cardiac output. The benefit of ICDs in ATTR-CM has not been studied  in  randomized  trials,  and  a  case-control  study showed unclear benefit. 5  CRT has not been studied in ATTR-CM with HFrEF. Disease-modifying therapies include TTR silencers (disrupt hepatic synthesis via mRNA inhibition/degradation: inotersen and  patisiran),  TTR stabilizers (prevent misfolding/deposition: diflunisal and tafamidis), and TTR disruptors (target tissue clearance: doxycycline,  tauroursodeoxycholic  acid  [TUDCA],  and epigallocatechin-3-gallate  [EGCG]  in  green  tea).  Light chain  cardiac  amyloidosis  is  managed  by  hematologyoncology specialists and beyond the scope of cardiologists, but diagnosis is often made by cardiologists when cardiac amyloid becomes manifest (Figure 13). AL amyloidosis  is  treatable,  and  patients  with  AL  amyloidosis with cardiac involvement should promptly be referred to hematology-oncology for timely treatment. Inotersen and patisiran are associated with slower progression of amyloidosis-related  polyneuropathy  in  ATTRv-CM. 6,7 There are  ongoing trials  of  the  impact  of  inotersen  and  patisiran and newer generation mRNA inhibitors-degraders on cardiovascular morbidity or mortality. There is limited benefit  of  diflunisal, 8 doxycycline  plus  TUDCA, 9,10 and EGCG, 11  on surrogate endpoints such as LV mass, but the  impact  of  these  agents  on  cardiovascular  morbidity and mortality has not been assessed. Evaluation and management of autonomic  dysfunction,  volume  status, and arrhythmia are important.

## Recommendation-Specific Supportive Text

1. Tafamidis is currently the only therapy to improve cardiovascular outcomes in ATTR-CM. 1  Tafamidis binds  the  thyroxin-binding  site  of  TTR.  In  the ATTR-ACT (Safety  and  Efficacy  of  Tafamidis  in Patients With Transthyretin Cardiomyopathy) clinical  trial,  a  randomized  trial  of  patients  with ATTRwt-CM or ATTRv-CM and NYHA class I to III symptoms, tafamidis had lower all-cause mortality  (29.5%  versus  42.9%)  and  lower  cardiovascular-related hospitalization (0.48 versus 0.70 per year) after 30 months. 1  There was a higher rate of cardiovascular-related hospitalizations in patients with NYHA class III HF, potentially attributable  to  longer  survival  during  a  more  severe period of disease. Given that tafamidis prevents but does not reverse amyloid deposition, tafamidis  is  expected  to  have  greater  benefit  when administered early in the disease course. As the survival curves separate after 18 months, patients for whom noncardiac disease is not expected to limit survival should be selected. Benefit has not been  observed  in  patients  with  class  IV  symptoms,  severe  aortic  stenosis,  or  impaired  renal function  (eGFR  &lt;25  mL·min -1 ·1.73  m -2   body surface area). Tafamidis is available in 2 formulations: tafamidis meglumine is available in 20-mg capsules; and the FDA-approved dose is 80 mg (4  capsules)  once  daily.  Tafamidis  is  also  available in 61-mg capsules; the FDA-approved dose for this new formulation is 61 mg once daily.
2. One  model-based  analyses  used  the  results  of the ATTR-ACT study 1  to evaluate the cost-effectiveness of chronic tafamidis compared with no amyloidosis-specific therapy among patients with wild-type or variant transthyretin amyloidosis and NYHA class I to III  HF. 2 With  assumptions  that tafamidis remained effective beyond the clinical trial duration, they estimated tafamidis increased average survival by 1.97 years and QAL Y by 1.29. Despite  these  large  clinical  benefits,  tafamidis (with an annual cost of $225 000) had an incremental  cost-effectiveness  ratio  &gt;$180 000  per QALY gained, the benchmark used by this guideline  for  low  value.  The  cost  of  tafamidis  would need  to  decrease  by  approximately  80%  for  it to  be  intermediate  value  with  a  cost  per  QAL Y &lt;$180 000.
3. Intracardiac  thrombosis  occurs  in  approximately one-third of patients with cardiac amyloidosis, in some cases in the absence of diagnosed AF 3,4,12 and  regardless  of  CHA 2 DS 2 -VASc  score. 13 The use of anticoagulation reduced the risk of intracardiac  thrombi  in  a  retrospective  study. 4 The choice of direct oral anticoagulants  (DOAC)

## Table 16. ESC Definition of Advanced HF

| All these criteria must be present despite optimal guideline-directed treatment:                                                                                                                                                                                                                              | All these criteria must be present despite optimal guideline-directed treatment:                                                                                                                                                                                                                              |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1.                                                                                                                                                                                                                                                                                                            | Severe and persistent symptoms of HF (NYHA class III [advanced] or IV)                                                                                                                                                                                                                                        |
| 2.                                                                                                                                                                                                                                                                                                            | Severe cardiac dysfunction defined by ≥ 1 of these:                                                                                                                                                                                                                                                           |
|                                                                                                                                                                                                                                                                                                               | LVEF ≤ 30% Isolated RV failure Nonoperable severe valve abnormalities Nonoperable severe congenital heart disease EF ≥ 40%, elevated natriuretic peptide levels and evidence of significant diastolic dysfunction                                                                                             |
| 3.                                                                                                                                                                                                                                                                                                            | Hospitalizations or unplanned visits in the past 12 mo for episodes of:                                                                                                                                                                                                                                       |
|                                                                                                                                                                                                                                                                                                               | Congestion requiring high-dose intravenous diuretics or diuretic com- binations Low output requiring inotropes or vasoactive medications Malignant arrhythmias                                                                                                                                                |
| 4.                                                                                                                                                                                                                                                                                                            | Severe impairment of exercise capacity with inability to exercise or low 6-minute walk test distance (<300 m) or peak VO 2 (<12-14 mL/kg/min) estimated to be of cardiac origin                                                                                                                               |
| Criteria 1 and 4 can be met in patients with cardiac dysfunction (as described in criterion 2) but who also have substantial limitations as a result of other conditions (eg, severe pulmonary disease, noncardiac cirrhosis, renal disease). The therapeutic options for these patients may be more limited. | Criteria 1 and 4 can be met in patients with cardiac dysfunction (as described in criterion 2) but who also have substantial limitations as a result of other conditions (eg, severe pulmonary disease, noncardiac cirrhosis, renal disease). The therapeutic options for these patients may be more limited. |

EF indicates  ejection  fraction;  ESC,  European  Society  of  Cardiology;  HF, heart failure; LVEF, left ventricular ejection fraction; NYHA, New York Heart Association; RV, right ventricular; and VO 2 , oxygen consumption/oxygen uptake. Adapted with permission from Crespo-Leiro et al. 1

versus warfarin has not been studied in patients with ATTR, nor has the role of left atrial appendage closure devices. The risk of anticoagulation on  bleeding  risk  in  patients  with  ATTR-CM  and AF has not been established. However, although patients with AL amyloidosis may have acquired hemostatic  abnormalities,  including  coagulation factor deficiencies, hyperfibrinolysis, and platelet dysfunction,  TTR  amyloidosis  is  not  associated with hemostatic defects.

## 8. STAGE D (ADVANCED) HF

## 8.1. Specialty Referral for Advanced HF

| Recommendation for Specialty Referral for Advanced HF   | Recommendation for Specialty Referral for Advanced HF   | Recommendation for Specialty Referral for Advanced HF                                                                                                                                                                                                                                                  |
|---------------------------------------------------------|---------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                     | LOE                                                     | Recommendation                                                                                                                                                                                                                                                                                         |
| 1                                                       | C-LD                                                    | 1. In patients with advanced HF, when consistent with the patient's goals of care, timely refer- ral for HF specialty care is recommended to review HF management and assess suitability for advanced HF therapies (eg, LVAD, cardiac transplantation, palliative care, and palliative inotropes). 1-6 |

## Synopsis

A subset of patients with chronic HF will continue to progress  and  develop  persistently  severe  symptoms despite  maximum  GDMT.  Several  terms  have  been used to describe this population, including 'end-stage,' 'advanced,' and 'refractory' HF. In 2018, the European Society of Cardiology updated its definition of advanced HF (Table 16), which now includes 4 distinct criteria. 1 The revised definition focuses on refractory symptoms rather than cardiac function and more clearly acknowledges that advanced HF can occur in patients without severely reduced EF, including those with isolated RV dysfunction, uncorrectable valvular or congenital heart disease, and in patients with preserved and mildly reduced  EF. 1,3   The  INTERMACS  (Interagency  Registry for  Mechanically  Assisted  Circulatory  Support)  has developed 7 profiles that further stratify patients with advanced HF (Table 17). 7

Determining that HF and not a concomitant pulmonary disorder  is  the  basis  of  dyspnea  is  important.  Severely symptomatic  patients  presenting  with  a  new  diagnosis of HF can often improve substantially if they are initially stabilized. Patients should also be evaluated for nonadherence  to  medications. 8-11 Finally,  a  careful  review  of medical management should be conducted to verify that all  therapies likely to improve clinical status have been considered.

## Recommendation-Specific Supportive Text

1.  Clinical indicators of advanced HF that should trigger  possible  referral  to  an  advanced  HF  specialist are shown in Table 18. 1,2,12-14 Timely referral for review and consideration of advanced HF therapies is crucial to achieve optimal patient outcomes. 15-17 Acronyms such as I-Need-Help…
2. I, Intravenous inotropes
3. N,    New York Heart Association (NYHA) class IIIB to IV or persistently elevated natriuretic peptides
4. E,    End-organ dysfunction
5. E,    EF ≤ 35%
6. D,    Defibrillator shocks
7. H,    Hospitalizations &gt;1
8. E,    Edema despite escalating diuretics
9. L,      Low systolic BP ≤ 90, high heart rate
10. P,      Prognostic  medication;  progressive  intolerance or down-titration of GDMT

…have been developed to assist in decision-making for referral to advanced HF. 18  Indications and contraindications to durable mechanical support are listed in Table  19.  After  patients  develop  end-organ  dysfunction or cardiogenic shock, they may no longer qualify for  advanced  therapies. 19,20   A  complete  assessment of the patient is not required before referral, because comprehensive,  multidisciplinary  assessment  of  cardiac  disease  and  comorbid  conditions  is  routinely performed  when  evaluating  patients  for  advanced therapies. 19,20   Decisions  around  evaluation  and  use of advanced therapies should be informed by the patient's values, goals, and preferences. Discussion with

Table 17. INTERMACS Profiles

|   Profile* | Profile Description                      | Features                                                                                                                                                                                                                                                                                                                                                                                                    |
|------------|------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|          1 | Critical cardiogenic shock               | Life-threatening hypotension and rapidly escalating inotropic/pressor support, with critical organ hypoperfusion often confirmed by worsening acidosis and lactate levels.                                                                                                                                                                                                                                  |
|          2 | Progressive decline                      | 'Dependent' on inotropic support but nonetheless shows signs of continuing deterioration in nutrition, renal function, fluid retention, or other major status indicator. Can also apply to a patient with refractory volume over- load, perhaps with evidence of impaired perfusion, in whom inotropic infusions cannot be maintained because of tachyarrhythmias, clinical ischemia, or other intolerance. |
|          3 | Stable but inotrope dependent            | Clinically stable on mild-moderate doses of intravenous inotropes (or has a temporary circulatory support de- vice) after repeated documentation of failure to wean without symptomatic hypotension, worsening symptoms, or progressive organ dysfunction (usually renal).                                                                                                                                  |
|          4 | Resting symptoms on oral therapy at home | Patient who is at home on oral therapy but frequently has symptoms of congestion at rest or with activities of daily living (dressing or bathing). He or she may have orthopnea, shortness of breath during dressing or bath- ing, gastrointestinal symptoms (abdominal discomfort, nausea, poor appetite), disabling ascites, or severe lower extremity edema.                                             |
|          5 | Exertion intolerant                      | Patient who is comfortable at rest but unable to engage in any activity, living predominantly within the house or housebound.                                                                                                                                                                                                                                                                               |
|          6 | Exertion limited                         | Patient who is comfortable at rest without evidence of fluid overload but who is able to do some mild ac- tivity. Activities of daily living are comfortable, and minor activities outside the home such as visiting friends or going to a restaurant can be performed, but fatigue results within a few minutes or with any meaningful physical exertion.                                                  |
|          7 | Advanced NYHA class III                  | Patient who is clinically stable with a reasonable level of comfortable activity, despite a history of previous decompensation that is not recent. This patient is usually able to walk more than a block. Any decompensation requiring intravenous diuretics or hospitalization within the previous month should make this person a Patient Profile 6 or lower.                                            |

ICD indicates implantable cardioverter-defibrillator; INTERMACS, Interagency Registry for Mechanically Assisted Circulatory Support; and NYHA, New York Heart Association.

Adapted from Stevenson et al, 7  with permission from the International Society for Heart and Lung Transplantation.

*Modifier options: Profiles 3 to 6 can be modified for patients with recurrent decompensations leading to frequent (generally at least 2 in past 3 mo or 3 in past 6 mo) emergency department visits or hospitalizations for intravenous diuretics, ultrafiltration, or brief inotropic therapy. Profile 3 can be modified in this manner if the patient is usually at home. If a Profile 7 patient meets the modification of frequent hospitalizations, the patient should be moved to Profile 6 or worse. Other modifier options include arrhythmia, which should be used in the presence of recurrent ventricular tachyarrhythmias contributing to the overall clinical course (eg, frequent ICD shocks or requirement of external defibrillation, usually more than twice weekly); or temporary circulatory support for hospitalized patients Profiles 1 to 3.

HF specialists and other members of the multidisciplinary team may help ensure that the patient has adequate information to make an informed decision.

## 8.2. Nonpharmacological Management: Advanced HF

| Recommendation for Nonpharmacological Management: Advanced HF   | Recommendation for Nonpharmacological Management: Advanced HF   | Recommendation for Nonpharmacological Management: Advanced HF                                                                         |
|-----------------------------------------------------------------|-----------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                             | LOE                                                             | Recommendation                                                                                                                        |
| 2b                                                              | C-LD                                                            | 1. For patients with advanced HF and hypona- tremia, the benefit of fluid restriction to reduce congestive symptoms is uncertain. 1-4 |

## Synopsis

Hyponatremia  and  diuretic-refractory  congestion  is common in advanced HF and is associated with poor clinical 5,6 and  patient-reported  outcomes. 7 Moreover, improvement  in  hyponatremia  has  been  shown  to improve clinical outcomes. 8,9 Fluid  restriction  is  commonly  prescribed  for  patients  with  hyponatremia  in acute HF but only improves hyponatremia modestly. 1 Although restricting fluid is a common recommendation for patients with HF, evidence in this area is of low quality, 10  and many studies have not included patients with advanced HF specifically. Moreover, fluid restric- tion  has  limited-to-no  effect  on  clinical  outcomes  or diuretic use. 4  Although HF nutritional counseling typically focuses on restricting sodium and fluid, patients with advanced HF have the greatest risk of developing cachexia or malnutrition. 11 Hence, dietary restrictions and recommendation should be both evidence-based and comprehensive.

## Recommendation-Specific Supportive Text

1.  In a registry study of hyponatremia in acute decompensated HF, fluid restriction only improved hyponatremia  marginally. 1 A  registered  dietitian-guided fluid  and  sodium  restriction  intervention  improved NYHA functional  classification  and  leg  edema  in patients with HFrEF who were not in stage D HF, 2 and fluid restriction improved QOL in a pilot RCT of patients with HFrEF and HFpEF (NYHA class I to IV). 3 In a meta-analysis of RCTs on fluid restriction in  HF in general, restricted fluid intake compared with free fluid consumption did not result in reduced hospitalization or mortality rates, changes in thirst, the duration of intravenous diuretic use, serum creatinine,  or  serum  sodium  levels. 4 The  validity  of  a previous  trial  supporting  clinical  benefits  of  fluid restriction in HF is in serious question. 12

## Table 18. Clinical Indicators of Advanced HF 1,2,12,13,23-37

| Repeated hospitalizations or emergency department visits for HF in the past 12 mo.                                                                                                             |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Need for intravenous inotropic therapy.                                                                                                                                                        |
| Persistent NYHA functional class III to IV symptoms despite therapy.                                                                                                                           |
| Severely reduced exercise capacity (peak VO 2 , <14 mL/kg/min or <50% predicted, 6-min walk test distance <300 m, or inability to walk 1 block on level ground because of dyspnea or fatigue). |
| Intolerance to RAASi because of hypotension or worsening renal function.                                                                                                                       |
| Intolerance to beta blockers as a result of worsening HF or hypotension.                                                                                                                       |
| Recent need to escalate diuretics to maintain volume status, often reaching daily furosemide equivalent dose >160 mg/d or use of supplemental meto- lazone therapy.                            |
| Refractory clinical congestion.                                                                                                                                                                |
| Progressive deterioration in renal or hepatic function.                                                                                                                                        |
| Worsening right HF or secondary pulmonary hypertension.                                                                                                                                        |
| Frequent SBP ≤ 90 mm Hg.                                                                                                                                                                       |
| Cardiac cachexia.                                                                                                                                                                              |
| Persistent hyponatremia (serum sodium, <134 mEq/L).                                                                                                                                            |
| Refractory or recurrent ventricular arrhythmias; frequent ICD shocks.                                                                                                                          |
| Increased predicted 1-year mortality (eg, >20%) according to HF survival models (eg, MAGGIC, 21 SHFM 22 ).                                                                                     |

HF indicates heart failure; ICD, implantable cardioverter-defibrillator; MAGGIC, Meta-analysis Global Group in Chronic Heart Failure; NYHA, New York Heart  Association;  RAASi,  renin-angiotensin-aldosterone  system  inhibitors; SBP, systolic blood pressure; SHFM, Seattle Heart Failure model; and VO 2 , oxygen consumption/oxygen uptake.

## 8.3. Inotropic Support

| Recommendations for Inotropic Support Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Inotropic Support Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Inotropic Support Referenced studies that support the recommendations are summarized in the Online Data Supplements.                                                                                                                                                          |
|--------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                        | LOE                                                                                                                                        | Recommendations                                                                                                                                                                                                                                                                                   |
| 2a                                                                                                                                         | B-NR                                                                                                                                       | 1. In patients with advanced (stage D) HF refrac- tory to GDMT and device therapy who are eligible for and awaiting MCS or cardiac trans- plantation, continuous intravenous inotropic support is reasonable as 'bridge therapy. ' 1-4                                                            |
| 2b                                                                                                                                         | B-NR                                                                                                                                       | 2. In select patients with stage D HF, despite optimal GDMT and device therapy who are ineligible for either MCS or cardiac transplan- tation, continuous intravenous inotropic sup- port may be considered as palliative therapy for symptom control and improvement in func- tional status. 5-7 |
| 3: Harm                                                                                                                                    | B-R                                                                                                                                        | 3. In patients with HF, long-term use of either continuous or intermittent intravenous inotropic agents, for reasons other than palliative care or as a bridge to advanced therapies, is potentially harmful. 5,6,8-11                                                                            |

## Synopsis

Despite  improving  hemodynamic  compromise,  positive inotropic  agents  have  not  shown  improved  survival  in patients with HF in either the hospital or the outpatient setting. 6 Regardless of their mechanism of action (eg, inhibition of phosphodiesterase, stimulation of adrenergic

Table 19. Indications and Contraindications to Durable Mechanical Support 37

| Indications (combination of these):                                  |
|----------------------------------------------------------------------|
| Frequent hospitalizations for HF                                     |
| NYHA class IIIb to IV functional limitations despite maximal therapy |
| Intolerance of neurohormonal antagonists                             |
| Increasing diuretic requirement                                      |
| Symptomatic despite CRT                                              |
| Inotrope dependence                                                  |
| Low peak VO 2 (<14-16)                                               |
| End-organ dysfunction attributable to low cardiac output             |
| Contraindications:                                                   |
| Absolute                                                             |
| Irreversible hepatic disease                                         |
| Irreversible renal disease                                           |
| Irreversible neurological disease                                    |
| Medical nonadherence                                                 |
| Severe psychosocial limitations                                      |
| Relative                                                             |
| Age >80 y for destination therapy                                    |
| Obesity or malnutrition                                              |
| Musculoskeletal disease that impairs rehabilitation                  |
| Active systemic infection or prolonged intubation                    |
| Untreated malignancy                                                 |
| Severe PVD                                                           |
| Active substance abuse                                               |
| Impaired cognitive function                                          |
| Unmanaged psychiatric disorder                                       |
| Lack of social support                                               |

CRT indicates cardiac resynchronization therapy; HF, heart failure; NYHA, New York Heart Association; VO 2, oxygen consumption; and PVD, peripheral vascular disease.

or dopaminergic receptors, calcium sensitization), parenteral  inotropes  remain  an  option  to  help  the  subset  of patients with HF who are refractory to other therapies and are suffering consequences from end-organ hypoperfusion. In hospitalized patients presenting with documented severe systolic  dysfunction  who  present  with low blood pressure and significantly low cardiac index, short-term, continuous  intravenous  inotropic  support may be reasonable to maintain systemic perfusion and preserve  end-organ  performance. 8,11,12 There  continues to be lack of robust evidence to suggest the clear benefit of 1 inotrope over another. 13 To minimize adverse effects, lower doses of parenteral inotropic drugs are preferred, although the development of tachyphylaxis should be acknowledged, and the choice of agent may need to be changed during longer periods of support. Similarly, the ongoing need for inotropic support and the possibility of discontinuation should be regularly assessed. Table 20 compares commonly used inotropes.

Table 20. Intravenous Inotropic Agents Used in the Management of HF

|                     | Dose (mcg/kg)       | Dose (mcg/kg)       |                              | Effects             | Effects             | Effects             | Effects             |                                         |                                                                                      |
|---------------------|---------------------|---------------------|------------------------------|---------------------|---------------------|---------------------|---------------------|-----------------------------------------|--------------------------------------------------------------------------------------|
| Inotropic Agent     | Bolus               | Infusion (/min)     | Drug Kinetics and Metabolism | CO                  | HR                  | SVR                 | PVR                 | Adverse Effects                         | Special Considerations                                                               |
| Adrenergic agonists | Adrenergic agonists | Adrenergic agonists | Adrenergic agonists          | Adrenergic agonists | Adrenergic agonists | Adrenergic agonists | Adrenergic agonists | Adrenergic agonists                     | Adrenergic agonists                                                                  |
| Dopamine            | NA                  | 5-10                | t 1/2 : 2-20 min             | ↑                   | ↑                   | ↔                   | ↔                   | T, HA, N, tissue necrosis               | Caution: MAO-I                                                                       |
| Dopamine            | NA                  | 10-15               | R, H, P                      | ↑                   | ↑                   | ↑                   | ↔                   |                                         |                                                                                      |
| Dobutamine          | NA                  | 2.5-20              | t 1/2 : 2-3 min H            | ↑                   | ↑                   | ↔                   | ↔                   | ↑ / ↓ BP, HA, T, N, F, hypersensitivity | Caution: MAO-I; CI: sulfite allergy                                                  |
| PDE 3 inhibitor     | PDE 3 inhibitor     | PDE 3 inhibitor     | PDE 3 inhibitor              | PDE 3 inhibitor     | PDE 3 inhibitor     | PDE 3 inhibitor     | PDE 3 inhibitor     | PDE 3 inhibitor                         | PDE 3 inhibitor                                                                      |
| Milrinone           | NR                  | 0.125-0.75          | t 1/2 : 2.5 h H              | ↑                   | ↑                   | ↓                   | ↓                   | T, ↓ BP                                 | Accumulation may occur in setting of renal failure; monitor kidney function and LFTs |
| Vasopressors        | Vasopressors        | Vasopressors        | Vasopressors                 | Vasopressors        | Vasopressors        | Vasopressors        | Vasopressors        | Vasopressors                            | Vasopressors                                                                         |
| Epinephrine         | NR                  | 5-15 mcg/min        | t 1/2 : 2-3 min              | ↑                   | ↑                   | ↑ ( ↓ )             | ↔                   | HA, T                                   | Caution: MAO-I                                                                       |
| Epinephrine         | NR                  | 15-20 mcg/min       | t 1/2 : 2-3 min              | ↑                   | ↑↑                  | ↑↑                  | ↔                   | HA, T                                   | Caution: MAO-I                                                                       |
| Norepinephrine      | NR                  | 0.5-30 mcg/min      | t 1/2 : 2.5 min              | ↔                   | ↑                   | ↑↑                  | ↔                   | ↓ HR, tissue necrosis                   | Caution: MAO-I                                                                       |

BP indicates blood pressure; CI, contraindication; CO, cardiac output; F, fever; H, hepatic; HA, headache; HF, heart failure; HR, heart rate; LFT, liver function test; MAO-I, monoamine oxidase inhibitor; N, nausea; NA, not applicable; NR, not recommended; P, plasma; PDE, phosphodiesterase; PVR, pulmonary vascular resistance; R, renal; SVR, systemic vascular resistance; T, tachyarrhythmias; and t 1/2 , elimination half-life.

Up arrow means increase. Side arrow means no change. Down arrow means decrease. Up/down arrow means either increase or decrease.

## Recommendation-Specific Supportive Text

1. More prolonged use of inotropes as 'bridge' therapy for those awaiting either heart transplantation or  MCS may have benefit in reducing pulmonary hypertension and maintaining end-organ perfusion beyond initial stabilization of patients. 1-4
2. The  use  of  inotropes  for  palliation  does  carry with it risks for arrhythmias and catheter-related infections,  although  the  presence  of  an  ICD does  decrease  the  mortality  associated  with arrhythmias.  This  risk  should  be  shared  with patients  if  there  is  planned  use  of  inotropes in  a  patient  without  an  ICD,  or  in  whom  the preference is to deactivate the ICD for palliative purposes. The rate of inappropriate shocks for  sinus  tachycardia  is  relatively  low,  and  the concomitant use of beta blockers may help in these patients. Patients may elect to have their shocking devices deactivated, especially if they receive numerous shocks. 14,15
3. With  the  currently  available  inotropic  agents, the  benefit  of  hemodynamic  support  and  stabilization  may  be  compromised  by  increased myocardial oxygen demand and increased arrhythmic burden. As newer agents are developed, more options may not have these known risks. There are investigational inotropic agents that may provide more options for the management of patients with HF and represent different classes of agents. 16

## 8.4. Mechanical Circulatory Support

| Recommendations for Mechanical Circulatory Support Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Mechanical Circulatory Support Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Mechanical Circulatory Support Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                 |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                       | LOE                                                                                                                                                       | Recommendations                                                                                                                                                                                                                                         |
| 1                                                                                                                                                         | A                                                                                                                                                         | 1. In select patients with advanced HFrEF with NYHA class IV symptoms who are deemed to be dependent on continuous intravenous inotropes or temporary MCS, durable LVAD implantation is effective to improve functional status, QOL, and survival. 1-18 |
| 2a                                                                                                                                                        | B-R                                                                                                                                                       | 2. In select patients with advanced HFrEF who have NYHA class IV symptoms despite GDMT, durable MCS can be beneficial to improve symptoms, improve functional class, and reduce mortality. 2,4,7,10,12-17,19                                            |
| Value Statement: Uncertain Value (B-NR)                                                                                                                   | Value Statement: Uncertain Value (B-NR)                                                                                                                   | 3. In patients with advanced HFrEF who have NYHA class IV symptoms despite GDMT, durable MCS devices provide low to intermedi- ate economic value based on current costs and outcomes. 20-24                                                            |
| 2a                                                                                                                                                        | B-NR                                                                                                                                                      | 4. In patients with advanced HFrEF and hemody- namic compromise and shock, temporary MCS, including percutaneous and extracorporeal ventricular assist devices, are reasonable as a 'bridge to recovery' or 'bridge to decision. ' 25-29                |

## Synopsis

MCS is a therapeutic  option  for  patients  with  advanced HFrEF to prolong life and improve functional capacity. Over the past 10 years, evolution and refinement of temporary and durable options has continued. MCS is differentiated by  the  implant  location,  approach,  flow  characteristics,

pump mechanisms, and ventricle(s) supported. It can be effective for short-term support (hours to days) and for longterm management (months to years). There are anatomic and physiologic criteria that make durable MCS inappropriate for some patients; it is most appropriate for those with HFrEF and a dilated ventricle. With any form of MCS, the device will eventually be turned off, whether at the time of explant for transplantation or recovery, or to stop support in a patient who either no longer wishes to continue support, or in whom the continued functioning of an MCS prevents their death from other causes, such as a catastrophic neurologic event, or metastatic malignancy. 30 This topic should be  addressed  a  priori  with  patients  before  discussions about MCS. Particularly with temporary devices, the potential need to either discontinue or to escalate support should be addressed at time of implantation.

## Recommendation-Specific Supportive Text

1.  Durable LVADs should be considered in selected patients with NHYA class IV symptoms who are deemed  dependent  on  IV  inotropes  or  temporary  MCS.  The  magnitude  of  the  survival  benefit for durable L VAD support in advanced NYHA class  IV  patients  has  progressively  improved, with a 2-year survival &gt;80% in recent trials with newer generation LVADs, which approaches the  early  survival  after  cardiac  transplantation. 2 The  2020  INTERMACS  (Interagency  Registry for  Mechanically  Assisted  Circulatory  Support) report showed that 87.6% of recent durable LVAD recipients were categorized as INTERMACS 1 to 3  before  their  implant  surgery. 10 It  also  showed improved mean survival,  &gt;4  years  for  the  destination LVAD cohort, and &gt;5 years for bridge-totransplant patients. Durable L VAD support has also achieved impressive functional improvement and QOL improvement in multiple trials, 2,7,31 although patients  remain  tethered  to  external  electrical power supplies via a percutaneous lead can limit this improvement. Most patients require rehospitalization within the first year post-implant. These factors emphasize the need for a thorough evaluation and patient education before the decision to proceed  with  the  treatment.  Appropriate  patient selection  benefits  from  review  by  a  multidisciplinary team that typically includes an HF cardiologist, surgeon, social worker, nurse, pharmacist, dietician, and a palliative medicine specialist.
2. Durable  MCS  should  be  considered  in  patients with  NHYA  class  IV  symptoms  despite  optimal medical therapy  or  those  deemed  dependent on  IV  inotropes.  Destination  therapy  MCS  provides  considerable  survival  advantage  in  addition to  improvement  in  functional  status  and  healthrelated QOL. 1,7,12,32,33 There is no clear 1-risk model

to  assess  patient  risk  for  complications,  but  factors  such  as  elevated  central  venous  pressure, pulmonary  hypertension,  and  coagulopathy  have been linked to poorer outcomes. 15,34-36 In patients who  are  unable  to  tolerate  anticoagulation  after repeated  challenges,  implantation  of  a  durable MCS is associated with excess morbidity; incidents of pump thrombosis, hemolysis, and ischemic neurologic  events  have  been  linked  to  subtherapeutic  international  normalized  ratios. 37-41 In  addition, implantation of MCS in patients with INTERMACS profile of 1 has been associated with poorer outcome, while those ambulatory patients with profiles 5 to 7 might be too well to have large significant benefit, depending on their symptom burden. 19  For patients  who  are  initially  considered  to  be  transplant  ineligible  because  of  pulmonary  hypertension, obesity, overall frailty, or other reasons, MCS can provide time to reverse or modify these conditions. 35,42-44  Continuing and uptitrating GDMT in patients with durable MCS is recommended. 45

3. Multiple studies evaluated the cost-effectiveness of ventricular assist device implantation for advanced HF between 2012 and 2017. 20,21,23   They  consistently  found  device implantation was of low economic  value,  with  incremental  cost-effectiveness ratios  of  $200  000  per  QAL Y  gained  compared with  medical  therapy  alone  among  patients  who potentially underwent subsequent heart transplant and those who were ineligible for heart transplant. In these studies, costs after implantation remained high given high rates of complication and rehospitalization.  However,  these  studies  used  earlier estimates  of  post-implant  outcomes  and  complication-related costs that have generally improved over time with better care and newer devices. 46-48 Additionally, limited recent data suggest improvement in  health  care  costs  and  intermediate  economic  value with LVAD  among  patients  with advanced HF who are either eligible or ineligible for subsequent heart transplant. 22,24   The improvement  may  result  from  lower  complication  rates, increased survival, lower implant costs, and higher estimated  QOL.  However,  given  the  conflicting data  and  limited  analyses  of  contemporary  data, the current value of L VAD therapy is uncertain.
4. Temporary  MCS  can  help  stabilize  patients  and allow time for decisions about the appropriateness of  transitions  to  definitive  management,  such  as durable  MCS  as  a  bridge  or  destination  therapy, stabilization until cardiac transplantation or, in the case  of  improvement  and  recovery,  suitability  for device removal. 45 These patients often present in cardiogenic shock that cannot be managed solely with IV inotropes and in whom other organ function is  at  risk.  T emporary  MCS  is  also  appropriate  for

use to allow patients to engage in decision-making for durable MCS or transplantation and for determination of recovery of neurologic status.

## 8.5. Cardiac Transplantation

| Recommendation for Cardiac Transplantation   | Recommendation for Cardiac Transplantation   | Recommendation for Cardiac Transplantation                                                                                      |
|----------------------------------------------|----------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------|
| COR                                          | LOE                                          | Recommendation                                                                                                                  |
| 1                                            | C-LD                                         | 1. For selected patients with advanced HF despite GDMT, cardiac transplantation is indi- cated to improve survival and QOL. 1-3 |
| Value Statement: Intermediate Value (C-LD)   | Value Statement: Intermediate Value (C-LD)   | 2. In patients with stage D (advanced) HF despite GDMT, cardiac transplantation provides inter- mediate economic value. 4       |

## Synopsis

The  evidence  that  cardiac  transplantation  provides  a mortality  and  morbidity  benefit  to  selected  patients with stage D HF (refractory, advanced) is derived from observational cohorts. Datasets from the International Society for Heart and Lung Transplantation 1  and United Network of Organ Sharing 2  document the median survival  of  adult  transplant  recipients  to  be  now  &gt;12 years; the median survival of patients with stage D HF without advanced therapies is &lt;2 years. For comparison,  the  risk  of  death  becomes  greater  than  survival between 3 and 4 years on an LVAD, regardless of implant  strategy  (eg,  bridge-to-transplant,  bridge-to-decision, destination therapy). 3  Improvements in pre- and posttransplant management have also increased more patients to be eligible for transplant, and treated rejection rates in the first year after transplantation are now &lt;15%. 1  Minimizing waitlist mortality while maximizing posttransplant outcomes continues to be a priority in heart transplantation and was addressed with the recent  changes  in  donor  allocation  policy  instituted  in 2018. 5  Several analyses 6-11  have confirmed a decrease in waitlist mortality as well as an increase in the use of temporary  circulatory  support  devices,  graft  ischemic times, and distances between donor and recipient hospitals.  The  impact  on  posttransplant  survival  remains uncertain. Multiorgan transplantation remains uncommon  and  reserved  for  highly  selected  candidates.  In 2018, 7% of all heart transplants involved another organ, in addition to the heart. 1

## Recommendation-Specific Supportive Text

1. Cardiac  transplantation  is  the  established  treatment for eligible patients with stage D HF refractory  to  GDMT,  device,  and  surgical  optimization. The  survival  of  adult  recipients  who  received  a transplantation between 2011 and 2013 at 1, 3, and 5 years is 90.3%, 84.7%, and 79.6%, respectively. 2 Conditional  survival  now  approaches  15

years. 1 Cardiac transplantation also improves functional status and  health-related  QOL. 12-15 Good outcomes can be achieved in patients not only  with  HF  that  is  primarily  cardiovascular  in origin,  including  reversible  pulmonary  hypertension, 16 congenital  heart  disease, 17 and  hypertrophic  cardiomyopathy, 18 but  also  in  patients  with systemic conditions complicated by HF, such as muscular  dystrophy, 19 sarcoidosis, 20 and  amyloidosis. 21   CPET  can  refine  candidate  prognosis and  selection. 22-28 Appropriate  patient  selection should include integration of comorbidity burden, caretaker  status,  and  goals  of  care.  The  listing criteria,  evaluation,  and  management of patients undergoing cardiac transplantation are described by  the  International  Society  for  Heart  and  Lung Transplantation. 29 The  United  Network  of  Organ Sharing  Heart  Transplant  Allocation  Policy  was revised in 2018 with a broader geographic sharing policy and a 6-tiered system to better prioritize more unstable patients and minimize waitlist mortality. 5-11

2. One  study  evaluated  the  cost-effectiveness  of heart transplantation compared  with medical therapy among patients with inotrope-dependent advanced HF. 30  This analysis found transplantation was of intermediate value. The results were similar across a broad range of patient age, waitlist duration, and monthly mortality risk with medical therapy.

## 9. PATIENTS HOSPITALIZED WITH ACUTE DECOMPENSATED HF

## 9.1. Assessment of Patients Hospitalized With Decompensated HF

| Recommendations for Assessment of Patients Hospitalized With Decompensated HF   | Recommendations for Assessment of Patients Hospitalized With Decompensated HF   | Recommendations for Assessment of Patients Hospitalized With Decompensated HF                                                                                             |
|---------------------------------------------------------------------------------|---------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                             | LOE                                                                             | Recommendations                                                                                                                                                           |
| 1                                                                               | C-LD                                                                            | 1. In patients hospitalized with HF, severity of con- gestion and adequacy of perfusion should be assessed to guide triage and initial therapy. 1-5                       |
| 1                                                                               | C-LD                                                                            | 2. In patients hospitalized with HF, the common precipitating factors and the overall patient trajectory should be assessed to guide appro- priate therapy. 5,6           |
| Goals for Optimization and Continuation of GDMT                                 | Goals for Optimization and Continuation of GDMT                                 | Goals for Optimization and Continuation of GDMT                                                                                                                           |
| 1                                                                               | C-LD                                                                            | 3. For patients admitted with HF, treatment should address reversible factors, establish optimal volume status, and advance GDMT toward targets for outpatient therapy. 6 |

## Synopsis

Initial triage includes clinical assessment of the hemodynamic profile for severity of congestion and adequa-

Table 21. Common Factors Precipitating HF Hospitalization With Acute Decompensated HF

| ACS                                                        |
|------------------------------------------------------------|
| Uncontrolled hypertension                                  |
| AF and other arrhythmias                                   |
| Additional cardiac disease (eg, endocarditis)              |
| Acute infections (eg, pneumonia, urinary tract)            |
| Nonadherence with medication regimen or dietary intake     |
| Anemia                                                     |
| Hyper- or hypothyroidism                                   |
| Medications that increase sodium retention (eg, NSAID)     |
| Medications with negative inotropic effect (eg, verapamil) |

ACS indicates acute coronary syndrome; AF, atrial fibrillation; HF, heart failure; and NSAID, nonsteroidal anti-inflammatory drug.

cy of perfusion. 1-5  The diagnosis of cardiogenic shock warrants  consideration  of  recommendations  in  Section 9.5, 'Evaluation and Management of Cardiogenic Shock,' but any concern for worsening hypoperfusion should also trigger involvement of the multidisciplinary team  for  hemodynamic  assessment  and  intervention. Initial triage includes recognition of patients with ACS for  whom  urgent  revascularization  may  be  indicated. In the absence of ischemic disease, recent onset with accelerating hemodynamic decompensation may represent  inflammatory  heart  disease,  particularly  when accompanied  by  conduction  block  or  ventricular  arrhythmias. 7,8  However, most HF hospitalizations for decompensation are not truly 'acute' but follow a gradual increase  of  cardiac  filling  pressures  on  preexisting structural  heart  disease,  often  with  precipitating  factors that can be identified 3,6  (Table 21). Some patients present with pulmonary edema and severe hypertension,  which  require  urgent  treatment  to  reduce  blood pressure,  more  commonly  in  patients  with  preserved LVEF.  Patients  require  assessment  and  management of ischemia, arrhythmia and other precipitating factors and  comorbidities.  The  presenting  profile,  reversible factors, appropriate workup for the cause of HF including  ischemic  and  nonischemic  causes,  comorbidities, and potential for GDMT titration inform the plan of care to optimize the disease trajectory. 5

## Recommendation-Specific Supportive Text

1.    and  2.  Most  patients  admitted  with  HF  have clinical  evidence  of  congestion  without  apparent  hypoperfusion. 1-5,9,10 Although  elevations  of right-  and  left-sided  cardiac  filling  pressures are  usually  proportional  in  decompensation  of chronic  HF  with  low  EF,  up  to  1  in  4  patients have a mismatch between right- and left-sided filling  pressures. 9-11 Disproportionate  elevation

of  right-sided  pressures,  particularly  with  TR, hinders effective decongestion. Disproportionate elevation  of  left-sided  filling  pressures  may  be underrecognized as the cause of dyspnea in the absence of jugular venous distention and edema. Elevated  natriuretic  peptides  can  help  identify HF in the urgent care setting but with less utility in  certain  situations,  including  decreased  sensitivity  with  obesity  and  HFpEF  and  decreased specificity in the setting of sepsis. Resting hypoperfusion is  often  underappreciated  in  patients with chronic HF but can be suspected from narrow  pulse  pressure  and  cool  extremities 1,9 and by  intolerance  to  neurohormonal  antagonists. Elevated serum lactate levels may indicate hypoperfusion  and  impending  cardiogenic  shock. 12 When initial  clinical  assessment  does  not  suggest  congestion  or  hypoperfusion,  symptoms of  HF  may  be  a  result  of  transient  ischemia, arrhythmias, or noncardiac disease such as chronic  pulmonary  disease  or  pneumonia,  and more  focused  hemodynamic  assessment  may be warranted. Assessment of arrhythmia, device profiles  such  as  percent  LV  pacing  versus  RV pacing in patients with CRT, and device therapy and  shocks  in  patients  with  ICD  can  provide important information.

3. Hospitalization  for  HF  is  a  sentinel  event  that signals worse prognosis and the need to restore hemodynamic  compensation  but  also  provides key opportunities to redirect the disease trajectory. During the HF hospitalization, the approach to  management  should  include  and  address precipitating  factors,  comorbidities,  and  previous  limitations  to  ongoing  disease  management related to social determinants of health. 1 Patients  require  assessment  and  management of  ischemia,  arrhythmia,  and  other  precipitating  factors  and  comorbidities.  The  presenting profile,  reversible  factors,  appropriate  work-up for  cause  of  HF  including  ischemic  and  nonischemic causes, comorbidities, disease trajectory,  and  goals  of  care  should  be  addressed. Establishment  of  optimal  volume  status  is  a major goal,  and  patients  with  residual  congestion merit careful consideration for further intervention  before  and  after  discharge,  because they  face  higher  risk  for  rehospitalization  and death. 2-5  The disease trajectory for patients hospitalized with reduced EF is markedly improved by  optimization  of  recommended medical therapies,  which  should  be  initiated  or  increased toward target doses once the efficacy of diuresis has been shown. 13,14

## 9.2. Maintenance or Optimization of GDMT During Hospitalization

| Recommendations for Maintenance or Optimization of GDMT During Hospitalization Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Maintenance or Optimization of GDMT During Hospitalization Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Maintenance or Optimization of GDMT During Hospitalization Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                     |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                   | LOE                                                                                                                                                                                   | Recommendations                                                                                                                                                                                         |
| 1                                                                                                                                                                                     | B-NR                                                                                                                                                                                  | 1. In patients with HFrEF requiring hospitalization, preexisting GDMT should be continued and optimized to improve outcomes, unless contra- indicated. 1-5                                              |
| 1                                                                                                                                                                                     | B-NR                                                                                                                                                                                  | 2. In patients experiencing mild decrease of renal function or asymptomatic reduction of blood pressure during HF hospitalization, diuresis and other GDMT should not routinely be discontin- ued. 6-11 |
| 1                                                                                                                                                                                     | B-NR                                                                                                                                                                                  | 3. In patients with HFrEF, GDMT should be initi- ated during hospitalization after clinical stability is achieved. 2,3,5,12-18                                                                          |
| 1                                                                                                                                                                                     | B-NR                                                                                                                                                                                  | 4. In patients with HFrEF, if discontinuation of GDMT is necessary during hospitalization, it should be reinitiated and further optimized as soon as possible. 19-22                                    |

## Synopsis

Hospitalization  for  HFrEF  is  a  critical  opportunity  to continue, initiate, and further optimize GDMT. 23-25 Continuation of oral GDMT  during  hospitalization for  HF  has  been  shown in  registries  to  lower  risk  of postdischarge  death  and  readmission  compared  with discontinuation. 1-5  Initiation of oral GDMT during hospitalization  for  HF  is  associated  with  numerous  clinical outcome benefits. 2,5,12,16,17   Based on data from the CHAMP-HF (Change the Management of Patients with Heart Failure) registry,  however,  only  73%,  66%, and 33% of eligible patients with HFrEF were prescribed ACEi-ARB-ARNi,  beta  blockers,  and  MRA  therapy, respectively. 19 Furthermore,  based  on  information  obtained from claims data, roughly 42% of patients are not  prescribed  any  GDMT  within  30  days  postindex hospitalization, 20  and 45% are prescribed either no oral GDMT or monotherapy within 1-year post-hospitalization. 21 In  the  management  of  patients  with  HFrEF  in the  community,  very  few  receive  target  doses  of  oral GDMT. 6  Moreover, most patients with HFrEF have no changes made to oral GDMT over 12 months, 21  despite being discharged on suboptimal doses or no GDMT. 22  It cannot be assumed that oral GDMT will be initiated or optimized after hospitalization for HFrEF.

## Recommendation-Specific Supportive Text

1.  In OPTIMIZE-HF (Organized Program to Initiate Lifesaving  Treatment  in  Hospitalized  Patients with Heart Failure), discontinuation of beta blockers  was  associated  with  a  higher  risk  for mortality compared with those continued on beta

blockers. 1 In  a  meta-analysis  of  observational and trial data, discontinuation of beta blockers in hospitalized patients with HFrEF also was associated with a higher risk of in-hospital mortality, short-term mortality, and the combined endpoint of short-term rehospitalization or mortality. 4 Withholding  or  reducing  beta-blocker  therapy should  be  considered  in  patients  with  marked volume overload or marginal low cardiac output. In  the  Get  With  The  Guidelines-Heart  Failure (GWTG-HF)  registry,  withdrawal  of  ACEi-ARB among  patients  hospitalized  with  HFrEF  was associated  with  higher  rates  of  postdischarge mortality and readmission. 2 In the  COACH (Coordinating study evaluating  Outcomes  of Advising and Counselling in Heart failure) study, continuation of spironolactone among hospitalized  patients  with  HFrEF  was  associated  with lower  30-day  mortality  and  HF  rehospitalization. 3 From  the  ARIC  (Atherosclerosis  Risk  in Communities) study, discontinuation of any oral GDMT among patients hospitalized with HFrEF was associated with higher mortality risk. 5  Oral GDMT should not be withheld for mild or transient  reductions  in  blood  pressure 6-9 or  mild deteriorations in renal function. 10,11 True contraindications  are  rare,  such  as  advanced  degree atrioventricular  block  for  beta  blockers  in  the absence of pacemakers; cardiogenic shock that may  preclude  use  of  certain  medications  until resolution  of  shock  state;  or  angioedema  for ACEi or ARNi.

2. In  CHAMP-HF,  very  few  patients  with  HF  and SBP &lt;110 mm Hg received target doses of beta blockers  (17.5%)  ACEi-ARB  (6.2  %),  or  ARNi (1.8%). 6  In PARADIGM-HF, patients with HF and lower SBP on sacubitril-valsartan had the same tolerance and  relative benefit over enalapril compared with patients with higher SBP. 7  From the  SENIORS  (Study  of  Effects  of  Nebivolol Intervention on Outcomes and Rehospitalization in Seniors With Heart Failure) trial, nebivolol had equivalent tolerance and benefits irrespective of SBP. 8 In Val-HeFT (Valsartan Heart Failure Trial), decreases in SBP did not offset the beneficial effects of valsartan on HF morbidity. 9 In patients with  HF  on  oral  GDMT,  small  to  moderate worsening  of  renal  function  (defined  as ≥ 20% decrease in eGFR in that study) was not associated with AKI. 10   Moreover, it has been shown that spironolactone and beta blockers might be protective  in  patients  with  HF  and  worsening renal function. 11
3.  In  OPTIMIZE-HF,  discharge  use  of  carvedilol was  associated  with  a  reduction in 60-  to 90-day mortality and composite risk of mortality

or rehospitalization compared with no carvedilol use. 12,13   Discharge use of beta blockers is also associated with lower 30-day all-cause mortality and  4-year  all-cause  mortality/all-cause  readmission. 14  Caution should be used when initiating beta blockers in patients who have required inotropes during hospitalization. In GWTG-HF, initiation  of  ACEi-ARB  in  patients  hospitalized  with HFrEF  reduced  30-day  and  1-year  mortality. 2 Among patients hospitalized with HFrEF, initiation of ACEi-ARB also is associated with lower risk  of  30-day  all-cause  readmission  and  allcause mortality. 15 In  a  claims  study,  initiation  of MRA therapy at hospital discharge was associated with improved HF readmission but not mortality or cardiovascular readmission among older adults  hospitalized  with  HFrEF. 16   In  COACH, initiating  spironolactone  among  patients  hospitalized  with  HFrEF  was  associated  with  lower 30-day  mortality  and  HF  rehospitalization. 3 In the  PIONEER-HF  trial,  ARNi  use  was  associated with reduced NT-proBNP levels in patients hospitalized for acute decompensated HF without increased rates of adverse events (worsening  renal  function,  hyperkalemia,  symptomatic hypotension, angioedema) when compared with enalapril. 18 In the ARIC study, initiation of any oral GDMT was associated with reduced 1-year mortality among patients hospitalized with HFrEF. 5 In SOLOIST-WHF, initiation of sotagliflozin  before or shortly after discharge reduced cardiovascular mortality and hospitalization. 17

4.  Nearly half (46%) of patients with HFrEF have no  changes  made  to  oral  GDMT  in  the  12 months after hospitalization despite many being discharged on suboptimal doses. 21  From claimsbased  studies,  42%  of  patients  with  HFrEF are  not  prescribed  any  GDMT  within  30  days post-index  hospitalization, 20   and  45%  are  prescribed  either  no  oral  GDMT  or  monotherapy within  1-year  post-index  hospitalization. 21 From CHAMP-HF, initiation or dose increases of beta blockers,  ACEi-ARB-ARNi,  and  MRA  occur  in ≤ 10% of patients with HFrEF within 1 year of hospitalization. 22 Very  few  eligible  patients  with HFrEF  receive  target  doses  of  beta  blockers (18.7%),  ACEi-ARB (10.8%), or  ARNi  (2.0%). 6 Less than 1% of patients with HFrEF are on target doses of ACEi-ARB-ARNi, beta blockers, and MRA within 12 months of an index hospitalization. 22  For patients with HFrEF, there is a graded improvement in the risk of death or rehospitalization  with  monotherapy,  dual  therapy,  and  triple therapy compared with no GDMT after an index hospitalization in Medicare claims data. 21

## 9.3. Diuretics in Hospitalized Patients: Decongestion Strategy

| Recommendations for Diuretics in Hospitalized Patients: Decongestion Strategy Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Diuretics in Hospitalized Patients: Decongestion Strategy Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Diuretics in Hospitalized Patients: Decongestion Strategy Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                         |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                  | LOE                                                                                                                                                                                  | Recommendations                                                                                                                                                                                                                                                            |
| 1                                                                                                                                                                                    | B-NR                                                                                                                                                                                 | 1. Patients with HF admitted with evidence of significant fluid overload should be promptly treated with intravenous loop diuretics to improve symptoms and reduce morbidity. 1                                                                                            |
| 1                                                                                                                                                                                    | B-NR                                                                                                                                                                                 | 2. For patients hospitalized with HF, therapy with diuretics and other guideline-directed medica- tions should be titrated with a goal to resolve clinical evidence of congestion to reduce symp- toms and rehospitalizations. 1-6                                         |
| 1                                                                                                                                                                                    | B-NR                                                                                                                                                                                 | 3. For patients requiring diuretic treatment during hospitalization for HF, the discharge regimen should include a plan for adjustment of diuret- ics to decrease rehospitalizations. 7                                                                                    |
| 2a                                                                                                                                                                                   | B-NR                                                                                                                                                                                 | 4. In patients hospitalized with HF when diuresis is inadequate to relieve symptoms and signs of congestion, it is reasonable to intensify the diuretic regimen using either: a. higher doses of intravenous loop diuretics. 1,3 ); or b. addition of a second diuretic. 3 |

## Synopsis

Intravenous  loop  diuretic  therapy  provides  the  most rapid and effective treatment for signs and symptoms of congestion leading to hospitalization for HF. Titration to achieve effective diuresis may require doubling of initial doses, adding a thiazide diuretic, or adding an MRA that has diuretic effects in addition to its cardiovascular benefits. A major goal of therapy is resolution of the signs and symptoms of congestion before discharge, as persistent congestion  scored  at  discharge  has  been  associated with higher rates of rehospitalizations and mortality. Most patients who have required intravenous diuretic therapy during hospitalization for HF will require prescription of loop  diuretics  at  discharge  to  decrease  recurrence  of symptoms and hospitalization.

## Recommendation-Specific Supportive Text

1. Diuretic  therapy  with  oral  furosemide  was  the cornerstone of HF therapy for &gt;20 years before construction  of  the  modern  bases  of  evidence for HF therapies. The pivotal RCTs showing benefit  in  ambulatory  HFrEF  have  been  conducted on  the  background  of  diuretic  therapy  to  treat and prevent recurrence of fluid retention. An RCT compared intravenous diuretic doses and infusion to  bolus  dosing  during  hospitalization  for  HF  but without a placebo arm. 1 Protocols for recent trials of other medications in patients hospitalized with HF have all included intravenous diuretic therapy

as background therapy. 1-6,8,9  There are no RCTs for hospitalized  patients  comparing  intravenous  loop diuretics to placebo, for which equipoise is considered unlikely. 10

2. Monitoring HF treatment includes careful measurement of fluid intake and output, vital signs, standing body weight at the same time each day, and clinical signs and symptoms of congestion and hypoperfusion. Daily laboratory tests during active medication adjustment include serum electrolytes, urea nitrogen, and creatinine concentrations. Signs and symptoms of congestion have been specified as inclusion criteria in recent trials of patients hospitalized for HF , in which resolution of these signs and symptoms has been defined as a goal to be achieved by hospital discharge, 1-6,8,9 as it has in the recent HF hospitalization pathway consensus document. 11  Evidence of persistent  congestion  at  discharge  has  been  reported  in 25% to 50% of patients, 4,5,12 who have higher rates of mortality and readmission and are more likely to have elevated right atrial pressures, TR, and renal dysfunction. Diuresis should not be discontinued prematurely because  of  small  changes  in  serum  creatinine, 13,14 because elevations in the range of 0.3 mg/dL do not predict  worse  outcomes  except  when  patients  are discharged with persistent congestion. Decongestion often requires not only diuresis but also adjustment of other guideline-directed therapies, because elevated volume status and vasoconstriction can contribute to elevated filling pressures.
3.  After discharge, ACEi-ARB, MRAs, and beta blockers all may decrease recurrent congestion leading to hospitalization in HFrEF. Despite these therapies, most patients with recent HF hospitalization require continued use of diuretics after discharge to prevent  recurrent  fluid  retention  and  hospitalization, as shown in a recent large observational analysis. 7 Increases in diuretic doses are frequently required early after discharge even in patients on all other currently  recommended  therapies  for  HFrEF. 8 It is  unknown how increased penetration of therapy with ARNi and SGLT2i will, in the future, affect the dosing of diuretics after discharge with HFrEF.
4. Titration  of  diuretics  has  been  described  in  multiple recent trials of patients hospitalized with HF, often initiated with at least 2 times the daily home diuretic  dose  (mg  to  mg)  administered  intravenously. 1 Escalating attempts to achieve net diuresis include serial doubling of intravenous loop diuretic doses, which can be done by bolus or infusion, and sequential  nephron  blockade  with  addition  of  a thiazide diuretic, as detailed specifically in the protocol for the diuretic arms of the CARRESS and ROSE trials. 3,9  In the DOSE (Diuretic Optimization Strategies Evaluation) trial, there were no significant differences in patients' global assessment of

symptoms or in the change in renal function when diuretic therapy was administered by bolus, compared with continuous infusion or at a high dose compared with a low dose. Patients in the low-dose group were more likely to require a 50% increase in the dose at 48 hours than were those in the highdose group, and all treatment groups had higher doses of diuretics compared with baseline preadmission doses, underlining the necessity to intensify and individualize diuretic regimen. 1  MRAs have mild diuretics properties and addition of MRAs can help with diuresis in addition to significant cardiovascular benefits in patients with HF. Addition of low-dose dopamine to diuretic therapy in the setting of reduced eGFR did not improve outcomes in a study that included patients with all EFs, but a subset analysis showed increased urine output and weight loss in patients with L VEF &lt;0.40, 9 with significant interaction of effect with L VEF. Bedside ultrafiltration initiated early after admission increased fluid loss, with decreased rehospitalizations  in  some  studies  when  compared  with  use of  diuretics  without  systematic  escalation. 15,16 and was also associated with adverse events related to the intravenous catheters required. 3  Many aspects of  ultrafiltration  including  patient  selection,  fluid removal rates, venous access, prevention of therapy-related complications, and cost require further investigation.

## 9.4a. Parenteral Vasodilation Therapy in Patients Hospitalized With HF

| Recommendation for Parenteral Vasodilation Therapy in Patients Hos- pitalized With HF Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Parenteral Vasodilation Therapy in Patients Hos- pitalized With HF Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for Parenteral Vasodilation Therapy in Patients Hos- pitalized With HF Referenced studies that support the recommendation are summarized in the Online Data Supplements.                                       |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                       | LOE                                                                                                                                                                                       | Recommendation                                                                                                                                                                                                                |
| 2b                                                                                                                                                                                        | B-NR                                                                                                                                                                                      | 1. In patients who are admitted with decompen- sated HF, in the absence of systemic hypoten- sion, intravenous nitroglycerin or nitroprusside may be considered as an adjuvant to diuretic therapy for relief of dyspnea. 1,2 |

## Synopsis

Vasodilators can be used in acute HF to acutely relieve symptoms of pulmonary congestion in selected patients. Although they may mitigate dyspnea and relieve pulmonary congestion, their benefits have not been shown to have durable effects for either rehospitalization or mortality  benefit.  In  select  patients  who present with signs of hypoperfusion such as worsening renal function, even in the absence of hypotension, other escalation of care may need to be considered (see Section 8.3, 'Inotropic Support,' and Section 9.5, 'Evaluation and Management of Cardiogenic Shock').

## Recommendation-Specific Supportive Text

1.  The  role  for  directed  vasodilators  in  acute  decompensated HF remains uncertain. Part of the rationale for their use is targeting pulmonary congestion, while trying to avoid some potential adverse consequences of loop diuretics. Patients with hypertension, coronary ischemia, or significant MR may be suitable candidates for  the  use  of  intravenous  nitroglycerin.  However, tachyphylaxis  may  develop  within  24  hours,  and  up to 20% of those with HF may develop resistance to even high doses. 3,4 Because of sodium nitroprusside's potential for producing marked hypotension, invasive hemodynamic blood pressure monitoring (eg, an arterial line) is typically required, and nitroprusside is usually used in the intensive care setting; longer infusions of the drug have been associated, albeit rarely, with thiocyanate and cyanide toxicity, particularly in the setting of renal insufficiency and significant hepatic disease. Nitroprusside is potentially of value in severely congested patients with hypertension or severe MV regurgitation  complicating  L V  dysfunction. 5 Overall, there are no data that suggest that intravenous vasodilators improve outcomes in the patient hospitalized with HF; as such, use of intravenous vasodilators is limited to the relief of dyspnea in the hospitalized HF patient with intact or high blood pressure. 6,7

## 9.4b. VTE Prophylaxis in Hospitalized Patients

| Recommendation for VTE Prophylaxis in Hospitalized Patients Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for VTE Prophylaxis in Hospitalized Patients Referenced studies that support the recommendation are summarized in the Online Data Supplements.   | Recommendation for VTE Prophylaxis in Hospitalized Patients Referenced studies that support the recommendation are summarized in the Online Data Supplements.   |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                             | LOE                                                                                                                                                             | Recommendation                                                                                                                                                  |
| 1                                                                                                                                                               | B-R                                                                                                                                                             | 1. In patients hospitalized with HF, prophylaxis for VTE is recommended to prevent venous throm- boembolic disease. 1-3                                         |

## Synopsis

HF has long been recognized as affording additional risk for  venous  thromboembolic  disease.  When  patients  are hospitalized for decompensated HF, or when patients with chronic stable HF are hospitalized for other reasons, they are at increased risk for venous thromboembolic disease. The risk may be associated with higher HF symptom burden. 4 This risk may extend for up to 2 years after hospitalization but is greatest in the first 30 days. 5,6  The use of anticoagulation  with  subcutaneous  low-molecular-weight heparin, unfractionated heparin, fondaparinux, or approved DOAC are used for the prevention of clinically symptomatic deep vein thrombosis and pulmonary embolism. 7,8

## Recommendation-Specific Supporting Text

1.  Trials  using  available  antithrombotic  drugs  often were not limited to patients with HF but included

patients with acute illnesses, severe respiratory diseases, or simply a broad spectrum of hospitalized medical  patients. 9-12 All  included  trials  excluded patients  perceived  to  have  an  elevated  risk  of bleeding complications or of toxicity from the specific  agent tested (eg, enoxaparin in patients with compromised renal function). In some trials, aspirin was allowed but not controlled for as a confounding variable. Despite the increased risk for the development of  VTE  in  the  30  days  after  hospitalization, the data for extending prophylaxis to the immediate post-hospital period have shown decreased development of VTE but were associated with increased bleeding events and overall do not appear to provide  additional  benefit. 2,3,11 For  patients  admitted specifically  for  decompensated HF and with adequate  renal  function  (creatinine  clearance,  &gt;30 mL/min), randomized trials suggest that enoxaparin 40  mg  subcutaneously  once  daily, 1,13 unfractionated  heparin  5000  units  subcutaneously  every  8 or 12 hours, 14-17 or rivaroxaban 10 mg once daily 11 will  radiographically  reduce  demonstrable  venous thrombosis.  Effects  on  mortality  or  clinically  significant pulmonary embolism rates are unclear. For obese patients, a higher dose of enoxaparin 60 mg once daily achieved target range of thromboprophylaxis without increased bleeding. 12

## 9.5. Evaluation and Management of Cardiogenic Shock

| Recommendations for Evaluation and Management of Cardiogenic Shock Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Evaluation and Management of Cardiogenic Shock Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Evaluation and Management of Cardiogenic Shock Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.      |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                       | LOE                                                                                                                                                                       | Recommendations                                                                                                                                                              |
| 1                                                                                                                                                                         | B-NR                                                                                                                                                                      | 1. In patients with cardiogenic shock, intravenous inotropic support should be used to maintain systemic perfusion and preserve end-organ performance. 1-8                   |
| 2a                                                                                                                                                                        | B-NR                                                                                                                                                                      | 2. In patients with cardiogenic shock, temporary MCS is reasonable when end-organ function cannot be maintained by pharmacologic means to support cardiac function. 9-17     |
| 2a                                                                                                                                                                        | B-NR                                                                                                                                                                      | 3. In patients with cardiogenic shock, manage- ment by a multidisciplinary team experienced in shock is reasonable. 17-22                                                    |
| 2b                                                                                                                                                                        | B-NR                                                                                                                                                                      | 4. In patients presenting with cardiogenic shock, placement of a PA line may be considered to define hemodynamic subsets and appropriate management strategies. 23-27        |
| 2b                                                                                                                                                                        | C-LD                                                                                                                                                                      | 5. For patients who are not rapidly responding to initial shock measures, triage to centers that can provide temporary MCS may be consid- ered to optimize management. 17-22 |

## Synopsis

Cardiogenic shock is a commonly encountered clinical challenge with a high mortality and is characterized by

Table 22. Suggested Shock Clinical Criteria* 29

| SBP <90 mm Hg for >30 min:   | SBP <90 mm Hg for >30 min:                                                              |
|------------------------------|-----------------------------------------------------------------------------------------|
| a.                           | Or mean BP <60 mm Hg for >30 min                                                        |
| b.                           | Or requirement of vasopressors to maintain systolic BP ≥ 90 mm Hg or mean BP ≥ 60 mm Hg |
| Hypoperfusion defined by:    | Hypoperfusion defined by:                                                               |
| c.                           | Decreased mentation                                                                     |
| d.                           | Cold extremities, livedo reticularis                                                    |
| e.                           | Urine output <30 mL/h                                                                   |
| f.                           | Lactate >2 mmol/L                                                                       |

BP indicates blood pressure; and SBP, systolic blood pressure.

*Systolic BP and hypoperfusion criteria need to be met for the shock diagnosis.

a  critical  reduction  in  cardiac  output  manifest  by  endorgan  dysfunction. 28   Hypotension  (eg,  SBP  &lt;90  mm Hg) is the primary clinical manifestation of shock but is not  sufficient  for  the  diagnosis.  Additionally,  end-organ hypoperfusion should be present as a consequence of cardiac  dysfunction  (Tables  22,  23,  24). 29 Causes  can be  broadly  separated  into  acute  decompensations  of chronic HF, acute myocardial dysfunction without precedent  HF,  and  survivors  of  cardiac  arrest.  In  the  case of acute MI, urgent revascularization is paramount. The approach to cardiogenic shock should include its early

Table 23. Suggested Shock Hemodynamic Criteria* 29

|   1. | SBP <90 mm Hg or mean BP <60 mm Hg                                                                                                                                                                                     |
|------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|    2 | Cardiac index <2.2 L/min/m 2                                                                                                                                                                                           |
|    3 | Pulmonary capillary wedge pressure >15 mm Hg                                                                                                                                                                           |
|    4 | Other hemodynamic considerations a. Cardiac power output ([CO x MAP]/451) <0.6W b. Shock index (HR/systolic BP) >1.0 c. RV shock i. Pulmonary artery pulse index [(PASP-PADP)/CVP] ii. CVP >15 mm Hg iii. CVP-PCW >0.6 |

BP indicates blood pressure; CO, cardiac output; CVP, central venous pressure;  HR,  heart  rate;  MAP,  mean  arterial  pressure;  PADP,  pulmonary  artery diastolic pressure; PASP, pulmonary artery systolic pressure; PCW, pulmonary capillary wedge; RV, right ventricular; and SBP, systolic blood pressure.

*Diagnosis of  shock  requires ≥ 1  criteria  to  be  present  along  with  cardiac index &lt;2.0 L/min/m 2  and SBP &lt;90 mm Hg.

recognition,  invasive  hemodynamic  assessment  when there is insufficient clinical improvement to initial measures  and  providing  appropriate  pharmacological  and MCS to optimize end-organ perfusion and prevent metabolic complications. The evidence that supports the use of  specific  pharmacologic  therapies  and  the  nature  of temporary MCS is primarily gleaned from observational retrospective datasets. Only a few randomized trials have been conducted to assess the most appropriate circulatory support device, and they have been limited by small

Table 24. Society for Cardiovascular Angiography and Interventions (SCAI) Cardiogenic Shock Criteria 29

| Stage                                                                                                       | Bedside Findings                                                                                                                                    | Selected Laboratory Markers                                                    | Hemodynamics                                                                                                                                                                                |
|-------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| A: At risk Normotensive Normal perfusion Cause for risk for shock such as large myocardial infarction or HF | Normal venous pressure Clear lungs Warm extremities Strong palpable pulses Normal mentation                                                         | Normal renal function Normal lactate                                           | SBP >100 mm Hg Hemodynamics: Normal                                                                                                                                                         |
| B:Beginning shock ('pre-shock') Hypotension Normal perfusion                                                | Elevated venous pressure Rales present Warm extremities Strong pulses Normal mentation                                                              | Preserved renal function Normal lactate Elevated BNP                           | SBP <90 mm Hg, MAP <60 mm Hg, or >30 mm Hg decrease from baseline SBP HR >100 bpm Hemodynamics: CI ≥ 2.2 L/min/m 2                                                                          |
| C:Classic cardiogenic shock Hypotension Hypoperfusion                                                       | Elevated venous pressure Rales present Cold, ashen, livedo Weak or nonpalpable pulses Altered mentation Decreased urine output Respiratory distress | Impaired renal function Increased lactate Elevated BNP Increased LFTs Acidosis | SBP <90 mm Hg; MAP <60 mm Hg; >30 mm Hg from baseline SBP despite drugs and temporary MCS HR >100 bpm Hemodynamics: CI ≤ 2.2 L/min/m 2 ; PCW >15 mm Hg; CPO <0.6 W; PAPi <2.0; CVP-PCW >1.0 |
| D:Deteriorating Worsening hypotension Worsening hypoperfusion                                               | Same as stage C                                                                                                                                     | Persistent or worsening values of stage C                                      | Escalating use of pressors or MCS to main- tain SBP and end-organ perfusion in setting of stage C hemodynamics                                                                              |
| E: Extremis Refractory hypotension Refractory hypoperfusion                                                 | Cardiac arrest CPR                                                                                                                                  | Worsening values of stage C laboratories                                       | SBP only with resuscitation PEA Recurrent VT/VF                                                                                                                                             |

BNP indicates brain natriuretic peptide; CI, cardiac index; CPO, cardiac power output; CPR, cardiopulmonary resuscitation; CVP, central venous pressure; HR, heart rate; LFT, liver function test; MAP, mean arterial blood pressure; MCS, mechanical circulatory support; PAPi, pulmonary artery pulsatility index; PCW, pulmonary capillary wedge pressures; PEA, pulseless electrical activity; SBP, systolic blood pressure; VF, ventricular fibrillation; and VT, ventricular tachycardia. Adapted from Baran D et al, 29  with permission from Wiley Periodicals, Inc.

sample size, the inherent open-label study design, short follow-up, and surrogate endpoints.

## Recommendation-Specific Supportive Text

1.  Intravenous inotropic support can increase cardiac  output  and  improve  hemodynamics  in patients presenting with cardiogenic shock. Despite their ubiquitous use for initial management  of  cardiogenic  shock,  there  are  few  prospective data and a paucity of randomized trials to guide their use. 1-8  However, their broad availability, ease of administration, and clinician familiarity  favor  such  agents as the first therapeutic consideration  when  signs  of  organ  hypoperfusion persist despite empiric volume replacement and vasopressors. There is a lack of robust evidence to suggest the clear benefit of one inotropic agent over another in cardiogenic shock. 30  In general, the choice of a specific inotropic agent is guided by blood pressure, concurrent arrhythmias, and availability of drug.
2.  Despite the lack of direct comparative data, the use of short-term MCS  has  dramatically increased. 9-16,31,32   The  hemodynamic  benefits  of the  specific  devices  vary,  and  few  head-to-head randomized  comparisons  exist. 33-39   Randomized clinical  trials  are  underway  that  will  address  the risks  and  benefits  of  one  modality  over  another. Vascular,  bleeding,  and  neurologic  complications are common to MCS devices, and the risk of such complications  should  generally  be  considered  in the calculation to proceed with such support. 40  As much as possible, an understanding of a patient's wishes, overall prognosis and trajectory, and assessment of therapeutic risk should precede the use of invasive temporary MCS.
3.  Team-based cardiogenic shock management provides the opportunity for various clinicians to provide  their  perspective  and  input  to  the  patient's management. 17-22   The  escalation  of  either  pharmacological  and  mechanical  therapies  should be considered in the context of multidisciplinary teams  of  HF  and  critical  care  specialists,  interventional cardiologists, and  cardiac surgeons. Such  teams  should  also  be  capable  of  providing appropriate palliative care. Most documented experiences  have  suggested  outcomes  improve after  shock  teams  are  instituted. 17-22 In  1  such experience, the use of a shock team was associated  with  improved  30-day  all-cause  mortality (HR, 0.61; 95% CI, 0.41-0.93) and reduced inhospital mortality (61.0% vs. 47.9%; P =0.041). 19
4. If time allows, escalation to MCS should be guided by invasively obtained hemodynamic data (eg, PA catheterization). Several observational experiences

have associated PA catheterization use with improved outcomes, particularly in conjunction with short-term MCS. 23-27,41 PA catheterization may also be useful when there is diagnostic uncertainty as to the cause of hypotension or end-organ dysfunction,  particularly  when  a  patient  in  shock  is  not responding to empiric initial shock measures. 42

5. Transfer to centers capable of providing such support should be considered early in the assessment of a patient with cardiogenic shock and a trajectory  of  worsening  end-organ  malperfusion. 17-22,43 The treatment of shock should be recognized as a temporizing strategy to support end-organ perfusion and blood pressure until the cause of the cardiac failure has either been treated (eg, revascularization  in  ST-elevation  MI)  or  recovery  (eg, myocarditis) or a definitive solution to the cardiac failure  can  be  accomplished  (eg,  durable  L VAD or transplant). In many cases, pharmacological or MCS  can  provide  sufficient  time  to  address  the appropriateness  of  more  definitive  therapies  (eg, bridge-to-decision) with the patient, family, and the multidisciplinary shock team.

## 9.6. Integration of Care: Transitions and Team-Based Approaches

| Recommendations for Integration of Care: Transitions and Team-Based Approaches Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Integration of Care: Transitions and Team-Based Approaches Referenced studies that support the recommendations are summarized in the Online Data Supplements.   | Recommendations for Integration of Care: Transitions and Team-Based Approaches Referenced studies that support the recommendations are summarized in the Online Data Supplements.                                        |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                 | LOE                                                                                                                                                                                 | Recommendations                                                                                                                                                                                                          |
| 1                                                                                                                                                                                   | B-R                                                                                                                                                                                 | 1. In patients with high-risk HF, particularly those with recurrent hospitalizations for HFrEF, refer- ral to multidisciplinary HF disease management programs is recommended to reduce the risk of hospitalization. 1-4 |
| 1                                                                                                                                                                                   | B-NR                                                                                                                                                                                | 2. In patients hospitalized with worsening HF, patient-centered discharge instructions with a clear plan for transitional care should be pro- vided before hospital discharge. 5,6                                       |
| 2a                                                                                                                                                                                  | B-NR                                                                                                                                                                                | 3. In patients hospitalized with worsening HF, participation in systems that allow benchmark- ing to performance measures is reasonable to increase use of evidence-based therapy, and to improve quality of care. 7-10  |
| 2a                                                                                                                                                                                  | B-NR                                                                                                                                                                                | 4. In patients being discharged after hospital- ization for worsening HF, an early follow-up, generally within 7 days of hospital discharge, is reasonable to optimize care and reduce rehos- pitalization. 11,12        |

## Synopsis

For  patients  with  HF,  the  transition  from  inpatient  to outpatient  care  can  be  an  especially  vulnerable  period because of the progressive nature of the disease state, complex medical regimens, the large number of comorbid  conditions,  and  the  multiple  clinicians  who  may  be

## Table 25. Important Components of a Transitional Care Plan

A transitional care plan, communicated with the patient and their outpatient clinicians before hospital discharge, should clearly outline plans for:

Addressing any precipitating causes of worsening HF identified in the hospital;

Adjusting diuretics based on volume status (including weight) and electrolytes;

Coordination of safety laboratory checks (eg, electrolytes after initiation or intensification of GDMT);

Further changes to optimize GDMT, including:

Plans for resuming medications held in the hospital;

Plans for initiating new medications;

Plans for titration of GDMT to goal doses as tolerated;

Reinforcing HF education and assessing compliance with medical therapy and lifestyle modifications, including dietary restrictions and physical activity;

Addressing high-risk characteristics that may be associated with poor postdischarge clinical outcomes, such as:

Comorbid conditions (eg, renal dysfunction, pulmonary disease, diabetes, mental health, and substance use disorders);

Limitations in psychosocial support;

Impaired health literacy, cognitive impairment;

Additional surgical or device therapy, referral to cardiac rehabilitation in the future, where appropriate;

Referral to palliative care specialists and/or enrollment in hospice in selected patients.

GDMT indicates guideline-directed medical therapy; and HF, heart failure.

involved. Patients are at highest risk for decompensation requiring readmission in the days and weeks post-hospital discharge. 13  Optimal transitions of care can decrease avoidable  readmissions  and  improve  patient  satisfaction. 14 Multidisciplinary systems of care that promote improved communication between health care professionals, systematic use and monitoring of GDMT, medication reconciliation, and consistent documentation are examples of patient safety standards that should be ensured for all patients with HF transitioning out of the hospital.

## Recommendation-Specific Supportive Text

1.  HF  disease management  programs  can  help to  organize  the  patient's  care  across  settings. Potential team members may include cardiologists, primary  care  clinicians,  HF  nurses,  pharmacists, dieticians,  social  workers,  and  community  health workers. A Cochrane systematic review of 47 RCTs of disease management interventions after hospital discharge found that interventions that use case management (case manager or nurse coordinates care  for high-risk patients) or multidisciplinary approach  may  decrease  all-cause  mortality  and rehospitalization. 3  Disease management programs may comprise education, self-management, medication  optimization,  device  management,  weight monitoring, exercise and dietary advice, facilitated access to care during episodes of decompensation, and  social  and  psychological  support. 14 Disease

management programs coordinated by HF specialists,  including  HF  nurses, may be best suited for patients with HFrEF; however, there are far fewer data on the effectiveness of disease management programs in patients with HFpEF. 2

2. Although  hospitalizations  for  worsening  HF  are often  characterized  by  rapid  changes  in  medical, surgical, and device therapy to optimize a patient's clinical status, the patient's journey with achieving optimal  HF  care  continues  beyond  hospital  discharge.  Written  discharge  instructions  or  educational material given to the patient, family members, or caregiver during the hospital stay or at discharge to home should address all of these: activity level, diet,  discharge  medications,  follow-up  appointment, weight monitoring, cardiac rehabilitation, and what  to  do  if  symptoms  worsen. 14 Thorough  discharge planning that includes special emphasis on ensuring adherence to an evidence-based medication  regimen  is  associated  with  improved  patient outcomes. 15,16 Details  of  the  hospital  course  and the transitional plan of care, with special attention to changes in medications and new medical diagnoses, must be transmitted in a timely and clearly understandable  form  to  all  of  the  patient's  clinicians who will be delivering follow-up care (Table 25).  Any  changes  in  prognosis  that  will  require appropriate care coordination and follow-up postdischarge should be noted.
3. Systems of care designed to support patients with HF as they move through the continuum of care can improve outcomes. 7,14,17,18   Real-time feedback on performance measure benchmarks can improve use  of  evidence-based  therapy  and  quality  of care. 8   Quality improvement programs designed to increase the prescription of appropriate discharge medications  can  increase  GDMT  prescription  at discharge and decrease readmissions and mortality. 9 Electronic point-of-care reminders to prescribe GDMT in patients with HFrEF can improve use. 10,19 Leveraging transparent health care analytics platforms for benchmarking and performance improvement may be helpful. There are ongoing studies to determine the most effective strategies to improve evidence-based care. 20
4. Early  outpatient  follow-up,  a  central  element  of transitional  care,  varies  significantly  across  US hospitals. 11  Early postdischarge follow-up may help minimize gaps in understanding of changes to the care plan or knowledge of test results and has been associated with a lower risk of subsequent rehospitalization. 11,12 Transition of care interventions have  often  bundled  timely  clinical  follow-up  with other  interventions,  making  it  challenging  to  isolate any unique intervention effects. 21 A structured contact with the patient within 7 days of hospital

Table 26. Most Common Co-Occurring Chronic Conditions Among Medicare Beneficiaries With HF (N=4 947 918), 2011

| Beneficiaries Age ≥ 65 y (n=4376150)*   | Beneficiaries Age ≥ 65 y (n=4376150)*   | Beneficiaries Age ≥ 65 y (n=4376150)*   | Beneficiaries Age <65 y (n=571768)†   | Beneficiaries Age <65 y (n=571768)†   | Beneficiaries Age <65 y (n=571768)†   |
|-----------------------------------------|-----------------------------------------|-----------------------------------------|---------------------------------------|---------------------------------------|---------------------------------------|
|                                         | n                                       | %                                       |                                       | n                                     | %                                     |
| Hypertension                            | 3685373                                 | 84.2                                    | Hypertension                          | 461235                                | 80.7                                  |
| Ischemic heart disease                  | 3145718                                 | 71.9                                    | Ischemic heart disease                | 365889                                | 64.0                                  |
| Hyperlipidemia                          | 2623601                                 | 60.0                                    | Diabetes                              | 338687                                | 59.2                                  |
| Anemia                                  | 2200674                                 | 50.3                                    | Hyperlipidemia                        | 325498                                | 56.9                                  |
| Diabetes                                | 2027875                                 | 46.3                                    | Anemia                                | 284102                                | 49.7                                  |
| Arthritis                               | 1901447                                 | 43.5                                    | CKD                                   | 257015                                | 45.0                                  |
| CKD                                     | 1851812                                 | 42.3                                    | Depression                            | 207082                                | 36.2                                  |
| COPD                                    | 1311118                                 | 30.0                                    | Arthritis                             | 201964                                | 35.3                                  |
| AF                                      | 1247748                                 | 28.5                                    | COPD                                  | 191016                                | 33.4                                  |
| Alzheimer's disease or dementia         | 1207704                                 | 27.6                                    | Asthma                                | 88816                                 | 15.5                                  |

Data source: Centers for Medicare &amp; Medicaid Services administrative claims data, January 2011 to December 2011, from the Chronic Condition Warehouse (CCW), ccwdata.org. 50

AF indicates atrial fibrillation; CKD, chronic kidney disease; COPD, chronic obstructive pulmonary disease; and HF, heart failure.

*Mean No. of conditions is 6.1; median is 6.

†Mean No. of conditions is 5.5; median is 5.

discharge  is  a  desired  goal.  Although  historically this  has  been  an  in-person  visit,  telemedicine  is being increasingly used for chronic management. A pragmatic randomized trial found that an initial telephone visit with a nurse or pharmacist to guide follow-up may reduce the need for in-person visits if they are constrained. 22 Overall, the timing and method of delivery (in-person clinic versus virtual visit by video or telephone) should be individualized based on patient  risk  and  available  care  delivery options.  Clinical  risk  prediction  tools  may  help  to identify  patients  at  highest  risk  of  postdischarge adverse outcomes. 23-25

## 10. COMORBIDITIES IN PATIENTS WITH HF 10.1. Management of Comorbidities in Patients With HF

| Recommendations for the Management of Comorbidities in Patients With HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for the Management of Comorbidities in Patients With HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for the Management of Comorbidities in Patients With HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                            | LOE                                                                                                                                                                            | Recommendations                                                                                                                                                                |
| Management of Anemia or Iron Deficiency                                                                                                                                        | Management of Anemia or Iron Deficiency                                                                                                                                        | Management of Anemia or Iron Deficiency                                                                                                                                        |
| 2a                                                                                                                                                                             | B-R                                                                                                                                                                            | 1. In patients with HFrEF and iron deficiency with or without anemia, intravenous iron replace- ment is reasonable to improve functional status and QOL. 1-4                   |
| 3: Harm                                                                                                                                                                        | B-R                                                                                                                                                                            | 2. In patients with HF and anemia, erythropoietin- stimulating agents should not be used to improve morbidity and mortality. 5,6                                               |
| Management of Hypertension                                                                                                                                                     | Management of Hypertension                                                                                                                                                     | Management of Hypertension                                                                                                                                                     |
| 1                                                                                                                                                                              | C-LD                                                                                                                                                                           | 3. In patients with HFrEF and hypertension, uptitration of GDMT to the maximally tolerated target dose is recommended. 7,8                                                     |

| Recommendations for the Management of Comorbidities in Patients With HF (Continued)   | Recommendations for the Management of Comorbidities in Patients With HF (Continued)   | Recommendations for the Management of Comorbidities in Patients With HF (Continued)                                                                                                                        |
|---------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                   | LOE                                                                                   | Recommendations                                                                                                                                                                                            |
| Management of Sleep Disorders                                                         | Management of Sleep Disorders                                                         | Management of Sleep Disorders                                                                                                                                                                              |
| 2a                                                                                    | C-LD                                                                                  | 4. In patients with HF and suspicion of sleep-dis- ordered breathing, a formal sleep assessment is reasonable to confirm the diagnosis and differentiate between obstructive and central sleep apnea. 9,10 |
| 2a                                                                                    | B-R                                                                                   | 5. In patients with HF and obstructive sleep apnea, continuous positive airway pressure may be reasonable to improve sleep quality and decrease daytime sleepiness. 9,11-13                                |
| 3: Harm                                                                               | B-R                                                                                   | 6. In patients with NYHA class II to IV HFrEF and central sleep apnea, adaptive servo-ventilation causes harm. 11,12                                                                                       |
| Management of Diabetes                                                                | Management of Diabetes                                                                | Management of Diabetes                                                                                                                                                                                     |
| 1                                                                                     | A                                                                                     | 7. In patients with HF and type 2 diabetes, the use of SGLT2i is recommended for the man- agement of hyperglycemia and to reduce HF- related morbidity and mortality. 14-17                                |

## Synopsis

Multimorbidity is common in patients with HF, with &gt;85% of patients having ≥ 2 additional chronic conditions. 18,19  Hypertension, ischemic heart disease, diabetes, anemia, CKD, morbid obesity, frailty, and malnutrition are among the most common comorbid conditions in patients with HF (Table 26).  These  chronic  conditions  complicate  the  management of HF and have a significant impact on its prognosis. How  to  generate  specific  recommendations  addressing many of these conditions in the setting of HF is challenging given the current state of the evidence. For example, although depression is common in patients with HF and strongly  impacts  QOL  and  mortality,  conventional  therapies  such  as  antidepressants  have  not  been  effective  in

Figure 14. Recommendations for Treatment of Patients With HF and Selected Comorbidities.

<!-- image -->

Colors correspond to COR in Table 2. Recommendations for treatment of patients with HF and select comorbidities are displayed. ACEi indicates angiotensin-converting enzyme inhibitor; AF, atrial fibrillation; ARB, angiotensin receptor blocker; AV, atrioventricular; CHA 2 DS 2 -VASc, congestive heart failure, hypertension, age ≥ 75 years, diabetes mellitus, stroke or transient ischemic attack [TIA], vascular disease, age 65 to 74 years, sex category; CPAP, continuous positive airway pressure; CRT, cardiac resynchronization therapy; EF, ejection fraction; GDMT, guideline-directed medical therapy; HF, heart failure; HFrEF, heart failure with reduced ejection fraction; IV, intravenous; L VEF, left ventricular ejection fraction; NYHA, New York Heart Association; SGLT2i, sodium-glucose cotransporter-2 inhibitor; and VHD, valvular heart disease. *Patients with chronic HF with permanent-persistent-paroxysmal AF and a CHA 2 DS 2 -VASc score of ≥ 2 (for men) and ≥ 3 (for women).

improving outcomes. 20-22   CKD and HF are closely intertwined in pathophysiology and have a complex and bidirectional relationship. 23 Renal dysfunction increases the risk of toxicities of HF therapies and impairs response to diuretics. 23  The effectiveness of GDMT in patients with HF and concomitant kidney disease is uncertain, because data for treatment outcomes in this patient population are sparse. 24 Recommendations surrounding the management of anemia, hypertension, diabetes, and sleep disorders that are attributable to the presence of evolving evidence for specific treatment strategies in HF are discussed next. Other comorbidities not addressed in the recommendations are, of  course,  also  important  and  warrant  attention  but,  because of lack of large-scale trial data, are not addressed as specific recommendations. Figure 14 summarizes COR 1 and 2a for management of select HF comorbidities.

## Recommendation-Specific Supportive Text Anemia

1.  Routine baseline assessment of all patients with HF includes an evaluation for anemia. Anemia is independently associated with HF disease severity  and  mortality, 25 and  iron  deficiency  appears to  be  uniquely  associated  with  reduced  exercise capacity. 26 Iron  deficiency  is  usually  defined  as ferritin level &lt;100 μg /L or 100 to 300 μg/L, if the  transferrin  saturation  is  &lt;20%.  Intravenous repletion of iron has been shown to improve exercise capacity and QOL. 1-3,27   The FAIR-HF (Ferric Carboxymaltose Assessment in Patients With Iron Deficiency and Chronic Heart Failure) trial showed significant  improvement  in  NYHA  classification,

the 6-minute walk test, and QOL of 459 outpatients with chronic HF who received weekly intravenous ferric carboxymaltose until iron repletion. 1 The  improvement  was  independent  of  the  presence  of  anemia.  These  findings  were  confirmed in 2 more recent trials. 2,3  The IRONOUT HF (Iron Repletion  Effects  on  Oxygen  Uptake  in  Heart Failure)  trial,  however,  showed  no  such  improvement  with  oral  iron  supplementation. 28 This  is attributed to the poor absorption of oral iron and inadequacy of oral iron to replete the iron stores in patients with HF. Therefore, oral iron is not adequate to treat iron  deficiency  anemia  in  patients with HF. Although these trials were underpowered to detect reductions in hard clinical endpoints, 2 meta-analyses  have  suggested  intravenous  iron is  associated  with  a  reduction  in  cardiovascular death  and  hospitalizations. 27,29 Most  recently,  the AFFIRM-AHF  multicenter  trial,  which  included 1132  patients  with  EF  &lt;50%  hospitalized  for HF, showed a decrease in hospitalization for HF with intravenous ferric carboxymaltose compared to placebo (RR, 0.74; 95% CI, 0.58-0.94) but no reduction in cardiovascular death. 4

2. Anemia  in  patients  with  HF  is  associated  with impaired  erythropoietin  production,  with  low  levels  found  to  be  associated  with  worse  long-term outcomes. 30,31 Although  small  studies  examining the  use  of  erythropoietin-stimulating  agents  for the treatment of anemia in patients with HF have suggested  a  trend  toward  improvement  in  functional  capacity  and  reduction  in  hospitalization, a high-quality randomized  trial of  darbepoetin alpha in 2278 patients showed no benefit and an increase in thrombotic events, including stroke. 5,6,32 A meta-analysis of 13 trials supports these findings. 6 Accordingly, erythropoietin-stimulating agent therapy is not recommended for the treatment of anemia in patients with HF.

## Hypertension

3.  Clinical  trials  assessing  the  impact  of  goal  blood pressure  reduction  on  outcomes  in  patients  with HFrEF and concomitant hypertension are lacking. The  optimal  blood  pressure  goal  and  antihypertensive  regimen  are  not  known.  Antihypertensive therapy  is  associated  with  a  decrease  in  the  risk of incident HF in the general population, 33,34  notably with the more stringent SBP target &lt;120 mm Hg. 35 However, low blood pressure, not as a part of an antihypertensive treatment, has been associated with poor outcomes in patients with HFrEF. 7,8  This observation  may  reflect  the  association  between low cardiac output and low blood pressure, rather than  the  effects  of  treatment  for  hypertension.

Nevertheless, hypertension in patients with HFrEF represents  an  opportunity  to  maximize  GDMT  to goal  blood  pressures  defined  by  the  ACC/AHA hypertension guidelines. 36

## Sleep Disorders

4. In  patients  with  HF,  daytime  sleepiness-typically a  feature  of  obstructive  sleep  apnea-may  not reflect the degree of underlying sleep-disordered breathing. 37 Hence, the decision to refer a patient for a sleep study should be based on clinical judgment. Because the treatment of obstructive sleep apnea and central sleep apnea differ, and because obstructive  sleep  apnea  and  central  sleep  apnea can co-occur, 9,11,12 sleep studies can inform clinical decision-making in patients with HF.
5. In patients with HF and central sleep apnea, continuous  positive  airway  pressure  is  associated with  better  sleep  quality  and  nocturnal  oxygenation 9 but  has  not  been  shown  to  affect  survival. 38  In adults with HFrEF and sleep-disordered breathing,  meta-analyses  of  RCTs  have  shown that positive airway pressure therapy results in a moderate reduction in BNP 39  and improvement in blood pressure and LVEF. 40
6. Adaptive  servo-ventilation  was  associated  with increased mortality in 2 RCTs involving patients with HFrEF and central sleep apnea. 11,12  Metaanalyses  have  supported  these  results. 41,42 The weight  of  evidence  does  not  support  the  use of  adaptive  servo-ventilation  for  central  sleep apnea in HFrEF.

## Diabetes

7.  The American Diabetes Association guidelines recommend the use of SGLT2i as first-line agent for the treatment of hyperglycemia in patients with diabetes  with  HF  or  at  high  risk  of  HF. 43   SGLT2i are  the  first  class  of  glucose-lowering  agents  to receive approval from the FDA for the treatment of HFrEF. Treatment of patients with type 2 diabetes with  SGLT2i,  including  canagliflozin,  dapagliflozin, empagliflozin,  and  sotagliflozin,  is  associated  with a reduction in major adverse cardiovascular events, including hospitalization for HF and cardiovascular death. 44   The  mechanisms underlying the improvement  in cardiovascular outcomes  attributed to SGLT2i  are,  however,  unknown  but  appear  to  be only partially related to the glucosuric effect. 45  Two RCTs  totaling  8474  patients  with  NYHA  class  II, III,  or  IV  HF  and  EF ≤ 40%-DAPA-HF assessing dapagliflozin  and  EMPEROR-Reduced  assessing empagliflozin-showed significant reductions in the relative risk of all-cause death (13%), cardiovascular

death  (14%),  hospitalization  for  HF  (26%),  and renal outcomes (38%) with SGLT2i treatment. 14-17 Benefits  were  consistent  across  age,  sex,  and  in patients  with  or  without  diabetes.  Whether  dapagliflozin  or  empagliflozin  improves  outcomes  specifically in patients with HFpEF is being studied. 46,47 The SOLOIST-WHF  trial extends the benefits of  SGLT2i  to  patients  with  diabetes  and  acutely decompensated  HF. 48   Patients  on  SGL T2i  should be  closely  monitored  for  potential  risks,  including severe genitourinary infections and, less commonly, diabetic ketoacidosis. 49

## 10.2. Management of AF in HF

| Recommendations for Management of AF in HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Management of AF in HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Management of AF in HF Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                    |
|---------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                               | LOE                                                                                                                                               | Recommendations                                                                                                                                                                                                                                    |
| 1                                                                                                                                                 | A                                                                                                                                                 | 1. Patients with chronic HF with permanent-per- sistent-paroxysmal AF and a CHA 2 DS 2 -VASc score of ≥ 2 (for men) and ≥ 3 (for women) should receive chronic anticoagulant therapy. 1-5                                                          |
| 1                                                                                                                                                 | A                                                                                                                                                 | 2. For patients with chronic HF with permanent- persistent-paroxysmal AF, DOAC is recom- mended over warfarin in eligible patients. 2-10                                                                                                           |
| 2a                                                                                                                                                | B-R                                                                                                                                               | 3. For patients with HF and symptoms caused by AF, AF ablation is reasonable to improve symp- toms and QOL. 11-14                                                                                                                                  |
| 2a                                                                                                                                                | B-R                                                                                                                                               | 4. For patients with AF and LVEF ≤ 50%, if a rhythm control strategy fails or is not desired, and ventricular rates remain rapid despite medi- cal therapy, atrioventricular nodal ablation with implantation of a CRT device is reasonable. 15-22 |
| 2a                                                                                                                                                | B-NR                                                                                                                                              | 5. For patients with chronic HF and permanent- persistent-paroxysmal AF, chronic anticoagulant therapy is reasonable for men and women with- out additional risk factors. 23-26                                                                    |

## Synopsis

The interplay between AF and HF is complex. It is clear that AF may worsen HF but also that HF increases the risk of AF. Data from randomized trials support the use of anticoagulation among those with HF and AF but not in patients with HF without AF. Anticoagulation may be accomplished with DOAC or with warfarin when favored because of other indications, cost or drug-drug interactions  (the  DOAC  are  generally  preferred).  The  choice between  rate  or  rhythm  control  strategy  reflects  both patient symptoms and the likelihood of better ventricular function with sinus rhythm. RCTs of rhythm control with antiarrhythmic agents versus rate control have not shown a benefit of rhythm control. More recent RCTs with ablation show that ablation may be preferable to antiarrhythmic drugs for a rhythm control strategy. Patients thought to have a cardiomyopathy resulting from rapid AF despite attempts at rate control should be aggressively treated to  maintain  sinus  rhythm  and,  if  that  is  not  successful, atrioventricular nodal ablation with placement of a CRT device can be considered. Patients with HF, and difficult to  control  rates,  may  benefit  from  atrioventricular  node ablation and implantation of a permanent pacemaker if other rate and rhythm control measures fail. If their L VEF is &gt;50%, there is no current evidence that CRT is beneficial compared with RV pacing. 15,21

## Recommendation-Specific Supportive Text

1. The efficacy of long-term warfarin for the prevention of stroke in patients with AF is well established; randomized  trials  have  shown  reduced  embolic rates and mortality. The AHA/ACC/Heart Rhythm Society guidelines for AF recommend use of the CHA 2 DS 2 -VASc  score  (history  of  hypertension, age ≥ 75 [doubled weight], diabetes mellitus, previous stroke or transient ischemic attack or thromboembolism [doubled weight], vascular disease, age 65 to 74 years, sex category) to assess patient risk for adverse outcomes before initiating anticoagulation therapy. 1,27,28  Regardless of whether patients receive  rhythm  or  rate  control,  anticoagulation  is recommended  for  patients  with  HF  and  AF  for stroke prevention with a CHA 2 DS 2 -VASc score of ≥ 2 (for men) and ≥ 3 (for women). 2-5
2. Trials  of  DOAC  have  compared  the  efficacy  and safety  with  warfarin  therapy  rather  than  placebo. Several  DOAC  are  available,  including  the  factor Xa inhibitors apixaban, rivaroxaban, edoxaban, and the  direct  thrombin  inhibitor  dabigatran. 2-5 These drugs do not need routine anticoagulation monitoring or dose adjustment. The fixed dosing together with fewer interactions may simplify patient management, particularly with the polypharmacy commonly seen in HF, but cost for some patients can be  prohibitive  when  not  covered  by  insurance. These drugs have a potential for an improved benefit-risk profile compared with warfarin, which may increase their use in practice, especially in those at increased bleeding risk. 6-9 In a meta-analysis of 4 trials examining efficacy and safety of DOAC in patients with and without HF, DOAC more effectively reduced the rate of stroke or systemic embolism, major  bleeding, and  intracranial  bleeding compared with warfarin, with no treatment heterogeneity by HF status. 10
3.  The 2 largest RCTs of AF ablation in HF showed a  benefit  in  hospitalizations  and  mortality  with ablation. 11,12 although other smaller trials did not. In the AATAC (Ablation Versus Amiodarone for  Treatment  of  Persistent  Atrial  Fibrillation  in Patients  with  Congestive  Heart  Failure  and  an Implanted Device) trial, 203 patients with persistent AF, LVEF &lt;40%, and NYHA class II to III HF, ablation  improved  the  likelihood  of  maintaining

normal  sinus  rhythm  at  24  months  compared with  amiodarone  and,  in  addition,  had  a  45% decrease in hospitalization and decrease in mortality (8% vs. 18%). 11  The CASTLE AF (Catheter Ablation for Atrial Fibrillation with Heart Failure) trial randomized 363 patients with paroxysmal or persistent AF, LVEF &lt;35%, NYHA class II to IV HF, and ICD to ablation versus standard medical  care. 12   The  composite endpoint of death or rehospitalization  was  lower  in  ablation  (28.5%) compared with standard care (44.6%). In addition, there was a lower mortality in the ablation group. In a meta-analysis of 11 RCTs comparing rhythm versus rate control, patients undergoing catheter  ablation  had  improved  survival  (49% relative risk reduction) and reduced hospitalizations (56% relative risk reduction). 13

4. If  a  rhythm  control  strategy  fails  or  is  undesired, and  ventricular  rates  remain  rapid  despite  medical  therapy  after  all  other  options  are  exhausted, atrioventricular nodal ablation with implantation of a  CRT device can be considered as a treatment option. Ablate and pace is an old strategy for difficult to rate control AF. Early studies with RV pacing showed benefit. 15,16  However, when RV pacing was compared with cardiac resynchronization in more recent trials, especially in those with reduced L VEFs, CRT generally produced more benefit than RV pacing. 17-21  The PAVE (Left Ventricular-Based Cardiac Stimulation  post  AV  Nodal  Ablation  Evaluation) and  the  BLOCK-HF  (Biventricular  versus  Right Ventricular Pacing in Patients with AV block) trials included patients with L VEF &gt;35%, with mean EF 46% 22  in PAVE and 40% in BLOCK-HF (enrolled ≤ 50%). In both of these trials, patients undergoing CRT had improved outcomes.
5. HF  is  a  hypercoagulable  state  and  serves  as an  independent  risk  factor  for  stroke,  systemic embolism, and mortality in the setting of AF. 23,24 There are compelling data to support the use of anticoagulation in most patients with HF and concomitant AF, barring contraindications. In patients with HF and a CHA 2 DS 2 -VASc score of 1, those with AF had a 3-fold higher risk compared with individuals  without  concomitant  AF. 25 In  a  post hoc analysis of 2 contemporary HF trials, paroxysmal  and  new  onset  AF  were  associated  with a  greater  risk  for  hospitalization  caused  by  HF or stroke. 26 In a recent registry study, the risk of stroke was particularly higher in the initial period after diagnosis of HF among patients with prevalent AF. 29  Because HF is a risk factor, additional risk  factors  may  not  be  required  to  support  the use  of  anticoagulation  in  patients  with  HF,  and the decision to anticoagulate can be individualized according to risk versus benefit.

## 11. SPECIAL POPULATIONS

## 11.1. Disparities and Vulnerable Populations*

| Recommendations for Disparities and Vulnerable Populations Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Disparities and Vulnerable Populations Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Disparities and Vulnerable Populations Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                            |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                               | LOE                                                                                                                                                               | Recommendations                                                                                                                                                                                                                                                            |
| 1                                                                                                                                                                 | C-LD                                                                                                                                                              | 1. In vulnerable patient populations at risk for health disparities, HF risk assessments and multidisciplinary management strategies should target both known risks for CVD and social determinants of health, as a means toward elimination of disparate HF outcomes. 1-6 |
| 1                                                                                                                                                                 | C-LD                                                                                                                                                              | 2. Evidence of health disparities should be moni- tored and addressed at the clinical practice and the health care system levels. 7-13                                                                                                                                     |

*This section crosslinks to Section 7 .1.1, 'Stage C Nonpharmacological Interventions and Self-Care Support in HF, ' where screening and interventions for social determinants of health are now addressed.

## Synopsis

There  are  important  differences  in  HF  incidence,  risk factors, clinical care needs, and outcomes between specific patient populations 2,3,14,15 (Table 27). It is essential that  HF  clinicians  be  aware  of  the  biological  factors, social  determinants  of  health,  and  implicit  biases  that impact the burden of disease, clinical decision-making, and effective delivery of GDMT. 9,16-18  Women generally present with HF later in life, with more comorbidities and lower patient-reported health status than men. 10,19  Survival for women with HF is generally more favorable, 20 although  access  to  specialty  care  may  be  lower. 21-24 The highest incident of HF is consistently observed in self-identified Black patients. 25,26 HF hospitalization and mortality  rates  for  Black  patients  are  also  higher  than for White patients, with the gap increasing over time for young men. 2,4,27  These differences are driven mostly by social circumstances; a biological premise or genetic explanation for disease or disease severity should not be inferred  by  race  or  ethnicity. 28 Older  patients  with  HF are especially vulnerable to polypharmacy, multimorbidity,  cognitive  decline,  and  frailty. 29,30 Important  strategies to remove biases within health care professionals and systems impacting minority and socioeconomically disadvantaged patient populations include implicit bias training,  recruiting  a  diverse  workforce,  and  promoting broad access to HF care. 28,31-35

## Recommendation-Specific Supportive Text

1. Hypertension  is  significantly  more  prevalent  in Black patients, compared with White patients, populations in the United States, with a younger age of  onset  and  greater  attributable  cardiovascular risks. 36,37   An estimated 50  000 to 350  000 immigrants to the United States from Mexico and Central America  may  have  asymptomatic Trypanosoma

Table 27. Risk of HF and Outcomes in Special Populations

| Vulnerable Population                          | Risk of HF                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | HF Outcomes                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------| |
| Women                                          | The lifetime risk of HF is equivalent between sexes, but HFpEF risk is higher in women-in FHS participants with new-onset HF, odds of HFpEF (EF >45%) are 2.8-fold higher in women than in men. 66 Sex-specific differences in the predictive value of cardiac bio- markers for incident HF. 67 Nontraditional cardiovascular risk factors, including anxiety, de- pression, caregiver stress, and low household income may contrib- ute more toward incident heart disease in women than men. 68 | Overall, more favorable survival with HF than men. In the OPTI- MIZE-HF registry, women with acute HF had a lower 1-y mortality (HR, 0.93; 95% CI, 0.89-0.97), although women are more likely not to receive optimal GDMT. 20,69-71 Lower patient-reported quality of life for women with HFrEF, com- pared with men. 10,71 Greater transplant waitlist mortality for women but equivalent sur- vival after heart transplantation or LVAD implantation. 24,52                                                                                                                                                                                                                                                                                  |
| Older adults                                   | Per FHS, at 40 y of age, the lifetime risk of incident HF is 20% for both sexes; at 80 y of age, the risk remains 20% for men and women despite the shorter life expectancy. 72 LVEF is preserved in at least two-thirds of older adults with the diagnosis of HF. 73                                                                                                                                                                                                                             | Among 1233 patients with HF aged ≥ 80 y, 40% mortality during mean 27-mo follow-up; survival associated with prescription of GDMT. 74                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| Lower socioeconomic status populations         | Among 27078 White and Black adults of low income (70% earned <$15000/y) participating from 2002-2009 in the Southern Community Cohort Study, a 1 interquartile increase in neighborhood deprivation index was associated with a 12% in- crease in risk of HF (adjusted HR, 1.12; 95% CI, 1.07-1.18). 46                                                                                                                                                                                           | Age-adjusted 1999-2018 HF mortality (deaths/100000; mean and 95% CI) was higher with increasing quartiles of ADI, which is based on 17 indicators of employment, poverty, and education: Quartile 1, 20.0 (19.4-20.5); Quartile 2, 23.3 (22.6-24.0); Quartile 3, 26.4 (25.5-27.3); Quartile 4, 33.1 (31.8-34.4). 6                                                                                                                                                                                                                                                                                                                                                                                                                             |
| Black populations                              | In MESA, patients of Black race had highest risk of incident HF (4.6/1000 person-years) and highest proportion of nonisch- emic incident HF. 26 Higher prevalence of HF risk factors including hypertension, obesity, and diabetes, compared with White populations. 75                                                                                                                                                                                                                           | CDC data show race-based differences in HF mortality over time: Black men had a 1.16-fold versus 1.43-fold higher age-adjusted HF-related CVD death rate compared with White men in 1999 ver- sus 2017; Black women had a 1.35-fold versus 1.54-fold higher age-adjusted HF-related CVD death rate compared with White women in 1999 versus 2017. 27 Gap in outcomes is more pronounced among younger adults (35- 64 y of age) versus older adults (65-84 y of age); age-adjusted HF-related CVD death rates were 2.60-fold and 2.97-fold higher in young Black versus White men and women, respectively. 27 Higher rates of hospitalization 3 and mortality among patients with HFpEF. 76 Lower 5-year survival after heart transplant. 77-79 |
| Hispanic populations                           | MESA study showed higher HF incidence in Hispanic com- pared with non-Hispanic White groups (3.5 versus 2.4 per 1000 person-years) but lower than for African Americans (4.6/1000 person-years). 7,26,80                                                                                                                                                                                                                                                                                          | Despite higher rates of hospitalization for HF compared with non- Hispanic Whites, Hispanic patients with HF have shown lower short-term mortality rates. 81 In GWTG, Hispanic patients with HFpEF had lower mortality (OR, 0.50; 95% CI, 0.31-0.81) than non-Hispanic Whites, but this was not the case for Hispanic patients with HFrEF (OR, 0.94; 95% CI, 0.62-1.43). 82 Lower risk of developing AF in the setting of HF, compared with                                                                                                                                                                                                                                                                                                    |
| Asian and Pacific Islander populations         | Limited population-specific data for Asian and Pacific Islander subgroups in the United States. 84,85                                                                                                                                                                                                                                                                                                                                                                                             | High rates of preventable HF hospitalization observed in some Asian and Pacific Islander populations. 13 Lower mortality rates from HF for Asian subgroups when listed as the primary cause of death, compared with non-Hispanic White groups. 86                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| Native American and Alaskan Native populations | Limited population-specific data, with cardiovascular risk fac- tor trends best characterized by the Strong Heart Study and Strong Heart Family Study, demonstrating high rates of hyper- tension and diabetes. 11,87                                                                                                                                                                                                                                                                             | Limited data suggest HF mortality rates in American Indians and Alaska Natives are similar to those in White populations. 88                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |

CDC indicates Centers for Disease Control and Prevention; CVD, cardiovascular disease; FHS, Framingham Heart Study; GDMT, guideline-directed medical therapy; GWTG, Get With The Guidelines registry; HF, heart failure; HFpEF, heart failure with preserved ejection fraction; HFrEF, heart failure with reduced ejection fraction; HR, hazard ratio; LVAD, left ventricular assist device; LVEF, left ventricular ejection fraction; MESA, Multi-Ethnic Study of Atherosclerosis; OPTMIZE-HF, Organized Program To Initiate Lifesaving Treatment In Hospitalized Patients With Heart Failure; and OR, odds ratio.

cruzi ,  with 20% progressing to Chagas cardiomyopathy. 38 Diabetes is highly prevalent in Southeast Asian  and  Pacific  Islander  populations  and  more strongly  associated  with  poor  HF  outcomes. 39,40 Among  patients  with  established  HF,  social  and medical vulnerabilities can impede successful delivery of GDMT and are associated with poorer outcomes. 5,41   Among  older  adults,  low  income, social  isolation,  and  lack  of  caregiver  support increase HF mortality and low QOL. 9,18,42 Nursing home residents, and elderly inpatients with acute HF, are at risk of inadequate GDMT prescription,

- although  interventions  in  nursing  facilities  can improve  care  delivery  for  HF. 30,43-45 Lower  socioeconomic status is associated with HF incidence and HF mortality. 6,46,47  Homelessness, 48  substance use,  food  insecurity,  and  lack  of  transportation each  represent  potential  barriers  to  optimal  disease management. 49  Case management and social work services are essential to the comprehensive multidisciplinary HF team approach for coordinating complex medical, psychiatric, and social needs across multiple sectors.
2.  Health care system factors are a potential source of  disparate  HF  care  delivery  and  outcomes. Women  are  less likely to receive discharge instructions for HF, 50 less likely to be referred to specialty care, 21,22 and less likely to receive a heart transplantation, 51-54  compared with men. Patients with HF of Black race have been identified as less likely  to  receive  care  from  a  cardiologist  during an ICU admission for HF, 55  have less access to specialized inpatient HF care, 12   and may be vulnerable  to  clinician  biases  during  evaluation  for advanced  HF  therapies. 11,53 Hispanic  patients are  disproportionately  noninsured  in  the  United States, 56   may  experience  language  barriers  to quality care, 7,57  and also have less access to specialized inpatient HF care. 12  Native American and Alaskan  Native  populations  experience  particular  challenges  in  specialty  care  access  because Indian Health Service facilities are often small and rural. 11   Engaging patients in medical care within culturally  tailored  environments  has  proven  successful. 58,59 HF  written  educational  materials  for patients and caregivers should be delivered at or below the sixth grade reading level. 60   Workplace interventions  that  improve  cultural  competency and address implicit biases are increasingly available.  Many  aspects  of  GDMT  have  been  inadequately studied by population subgroups, largely as a result of clinical trial underrepresentation. 61-65

## 11.2. Cardio-Oncology

| Recommendations for Cardio-Oncology Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Cardio-Oncology Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Cardio-Oncology Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                                |
|--------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                        | LOE                                                                                                                                        | Recommendations                                                                                                                                                                                                                                                         |
| 1                                                                                                                                          | B-NR                                                                                                                                       | 1. In patients who develop cancer therapy-related cardiomyopathy or HF, a multidisciplinary discussion involving the patient about the risk- benefit ratio of cancer therapy interruption, dis- continuation, or continuation is recommended to improve management. 1,2 |
| 2a                                                                                                                                         | B-NR                                                                                                                                       | 2. In asymptomatic patients with cancer therapy- related cardiomyopathy (EF <50%), ARB, ACEi, and beta blockers are reasonable to prevent progression to HF and improve cardiac function. 2-4                                                                           |

| Recommendations for Cardio-Oncology (Continued)   | Recommendations for Cardio-Oncology (Continued)   | Recommendations for Cardio-Oncology (Continued)                                                                                                                                                                                                                                             |
|---------------------------------------------------|---------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                               | LOE                                               | Recommendations                                                                                                                                                                                                                                                                             |
| 2a                                                | B-NR                                              | 3. In patients with cardiovascular risk factors or known cardiac disease being considered for potentially cardiotoxic anticancer therapies, pretherapy evaluation of cardiac function is rea- sonable to establish baseline cardiac function and guide the choice of cancer therapy. 2,5-16 |
| 2a                                                | B-NR                                              | 4. In patients with cardiovascular risk factors or known cardiac disease receiving potentially cardiotoxic anticancer therapies, monitoring of cardiac function is reasonable for the early iden- tification of drug-induced cardiomyopathy. 2,4,6,8                                        |
| 2b                                                | B-R                                               | 5. In patients at risk of cancer therapy-related cardiomyopathy, initiation of beta blockers and ACEi/ARB for the primary prevention of drug-induced cardiomyopathy is of uncertain benefit. 17-28                                                                                          |
| 2b                                                | C-LD                                              | 6. In patients being considered for potentially car- diotoxic therapies, serial measurement of car- diac troponin might be reasonable for further risk stratification. 29-32                                                                                                                |

## Synopsis

Advances in cancer therapy and an aging population have led to a growing number of cancer patients with comorbid CVD receiving treatment for cancer. 33,34  Cardiovascular  complications  of  cancer  therapy,  notably cardiomyopathy and HF, can result in significant morbidity  and  interruption  of  treatment,  impacting  both short- and long-term survival. 35,36  Because drug development in cancer therapeutics grows at an exponential pace,  establishing  a  unified  framework  for  the  management of cancer therapy-related cardiomyopathycommonly defined as a decrease in LVEF of at least 10% to &lt;50%-is necessary to  mitigate  the  cardiovascular risks of established novel therapies. Cardiooncology is the practice of precancer therapy cardiovascular risk stratification, prevention, early detection, and  treatment  of cardiovascular complications. 36,37 The evidence from which guideline recommendations in cardio-oncology have emerged has been based on studies of anthracycline and trastuzumab-induced cardiomyopathy. Cancer therapy-related cardiomyopathy is,  however,  a  heterogeneous  disease,  with  a  wide range  of  presentations-from  asymptomatic  LV  dysfunction  to  cardiogenic  shock-and  drug-dependent pathophysiologic  mechanisms  that  are  often  poorly understood. Until sufficient high-quality, drug-specific evidence and cost-effectiveness analyses for screening  and  monitoring  are  available,  these  recommendations  are  applicable  across  potentially  cardiotoxic therapies (Table 28).

## Recommendation-Specific Supportive Text

1. HF  secondary  to  cancer  therapy-related  cardiomyopathy  is  associated  with  significantly  worse

Table 28. Cancer Therapies Known to Be Associated With Cardiomyopathy

|                                                      |                                                                                                                            | Cardiac Function Monitoring Often Performed in Clinical Practice   | Cardiac Function Monitoring Often Performed in Clinical Practice   |
|------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------|--------------------------------------------------------------------|
| Class                                                | Agent(s)                                                                                                                   | Pretherapy                                                         | Serial                                                             |
| Anthracyclines 55-57                                 | Doxorubicin, epirubicin                                                                                                    | X                                                                  | X                                                                  |
| Alkylating agents 58-60                              | Cyclophosphamide, ifosfamide, melphalan                                                                                    | X                                                                  |                                                                    |
| Antimicrotubule agents. 61,62                        | Docetaxel                                                                                                                  |                                                                    |                                                                    |
| Antimetabolites 63-72                                | Fluorouracil, capecitabine, fludarabine, decitabine                                                                        |                                                                    |                                                                    |
| Anti-HER2 agents 73-76                               | Trastuzumab, pertuzumab                                                                                                    | X                                                                  | X                                                                  |
| Monoclonal antibodies 77                             | Rituximab                                                                                                                  |                                                                    |                                                                    |
| Tyrosine-kinase inhibitors 78-100                    | Dabrafenib, dasatinib, lapatinib, pazopanib, ponatinib, sorafenib, trametinib, sunitinib, vandetanib, imatinib, vandetanib |                                                                    |                                                                    |
| Immune checkpoint inhibitors 39,40,101               | Nivolumab, ipilimumab, pembrolizumab                                                                                       |                                                                    |                                                                    |
| Protease inhibitors 102-106                          | Bortezomib, carfilzomib                                                                                                    |                                                                    |                                                                    |
| Endocrine therapy 107-111                            | Goserelin, leuprolide, flutamide, bicalutamide, nilutamide                                                                 |                                                                    |                                                                    |
| Chimeric antigen receptor T-cell therapy. 112,113    | Tisagenlecleucel, axicabtagene ciloleucel                                                                                  | X                                                                  |                                                                    |
| Hematopoietic stem cell transplantation 7,44,114-119 | Hematopoietic stem cell transplantation                                                                                    | X                                                                  |                                                                    |
| Radiation 7,44,114-119                               | Chest                                                                                                                      |                                                                    |                                                                    |

outcomes. 1,2,38   Patients  who  develop  HF  while receiving potentially cardiotoxic therapies should have these therapies discontinued while a diagnostic workup is undertaken to ascertain the  cause  of  HF  and  initiate  GDMT.  The  complex decision to resume, modify, or permanently discontinue  therapy  by  the  primary  oncologist should be done in a patient-centered approach in  concert  with  a  cardiovascular  specialist  in cardio-oncology. Factors impacting the decision include  the  severity  of  cancer  therapy-related cardiomyopathy and the response to neurohormonal  blockade,  the  offending  agent's  specific mechanism of injury, the patient's comorbid conditions and cancer-related prognosis and, lastly, the availability of alternative noncardiotoxic treatment options.  However,  the  clinical  significance of  asymptomatic  cancer  therapy-related cardiomyopathy  that is identified on routine monitoring is less clear. This is most apparent in patients receiving trastuzumab in whom asymptomatic decreases in LVEF can occur in &gt;10% of patients yet result in a high recovery rate and low rate of discontinuation of therapy. 1,2 Accordingly, trastuzumab is often continued in patients deemed low risk while neurohormonal blockade is  initiated.  Conversely,  patients diagnosed with immune checkpoint-related myocarditis typically have  the  offending  agents  discontinued  indefinitely, given the associated high mortality. 39,40

2.  Studying  the  effectiveness  of  neurohormonal therapies specifically in patients with the CTRC gene is challenging given the relative infrequency of  events,  heterogeneity  of  offending  agents, the  poorly  understood  pathophysiology,  and  the

overlap  with  comorbid  CVD.  Available  data  in patients with  anthracycline  and  trastuzumabinduced  cardiomyopathy  suggest  beta  blockers and ACEi are effective in improving LV dysfunction. 2-4  Given the dearth of data specific to cancer  therapy-related  cardiomyopathy  for  other GDMT,  their  use  should  align  with  the  HFrEF management guidelines. Initiation and uptitration of standard HF therapies remains the mainstay of treatment in patients with cancer therapy-related cardiomyopathy or LVEF &lt;50%, with close monitoring  of  cardiac  function  to  guide  discussions with oncology on the resumption of, or choice of, subsequent cancer therapies. 2

3. Pretherapy  quantification  of  LVEF  in  patients receiving  potentially  cardiotoxic  cancer  therapies serves 4 purposes: 1) pretherapy risk stratification  and  diagnosis  of  preexisting  cardiomyopathy,  2)  establish  a  reference  baseline to which reevaluations can be compared, 3) initiate  cardioprotective  medications  before  cancer therapy, and 4) guide choice of cancer therapy. Echocardiography is recommended as the firstline  modality  for  LVEF  assessment  given  its availability, safety, relatively low cost, and its ability  to  provide structural and functional information  beyond  LVEF. 2,5-16,41-47 The  risk  of  cancer therapy-related  cardiomyopathy  varies  greatly across cancer therapies and is modified by preexisting  cardiovascular  risk  factors  (Table  29). Pretherapy LVEF is a strong predictor of major adverse cardiovascular events in patients receiving potentially cardiotoxic therapies. 2,5-10,42-47  The clinical use and cost-effectiveness of systematic screening in all patients, however, is unclear. 11-16

Table 29. Risk Factors for Cancer Therapy-Related Cardiomyopathy

| Age ≥ 60 y                          |
|-------------------------------------|
| Black race                          |
| CAD                                 |
| Hypertension                        |
| Diabetes                            |
| Preexisting cardiomyopathy          |
| Previous exposure to anthracyclines |
| Previous chest radiation            |
| Elevated troponin pretherapy        |

CAD indicates coronary artery disease.

Patients  with  cancer  and  preexisting  cardiovascular  risk  factors  are  at  significantly  higher risk  of  cancer  therapy-related  cardiomyopathy, representing  a  population  in  which  pretherapy evaluation would  have  a  significantly higher yield. 2,5-10,42-47

4. The  purpose  of  serial  monitoring  of  LVEF  in patients  receiving  potentially  cardiotoxic  anticancer  agents  is  to  identify  subclinical  cardiac injury,  initiate  cardioprotective agents, and consider  temporary  or  permanent  interruption  of the offending agent. 2,4,6,8,48  The practice of LVEF monitoring  has  mostly  been  implemented  in patients  receiving  anthracyclines,  trastuzumab, or both (Table 28). In a study of 2625 patients receiving  anthracyclines  for  breast  cancer  or lymphoma  who  underwent  serial  LVEF  monitoring,  cancer  therapy-related  cardiomyopathy occurred in 9% of patients, of whom 81% had mild symptoms (NYHA class I to II). 4  Beta blockers and ACEi-ARB were initiated in all patients, with  86%  having  at  least  partial  recovery  of LVEF. 4  Patients with recovered LVEF had a lower incidence  of  cardiac  events  than  those  that did  not. 4 The  clinical  significance  of  an  asymptomatic  decrease  in  LVEF  and  the  optimal  frequency and duration of monitoring is less clear and likely depend on patient risk, the anticancer agent  used,  and  its  cumulative  dose.  Although a  one-size-fits-all  approach  to  monitoring  for cancer therapy-related cardiomyopathy may be easier to implement systematically, it may not be the most cost-effective. Until additional data are available,  limiting  the  monitoring  to  patients  at higher risk of cancer therapy-related cardiomyopathy (Table 29) is a reasonable strategy.
5.  Whether the preemptive use of ACEi-ARB, spironolactone,  or  selected  beta  blockers  such  as carvedilol and nebivolol is effective in reducing the risk  of  cancer  therapy-related  cardiomyopathy

has  been  investigated  in  a  number  of  small clinic  trials,  with  conflicting  findings. 17-27,49 The most supportive  of  this  practice  is  a  study  that randomized  114  patients  receiving  high-dose chemotherapy and having a posttreatment troponin  rise  &gt;0.07  ng/mL  to  enalapril  or  placebo. 20 None of the patients in the enalapril arm met the primary  endpoint  (&gt;10%  decrease  in  LVEF  to below 50%), while 43% of patients in the standard  of  care  group  had  a  significant  decrease in  L VEF. 20   Although  other  studies  have  shown similar findings, the magnitude of the difference in  L VEF  between  arms  was  often  small  (&lt;5%) and of questionable clinical significance. 19,22  Not all studies have replicated these findings. 18,21,24,26 Most  importantly, none  of the studies have assessed whether preemptive use of HF therapies in patients at risk for cancer therapy-related cardiomyopathy improves clinical outcomes, such as mortality or hospitalization for HF. Additional studies are needed to define the appropriate criteria  and  patient  population  in  whom  to  initiate medical  therapies  for  the  primary  prevention  of cancer therapy-related cardiomyopathy.

6.  Cardiovascular biomarkers, notably troponin, have been  studied  for  cardiovascular  risk  stratification in patients undergoing potentially cardiotoxic therapies. 29-32 A study of 452 patients with breast cancer  showed  that  an  elevated  pretreatment level  (&gt;14  ng/L)  was  associated  with  a  4-fold increase in the risk of cancer therapy-related cardiomyopathy. 32   Other smaller studies have found no advantage in measuring troponin or natriuretic peptides pretherapy. 50-53  Overall, these biomarker studies  were  observational  and  small  in  sample size  and  number  of  events. 54 Serial  biomarkers may be more useful in risk stratification. For example,  in  a  study  of  703  patients  receiving anthracyclines, an increase in troponin within 72 hours of chemotherapy and 1 month after the completion of treatment course were associated with a greater risk of cancer therapy-related cardiomyopathy. 29   The clinical use of measuring biomarkers was assessed in 1 trial in which 114 patients with posttreatment increase in troponin to &gt;0.07 ng/mL were randomized to enalapril or standard of  care. 20 None  of  the  patients  in  the  enalapril group  had  a  decrease  in  L VEF,  compared  with 43% in the standard of care group. 20  Data for the use of natriuretic peptides are limited. In practice, biomarkers could provide rapid risk stratification in  patients  for  which  echocardiographic  findings are equivocal and help determine whether symptoms are cardiovascular in origin.

## 11.3. HF and Pregnancy

| Recommendations for HF and Pregnancy Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for HF and Pregnancy Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for HF and Pregnancy Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                        |
|---------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                         | LOE                                                                                                                                         | Recommendations                                                                                                                                                                                                                                  |
| 1                                                                                                                                           | C-LD                                                                                                                                        | 1. In women with a history of HF or cardiomyopathy, including previous peripartum cardiomyopathy, patient-centered counseling regarding contra- ception and the risks of cardiovascular deteriora- tion during pregnancy should be provided. 1-8 |
| 2b                                                                                                                                          | C-LD                                                                                                                                        | 2. In women with acute HF caused by peripartum cardiomyopathy and LVEF <30%, anticoagula- tion may be reasonable at diagnosis, until 6 to 8 weeks postpartum, although the efficacy and safety are uncertain. 9-12                               |
| 3: Harm                                                                                                                                     | C-LD                                                                                                                                        | 3. In women with HF or cardiomyopathy who are pregnant or currently planning for pregnancy, ACEi, ARB, ARNi, MRA, SGLT2i, ivabradine, and vericiguat should not be administered because of significant risks of fetal harm. 13-15                |

## Synopsis

HF may complicate pregnancy either secondary to an existing prepregnancy cardiomyopathy, or as a result of peripartum cardiomyopathy. 16-18 Peripartum cardiomyopathy is defined as systolic dysfunction, typically L VEF &lt;45%, often with L V dilation, occurring in late pregnancy or early postpartum with no other identifiable cardiomyopathy cause. 14,19-21 Peripartum  cardiomyopathy  occurs  globally, 22,23 with  the highest incidences in Nigeria, Haiti, and South Africa. Incidence in the United States is 1 in 1000 to 8000 deliveries and has risen over time. 24,25  Peripartum cardiomyopathy risk factors include maternal age &gt;30 years, African ancestry, multiparity, multigestation, preeclampsia/eclampsia, anemia, diabetes, obesity, and prolonged tocolysis. 22,23,26-30 A genetic contribution is recognized, 31-33 particularly titan gene mutations. 34,35   Most women present with HF within 1  month  postpartum;  cardiogenic  shock,  arrhythmias,  or venous-arterial  thromboembolism  are  all  possible.  Treatment includes GDMT adjusted for pregnancy or breastfeeding status  and  anticoagulation  consideration 16 ;  identification of a pathogenic 16-kDa prolactin led to trials of the dopamine-agonist bromocriptine. 36-41 Patient-centered multidisciplinary planning is essential, including early institution of mechanical support for shock 42 (T able 30). Prognosis is related to initial L VEF, L V thrombosis, RV involvement, preeclampsia, geographic region, and race. 7,43-48 L V recovery and survival is generally favorable in developed countries 11,25,49 ;  a  100-patient  US  registry  showed  93% transplant/L VAD-free 1-year survival. 46

## Recommendation-Specific Supportive Text

1. Pregnancy is generally well-tolerated in women with cardiomyopathy  and  NYHA  class  I  prepregnancy. However,  clinical  deterioration  can  occur,  so  prepregnancy counseling and shared decision-making

are  essential. 1,3,50   Among  women  with  non-peripartum cardiomyopathy, major cardiovascular events occurred in 39% (United States) and 35% (Canada) of pregnancies, with 1% and 7% mortality, respectively. 51,52  Previous cardiac events, NYHA class III to IV, or L VEF &lt;40% markedly increased maternal and fetal risks. 51-55  The ROPAC (Registry of Pregnancy and Cardiac disease) study describes pregnancy outcomes for 1321 women with structural  heart  disease:  Women with prepregnancy or peripartum cardiomyopathy had the highest mortality rate (2.4%). 2,22  ROPAC was used to validate the modified WHO risk classification 56 ; the ZAHARA I (Zwangerschap bij Aangeboren Hartafwijkingen I) and CARPREG II (CARdiac disease in PREGnancy) scores also support shared decision-making. 51,57,58 Subsequent pregnancies for women with previous peripartum cardiomyopathy have been associated with  further  decreases  in  L V  function,  maternal death, and adverse fetal outcomes. 43,58 The strongest prognostic determinant is L VEF &lt;50% before a  subsequent  pregnancy. 6-8 An  international  systematic review that included 93 subsequent pregnancies  with  persistent  L V  dysfunction  reported 48% further  L VEF  deterioration,  49%  HF  symptoms, and 16% mortality, whereas among 98 with recovered  L V  function  presubsequent  pregnancy, these rates were 27%, 32%, and 0%, respectively. 5

2. Pregnancy is a hypercoagulable state even in the absence of cardiovascular complications. In the setting of acute HF, particularly when there is L V blood stasis because of severely reduced systolic function, the risk  of  intracardiac  thrombus  formation  is  significant. The incidence of intracardiac thrombi during acute HF caused by peripartum cardiomyopathy has been reported to be around 16% to 17%. 9,10 with  9%  thromboembolic  events  in  2  separate cohorts 11,12 Women with  an  intracardiac  thrombus or  a  thromboembolic  event  receive  anticoagulation as per standard of care. Women with severely depressed  L VEF  (&lt;30%)  in  the  setting  of  acute HF caused by peripartum cardiomyopathy can be considered for anticoagulation, especially in the first 6  to  8  weeks  postpartum,  when  hypercoagulability is most pronounced. If bromocriptine is used for postpartum women with severe acute HF caused by peripartum cardiomyopathy and L VEF &lt;35%, it should  be  accompanied  by  at  least  prophylacticdosed  anticoagulation,  because  of  the  potential association with thromboembolic events. 6  However, the efficacy and safety of bromocriptine for acute peripartum cardiomyopathy treatment currently remains uncertain, and further randomized placebocontrolled trials are required to define the role of this therapy, particularly in the setting of contemporary HF GDMT and cardiogenic shock management.

Table 30. HF Management Strategies Across the Pregnancy Continuum

|                                                   | Preconception                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | During Pregnancy                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | Postpartum                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|---------------------------------------------------| | | |
| Nonpharmacological strategies                     | Preconception genetic counseling and testing for potentially heritable cardiac conditions. Use of pregnancy cardiovascular risk tools, 51,56-58 and echocardiography for myo- cardial structure and function assessment, to provide information that facilitates informed counseling. For women planning a pregnancy, provide per- sonalized counseling that promotes the auton- omy and goals of the patient (and her partner, as applicable), the patient's ability for self-care and risk awareness, and ensures adequate psychosocial support for decision-making. 3 For women not currently planning a pregnancy but who might conceive, discuss HF-specific considerations regarding pregnancy and refer to gynecology or primary care for contracep- tive counseling. | Close maternal monitoring for HF signs or symp- toms or other cardiovascular instability by cardiol- ogy and obstetric and maternal-fetal medicine teams; close fetal monitoring by the obstetric and maternal-fetal medicine teams. Consideration of routine echocardiographic screening in the third trimester for reassess- ment of myocardial structure and function before labor; echocardiography for any signifi- cant changes in HF symptoms or signs during pregnancy, or if HF medications are reduced or discontinued. 18 BNP or NT-proBNP monitoring during preg- nancy may have some value for prediction of cardiovascular events. 73,74 Close maternal monitoring by obstetrics and maternal-fetal medicine teams for preeclamp- sia, which has shared risk factors and patho- genesis with PPCM. 47,75 For women presenting with decompensated HF or cardiogenic shock, hemodynamic moni- toring and MCS, as appropriate, within a mul- tidisciplinary collaborative approach that sup- ports prompt decision-making about the timing and mechanism of delivery. | Multidisciplinary recommendations from ob- stetrics and neonatology and pediatrics teams and shared decision-making regarding the maternal and neonatal risks and benefits of breastfeeding. For women presenting with decompensated HF or cardiogenic shock, HF management should include hemodynamic monitoring and mechanical circulatory support as appropriate                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| Pharmacological strat- egies                      | Review of all current medications. For women planning pregnancy imminently, modification of HF pharmacotherapy includ- ing. discontinuation of any ACEi, ARB, ARNi, MRA, or SGLT2i or ivabradine medications; within a construct of multidisciplinary shared decision-making, continuation of a beta block- er (most commonly metoprolol), hydralazine, and nitrates; adjustment of diuretic dosing to minimize the risk of placental hypoperfu- sion. 13-15 Ideally, repeat echocardiography approximately 3 mo after preconception HF medication adjustments to ensure stability of myocardial structure and function before conception.                                                                                                                                   | Close monitoring of maternal blood pressure, heart rate, and volume status, with adjustment of the modified HF regimen as appropriate to avoid hypotension (systemic vasodilation peaks in the second trimester) and placental hypoperfusion. For women with HF or cardiomyopathy presenting during pregnancy without precon- ception counseling and assessment, urgent discontinuation of any GDMT pharmacothera- pies with fetal toxicities; within a construct of multidisciplinary shared decision-making, continuation of a beta blocker (most com- monly metoprolol succinate), hydralazine, and nitrates; adjustment of diuretic dosing to mini- mize the risk of placental hypoperfusion.                                                                                                                                                                                                                                                                                                                                                                                | For women with acute HF caused by PPCM and LVEF <30%, consideration of anticoagula- tion until 6-8 wk postpartum, although the ef- ficacy and safety remain uncertain at this time. For postpartum women with severe acute HF caused by PPCM and LVEF <35%, in GDMT pharmacotherapy and prophylactic anticoagula- tion, to improve LVEF recovery 6,31,3641,76 ; the efficacy and safety of bromocriptine for acute PPCM treatment remains uncertain at this time, particularly in the setting of contemporary HF GDMT and cardiogenic shock management.* For women who choose to breastfeed, review medications with neonatology and pediatrics teams for neonatal safety during lactation, ideally with pharmacist consultation if available. Within a construct of multidisciplinary shared decision-making, medications that may be ap- propriate during breastfeeding include ACEi (enalapril or captopril preferred, monitor neona- tal weight), beta blockers (metoprolol preferred, monitor neonatal heart rate). 15 Diuretics can suppress lactation, but with neo- natal follow-up the use of furosemide may be appropriate. 15 |
| Multidisciplinary care beyond the cardiology team | Consultation with genetics, gynecology, and maternal-fetal medicine teams, as appropriate to the outcome of shared decision-making.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          | Multidisciplinary management with obstetrics and maternal-fetal medicine teams during pregnancy. For women with decompensated HF or evi- dence of hemodynamic instability antepartum, delivery planning will include obstetrics and maternal-fetal medicine, anesthesia, and neo- natology teams.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | Multidisciplinary management with obstetrics, maternal-fetal medicine, neonatology, and pe- diatrics teams, especially for multidisciplinary recommendations regarding lactation. Consultation with gynecology team for ongoing contraceptive planning.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |

ACEi indicates angiotensin-converting enzyme inhibitor; ARB, angiotensin receptor blocker; ARNi, angiotensin receptor-neprilysin inhibitor; BNP, B-natriuretic peptide; GDMT, guideline-directed medical therapy; HF, heart failure; LVEF, left ventricular ejection fraction; MCS, mechanical circulatory support; MRA, mineralocorticoid receptor antagonist; NT-proBNP, N-terminal prohormone of brain natriuretic peptide; PPCM, peripartum cardiomyopathy; RCT, randomized controlled trial; RV, right ventricular; and SGLT2i, sodiumglucose cotransporter-2 inhibitor.

*An initial open-label pilot RCT in South Africa suggested addition of bromocriptine to GDMT was associated with greater LVEF improvement and a lower rate of the composite endpoint at 6 mo. 37  Among 96 women with acute PPCM in a Burkina Faso RCT, 4 wk of bromocriptine was associated with LVEF recovery and lower mortality (16.6% versus 29.1%; P &lt;0.001). 39  A multicenter German study randomized 63 patients to 1 versus 8 wk of bromocriptine (no placebo, as deemed unethical), 38  with LVEF recovery ≥ 50% in 52% and 68% of the 1- and 8-wk groups, respectively, and no deaths. A substudy also showed high rates of RV recovery. 41  Two retrospective cohorts (Germany, Canada) and a multicenter cohort of subsequent pregnancies also suggested greater LVEF recovery with bromocriptine. 31,38,40  Bromocriptine may currently be most justified in women with LVEF &lt;25% or cardiogenic shock. The downsides of prohibiting breastfeeding should be considered. Bromocriptine should be accompanied by at least prophylactic-dosed anticoagulation, because of potential hypercoagulability. 38  The European Society of Cardiology endorses 'BOARD' (Bromocriptine, Oral HF therapy, Anticoagulation, vasoRelaxing agents, Diuretics) for acute PPCM management. 13,14

3. In  2015,  the  FDA  adopted  the  Pregnancy  and Lactation  Labeling  Rule,  which  retired  the  previous pregnancy risk categories A through X and, instead, assigned a descriptive risk summary to aid medication counseling  for  pregnant  and  breastfeeding  women. ACEi and ARB are associated with second- and thirdtrimester renal and tubular dysplasia, oligohydramnios, fetal  growth  restriction,  ossification  disorders  of  the skull, lung hypoplasia, contractures, large joints, anemia,  and  intrauterine  fetal  death  and  are,  therefore, strictly  contraindicated. 59-61 There  are  no  specific data for ARNi or ivabradine. For spironolactone, there is  sufficient  information  regarding  dose-dependent feminization of male rabbit and rat offspring to raise concern 62 ;  data  are  limited  for  eplerenone.  HFrEF medications considered acceptable during pregnancy, 15 within a construct of multidisciplinary shared decision-making  regarding  benefits  and  potential risks,  are  furosemide,  beta  blockers  (most  commonly metoprolol), 63-65 hydralazine, and nitrates. 13,14,19 Women  with  peripartum  cardiomyopathy  were  historically  counseled  against  breastfeeding  because of metabolic demands and prolactin stimulation, but breastfeeding may even be associated with L V recovery. 66-70  Postpartum women who breastfeed can start ACEi (enalapril or captopril preferred), and metoprolol remains the preferred beta blocker. 66,71 The National Library of Medicine hosts LactMed (https://www.ncbi. nlm.nih.gov/books/NBK501922/). 72

## 12. QUALITY METRICS AND REPORTING

## 12.1. Performance Measurement

| Recommendations for Performance Measurement Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Performance Measurement Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Performance Measurement Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                                               |
|----------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                | LOE                                                                                                                                                | Recommendations                                                                                                                                                                                                                                                                                |
| 1                                                                                                                                                  | B-NR                                                                                                                                               | 1. Performance measures based on professionally developed clinical practice guidelines should be used with the goal of improving quality of care for patients with HF. 1-7                                                                                                                     |
| 2a                                                                                                                                                 | B-NR                                                                                                                                               | 2. Participation in quality improvement programs, including patient registries that provide bench- mark feedback on nationally endorsed, clinical practice guideline-based quality and perfor- mance measures can be beneficial in improving the quality of care for patients with HF. 1,2,5,6 |

## Synopsis

The  ACC/AHA Task  Force  on  Performance  Measures (Task Force) distinguishes quality measures from performance measures. Performance measures are selected from  the  most  important  ACC/AHA  clinical  practice guideline recommendations with the strongest evidence. These measures are suitable for public reporting or pay for performance. Quality measures are those metrics that may be useful for local quality improvement but do not reach the performance measure standard. Performance measures of  the  ACC/AHA  focus  on  process  of  care measures that measure the quality of care by the clinician,  facility,  and  health  system.  Patient  registries  that track  such  measures  can  provide  feedback  to  participants, which may help with improvement in quality.

## Recommendation-Specific Supportive Text

1.  The  current  ACC/AHA  performance  and  quality  measures (based on the 2013 ACC/AHA HF guideline and the 2017 ACC/AHA/HFSA guideline supplement) are displayed in Table 31. 8 The performance measures are derived from the most definitive guideline recommendations (ie, NYHA class I and class III recommendations). Observational data suggest  that  hospitals  that  receive  feedback  on their HF care improve over time. 1-7
2. Hospitals  that  perform  well  on  medication-related performance  measures  have  better  HF  mortality rates than hospitals with poorer performance. 3,4 Other observational  data  suggest  that  hospitals  that  participate in registries have better process of care and outcomes compared with hospitals that do not participate. 5,6 Randomized studies of audit and feedback of performance, in many different patient groups, have, in  general, showed improvement in care. 7 However, public reporting of HF measures in Ontario, Canada, did not clearly improve care during a randomized trial. 9

## 13. GOALS OF CARE

## 13.1. Palliative and Supportive Care, Shared Decision-Making, and End-of-Life

| Recommendations for Palliative and Supportive Care, Shared Decision- Making, and End-of-Life Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Palliative and Supportive Care, Shared Decision- Making, and End-of-Life Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.   | Recommendations for Palliative and Supportive Care, Shared Decision- Making, and End-of-Life Referenced studies that support the recommendations are summa- rized in the Online Data Supplements.                                                                                                                                                                                                 |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                                                                                                                 | LOE                                                                                                                                                                                                 | Recommendations                                                                                                                                                                                                                                                                                                                                                                                   |
| 1                                                                                                                                                                                                   | C-LD                                                                                                                                                                                                | 1. For all patients with HF, palliative and supportive care-including high-quality communication, conveyance of prognosis, clarifying goals of care, shared decision-making, symptom man- agement, and caregiver support-should be provided to improve QOL and relieve suffering. 1                                                                                                               |
| 1                                                                                                                                                                                                   | C-LD                                                                                                                                                                                                | 2. For patients with HFbeing considered for, or treated with, life-extending therapies, the option for discontinuation should be anticipated and dis- cussed through the continuum of care, including at the time of initiation, and reassessed with changing medical conditions and shifting goals of care. 2,3                                                                                  |
| 2a                                                                                                                                                                                                  | B-R                                                                                                                                                                                                 | 3. For patients with HF-particularly stage D HF patients being evaluated for advanced therapies, patients requiring inotropic support or temporary mechanical support, patients experiencing uncontrolled symptoms, major medical decisions, or multimorbidity, frailty, and cognitive impairment-specialist palliative care consultation can be useful to improve QOL and relieve suffering. 4-6 |

Table 31. ACC/AHA 2020 HF Clinical Performance, Quality, and Structural Measures 8

| Measure No.                                                                                                | Measure Title                                                                                                         | Care Setting                                                                                               | Attribution                                                                                                | Measure Domain                                                                                             |
|------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------|
| PM-1                                                                                                       | LVEF assessment                                                                                                       | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Diagnostic                                                                                                 |
| PM-2                                                                                                       | Symptom and activity assessment                                                                                       | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Monitoring                                                                                                 |
| PM-3                                                                                                       | Symptom management                                                                                                    | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Treatment                                                                                                  |
| PM-4                                                                                                       | Beta-blocker therapy for HFrEF                                                                                        | Outpatient Inpatient                                                                                       | Individual practitioner Facility                                                                           | Treatment                                                                                                  |
| PM-5                                                                                                       | ACEi, ARB, or ARNi therapy for HFrEF                                                                                  | Outpatient Inpatient                                                                                       | Individual practitioner Facility                                                                           | Treatment                                                                                                  |
| PM-6                                                                                                       | ARNi therapy for HFrEF                                                                                                | Outpatient Inpatient                                                                                       | Individual practitioner Facility                                                                           | Treatment                                                                                                  |
| PM-7                                                                                                       | Dose of beta blocker therapy for HFrEF                                                                                | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Treatment                                                                                                  |
| PM-8                                                                                                       | Dose of ACEi, ARB, or ARNi therapy for HFrEF                                                                          | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Treatment                                                                                                  |
| PM-9                                                                                                       | MRA therapy for HFrEF                                                                                                 | Outpatient Inpatient                                                                                       | Individual practitioner Facility                                                                           | Treatment                                                                                                  |
| PM-10                                                                                                      | Laboratory monitoring in new MRA therapy                                                                              | Outpatient Inpatient                                                                                       | Individual practitioner Facility                                                                           | Monitoring                                                                                                 |
| PM-11                                                                                                      | Hydralazine and isosorbide dinitrate therapy for HFrEF in those patients self-identified as Black or African American | Outpatient Inpatient                                                                                       | Individual practitioner Facility                                                                           | Treatment                                                                                                  |
| PM-12                                                                                                      | Counseling regarding ICD placement for patients with HFrEF on GDMT                                                    | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Treatment                                                                                                  |
| PM-13                                                                                                      | CRT implantation for patients with HFrEF on GDMT                                                                      | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Treatment                                                                                                  |
| QM-1                                                                                                       | Patient self-care education                                                                                           | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Self-care                                                                                                  |
| QM-2                                                                                                       | Measurement of patient-reported outcome-health status                                                                 | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Monitoring                                                                                                 |
| QM-3                                                                                                       | Sustained or improved health status in HF                                                                             | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Outcome                                                                                                    |
| QM-4                                                                                                       | Post-discharge appointment for patients with HF                                                                       | Inpatient                                                                                                  | Individual practitioner, facility                                                                          | Treatment                                                                                                  |
| SM-1                                                                                                       | HF registry participation                                                                                             | Outpatient Inpatient                                                                                       | Facility                                                                                                   | Structure                                                                                                  |
| Rehabilitation PMs Related to HF (From the 2018 ACC/AHA performance measures for cardiac rehabilitation 10 | Rehabilitation PMs Related to HF (From the 2018 ACC/AHA performance measures for cardiac rehabilitation 10            | Rehabilitation PMs Related to HF (From the 2018 ACC/AHA performance measures for cardiac rehabilitation 10 | Rehabilitation PMs Related to HF (From the 2018 ACC/AHA performance measures for cardiac rehabilitation 10 | Rehabilitation PMs Related to HF (From the 2018 ACC/AHA performance measures for cardiac rehabilitation 10 |
| Rehab PM-2                                                                                                 | Exercise training referral for HF from inpatient setting                                                              | Inpatient                                                                                                  | Facility                                                                                                   | Process                                                                                                    |
| Rehab PM-4                                                                                                 | Exercise training referral for HF from outpatient setting                                                             | Outpatient                                                                                                 | Individual practitioner Facility                                                                           | Process                                                                                                    |

ACEi indicates angiotensin-converting enzyme inhibitor; ACC, American College of Cardiology; AHA, American Heart Association; ARB, angiotensin receptor blocker; ARNi, angiotensin receptor-neprilysin inhibitor; CRT, cardiac resynchronization therapy; GDMT, guideline-directed medical therapy; HF, heart failure; HFrEF, heart failure with reduced ejection fraction; ICD, implantable cardioverter-defibrillator; LVEF, left ventricular ejection fraction; MRA, mineralocorticoid receptor antagonist; PM, performance measure; QM, quality measure; and SM, structural measure.

| Recommendations for Palliative and Supportive Care, Shared Decision- Making, and End-of-Life (Continued)   | Recommendations for Palliative and Supportive Care, Shared Decision- Making, and End-of-Life (Continued)   | Recommendations for Palliative and Supportive Care, Shared Decision- Making, and End-of-Life (Continued)                                                                                            |
|------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                                                                                        | LOE                                                                                                        | Recommendations                                                                                                                                                                                     |
| 2a                                                                                                         | C-LD                                                                                                       | 4. For patients with HF, execution of advance care directives can be useful to improve docu- mentation of treatment preferences, delivery of patient-centered care, and dying in preferred place. 7 |
| 2a                                                                                                         | C-LD                                                                                                       | 5. In patients with advanced HF with expected survival <6 months, timely referral to hospice can be useful to improve QOL. 8                                                                        |

## Synopsis

Palliative  care-defined  as  patient-  and  family-centered  care  that  optimizes  health-related  QOL  by  anticipating,  preventing,  and  treating  suffering-should be  integrated  into  the  care  of  all  patients  with  HF. 9 Palliative  care  includes  high-quality  communication, estimation  of  prognosis,  anticipatory  guidance,  addressing  uncertainty;  shared  decision-making  about medically reasonable treatment options; advance care planning; attention to physical, emotional, spiritual, and

Figure 15. A Depiction of the Clinical Course of HF With Associated Types and Intensities of Available Therapies Over Time. 12 CHF indicates congestive heart failure; HF, heart failure; and MCS, mechanical circulatory support. Adapted with permission of the American Thoracic Society. Copyright © 2021 American Thoracic Society. All rights reserved. The American Journal of Respiratory and Critical Care Medicine is an official journal of the American Thoracic Society. 13  Readers are encouraged to read the entire article for the correct context at https://www.atsjournals.org/doi/abs/10.1164/rccm.200605-587ST. The authors, editors, and The American Thoracic Society are not responsible for errors or omissions in adaptations. Adapted with permission from the World Health Organization. 14  Copyright 1990 World Health Organization.

<!-- image -->

psychological  distress;  relief  of  suffering;  and  inclusion of family caregivers in patient care and attention to  their  needs  during  bereavement. 10 Other  supportive needs include home and case management assistance,  transportation,  and  care  coordination. 11 Palliative and supportive care has a role across the stages of HF, starting early in the course of illness, intensifying in end-stage disease, and extending into caregiver bereavement (Figure 15). 12  Many palliative care needs can and should be addressed by the patient's interdisciplinary care team (primary palliative care), including clarifying their core values, health outcome goals, and therapeutic preferences. 1  Specialty palliative care clinicians  (secondary  palliative  care)  may  be  consulted to  collaboratively  care  for  patients  and  their  families with more challenging needs. 7  Barriers to the receipt of palliative care include reluctance of health care professionals to address death and dying and a propensity for patients and caregivers to equate palliation and hospice as hastening death. 15

## Recommendation-Specific Supportive Text

1. Palliative and supportive approaches to the care of patients with HF is inherent to their overall care and should be incorporated throughout the course of illness by all health care professionals. 9 The application of the principles embraced have been shown to  improve  various  processes  of  care  and  patient outcomes (Table 32). Palliative and supportive care discussions do not imply that a formal palliative care consultation  is  needed  for  each  patient  but  that team members should integrate palliative and supportive considerations into routine care.
2. As overall illness progresses, major decisions are increasingly  made  regarding  the  initiation,  continued use, and discontinuation of potentially life-sustaining therapies, including intravenous inotropes, ICDs, MCS, and renal replacement therapy. Dependence  on,  and  deactivation  of,  potentially life-sustaining therapies should be anticipated and

Table 32. Palliative and Supportive Care Domains to Improve Processes of Care and Patient Outcomes

| Palliative and Supportive Domains of Care   | What Palliative Care Adds to Overall HF Management                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
|---------------------------------------------| |
| High-quality communication                  | Central to palliative care approaches are communication and patient-caregiver engagement techniques. 16                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| Conveyance of prognosis                     | Palliative care specifically addresses patient and caregiver understanding of disease, treatment, and prognosis. Research suggests that patients tend to overestimate their survival 17 and overestimate the potential benefits of treatment. 18 Objective risk models can calibrate expectations, but discussion of uncertainty should accompany prognostic conversations, often sum- marized as 'hope for the best, plan for the worst. '                                                                                                                                                                                    |
| Clarifying goals of care                    | Management of patients with HF as their disease becomes end-stage and death seems near includes decisions about when to discontinue treatments designed primarily to prolong life (eg, ICD, hospitalization, tube feeding), decisions on when to initiate treatments to reduce pain and suffering that may hasten death (eg, narcotics), and decisions about the location of death, home services, and hospice care. Exploring patients' expressed preferences, values, needs, concerns, means and desires through clinician-led discussion can clarify values-treatment concordance and improve medical deci- sion-making. 12 |
| Shared decision-making                      | Shared decision-making is a process by which patients and clinicians work together to make optimal health care decisions from medically reasonable options that align with what matters most to patients. Shared decision-making re- quires: unbiased medical evidence about the risks, benefits, and burdens of each alternative, including no intervention; clinician expertise in communication and tailoring that evidence for individual patients; and patient goals and informed preferences. 12                                                                                                                         |
| Symptom management                          | Dyspnea, fatigue, pain, nausea, depression, anxiety, and other symptoms of HF refractory to cardiovascular therapies can be partially remediated through palliative and supportive approaches in addition to GDMT. 5                                                                                                                                                                                                                                                                                                                                                                                                           |
| Caregiver support                           | Care of the patient with heart failure should extend to their loved ones, including beyond their death, to offer support to fami- lies and help them cope with loss.                                                                                                                                                                                                                                                                                                                                                                                                                                                           |

GDMT indicates guideline-directed medical therapy; HF, heart failure; and ICD, implantable cardioverter-defibrillator.

discussed at the time of initiation and reconsidered serially with changing medical realities and evolving goals of care. 12 Patients have a right to decline or withdraw care at any time, consistent with the principle of respect for autonomy. 19 Failure to proactively address topics such as deactivation of ICD and LVAD therapies can lead to suffering  at  the end of life. 2,3

3. Although a range of clinicians caring for patients with HF are able to manage many palliative care needs,  formal palliative  care  consultation  may be  particularly  helpful  for  patients  with  these:  1) refractory  symptoms;  2)  major  medical  decisions (eg,  in  the  United  States,  inclusion  of  a  palliative care specialist on the team is mandatory for payment from Medicare for L VAD implantation); and 3) multimorbidity, frailty, or cognitive impairment (multiple  validated  frailty  and  cognitive  measures  are available).  A  growing  body  of  evidence  supports the  inclusion  of  specialty  palliative  care  into  the management of patients diagnosed with a range of advanced diseases, 20 including HF. An interdisciplinary palliative care intervention in patients with advanced  HF  showed  greater  benefits  in  QOL, anxiety,  depression,  and  spiritual  well-being  compared  with  usual  care  alone  (PAL-HF  [Palliative Care in Heart Failure]). 4 However, other trials have been  mixed, 5,6 and  many  negative, 21-23 such  that formal  palliative  care  interventions  should  be  tailored to patient and caregiver wants and needs.
4. Advance  care  planning  is  a  process  that  supports understanding and sharing of patients' personal values, life goals, and preferences regarding future medical care. Key domains include discussing patients' values, documenting plans for medical  treatments,  designating  a  surrogate  decision maker,  and  revisiting  this  process  over  time. 24 Familiarity with local and state laws is needed relating to advance care planning, decisions regarding life-sustaining treatments, and evolving treatments with legal ramifications, especially when caring for vulnerable  populations. 19 Few  patients  with  HF have formally defined their care goals and designated a surrogate decision maker. 25
5. Hospice is a specific model of subspecialty palliative care that is offered to patients with a terminal disease who are at the end of life when curative or  life-prolonging  therapy  is  no  longer  the  focus of treatment. 10 Historically,  hospice use has been low  among  patients  dying  with  HF  and,  among those engaging in hospice, the duration of time in hospice  was  short,  suggesting  late  referral.  Low hospice  referral  rates  and  high-intensity  care  at end of life often reflects health care professional biases and limitations in models of care rather than patient  values. 26 This  appears  to  be  changing  in the United States, where CDC data from 2003 to 2017 on US site of death show that the proportion of  cardiovascular  deaths  related  to  HF  occurring in  hospice facilities rose from 0.2% to 8.2% and deaths at home rose from 20.6% to 30.7%. 27

## Table 33. Evidence Gaps and Future Research Directions

Definition

Consensus on specific classifications of HFrEF, HFpEF, HFmrEF, and HFimpEF or whether a 2-category definition of HFrEF and HF with normal EF, or an additional category of HFimpEF is needed separately for HFpEF; and whether these approaches can be uniformly applied to clinical trials and practice.

Definitions, detection, and management of myocarditis and myocardial injury, especially in the context of rapidly evolving concepts, such as COVID-19 infection and cardiotoxicity.

Definition and classification of cardiomyopathies.

Screening

Cost-effectiveness of different strategies to screen for HF.

Prediction of higher risk for HF among patients with traditional risk factors (eg, which patients with diabetes would be at a higher risk HF, warranting preventive treatment for HF).

Diagnostics and monitoring

Individualized treatment targeting specific causes.

Advanced role of precision medicine with incorporation of genetic, personalized, and individualized factors in medical management of HF.

High-value methods to use biomarkers in the optimization of medical therapy.

Ability to use integrated systems biology models, including biomarkers, molecular markers, omics, diagnostic modalities, and genetic variables for diagnosis, prognosis, and targeting therapies.

Ability to monitor and adjust therapy to individual changes over time.

Nonmedical strategies

Efficacy and safety of specific dietary interventions, sodium restriction, and fluid restriction to prevent and treat HF.

Efficacy and safety of cardiac rehabilitation in patients with HFpEF and HFmrEF.

Medical therapies

Effective management strategies for patients with HFpEF.

Evidence for specific treatment strategies for HFmrEF.

Research on causes and targeted therapies for cardiomyopathies such as peripartum cardiomyopathy.

Treatment of asymptomatic LV dysfunction to prevent transition to symptomatic HF.

Therapies targeting different phenotypes of HF; patients with advanced HF, persistent congestion, patients with profiles excluded from clinical trials such as those with advanced kidney failure or hypotension.

Studies on targets for optimal decongestion; treatment and prevention of cardiorenal syndrome and diuretic resistance.

Diagnostic and management strategies of RV failure.

Efficacy and safety of hydralazine isosorbide in non-African American patients with HF and also in African American patients on GDMT including SGLT2i and ARNi.

Efficacy and safety of vericiguat in patients with HFrEF and markedly elevated natriuretic peptide levels.

Efficacy and safety of omecamtiv mecarbil in patients with stage D (advanced HF) HFrEF.

Additional efficacy and safety of SGLT2i therapies in patients with HFpEF or patients with HFmrEF, efficacy and safety of combined SGLT2i and SGLT1i in HFrEF, HFmrEF, or HFpEF.

Additional efficacy and safety of SGLT2i studies in hospitalized patients with acute decompensated HF with and without diabetes.

Efficacy and safety of nonsteroidal, selective MRA in patients with HF.

Efficacy and safety of ARNi in pre-HF stage (stage B).

Effective management strategies for combined post- and precapillary pulmonary hypertension.

Novel treatments for ATTR cardiomyopathy.

Treatment strategies targeting downstream processes such as fibrosis, cardiac metabolism or contractile performance in dilated cardiomyopathies and HFpEF.

Comparative effectiveness and safety of different initiation and titration of GDMT at the same time or in different sequences, optimal strategies for sequencing and titration of therapies for HFrEF and HFpEF.

Studies on prediction of patient response; studies on how to incorporate patient preferences.

Efficacy and safety of optimal BP target in patients with established HF and hypertension.

Optimal BP target while optimizing GDMT in patients with HFrEF and HFpEF.

Appropriate management of electrolyte abnormalities in HF (eg, hyperkalemia or hypokalemia).

Role of potassium binders in optimization of GDMT and clinical outcomes in patients with HF.

Efficacy and safety of pirfenidone and other targeted treatment strategies for maladaptive fibrosis in patients with HFpEF.

AF risk in patients treated with PUFA for patients at risk for HF or with HF.

( Continued )

## Table 33. Continued

Device management and advanced therapies

Optimal and timely selection of candidates for percutaneous interventions, MCS, or cardiac transplantation.

Interventional approaches to recurrent, life-threatening ventricular tachyarrhythmias.

Comparative effectiveness of His-bundle pacing or multisite pacing to prevent progression of HF.

Safety and efficacy of cardiac contractility modulation, vagal nerve stimulation, autonomic modulation, and renal denervation in patients with HF.

Safety and efficacy of splanchnic nerve ablation splanchnic nerve ablation to reduce splanchnic vasoconstriction and volume redistribution in HF.

Safety and efficacy of interatrial shunt, pericardiectomy, baroreceptor and neuromodulation, and renal denervation in HFpEF.

Safety and efficacy of percutaneous or surgical interventions for tricuspid regurgitation.

Clinical outcomes

Impact of therapies in patient-reported outcomes, including symptoms and QOL.

Studies addressing patient goals about care and care intensity as it intersects with disease trajectory.

Real-world evidence data to characterize generalization of therapies in HF populations who may not have been represented in trials.

Systems of care and social determinants of health

Implementation studies on how to develop a structured approach to patient participation in informed decision-making and goal setting through the continuum of HF care.

Implementation science for adoption and optimization of GDMT by clinicians on how to initiate multiple or sequenced GDMT, how to integrate these into learning health systems and networks, and how to increase patient education and adherence.

Pragmatic studies on multidisciplinary new care models (eg, cardiac teams for structural and valve management, shock teams, cardiometabolic clinics, telemedicine, digital health, cardiac rehabilitation at home or postdischarge, and palliative care).

Studies on strategies to eliminate structural racism, disparities, and health inequities in HF care.

Studies addressing evidence gaps in women, racial, and ethnic populations.

Management strategies for palliative care.

Identification of factors that lead to unwarranted variations in HF care.

Identify characteristics of systems of care (eg, disciplines and staffing, electronic health records, and models of care) that optimize GDMT before and after the discharge of hospitalized patients.

## Comorbidities

Further studies on rhythm control versus ablation in AF.

Appropriate patient selection in evolving percutaneous approaches in VHD (eg, timing and appropriate patient selection for TAVI, Mitraclip, tricuspid valve interventions).

Effective and safe treatment options in CKD, sleep-disordered breathing, chronic lung disease, diabetes, depression, cognitive disorders, and iron deficiency.

Efficacy and safety of transvenous stimulation of the phrenic nerve or role of nocturnal supplemental oxygen for treatment of central sleep apnea in patients with HF.

Efficacy and safety of weight loss management and treatment strategies in patients with HF and obesity.

Efficacy and safety of nutritional and food supplementation in patients with HF and frailty and malnutrition.

Efficacy and safety of GDMT in end-stage renal disease or in patients with eGFR &lt;30 mL/min/1.73 m 2 .

Future/novel strategies

Pharmacological therapies targeting novel pathways and endophenotypes.

New device therapies, including percutaneous and durable mechanical support devices.

Invasive (eg, pulmonary artery pressure monitoring catheter) or noninvasive remote monitoring.

Studies on telehealth, digital health, apps, wearables technology, and artificial intelligence.

Role of enrichment trials, adaptive trials, umbrella trials, basket trials, and machine learning-based trials.

Therapies targeting multiple cardiovascular, cardiometabolic, renovascular, and pathobiological mechanisms.

Novel dissemination and implementation techniques to identify patients with HF (eg, natural language processing of electronic health records and automated analysis of cardiac imaging data) and to test and monitor proven interventions.

AF indicates atrial fibrillation; ARNi, angiotensin receptor-neprilysin inhibitor; ATTR, transthyretin amyloidosis; BP, blood pressure; CKD, chronic kidney disease; COVID-19, coronavirus disease 2019; eGFR, estimated glomerular filtration rate; GDMT, guideline-directed medical therapy; HF, heart failure; HFimpEF, heart failure with improved ejection fraction; HFmrEF, heart failure with mildly reduced ejection fraction; HFpEF, heart failure with preserved ejection fraction; HFrEF, heart failure with reduced ejection fraction; LV, left ventricular; MCS, mechanical circulatory support; MRA, mineralocorticoid receptor antagonist; PUFA, polyunsaturated fatty acid; QOL, quality of life; RV, right ventricular; SGLT1i, sodium-glucose cotransporter-1 inhibitors; SGLT2i, sodium-glucose cotransporter-2 inhibitors; TAVI, transcatheter aortic valve implantation; and VHD, valvular heart disease.

## 14. RECOMMENDATION FOR PATIENTREPORTED OUTCOMES AND EVIDENCE GAPS AND FUTURE RESEARCH DIRECTIONS

## 14.1. Patient-Reported Outcomes

| Recommendation for Patient-Reported Outcomes   | Recommendation for Patient-Reported Outcomes   | Recommendation for Patient-Reported Outcomes                                                                                                                                                                                            |
|------------------------------------------------|------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| COR                                            | LOE                                            | Recommendation                                                                                                                                                                                                                          |
| 2a                                             | C-LD                                           | 1. In patients with HF, standardized assessment of patient-reported health status using a vali- dated questionnaire can be useful to provide incremental information for patient functional status, symptom burden, and prognosis. 1-19 |

## Synopsis

Health status encapsulates symptoms, functional status, and health-related  QOL.  Understanding  health  status  is important  for  treatment  decisions  and  counseling.  Clinicians  traditionally  evaluate  health  status  based  on  the clinical interview and exam, summarizing it as the NYHA functional classification. Additionally, patient-reported health  status  can  be  ascertained  using  standardized questionnaires, such as the Kansas City Cardiomyopathy Questionnaire  or  the  Minnesota  Living  with  Heart  Failure  Questionnaire.  Previous  studies  found  discordance between patient-reported health status and clinician assessment using NYHA classification. 20,21 Patient-reported health status may have higher reliability and better sensitivity for clinical changes than NYHA classification and is moderately correlated with CPET and the 6-minute walk test. 1-8 Patient-reported health status is an independent predictor  of  hospitalization  and  mortality. 9-19 There  are minimal data regarding the effect of incorporating patientreported health status assessment into routine care. However,  these  assessments  provide  valuable  incremental information  beyond  the  standard  evaluation.  Increasing the  patient's  voice  in  clinical  assessment  and  decisionmaking is important in its own right. Additionally, there is substantial variation in risk-adjusted health status across practices. 22  Future efforts should focus on expanding the use of patient-reported health status in routine care while researching its implementation and impact.

## Recommendation-Specific Supportive Text

1.  Standardized patient-reported health status questionnaires  provide  reliable  measures  of  health status correlated to other functional status measures 1-8 and independently associated with clinical  outcomes. 9-19 HF-specific  health  status assessments  (eg,  Kansas  City  Cardiomyopathy Questionnaire, Minnesota Living with Heart Failure Questionnaire, PROMIS-Plus-HF [PatientReported Outcomes  Measurement  Information System-Plus-Heart Failure]) are preferable because  they  are  more  sensitive  to  changes  in

disease status and more responsive to HF therapy than  generic  health  status  measures. 1   Although select clinics have successfully implemented patient-reported health status in clinical practice, 23 there are minimal data regarding the impact of such efforts. However, there are potential advantages to routine assessment. First, better understanding of symptom burden and prognosis may improve the quality  of  treatment  decisions  and,  subsequently, QOL.  Health  status  can  be  improved  via  guideline-recommended  therapies. 24-31   Although  some therapies are recommended for mortality benefit, symptom assessment can identify patients needing  additional  interventions  (eg,  diuretic  escalation).  Second,  routine  assessment  can  facilitate population health management by identifying highrisk  patients  needing  closer  monitoring  or  referral  to  specialized  centers.  Third,  patient-reported health status assessment increases the patient's role,  which  can  motivate  initiation  and  uptitration of medical therapy. However, routine assessment of  patient-reported  status  increases  the  burden of data collection for patients and health systems and underscores the need for future studies evaluating the impact of assessment.

## 14.2. Evidence Gaps and Future Research Directions

Significant  gaps  exist  despite  evolving  evidence  and treatment strategies in patients with HF. Table 33 provides selected, common issues that should be addressed in future clinical research.

## ACC/AHA JOINT COMMITTEE MEMBERS

Joshua A. Beckman, MD, MS, FAHA, FACC, Chair; Patrick T. O'Gara, MD, MACC, FAHA, Immediate Past Chair*; Sana M. Al-Khatib, MD, MHS, FACC, FAHA*; Anastasia L. Armbruster, PharmD, FACC; Kim K. Birtcher, PharmD, MS, AACC*; Joaquin E. Cigarroa, MD, FACC*; Lisa de las Fuentes, MD, MS, FAHA; Anita Deswal, MD, MPH, FACC, FAHA; Dave L. Dixon, PharmD, FACC*; Lee A. Fleisher, MD, FACC, FAHA*; Federico Gentile, MD, FACC*; Zachary D. Goldberger, MD, FACC, FAHA*; Bulent Gorenek, MD, FACC; Norrisa Haynes, MD, MPH; Adrian F. Hernandez, MD, MHS; Mark A. Hlatky, MD, FACC, FAHA*; José A. Joglar, MD, FACC, FAHA; W. Schuyler Jones, MD, FACC; Joseph E. Marine, MD, FACC*; Daniel B. Mark, MD, MPH, FACC, FAHA; Debabrata Mukherjee, MD, FACC, FAHA; Latha P. Palaniappan, MD, MS, FACC, FAHA; Mariann R. Piano, RN, PhD, FAHA; Tanveer Rab, MD, FACC; Erica S. Spatz, MD, MS, FACC; Jacqueline E. Tamis-Holland, MD, FAHA, FACC; Duminda N. Wijeysundera, MD, PhD*; Y. Joseph Woo, MD, FACC, FAHA

*Former Task Force member; current member during the writing effort.

## PRESIDENTS AND STAFF

## American College of Cardiology

Dipti N. Itchhaporia, MD, FACC, President

Cathleen C. Gates, Chief Executive Officer

- MaryAnne Elma, MPH, Senior Director, Enterprise Content and Digital Strategy

Grace D. Ronan, Team Leader, Clinical Policy Publications Timothy  W.  Schutt,  MA,  Clinical  Practice  Guidelines Analyst

## American College of Cardiology/American Heart Association

- Thomas S.D. Getchius, Director, Guideline Strategy and Operations
- Abdul R. Abdullah, MD, Director, Guideline Science and Methodology

## American Heart Association

Donald M. Lloyd-Jones, MD, ScM, FAHA, President Nancy Brown, Chief Executive Officer

- Mariell  Jessup,  MD,  FAHA, Chief Science and Medical Officer
- Radhika  Rajgopal  Singh,  PhD,  Senior  Vice  President, Office of Science and Medicine
- Paul St. Laurent, DNP, RN, Senior Science and Medicine Advisor, Office of Science, Medicine and Health
- Jody  Hundley,  Production  and  Operations  Manager, Scientific Publications, Office of Science Operations

## ARTICLE INFORMATION

This  document  was  approved  by  the  American  College  of  Cardiology  Clinical Policy  Approval  Committee,  the  American  Heart  Association  Science  Advisory and Coordinating Committee, the American College of Cardiology Science and Quality Committee, and the Heart Failure Society of America Executive Committee in December 2021 and the American Heart Association Executive Committee in January 2022.

Supplemental materials are available with this article at https://www.ahajournals. org/doi/suppl/10.1161/CIR.0000000000001063

This article has been copublished in the Journal of the American College of Cardiology and the Journal of Cardiac Failure .

Copies: This document is available on the websites of the American Heart Association (professional.heart.org), the American College of Cardiology (www. acc.org), and the Heart Failure Society of America (www.hfsa.org). A copy of the document is  also  available  at  https://professional.heart.org/statements  by  selecting the 'Guidelines &amp; Statements' button. To purchase additional reprints, call 215-356-2721 or email Meredith.Edelman@wolterskluwer.com.

The  expert  peer  review  of  AHA-commissioned  documents  (eg,  scientific statements, clinical practice guidelines, systematic reviews) is conducted by the AHA Office of Science Operations. For more on AHA statements and guidelines development, visit https://professional.heart.org/statements. Select the 'Guidelines &amp; Statements' drop-down menu near the top of the webpage, then click 'Publication Development.'

Permissions: Multiple copies, modification, alteration, enhancement, and/or distribution of this document are not permitted without the express permission of the American Heart Association. Instructions for obtaining permission are located at https://www.heart.org/permissions. A link to the 'Copyright Permissions Request Form' appears in the second paragraph (https://www.heart.org/en/aboutus/statements-and-policies/copyright-request-form).

## REFERENCES PREAMBLE

1. Committee  on  Standards  for  Developing  Trustworthy  Clinical  Practice Guidelines, Institute of Medicine (US). Clinical Practice Guidelines We Can Trust . National Academies Press; 2011.
2.  Committee on Standards for Systematic Reviews of Comparative Effectiveness Research, Institute of Medicine (US). Finding What Works in Health Care: Standards for Systematic Reviews . National Academies Press; 2011.
3.  Anderson JL, Heidenreich PA, Barnett PG, et al. ACC/AHA statement on cost/value  methodology  in  clinical  practice  guidelines  and  performance measures: a report of the American College of Cardiology/American Heart Association Task Force on Performance Measures and Task Force on Practice Guidelines. Circulation . 2014;129:2329-2345.
4.  ACCF/AHA Task Force on Practice Guidelines. Methodology Manual and Policies From the ACCF/AHA Task Force on Practice Guidelines. American College of Cardiology and American Heart Association; 2010. Accessed June 3, 2020. https://www.acc.org/Guidelines/About-Guidelines-andClinical-Documents/Methodology and https://professional.heart.org/-/ media/phd-files/guidelines-and-statements/methodology\_manual\_and\_ policies\_ucm\_319826.pdf
5.  Halperin JL, Levine GN, Al-Khatib SM, et al. Further evolution of the ACC/ AHA clinical practice guideline recommendation classification system: a report  of  the  American  College  of  Cardiology/American  Heart  Association Task  Force  on  Clinical  Practice  Guidelines. Circulation .  2016;133:14261428.
6.  Arnett DK, Goodman RA, Halperin JL, et al. AHA/ACC/HHS strategies to enhance application of clinical practice guidelines in patients with cardiovascular  disease  and  comorbid  conditions:  from  the  American  Heart  Association, American College of Cardiology, and U.S. Department of Health and Human Services. Circulation . 2014;130:1662-1667.
7. Levine GN, O'Gara PT, Beckman JA, et al. Recent innovations, modifications, and evolution of ACC/AHA clinical practice guidelines: an update for our constituencies: a report of the American College of Cardiology/American Heart  Association  Task  Force  on  Clinical  Practice  Guidelines. Circulation . 2019;139:e879-e886.

## 1.4. Scope of the Guideline

1.  Yancy CW, Jessup M, Bozkurt B, et al. 2013 ACCF/AHA guideline for the management of heart failure: a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Circulation . 2013;128:e240-e327.
2.  Yancy CW, Jessup M, Bozkurt B, et al.  2017 ACC/AHA/HFSA focused update of the 2013 ACCF/AHA guideline for the management of heart failure: a report of the American College of Cardiology/American Heart Association Task Force on Clinical Practice Guidelines and the Heart Failure Society of America. Circulation . 2017;136:e137-e161.
3.  Arnett DK, Blumenthal RS, Albert MA, et al. 2019 ACC/AHA guideline on the primary prevention of cardiovascular disease: a report of the American College of Cardiology/American Heart Association Task Force on Clinical Practice Guidelines. Circulation . 2019;140:e596-e646.
4.  Otto CM, Nishimura RA, Bonow RO, et al. 2020 ACC/AHA guideline for the management of patients with valvular heart disease: a report of the American College of Cardiology/American Heart Association Joint Committee on Clinical Practice Guidelines. Circulation . 2021;143:e72-e227.
5.  Lawton JS, Tamis-Holland JE, Bangalore S, et al. 2021 ACC/AHA/SCAI guideline for coronary artery revascularization: a report of the American College of Cardiology/American Heart Association Joint Committee on Clinical Practice Guidelines. Circulation . 2022;145:e18-e114.
6. Hillis  LD,  Smith  PK,  Anderson  JL,  et  al.  2011  ACCF/AHA  guideline  for coronary artery bypass graft surgery. a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Developed in collaboration with the American Association for Thoracic Surgery, Society of Cardiovascular Anesthesiologists, and Society of Thoracic Surgeons. Circulation . 2011;124:e652-e735.
7.  Levine  GN,  Bates  ER,  Blankenship  JC,  et  al.  2011  ACCF/AHA/SCAI guideline for percutaneous coronary intervention. a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines and the Society for Cardiovascular Angiography and Interventions. Circulation . 2011;124:e574-e651.
8.  Levine GN, Bates ER, Blankenship JC, et al. 2015 ACC/AHA/SCAI focused update on primary percutaneous coronary intervention for patients

- with  ST-elevation  myocardial  infarction:  an  update  of  the  2011  ACCF/ AHA/SCAI guideline for percutaneous coronary intervention and the 2013 ACCF/AHA guideline for the Management of ST-elevation myocardial infarction. Circulation . 2016;133:1135-1147.
9.  Ommen SR, Mital S, Burke MA, et al. 2020 AHA/ACC guideline for the diagnosis and treatment of patients with hypertrophic cardiomyopathy: a report of the American College of Cardiology/American Heart Association Joint Committee  on  Clinical  Practice  Guidelines. Circulation .  2020;142:e558e631.
10.  January CT, Wann LS, Calkins H, et al. 2019 AHA/ACC/HRS focused update of the 2014 AHA/ACC/HRS guideline for the management of patients with atrial fibrillation: a report of the American College of Cardiology/ American Heart Association Task Force on Clinical Practice Guidelines and the Heart Rhythm Society. Circulation . 2019;140:e125-e151.
11.  Whelton PK, Carey RM, Aronow WS, et al. 2017 ACC/AHA/AAPA/ABC/ ACPM/AGS/APhA/ASH/ASPC/NMA/PCNA guideline for the prevention, detection, evaluation, and management of high blood pressure in adults: a report of the American College of Cardiology/American Heart Association Task  Force  on  Clinical  Practice  Guidelines. Hypertension .  2018;71:e13e115.
12.  Yancy CW, Jessup M, Bozkurt B, et al.  2016 ACC/AHA/HFSA focused update on new pharmacological therapy for heart failure: an update of the 2013 ACCF/AHA guideline for the management of heart failure: a report of the American College of Cardiology/American Heart Association Task Force on Clinical Practice Guidelines and the Heart Failure Society of America. Circulation . 2016;134:e282-e293.
13.  Fihn  SD,  Blankenship  JC,  Alexander  KP,  et  al.  2014  ACC/AHA/AATS/ PCNA/SCAI/STS focused update of the guideline for the diagnosis and management of patients with stable ischemic heart disease: a report of the American College of Cardiology/American Heart Association Task Force on Practice Guidelines, and the American Association for Thoracic Surgery, Preventive Cardiovascular Nurses Association, Society for Cardiovascular Angiography and Interventions, and Society of Thoracic Surgeons. Circulation . 2014;130:1749-1767.
14. Eckel  RH,  Jakicic  JM,  Ard  JD,  et  al.  2013  AHA/ACC  guideline  on  lifestyle management to reduce cardiovascular risk: a report of the American College of Cardiology/American Heart Association Task Force on Practice Guidelines. Circulation . 2014;129(suppl 2):S76-S99.
15.  Jensen MD, Ryan DH, Apovian CM, et al. 2013 AHA/ACC/TOS guideline for  the  management of overweight and obesity in adults: a report of the American College of Cardiology/American Heart Association Task Force on Practice Guidelines and The Obesity Society. Circulation .  2014;129(suppl 2):s102-s138.
16.  Grundy SM, Stone NJ, Bailey AL, et al. 2018 AHA/ACC/AACVPR/AAPA/ ABC/ACPM/ADA/AGS/APhA/ASPC/NLA/PCNA guideline on the management of blood cholesterol: a report of the American College of Cardiology/American Heart Association Task Force on Clinical Practice Guidelines. Circulation . 2019;139:e1082-e1143.
- 17 .  Stone NJ, Robinson JG, Lichtenstein  AH,  et  al.  2013  ACC/AHA  guideline  on  the  treatment  of  blood  cholesterol  to  reduce  atherosclerotic  cardiovascular risk in adults: a report of the American College of Cardiology/ American Heart Association Task Force on Practice Guidelines. Circulation . 2014;129(suppl 2):S1-S45.
18.  Goff DC Jr, Lloyd-Jones DM, Bennett G, et al. 2013 ACC/AHA guideline on the assessment of cardiovascular risk: a report of the American College of Cardiology/American Heart Association Task Force on Practice Guidelines. Circulation . 2014;129(suppl 2):S49-S73.
19.  O'Gara PT, Kushner FG, Ascheim DD, et al. 2013 ACCF/AHA guideline for the management of ST-elevation myocardial infarction: a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Circulation .2013;127:e362-e425.
20. Tracy  CM,  Epstein  AE,  Darbar  D,  et  al.  2012  ACCF/AHA/HRS  focused update of the 2008 guidelines for device-based therapy of cardiac rhythm abnormalities: a report of the American College of Cardiology Foundation/ American Heart Association Task Force on Practice Guidelines. Circulation . 2012;126:1784-1800.
21.  Fihn  SD,  Gardin  JM,  Abrams  J,  et  al.  2012  ACCF/AHA/ACP/AATS/ PCNA/SCAI/STS guideline for the diagnosis and management of patients with  stable  ischemic  heart  disease:  a  report  of  the  American  College  of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines, and the American College of Physicians, American Association for Thoracic Surgery, Preventive Cardiovascular Nurses Association, Society for Cardiovascular Angiography and Interventions, and Society of Thoracic Surgeons. Circulation . 2012;126:e354-e471.
23.  Smith SC Jr, Benjamin EJ, Bonow RO, et al. AHA/ACCF secondary prevention  and  risk  reduction  therapy  for  patients  with  coronary  and  other  atherosclerotic vascular disease: 2011 update: a guideline from the American Heart Association and American College of Cardiology Foundation. Circulation . 2011;124:2458-2473.
24.  Greenland P, Alpert JS, Beller GA, et al. 2010 ACCF/AHA guideline for assessment of cardiovascular risk in asymptomatic adults: a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Circulation . 2010;122:e584e636.
25. Peberdy  MA,  Callaway  CW,  Neumar  RW,  et  al.  Part  9:  post-cardiac  arrest  care:  2010  American  Heart  Association  guidelines  for  cardiopulmonary  resuscitation  and  emergency  cardiovascular  care. Circulation. 2010;122:S768-S786.
26.  Chobanian AV, Bakris GL, Black HR, et al. Seventh Report of the Joint National Committee on prevention, detection, evaluation, and treatment of high blood pressure. Hypertension. 2003;42:1206-1252.
- 27 .  Kittleson MM, Maurer MS, Ambardekar AV, et al. Cardiac amyloidosis: evolving diagnosis and management: a scientific statement from the American Heart Association. Circulation. 2020;142:e7-e22.
28.  Amsterdam  EA,  Kirk  JD,  Bluemke  DA,  et  al.  Testing  of  low-risk  patients  presenting  to  the  emergency  department  with  chest  pain:  a scientific  statement  from  the  American  Heart  Association. Circulation. 2010;122:1756-1776.
29.  Buse JB, Ginsberg HN, Bakris GL, et al. Primary prevention of cardiovascular diseases in people with diabetes mellitus: a scientific statement from the American Heart Association and the American Diabetes Association. Circulation. 2007;115:114-126.
30. Centers  for  Disease  Control  and  Prevention.  Prevention  and  control  of influenza:  recommendations  of  the  Advisory  Committee  on  Immunization Practices (ACIP). Accessed March 24, 2021. https://www.cdc.gov/mmwr/ preview/mmwrhtml/rr5510a1.htm

## 1.5. Class of Recommendation and Level of Evidence

1.  ACCF/AHA Task Force on Practice Guidelines. Methodology Manual and Policies From the ACCF/AHA Task Force on Practice Guidelines . American College of Cardiology and American Heart Association; 2010. Accessed June 3, 2020. https://www.acc.org/Guidelines/About-Guidelines-andClinical-Documents/Methodology and https://professional.heart.org/-/ media/phd-files/guidelines-and-statements/methodology\_manual\_and\_ policies\_ucm\_319826.pdf

## 2.1. Stages of HF

1.  Yancy CW, Jessup M, Bozkurt B, et al. 2013 ACCF/AHA guideline for the management of heart failure: a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Circulation . 2013;128:e240-e327.
2.  Hunt SA, Abraham WT, Chin MH, et al. 2009 Focused update incorporated into  the  ACC/AHA  2005  guidelines  for  the  diagnosis  and  management of heart failure in adults: a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Developed in collaboration with the International Society for Heart and Lung Transplantation. Circulation . 2009;119:e391-e479.
3.  Ammar KA, Jacobsen SJ, Mahoney DW, et al. Prevalence and prognostic significance of heart failure stages: application of the American College of Cardiology/American Heart Association heart failure staging criteria in the community. Circulation. 2007;115:1563-1570.
4.  Goldman L, Hashimoto B, Cook EF, et al. Comparative reproducibility and validity of systems for assessing cardiovascular functional class: advantages of a new specific activity scale. Circulation. 1981;64:12271234.
5. Caraballo C, Desai NR, Mulder H, et al. Clinical implications of the New York Heart Association classification. J Am Heart Assoc. 2019;8:e014240.
6.  Madsen BK, Hansen JF, Stokholm KH, et al. Chronic congestive heart failure: description and survival of 190 consecutive patients with a diagnosis of chronic congestive heart failure based on clinical signs and symptoms. Eur Heart J. 1994;15:303-310.
7.  Ahmed  A,  Aronow  WS,  Fleg  JL.  Higher  New  York  Heart  Association  classes  and  increased  mortality  and  hospitalization  in  patients with heart failure and preserved left ventricular function. Am Heart J. 2006;151:444-450.

## 2.2. Classification of HF by Left Ventricular Ejection Fraction (LVEF)

1.  Yancy CW, Jessup M, Bozkurt B, et al. 2013 ACCF/AHA guideline for the management of heart failure: a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Circulation . 2013;128:e240-e327.
2.  Dunlay SM, Roger VL, Redfield MM. Epidemiology of heart failure with preserved ejection fraction. Nat Rev Cardiol. 2017;14:591-602.
3. Wilcox JE, Fang JC, Margulies KB, et al. Heart failure with recovered left ventricular ejection fraction: JACC Scientific Expert Panel. J Am Coll Cardiol. 2020;76:719-734.
4. Bozkurt B, Coats AJS, Tsutsui H, et al. Universal definition and classification of heart failure: a report of the Heart Failure Society of America, Heart Failure Association of the European Society of Cardiology, Japanese Heart Failure Society and Writing Committee of the Universal Definition of Heart Failure. J Card Fail. 2021;27:387-413.
5. Halliday BP, Wassall R, Lota AS, et al. Withdrawal of pharmacological treatment  for  heart  failure  in  patients  with  recovered  dilated  cardiomyopathy (TRED-HF): an open-label, pilot, randomised trial. Lancet .  2019;393:6173.

## 2.3. Diagnostic Algorithm for Classification of HF According to LVEF

1.  Ponikowski P, Voors AA, Anker SD, et al. 2016 ESC guidelines for the diagnosis and treatment of acute and chronic heart failure. Rev Esp Cardiol (Engl Ed). 2016;69:1167.
2. Erdei T, Smiseth OA, Marino P, et al. A systematic review of diastolic stress tests in heart failure with preserved ejection fraction, with proposals from the EU-FP7 MEDIA study group. Eur J Heart Fail. 2014;16:1345-1361.
3. Donal E, Lund LH, Oger E, et al. Value of exercise echocardiography in heart failure with preserved ejection fraction: a substudy from the KaRen study. Eur Heart J Cardiovasc Imaging. 2016;17:106-113.
4. Borlaug  BA,  Nishimura  RA,  Sorajja  P,  et  al.  Exercise  hemodynamics  enhance diagnosis of early heart failure with preserved ejection fraction. Circ Heart Fail. 2010;3:588-595.
5. Reddy YNV, Carter  RE,  Obokata  M,  et  al.  A  simple,  evidence-based  approach to help guide diagnosis of heart failure with preserved ejection fraction. Circulation. 2018;138:861-870.
6.  Sepehrvand N, Alemayehu W, Dyck GJB, et al. External validation of the H2F-PEF model in diagnosing patients  with  heart  failure  and  preserved ejection fraction. Circulation. 2019;139:2377-2379.
7. Selvaraj S, Myhre PL, Vaduganathan M, et al. Application of diagnostic algorithms for heart failure with preserved ejection fraction to the community. J Am Coll Cardiol HF. 2020;8:640-653.
8. Pieske B, Tschope C, de Boer RA, et al. How to diagnose heart failure with preserved ejection fraction: the HFA-PEFF diagnostic algorithm: a consensus recommendation from the Heart Failure Association (HFA) of the European Society of Cardiology (ESC). Eur Heart J. 2019;40:3297-3317.

## 3.1. Epidemiology of HF

1. Heidenreich PA, Albert NM, Allen LA, et al. Forecasting the impact of heart failure in the United States: a policy statement from the American Heart Association. Circ Heart Fail. 2013;6:606-619.
2. Virani  SS,  Alonso  A,  Aparicio  HJ,  et  al.  Heart  disease  and  stroke  statistics-2021 update: a report from the American Heart Association. Circulation. 2021;143:e254-e743.
3. Ni  H,  Xu  J. Recent  trends  in  heart  failure-related  mortality:  United  States, 2000-2014 . NCHS Data Brief; 2015:1-8.
4. Agarwal  MA,  Fonarow  GC,  Ziaeian  B.  National  trends  in  heart  failure hospitalizations  and  readmissions  from  2010  to  2017 . JAMA  Cardiol . 2021;6:952-956.
5.  Khera R, Kondamudi N, Zhong L, et al. Temporal trends in heart failure incidence among Medicare beneficiaries across risk factor strata, 2011 to 2016. JAMA Netw Open. 2020;3:e2022190.
6. Tsao CW, Lyass A, Enserro D, et al. Temporal trends in the incidence of and mortality associated with heart failure with preserved and reduced ejection fraction. J Am Coll Cardiol HF. 2018;6:678-685.
7.  Dunlay SM, Roger VL, Redfield MM. Epidemiology of heart failure with preserved ejection fraction. Nat Rev Cardiol. 2017;14:591-602.
8. Savitz ST, Leong  T, Sung  SH,  et  al. Contemporary  reevaluation  of race  and  ethnicity  with  outcomes  in  heart  failure. J  Am  Heart  Assoc. 2021;10:e016601.
9.  Rathore SS, Foody JM, Wang Y, et al. Race, quality of care, and outcomes of elderly patients hospitalized with heart failure. JAMA . 2003;289:25172524.
10. Vivo RP, Krim SR, Liang L, et al. Short- and long-term rehospitalization and mortality for heart failure in 4 racial/ethnic populations. J Am Heart Assoc. 2014;3:e001134.

## 3.2. Cause of HF

1. Virani  SS,  Alonso  A,  Aparicio  HJ,  et  al.  Heart  disease  and  stroke  statistics-2021 update: a report from the American Heart Association. Circulation. 2021;143:e254-e743.

## 4.1. Clinical Assessment: History and Physical Examination

1. Ambrosy AP, Pang P, Khan S, et al. Clinical course and predictive value of congestion during hospitalization in patients admitted for worsening signs and symptoms of heart failure with reduced ejection fraction: findings from the EVEREST trial. Eur Heart J. 2013;34:835-843.
2. Selvaraj S, Claggett B, Pozzi A, et al. Prognostic implications of congestion on physical examination among contemporary patients with heart failure and reduced  ejection  fraction:  PARADIGM-HF. Circulation. 2019;140:13691379.
3. Selvaraj S, Claggett B, Shah SJ, et al. Utility of the cardiovascular physical examination and impact of spironolactone in heart failure with preserved ejection fraction. Circ Heart Fail. 2019;12:e006125.
4. Caldentey G, Khairy P, Roy D, et al. Prognostic value of the physical examination in patients with heart failure and atrial fibrillation: insights from the AF-CHF trial (atrial fibrillation and chronic heart failure). J Am Coll Cardiol HF. 2014;2:15-23.
5.  Simonavicius J, Sanders van-Wijk S, Rickenbacher P, et al. Prognostic significance of longitudinal clinical congestion pattern in chronic heart failure: insights from TIME-CHF Trial. Am J Med. 2019;132:e679-e692.
6. Fudim M, Parikh KS, Dunning A, et al. Relation of volume overload to clinical  outcomes  in  acute  heart  failure  (from  ASCEND-HF). Am  J  Cardiol. 2018;122:1506-1512.
7. Anker SD, Negassa A, Coats AJ, et al. Prognostic importance of weight loss in chronic heart failure and the effect of treatment with angiotensin-converting-enzyme inhibitors: an observational study. Lancet. 2003;361:10771083.
8.  Eshaghian S, Horwich TB, Fonarow GC. Relation of loop diuretic dose to mortality in advanced heart failure. Am J Cardiol. 2006;97:17591764.
9.  Gorodeski EZ, Chu E, Reese JR, et al. Prognosis on chronic dobutamine or milrinone infusions for stage D heart failure. Circ Heart Fail. 2009;2:320324.
10. Kittleson M, Hurwitz S, Shah MR, et al. Development of circulatory-renal limitations to angiotensin-converting enzyme inhibitors identifies patients with severe heart failure and early mortality. J Am Coll Cardiol. 2003;41:20292035.
11. Poole JE, Johnson GW, Hellkamp AS, et al. Prognostic importance of defibrillator shocks in patients with heart failure. N Engl J Med. 2008;359:10091017.
12.  Setoguchi S, Stevenson LW, Schneeweiss S. Repeated hospitalizations predict mortality in the community population with heart failure. Am Heart J. 2007;154:260-266.
13. Marume K, Noguchi T, Tateishi E, et al. Prognosis and clinical characteristics of dilated cardiomyopathy with family history via pedigree analysis. Circ J. 2020;84:1284-1293.
14.  Waddell-Smith KE, Donoghue T, Oates S, et al. Inpatient detection of cardiac-inherited disease: the impact of improving family history taking. Open Heart. 2016;3:e000329.
15. González-López E, Gagliardi C, Dominguez F, et al. Clinical characteristics of wild-type transthyretin cardiac amyloidosis: disproving myths. Eur Heart J. 2017;38:1895-1904.
16.  Lousada I, Comenzo RL, Landau H, et al. Light chain amyloidosis: patient experience survey from the Amyloidosis Research Consortium. Adv Ther. 2015;32:920-928.

- 17 . Drazner  MH,  Rame JE, Stevenson L, et al.  Prognostic  importance  of  elevated  jugular  venous  pressure  and  a  third  heart  sound  in  patients  with heart failure. N Engl J Med. 2001;345:574-581.
18. Drazner MH, Hellkamp AS, Leier CV, et al. Value of clinician assessment of hemodynamics in advanced heart failure: the ESCAPE trial. Circ Heart Fail. 2008;1:170-177.
19. Thibodeau  JT,  Turer  AT,  Gualano  SK,  et  al.  Characterization  of  a  novel symptom  of  advanced  heart  failure:  bendopnea. J  Am  Coll  Cardiol  HF. 2014;2:24-31.
20.  Felker GM, Cuculich PS, Gheorghiade M. The Valsalva maneuver: a bedside "biomarker" for heart failure. Am J Med. 2006;119:117-122.
21.  Kittleson MM, Maurer MS, Ambardekar AV, et al. Cardiac amyloidosis: evolving diagnosis and management: a scientific statement from the American Heart Association. Circulation. 2020;142:e7-e22.
22. Palladini  G,  Milani  P,  Merlini  G.  Management  of  AL  amyloidosis  in  2020. Blood. 2020;136:2620-2627.
23.  Alexandre  J,  Cautela  J,  Ederhy  S,  et  al.  Cardiovascular  toxicity  related  to  cancer  treatment:  a  pragmatic  approach  to  the  American and European  Cardio-Oncology  Guidelines. J Am  Heart Assoc. 2020;9:e018403.
24.  Chang HM, Moudgil R, Scarabelli T, et al. Cardiovascular complications of cancer therapy: best practices in diagnosis, prevention, and management: part 1. J Am Coll Cardiol. 2017;70:2536-2551.
25.  Chang HM, Okwuosa TM, Scarabelli T, et al. Cardiovascular complications of cancer therapy: best practices in diagnosis, prevention, and management: part 2. J Am Coll Cardiol. 2017;70:2552-2565.
26.  Prasad M, Hermann J, Gabriel SE, et al. Cardiorheumatology: cardiac involvement in systemic rheumatic disease. Nat Rev Cardiol. 2015;12:168176.
- 27 . Jabbar A, Pingitore A, Pearce S, et al. Thyroid hormones and cardiovascular disease. Nat Rev Cardiol. 2017;14:39-55.
28. Kenny HC, Abel ED. Heart  failure  in  type  2  diabetes  mellitus. Circ  Res. 2019;124:121-141.
29.  Zhang R, Gupta D, Albert SG. Pheochromocytoma as a reversible cause of  cardiomyopathy:  analysis  and  review  of  the  literature. Int  J  Cardiol. 2017;249:319-323.
30. Colao A, Grasso LFS, Di Somma C, et al. Acromegaly and heart failure. Heart Fail Clin. 2019;15:399-408.
31.  Horwich TB, Fonarow GC, Clark AL. Obesity and the obesity paradox in heart failure. Prog Cardiovasc Dis. 2018;61:151-156.
32.  Hershberger RE, Givertz MM, Ho CY, et al. Genetic evaluation of cardiomyopathy-a Heart Failure Society of America practice guideline. J Card Fail. 2018;24:281-302.
33.  Huizar  JF,  Ellenbogen  KA,  Tan  A,  et  al.  Arrhythmia-induced  cardiomyopathy: JACC state-of-the-art review. J Am Coll Cardiol. 2019;73:23282344.
34. Drazner  MH.  The  progression  of  hypertensive  heart  disease. Circulation. 2011;123:327-334.
35.  Kouranos V, Sharma R. Cardiac sarcoidosis: state-of-the-art review. Heart. 2021;107:1591-1599.
36. Muchtar  E,  Blauwet  LA,  Gertz  MA.  Restrictive  cardiomyopathy:  genetics, pathogenesis,  clinical  manifestations,  diagnosis,  and  therapy. Circ  Res. 2017;121:819-837.
- 37 . Tschope  C,  Ammirati  E,  Bozkurt  B,  et  al.  Myocarditis  and  inflammatory cardiomyopathy:  current  evidence  and  future  directions. Nat  Rev  Cardiol. 2021;18:169-193.
38.  Nunes MCP, Beaton A, Acquatella H, et al. Chagas cardiomyopathy: an update of current clinical knowledge and management: a scientific statement from the American Heart Association. Circulation . 2018;138:e169e209.
39.  Davis MB, Arany Z, McNamara D, et al. Peripartum cardiomyopathy: JACC state-of-the-art review. J Am Coll Cardiol. 2020;75:207-221.
40.  Napp LC, Bauersachs J. Takotsubo syndrome: between evidence, myths, and misunderstandings. Herz. 2020;45:252-266.
41. Pelliccia F, Kaski JC, Crea F, et al. Pathophysiology of Takotsubo syndrome. Circulation. 2017;135:2426-2441.
42.  Ware JS, Amor-Salamanca A, Tayal U, et al. Genetic etiology for alcoholinduced cardiac toxicity. J Am Coll Cardiol. 2018;71:2293-2302.
43.  Arenas  DJ, Beltran S, Zhou  S, et al. Cocaine, cardiomyopathy, and  heart  failure:  a  systematic  review  and  meta-analysis. Sci  Rep. 2020;10:19795.
44.  Reddy PKV, Ng TMH, Oh EE, et al. Clinical characteristics and management of methamphetamine-associated cardiomyopathy: state-of-the-art review. J Am Heart Assoc. 2020;9:e016704.

## 4.1.1. Initial Laboratory and Electrocardiographic Testing

1.  Cardinale D, Colombo A, Bacchiani G, et al. Early detection of anthracycline cardiotoxicity and improvement with heart failure therapy. Circulation. 2015;131:1981-1988.
2. Cardinale D, Sandri MT, Colombo A, et al. Prognostic value of troponin I in cardiac risk stratification of cancer patients undergoing high-dose chemotherapy. Circulation. 2004;109:2749-2754.
3. Castano  A,  Narotsky  DL,  Hamid  N,  et  al.  Unveiling  transthyretin  cardiac amyloidosis  and  its  predictors  among  elderly  patients  with  severe  aortic stenosis  undergoing  transcatheter  aortic  valve  replacement. Eur  Heart  J. 2017;38:2879-2887.
4.  Maurer MS, Hanna M, Grogan M, et al. Genotype and phenotype of transthyretin cardiac amyloidosis: THAOS (Transthyretin Amyloid Outcome Survey). J Am Coll Cardiol. 2016;68:161-172.
5. Gillmore  JD,  Maurer  MS,  Falk  RH,  et  al.  Nonbiopsy  diagnosis  of  cardiac transthyretin amyloidosis. Circulation. 2016;133:2404-2412.
6.  Brown EE, Lee YZJ, Halushka MK, et al. Genetic testing improves identification of transthyretin amyloid (ATTR) subtype in cardiac amyloidosis. Amyloid. 2017;24:92-95.
7.  Crawford TC, Okada DR, Magruder JT, et al. A contemporary analysis of heart transplantation and bridge-to-transplant mechanical circulatory support outcomes in cardiac sarcoidosis. J Card Fail. 2018;24:384-391.
8.  Wu RS, Gupta S, Brown RN, et al. Clinical outcomes after cardiac transplantation in muscular  dystrophy patients. J Heart Lung  Transplant. 2010;29:432-438.
9.  Kittleson MM, Maurer MS, Ambardekar AV, et al. Cardiac amyloidosis: evolving diagnosis and management: a scientific statement from the American Heart Association. Circulation. 2020;142:e7-e22.
10. Bozkurt B, Colvin M, Cook J, et al. Current diagnostic and treatment strategies for specific dilated cardiomyopathies: a scientific statement from the American Heart Association. Circulation. 2016;134:e579-e646.
11.  Hendren NS, Drazner MH, Bozkurt B, et al. Description and proposed management  of  the  acute  COVID-19  cardiovascular  syndrome. Circulation. 2020;141:1903-1914.
12.  Kouranos V, Sharma R. Cardiac sarcoidosis: state-of-the-art review. Heart. 2021;107:1591-1599.
13.  Nunes MCP, Beaton A, Acquatella H, et al. Chagas cardiomyopathy: an update of current clinical knowledge and management: a scientific statement from the American Heart Association. Circulation. 2018;138:e169-e209.
14. Tschope  C,  Ammirati  E,  Bozkurt  B,  et  al.  Myocarditis  and  inflammatory cardiomyopathy:  current  evidence  and  future  directions. Nat  Rev  Cardiol. 2021;18:169-193.
15.  Davis MB, Arany Z, McNamara D, et al. Peripartum cardiomyopathy: JACC state-of-the-art review. J Am Coll Cardiol. 2020;75:207-221.

## 4.2. Use of Biomarkers for Prevention, Initial Diagnosis, and Risk Stratification

1. Richards AM, Doughty R, Nicholls MG, et al. Plasma N-terminal pro-brain natriuretic peptide and adrenomedullin: prognostic utility and prediction of benefit from carvedilol in chronic ischemic left ventricular dysfunction. AustraliaNew Zealand Heart Failure Group. J Am Coll Cardiol. 2001;37:1781-1787.
2. Tang WH, Girod JP, Lee MJ, et al. Plasma B-type natriuretic peptide levels in ambulatory patients with established chronic symptomatic systolic heart failure. Circulation. 2003;108:2964-2966.
3.  Zaphiriou A, Robb S, Murray-Thomas T, et al. The diagnostic accuracy of plasma BNP and NTproBNP in patients referred from primary care with suspected heart failure: results of the UK natriuretic peptide study. Eur J Heart Fail. 2005;7:537-541.
4.  Son CS, Kim YN, Kim HS, et al. Decision-making model for early diagnosis of congestive heart failure using rough set and decision tree approaches. J Biomed Inform. 2012;45:999-1008.
5.  Kelder JC, Cramer MJ, van Wijngaarden J, et al. The diagnostic value of physical  examination  and  additional  testing  in  primary  care  patients  with suspected heart failure. Circulation. 2011;124:2865-2873.
6.  Booth RA, Hill SA, Don-Wauchope A, et al. Performance of BNP and NTproBNP for diagnosis of heart failure in primary care patients: a systematic review. Heart Fail Rev. 2014;19:439-451.
7. Dao Q, Krishnaswamy P, Kazanegra R, et al. Utility of B-type natriuretic peptide in the diagnosis of congestive heart failure in an urgent-care setting. J Am Coll Cardiol. 2001;37:379-385.

8. Davis M, Espiner E, Richards G, et al. Plasma brain natriuretic peptide in assessment of acute dyspnoea. Lancet. 1994;343:440-444.
9.  Maisel AS, Krishnaswamy P, Nowak RM, et al. Rapid measurement of Btype natriuretic peptide in the emergency diagnosis of heart failure. N Engl J Med. 2002;347:161-167.
10.  Januzzi JL Jr, Chen-Tournoux AA, Moe G. Amino-terminal pro-B-type natriuretic  peptide  testing  for  the  diagnosis  or  exclusion  of  heart  failure  in patients with acute symptoms. Am J Cardiol. 2008;101:29-38.
11.  Santaguida PL, Don-Wauchope AC, Ali U, et al. Incremental value of natriuretic peptide measurement in acute decompensated heart failure (ADHF): a systematic review. Heart Fail Rev. 2014;19:507-519.
12.  Hill SA, Booth RA, Santaguida PL, et al. Use of BNP and NT-proBNP for the diagnosis of heart failure in the emergency department: a systematic review of the evidence. Heart Fail Rev. 2014;19:421-438.
13. van Kimmenade RR, Januzzi JL Jr, Ellinor PT, et al. Utility of amino-terminal pro-brain natriuretic peptide, galectin-3, and apelin for the evaluation of patients with acute heart failure. J Am Coll Cardiol. 2006;48:1217-1224.
14. Bettencourt P, Azevedo A, Pimenta J, et al. N-terminal-pro-brain natriuretic peptide predicts outcome after hospital discharge in heart failure patients. Circulation . 2004;110:2168-2174.
15. Cheng V, Kazanagra R, Garcia A, et al. A rapid bedside test for B-type peptide predicts treatment outcomes in patients admitted for decompensated heart failure: a pilot study. J Am Coll Cardiol. 2001;37:386-391.
16.  Fonarow GC, Peacock WF, Phillips CO, et al. Admission B-type natriuretic peptide levels and in-hospital mortality in acute decompensated heart failure. J Am Coll Cardiol. 2007;49:1943-1950.
10. 17 . Logeart D, Thabut G, Jourdain P, et al. Predischarge B-type natriuretic peptide assay for identifying patients at high risk of re-admission after decompensated heart failure. J Am Coll Cardiol. 2004;43:635-641.
18.  Maisel A, Hollander JE, Guss D, et al. Primary results of the Rapid Emergency Department Heart Failure Outpatient Trial (REDHOT). A multicenter study of B-type natriuretic peptide levels, emergency department decision making, and outcomes in patients presenting with shortness of breath. J Am Coll Cardiol. 2004;44:1328-1333.
19. Zairis MN, Tsiaousis GZ, Georgilas AT, et al. Multimarker strategy for the prediction of 31 days cardiac death in patients with acutely decompensated chronic heart failure. Int J Cardiol. 2010;141:284-290.
20. Dhaliwal AS, Deswal A, Pritchett A, et al. Reduction in BNP levels with treatment of decompensated heart failure and future clinical events. J Card Fail. 2009;15:293-299.
21.  O'Connor CM, Hasselblad V, Mehta RH, et al. Triage after hospitalization with  advanced  heart  failure:  the  ESCAPE  (Evaluation  Study  of  Congestive Heart Failure and Pulmonary Artery Catheterization Effectiveness) risk model and discharge score. J Am Coll Cardiol. 2010;55:872-878.
22.  O'Brien RJ, Squire IB, Demme B, et al. Pre-discharge, but not admission, levels of NT-proBNP predict adverse prognosis following acute L VF. Eur J Heart Fail. 2003;5:499-506.
23.  Cohen-Solal A, Logeart D, Huang B, et al. Lowered B-type natriuretic peptide  in  response  to  levosimendan  or  dobutamine  treatment  is  associated with improved survival in patients with severe acutely decompensated heart failure. J Am Coll Cardiol. 2009;53:2343-2348.
24. Salah K, Kok WE, Eurlings LW, et al. A novel discharge risk model for patients hospitalised for acute decompensated heart failure incorporating N-terminal pro-B-type natriuretic peptide levels: a European coLlaboration on Acute decompeNsated Heart Failure: ELAN-HF Score. Heart. 2014;100:115-125.
25. Flint KM, Allen LA, Pham M, et al. B-type natriuretic peptide predicts 30-day readmission for heart failure but not readmission for other causes. J Am Heart Assoc. 2014;3:e000806.
26.  Kociol RD, Horton JR, Fonarow GC, et al. Admission, discharge, or change in  B-type  natriuretic  peptide  and  long-term  outcomes:  data  from  Organized Program to Initiate Lifesaving Treatment in Hospitalized Patients with Heart Failure (OPTIMIZE-HF) linked to Medicare claims. Circ  Heart  Fail. 2011;4:628-636.
20. 27 .  Kociol RD, McNulty SE, Hernandez AF, et al. Markers of decongestion, dyspnea relief, and clinical outcomes among patients hospitalized with acute heart failure. Circ Heart Fail. 2013;6:240-245.
28.  Verdiani V, Ognibene A, Rutili MS, et al. NT-ProBNP reduction percentage during hospital stay predicts long-term mortality and readmission in heart failure patients. J Cardiovasc Med (Hagerstown). 2008;9:694-699.
29.  Bayes-Genis A, Lopez L, Zapico E, et al. NT-ProBNP reduction percentage during  admission  for  acutely  decompensated  heart  failure  predicts  longterm cardiovascular mortality. J Card Fail. 2005;11:S3-S8.
30.  Huelsmann M, Neuhold S, Resl M, et al. PONTIAC (NT-proBNP selected prevention of cardiac events in a population of diabetic patients without a

history of cardiac disease): a prospective randomized controlled trial. J Am Coll Cardiol. 2013;62:1365-1372.

31. Ledwidge M, Gallagher J, Conlon C, et al. Natriuretic peptide-based screening and collaborative care for heart failure: the STOP-HF randomized trial. JAMA. 2013;310:66-74.
32. Clerico A, Fontana M, Zyw L, et al. Comparison of the diagnostic accuracy of brain natriuretic peptide (BNP) and the N-terminal part of the propeptide of BNP immunoassays in chronic and acute heart failure: a systematic review. Clin Chem. 2007;53:813-822.
33.  Jensen J, Ma LP, Bjurman C, et al. Prognostic values of NTpro BNP/ BNP  ratio  in  comparison  with  NTpro  BNP  or  BNP  alone  in  elderly patients  with  chronic  heart  failure  in  a  2-year  follow  up. Int  J  Cardiol. 2012;155:1-5.
34.  Kristensen SL, Jhund PS, Mogensen UM, et al. Prognostic value of N-terminal pro-B-type natriuretic peptide levels in heart failure patients with and without atrial fibrillation. Circ Heart Fail. 2017;10:e004409.
35.  Horwich TB, Hamilton MA, Fonarow GC. B-type natriuretic peptide levels in obese patients with advanced heart failure. J Am Coll Cardiol. 2006;47:8590.
36.  Mehra MR, Uber PA, Park MH, et al. Obesity and suppressed B-type natriuretic peptide levels in heart failure. J Am Coll Cardiol. 2004;43:15901595.
7. 37 . Felker GM, Anstrom KJ, Adams KF, et al. Effect of natriuretic peptide-guided therapy on hospitalization or cardiovascular mortality in high-risk patients with heart failure and reduced ejection fraction: a randomized clinical trial. JAMA. 2017;318:713-720.
38.  Januzzi JL Jr, Ahmad T, Mulder H, et al. Natriuretic peptide response and outcomes in chronic heart failure with reduced ejection fraction. J Am Coll Cardiol. 2019;74:1205-1217.
39.  Mark DB, Cowper PA, Anstrom KJ, et al. Economic and quality-of-life outcomes of natriuretic peptide-guided therapy for heart failure. J Am Coll Cardiol. 2018;72:2551-2562.
40. Aimo A, Januzzi JL Jr, Vergaro G, et al. Prognostic value of high-sensitivity troponin T in chronic heart failure: an individual patient data meta-analysis. Circulation. 2018;137:286-297.
41. Evans JDW, Dobbin SJH, Pettit SJ, et al. High-sensitivity cardiac troponin and new-onset heart failure: a systematic review and meta-analysis of 67 063 patients with 4 165 incident heart failure events. J Am Coll Cardiol HF. 2018;6:187-197.
42. Pang  PS,  Fermann  GJ,  Hunter  BR,  et  al.  TACIT  (High  Sensitivity  Troponin  T  Rules  Out  Acute  Cardiac  Insufficiency  Trial). Circ  Heart  Fail. 2019;12:e005931.
43. Ahmad T, Fiuzat  M,  Neely  B,  et  al.  Biomarkers  of  myocardial  stress  and fibrosis as predictors of mode of death in patients with chronic heart failure. J Am Coll Cardiol HF. 2014;2:260-268.
44. Ho JE, Liu C, Lyass A, et al. Galectin-3, a marker of cardiac fibrosis, predicts incident heart failure in the community. J Am Coll Cardiol. 2012;60:12491256.
45.  Kosmala W, Przewlocka-Kosmala M, Rojek A, et al. Comparison of the diastolic stress test with a combined resting echocardiography and biomarker approach  to  patients  with  exertional  dyspnea:  diagnostic  and  prognostic implications. J Am Coll Cardiol Img. 2019;12:771-780.
46. Nymo SH, Aukrust P, Kjekshus J, et al.  Limited  added  value  of  circulating inflammatory biomarkers in chronic heart failure. J Am Coll Cardiol HF. 2017;5:256-264.
17. 47 .  Emdin M, Aimo A, Vergaro G, et al. sST2 predicts outcome in chronic heart failure beyond NT-proBNP and high-sensitivity troponin T. J Am Coll Cardiol. 2018;72:2309-2320.
48.  Gaggin HK, Szymonifka J, Bhardwaj A, et al. Head-to-head comparison of serial  soluble  ST2,  growth  differentiation  factor-15,  and  highly-sensitive troponin T measurements in patients with chronic heart failure. J Am Coll Cardiol HF. 2014;2:65-72.
49. Richards AM. ST2 and prognosis in chronic heart failure. J Am Coll Cardiol. 2018;72:2321-2323.
50.  Anwaruddin  S,  Lloyd-Jones  DM,  Baggish  A,  et  al.  Renal  function, congestive  heart  failure, and  amino-terminal  pro-brain  natriuretic peptide measurement: results from the ProBNP Investigation of Dyspnea in the Emergency Department (PRIDE) Study. J Am Coll Cardiol. 2006;47:91-97.
51.  Redfield MM, Rodeheffer RJ, Jacobsen SJ, et al. Plasma brain natriuretic  peptide  concentration:  impact  of  age  and  gender. J  Am  Coll  Cardiol. 2002;40:976-982.
52.  Wang TJ, Larson MG, Levy D, et al. Impact of age and sex on plasma natriuretic peptide levels in healthy adults. Am J Cardiol. 2002;90:254-258.

53.  Chang AY, Abdullah SM, Jain T, et al. Associations among androgens, estrogens, and natriuretic peptides in young women: observations from the Dallas Heart Study. J Am Coll Cardiol. 2007;49:109-116.

## 4.3. Genetic Evaluation and Testing

1. Marume K, Noguchi T, Tateishi E, et al. Prognosis and clinical characteristics of dilated cardiomyopathy with family history via pedigree analysis. Circ J. 2020;84:1284-1293.
2.  Waddell-Smith KE, Donoghue T, Oates S, et al. Inpatient detection of cardiac-inherited disease: the impact of improving family history taking. Open Heart. 2016;3:e000329.
3. Pugh TJ, Kelly MA, Gowrisankar S, et al. The landscape of genetic variation in dilated cardiomyopathy as surveyed by clinical DNA sequencing. Genet Med. 2014;16:601-608.
4. Haas J, Frese KS, Peil B, et al. Atlas of the clinical genetics of human dilated cardiomyopathy. Eur Heart J. 2015;36:1123-1135a.
5. Roberts AM, Ware JS, Herman DS, et al. Integrated allelic, transcriptional, and phenomic dissection of the cardiac effects of titin truncations in health and disease. Sci Transl Med. 2015;7:270ra6.
6. Gigli  M,  Merlo  M,  Graw  SL,  et  al.  Genetic  risk  of  arrhythmic  phenotypes in patients with dilated cardiomyopathy. J Am Coll Cardiol. 2019;74:14801490.
7. James CA, Bhonsale A, Tichnell C, et al.  Exercise  increases  age-related penetrance and arrhythmic risk in arrhythmogenic right ventricular dysplasia/cardiomyopathy-associated  desmosomal  mutation  carriers. J  Am  Coll Cardiol. 2013;62:1290-1297.

## 4.4. Evaluation With Cardiac Imaging

1. Badgett RG, Mulrow CD, Otto P, et al. How well can the chest radiograph diagnose left ventricular dysfunction? J Gen Intern Med. 1996;11:625-634.
2.  Knudsen CW, Omland T, Clopton P, et al. Diagnostic value of B-type natriuretic peptide and chest radiographic findings in patients with acute dyspnea. Am J Med. 2004;116:363-368.
3. Tribouilloy C, Rusinaru D, Mahjoub H, et al. Impact of echocardiography in patients  hospitalized  for  heart  failure:  a  prospective  observational  study. Arch Cardiovasc Dis. 2008;101:465-473.
4. Doughty RNWG, Gamble G, et al. Left ventricular remodeling with carvedilol in patients with congestive heart failure due to ischemic heart disease. Australia-New Zealand Heart Failure Research Collaborative Group. J Am Coll Cardiol. 1997;29:1060-1066.
5. Duncker D, König T, Hohmann S, et al. Avoiding untimely implantable cardioverter/defibrillator implantation by intensified heart failure therapy optimization supported by the wearable cardioverter/defibrillator-the PROLONG study. J Am Heart Assoc. 2017;6:e004512.
6. Januzzi JL Jr, Prescott MF, Butler J, et al. Association of change in N-terminal pro-B-type natriuretic peptide following initiation of sacubitril-valsartan treatment with cardiac structure and function in patients with heart failure with reduced ejection fraction. JAMA. 2019;322:1-11.
7.  Solomon SD, Glynn RJ, Greaves S, et al. Recovery of ventricular function after myocardial infarction in the reperfusion era: the healing and early afterload reducing therapy study. Ann Intern Med. 2001;134:451-458.
8. Bellenger  NG,  Burgess  MI,  Ray  SG,  et  al.  Comparison  of  left  ventricular ejection fraction and volumes in heart failure by echocardiography, radionuclide ventriculography and cardiovascular magnetic resonance; are they interchangeable? Eur Heart J. 2000;21:1387-1396.
9.  Grothues F, Smith GC, Moon JC, et al. Comparison of interstudy reproducibility  of  cardiovascular  magnetic  resonance  with  two-dimensional  echocardiography in  normal  subjects  and  in  patients  with  heart  failure  or  left ventricular hypertrophy. Am J Cardiol. 2002;90:29-34.
10.  Longmore DB, Klipstein RH, Underwood SR, et al. Dimensional accuracy of magnetic resonance in studies of the heart. Lancet. 1985;1:1360-1362.
11.  Doherty JU, Kort S, Mehran R, et al. ACC/AATS/AHA/ASE/ASNC/HRS/ SCAI/SCCT/SCMR/STS 2019 appropriate use criteria for multimodality imaging in the assessment of cardiac structure and function in nonvalvular heart disease: a report of the American College of Cardiology Appropriate Use Criteria Task Force, American Association for Thoracic Surgery, American Heart Association, American Society of Echocardiography, American Society of Nuclear Cardiology, Heart Rhythm Society, Society for Cardiovascular Angiography and Interventions, Society of Cardiovascular Computed Tomography, Society for Cardiovascular Magnetic Resonance, and the Society of Thoracic Surgeons. J Am Coll Cardiol. 2019;73:488-516.
12.  van Royen N, Jaffe CC, Krumholz HM, et al. Comparison and reproducibility of visual echocardiographic and quantitative radionuclide left ventricular ejection fractions. Am J Cardiol. 1996;77:843-850.
13.  Fu H, Wang X, Diao K, et al. CT compared to MRI for functional evaluation of  the  right  ventricle:  a  systematic  review  and  meta-analysis. Eur  Radiol. 2019;29:6816-6828.
14. Kaniewska M, Schuetz GM, Willun S, et al. Noninvasive evaluation of global and regional left ventricular function using computed tomography and magnetic resonance imaging: a meta-analysis. Eur Radiol. 2017;27:1640-1659.
15. Takx RA, Moscariello A, Schoepf UJ, et al. Quantification of left and right ventricular  function  and  myocardial  mass:  comparison  of  low-radiation dose  2nd  generation  dual-source  CT  and  cardiac  MRI. Eur  J  Radiol. 2012;81:e598-e604.
16. Anderson LJ, Holden S, Davis B, et al. Cardiovascular T2-star (T2*) magnetic resonance for the early diagnosis of myocardial iron overload. Eur Heart J. 2001;22:2171-2179.
17. 17 .  Bruder O, Schneider S, Nothnagel D, et al. EuroCMR (European Cardiovascular Magnetic Resonance) registry: results of the German pilot phase. J Am Coll Cardiol. 2009;54:1457-1466.
18.  Bruder O, Wagner A, Lombardi M, et al. European Cardiovascular Magnetic Resonance (EuroCMR) registry--multi national results from 57 centers in 15 countries. J Cardiovasc Magn Reson. 2013;15:9.
19.  Karamitsos  TD,  Piechnik  SK,  Banypersad  SM,  et  al.  Noncontrast  T1 mapping for the diagnosis of cardiac amyloidosis. J  Am Coll Cardiol Img. 2013;6:488-497.
20. Martinez-Naharro A, Treibel TA, Abdel-Gadir A, et al. Magnetic resonance in transthyretin cardiac amyloidosis. J Am Coll Cardiol. 2017;70:466-477.
21. Puntmann VO, Voigt T, Chen Z, et al. Native T1 mapping in differentiation of normal myocardium from diffuse disease in hypertrophic and dilated cardiomyopathy. J Am Coll Cardiol Img. 2013;6:475-484.
22.  Sado DM, Maestrini V, Piechnik SK, et al. Noncontrast myocardial T1 mapping  using  cardiovascular  magnetic  resonance  for  iron  overload. J  Magn Reson Imaging. 2015;41:1505-1511.
23.  Sado DM, White SK, Piechnik SK, et al. Identification and assessment of Anderson-Fabry  disease  by  cardiovascular  magnetic  resonance  noncontrast myocardial T1 mapping. Circ Cardiovasc Imaging. 2013;6:392-398.
24.  Elhendy A, Sozzi F, van Domburg RT, et al. Effect of myocardial ischemia during dobutamine stress echocardiography on cardiac mortality in patients with  heart  failure  secondary  to  ischemic  cardiomyopathy. Am  J  Cardiol. 2005;96:469-473.
25. Miller WL, Hodge DO, Tointon SK, et al. Relationship of myocardial perfusion imaging findings to outcome of patients with heart failure and suspected ischemic heart disease. Am Heart J. 2004;147:714-720.
26.  Chow BJW, Coyle D, Hossain A, et al. Computed tomography coronary angiography for patients with heart failure (CTA-HF): a randomized controlled trial  (IMAGE-HF  1C). Eur  Heart  J  Cardiovasc  Imaging. 2021;22:10831090.
27. 27 . Ferreira JP, Rossignol P, Demissei B, et al. Coronary angiography in worsening heart failure: determinants, findings and prognostic implications. Heart. 2018;104:606-613.
28. Allman KC, Shaw LJ, Hachamovitch R, et al. Myocardial viability testing and impact  of  revascularization  on  prognosis  in  patients  with  coronary  artery disease and left ventricular dysfunction: a meta-analysis. J Am Coll Cardiol. 2002;39:1151-1158.
29. D'Egidio G, Nichol G, Williams KA, et al. PARR-2 Investigators. Increasing benefit  from  revascularization  is  associated  with  increasing  amounts  of myocardial hibernation: a substudy of the PARR-2 trial. J Am Coll Cardiol Img. 2009;2:1060-1068.
30. Ling LF, Marwick TH, Flores DR, et al. Identification of therapeutic benefit from revascularization in patients with left ventricular systolic dysfunction: inducible ischemia versus hibernating myocardium. Circ Cardiovasc Imaging. 2013;6:363-372.
31. Orlandini A, Castellana N, Pascual A, et al. Myocardial viability for decisionmaking  concerning  revascularization  in  patients  with  left  ventricular  dysfunction and coronary artery disease: a meta-analysis of non-randomized and randomized studies. Int J Cardiol. 2015;182:494-499.
32. Desideri  A,  Cortigiani  L,  Christen  AI,  et  al.  The  extent  of  perfusion-F18fluorodeoxyglucose  positron  emission  tomography  mismatch  determines mortality in medically treated patients with chronic ischemic left ventricular dysfunction. J Am Coll Cardiol. 2005;46:1264-1269.
33. Collins SP, Lindsell CJ, Storrow AB, et al. Prevalence of negative chest radiography results in the emergency department patient with decompensated heart failure. Ann Emerg Med. 2006;47:13-18.
34.  Echouffo-Tcheugui JB, Erqou S, Butler J, et al. Assessing the risk of progression  from  asymptomatic  left  ventricular  dysfunction  to  overt  heart

failure:  a  systematic  overview  and  meta-analysis. J  Am  Coll  Cardiol  HF. 2016;4:237-248.

35.  Levy D, Garrison RJ, Savage DD, et al. Prognostic implications of echocardiographically  determined  left  ventricular  mass  in  the  Framingham  Heart Study. N Engl J Med. 1990;322:1561-1566.
36. Nauta JF, Hummel YM, van der Meer P, et al. Correlation with invasive left ventricular  filling  pressures  and  prognostic  relevance  of  the  echocardiographic diastolic parameters used in the 2016 ESC heart failure guidelines and in the 2016 ASE/EACVI recommendations: a systematic review in patients with heart failure with preserved ejection fraction. Eur J Heart Fail. 2018;20:1303-1311.
3. 37 .  Solomon SD, Anavekar N, Skali H, et al Candesartan in Heart Failure Reduction in Mortality (CHARM) Investigators. Influence of ejection fraction on cardiovascular outcomes in a broad spectrum of heart failure patients. Circulation . 2005;112:3738-3744.
38. Al Saikhan L, Park C, Hardy R, et al. Prognostic implications of left ventricular strain by speckle-tracking echocardiography in the general population: a meta-analysis. Vasc Health Risk Manag. 2019;15:229-251.
39. Redfield  MM,  Jacobsen  SJ,  Burnett  JC  Jr,  et  al.  Burden  of  systolic  and diastolic ventricular dysfunction in the community: appreciating the scope of the heart failure epidemic. JAMA. 2003;289:194-202.
40. Bosch L, Lam CSP, Gong L, et al. Right ventricular dysfunction in left-sided heart failure with preserved versus reduced ejection fraction. Eur J Heart Fail. 2017;19:1664-1671.
41.  Lang RM, Badano LP, Mor-Avi V, et al. Recommendations for cardiac chamber quantification by echocardiography in adults: an update from the American Society of Echocardiography and the European Association of Cardiovascular Imaging. J Am Soc Echocardiogr. 2015;28:1-39.e14.
42.  Nagueh SF, Smiseth OA, Appleton CP, et al. Recommendations for the evaluation of left ventricular diastolic function by echocardiography: an update from the American Society of Echocardiography and the European Association of Cardiovascular Imaging. J Am Soc Echocardiogr. 2016;29:277-314.
43.  Biering-Sorensen T, Biering-Sorensen SR, Olsen FJ, et al. Global longitudinal strain by echocardiography predicts long-term risk of cardiovascular morbidity and mortality in a low-risk general population: the Copenhagen City Heart Study. Circ Cardiovasc Imaging. 2017;10:e005521.
44.  Kalam K, Otahal P, Marwick TH. Prognostic implications of global L V dysfunction: a systematic review and meta-analysis of global longitudinal strain and ejection fraction. Heart. 2014;100:1673-1680.
45. Morris  DA,  Ma  XX,  Belyavskiy  E,  et  al.  Left  ventricular  longitudinal  systolic function analysed by 2D speckle-tracking echocardiography in heart failure  with  preserved  ejection  fraction:  a  meta-analysis. Open  Heart. 4;2017:e000630.
46. Shah AM, Claggett B, Sweitzer NK, et al. Prognostic importance of impaired systolic  function  in  heart  failure  with  preserved  ejection  fraction  and  the impact of spironolactone. Circulation. 2015;132:402-414.
13. 47 .  Lipczynska M, Szymanski P, Klisiewicz A, et al. Hand-carried echocardiography in heart failure and heart failure risk population: a community based prospective study. J Am Soc Echocardiogr. 2011;24:125-131.
48.  Martin LD, Howell EE, Ziegelstein RC, et al. Hand-carried ultrasound performed by hospitalists: does it improve the cardiac physical examination? Am J Med. 2009;122:35-41.
49.  Maw AM, Hassanin A, Ho PM, et al. Diagnostic accuracy of point-of-care lung ultrasonography and chest radiography in adults with symptoms suggestive  of  acute  decompensated  heart  failure:  a  systematic  review  and meta-analysis. JAMA Netw Open. 2019;2:e190703.
50. Platz  E,  Campbell  RT,  Claggett  B,  et  al.  Lung  ultrasound  in  acute  heart failure: prevalence of pulmonary congestion and short- and long-term outcomes. J Am Coll Cardiol HF. 2019;7:849-858.
51. Pivetta E, Goffi A, Nazerian P, et al. Lung ultrasound integrated with clinical assessment for the diagnosis of acute decompensated heart failure in the emergency department: a randomized controlled trial. Eur J Heart Fail. 2019;21:754-766.
52. Palazzuoli A, Ruocco G, Beltrami M, et al. Combined use of lung ultrasound, B-type natriuretic peptide, and echocardiography for outcome prediction in patients with acute HFrEF and HFpEF. Clin Res Cardiol. 2018;107:586596.
53. Ottervanger JP, van't Hof AW, Reiffers S, et al. Long-term recovery of left ventricular function after primary angioplasty for acute myocardial infarction. Eur Heart J. 2001;22:785-790.
54.  Packer M, Colucci WS, Sackner-Bernstein JD, et al. Double-blind, placebocontrolled study of the effects of carvedilol in patients with moderate to severe heart failure. The PRECISE Trial. Prospective Randomized Evaluation of Carvedilol on Symptoms and Exercise. Circulation. 1996;94:2793-2799.
55.  St John Sutton MG, Plappert T, Abraham WT, et al. Effect of cardiac resynchronization therapy on left ventricular size and function in chronic heart failure. Circulation. 2003;107:1985-1990.
56.  Wilcox JE, Fonarow GC, Yancy CW, et al. Factors associated with improvement in ejection fraction in clinical practice among patients with heart failure: findings from IMPROVE HF. Am Heart J. 2012;163:49-56.e2.
23. 57 .  Konstam MA, Rousseau MF, Kronenberg MW, et al. Effects of the angiotensin converting enzyme inhibitor enalapril on the long-term progression of left ventricular dysfunction in patients with heart failure. SOL VD Investigators. Circulation. 1992;86:431-438.
58.  Lee MMY, Brooksbank KJM, Wetherall K, et al. Effect of empagliflozin on left ventricular volumes in patients with type 2 diabetes, or prediabetes, and heart  failure  with  reduced  ejection  fraction  (SUGAR-DM-HF). Circulation . 2021;143:516-525.
59. Nasser R, Van Assche L, Vorlat A, et al. Evolution of functional mitral regurgitation and prognosis in medically managed heart failure patients with reduced ejection fraction. J Am Coll Cardiol HF. 2017;5:652-659.
60.  Wilcox JE, Fang JC, Margulies KB, Mann DL. Heart failure with recovered left  ventricular  ejection  fraction:  JACC  Scientific  Expert  Panel. J  Am Coll Cardiol. 2020;76:719-734.
61.  Stout KK, Daniels CJ, Aboulhosn JA, et al. 2018 AHA/ACC guideline for the management of adults with congenital heart disease: a report of the American College of Cardiology/American Heart Association Task Force on Clinical Practice Guidelines. Circulation . 2019;139:e698-e800.
62. Yoshida  A,  Ishibashi-Ueda  H,  Yamada  N,  et  al.  Direct  comparison  of  the diagnostic  capability  of  cardiac  magnetic  resonance  and  endomyocardial biopsy in patients with heart failure. Eur J Heart Fail. 2013;15:166-175.
63.  Kim RJ, Albert TS, Wible JH, et al. Performance of delayed-enhancement magnetic resonance imaging with gadoversetamide contrast for the detection and assessment of myocardial infarction: an international, multicenter, double-blinded, randomized trial. Circulation. 2008;117:629-637.
64.  Wagner A, Mahrholdt H, Holly TA, et al. Contrast-enhanced MRI and routine single photon emission computed tomography (SPECT) perfusion imaging for detection of subendocardial myocardial infarcts: an imaging study. Lancet. 2003;361:374-379.
65. McCrohon  JA,  Moon  JC,  Prasad  SK,  et  al.  Differentiation  of  heart  failure  related  to  dilated  cardiomyopathy  and  coronary  artery  disease  using gadolinium-enhanced cardiovascular magnetic resonance. Circulation. 2003;108:54-59.
66. Valle-Muñoz A, Estornell-Erill J, Soriano-Navarro CJ, et al. Late gadolinium enhancement-cardiovascular magnetic resonance identifies coronary artery disease as the aetiology of left ventricular dysfunction in acute new-onset congestive heart failure. Eur J Echocardiogr. 2009;10:968-974.
33. 67 .  Ferreira VM, Schulz-Menger J, Holmvang G, et al. Cardiovascular magnetic resonance in nonischemic myocardial inflammation: expert recommendations. J Am Coll Cardiol. 2018;72:3158-3176.
68.  Wong TC, Piehler K, Meier CG, et al. Association between extracellular matrix expansion quantified by cardiovascular magnetic resonance and shortterm mortality. Circulation. 2012;126:1206-1216.
69. Flett AS, Hayward MP, Ashworth MT, et al. Equilibrium contrast cardiovascular magnetic resonance for the measurement of diffuse myocardial fibrosis: preliminary validation in humans. Circulation . 2010;122:138-144.
70.  Miller CA, Naish JH, Bishop P, et al. Comprehensive validation of cardiovascular magnetic resonance techniques for the assessment of myocardial extracellular volume. Circ Cardiovasc Imaging. 2013;6:373-383.
71.  Vita T, Grani C, Abbasi SA, et al. Comparing CMR mapping methods and myocardial patterns toward heart failure outcomes in nonischemic dilated cardiomyopathy. J Am Coll Cardiol Img. 2019;12:1659-1669.
72.  Greulich S, Deluigi CC, Gloekler S, et al. CMR imaging predicts death and other adverse events in suspected cardiac sarcoidosis. J  Am Coll Cardiol Img. 2013;6:501-511.
73.  Kuruvilla S, Adenaw N, Katwal AB, et al. Late gadolinium enhancement on cardiac magnetic resonance predicts adverse cardiovascular outcomes in nonischemic cardiomyopathy: a systematic review and meta-analysis. Circ Cardiovasc Imaging. 2014;7:250-258.
40. 7 4.  Kwong RY, Chan AK, Brown KA, et al. Impact of unrecognized myocardial scar detected by cardiac magnetic resonance imaging on event-free survival in patients presenting with signs or symptoms of coronary artery disease. Circulation. 2006;113:2733-2743.
75.  El Aidi H, Adams A, Moons KG, et al. Cardiac magnetic resonance imaging  findings  and  the  risk  of  cardiovascular  events  in  patients  with recent  myocardial  infarction  or  suspected  or  known  coronary  artery disease:  a  systematic  review  of  prognostic  studies. J  Am  Coll  Cardiol. 2014;63:1031-1045.

76. Lehrke S, Lossnitzer D, Schob M, et al. Use of cardiovascular magnetic resonance for risk stratification in chronic heart failure: prognostic value of late gadolinium enhancement in patients with non-ischaemic dilated cardiomyopathy. Heart. 2011;97:727-732.
2. 77 .  Fontana M, Pica S, Reant P, et al. Prognostic value of late gadolinium enhancement cardiovascular magnetic resonance in cardiac amyloidosis. Circulation. 2015;132:1570-1579.
78. Paterson DI, Wells G, Erthal F, et al. OUTSMART HF: a randomized controlled trial of routine versus selective cardiac magnetic resonance for patients with nonischemic heart failure (IMAGE-HF 1B). Circulation . 2020;141:818-827.
79. He J, Ogden LG, Bazzano LA, et al. Risk factors for congestive heart failure in US men and women: NHANES I epidemiologic follow-up study. Arch Intern Med. 2001;161:996-1002.
80.  Beanlands RS, Nichol G, Huszti E, et al. F-18-fluorodeoxyglucose positron emission tomography imaging-assisted management of patients with severe left ventricular dysfunction and suspected coronary disease: a randomized, controlled trial (PARR-2). J Am Coll Cardiol. 2007;50:2002-2012.
81. Bonow RO, Maurer G, Lee KL, et al. Myocardial viability and survival in ischemic left ventricular dysfunction. N Engl J Med. 2011;364:1617-1625.
82. Panza JA, Ellis AM, Al-Khalidi HR, et al. Myocardial viability and long-term outcomes in ischemic cardiomyopathy. N Engl J Med. 2019;381:739-748.
83.  Patel  MR,  White  RD,  Abbara  S,  et  al.  2013  ACCF/ACR/ASE/ASNC/ SCCT/SCMR appropriate utilization of cardiovascular imaging in heart failure: a joint report of the American College of Radiology Appropriateness Criteria Committee and the American College of Cardiology Foundation Appropriate Use Criteria Task Force. J Am Coll Cardiol. 2013;61:2207-2231.

## 4.5. Invasive Evaluation

1.  Cooper LT, Baughman KL, Feldman AM, et al. The role of endomyocardial biopsy in the management of cardiovascular disease: a scientific statement from the American Heart Association, the American College of Cardiology, and the European Society of Cardiology. Circulation . 2007;116:2216-2233.
2. Maurer  MS,  Schwartz  JH,  Gundapaneni  B,  et  al.  Tafamidis  treatment for  patients  with  transthyretin  amyloid  cardiomyopathy. N  Engl  J  Med. 2018;379:1007-1016.
3.  Binanay C, Califf RM, Hasselblad V, et al. Evaluation study of congestive heart  failure  and  pulmonary  artery  catheterization  effectiveness:  the  ESCAPE trial. JAMA. 2005;294:1625-1633.
4.  Shah MRHV, Stevenson LW, et al. Impact of the pulmonary artery catheter in  critically  ill  patients:  meta-analysis  of  randomized  clinical  trials. JAMA. 2005;294:1664-1670.
5.  Deckers JW, Hare JM, Baughman KL. Complications of transvenous right ventricular endomyocardial biopsy in adult patients with cardiomyopathy: a seven-year survey of 546 consecutive diagnostic procedures in a tertiary referral center. J Am Coll Cardiol. 1992;19:43-47.
6.  Veress G, Bruce CJ, Kutzke K, et al. Acute thrombus formation as a complication of right ventricular biopsy. J Am Soc Echocardiogr. 2010;23:10391044.
7.  Patel MR, Calhoon JH, Dehmer GJ, et al. ACC/AATS/AHA/ASE/ASNC/ SCAI/SCCT/STS 2017 appropriate  use  criteria  for  coronary  revascularization  in  patients  with  stable  ischemic  heart  disease. J  Am  Coll  Cardiol. 2017;69:2212-2241.
8.  Velazquez EJ, Lee KL, Deja MA, et al. Coronary-artery bypass surgery in patients with left ventricular dysfunction. N Engl J Med. 2011;364:16071616.
9.  Velazquez EJ, Lee KL, Jones RH, et al. Coronary-artery bypass surgery in patients  with  ischemic  cardiomyopathy. N  Engl  J  Med. 2016;374:15111520.

## 4.6. Wearables and Remote Monitoring (Including Telemonitoring and Device Monitoring)

1.  Abraham WT, Adamson PB, Bourge RC, et al. Wireless pulmonary artery haemodynamic monitoring in chronic heart failure: a randomised controlled trial. Lancet. 2011;377:658-666.
2.  Adamson PB, Abraham WT, Bourge RC, et al. Wireless pulmonary artery pressure monitoring guides management to reduce decompensation in heart failure with preserved ejection fraction. Circ Heart Fail. 2014;7:935-944.
3.  Givertz MM, Stevenson LW, Costanzo MR, et al. Pulmonary artery pressureguided  management  of  patients  with  heart  failure  and  reduced  ejection fraction. J Am Coll Cardiol. 2017;70:1875-1886.
4. Lindenfeld  J,  Zile  MR,  Desai  AS,  et  al.  Haemodynamic-guided  management of heart failure  (GUIDE-HF): a randomised controlled trial. Lancet. 2021;398:991-1001.
5.  Martinson M, Bharmi R, Dalal N, et al. Pulmonary artery pressure-guided heart failure management: US cost-effectiveness analyses using the results of the CHAMPION clinical trial. Eur J Heart Fail. 2017;19:652-660.
6.  Sandhu AT, Goldhaber-Fiebert JD, Owens DK, et al. Cost-effectiveness of implantable pulmonary artery pressure monitoring in chronic heart failure. J Am Coll Cardiol HF. 2016;4:368-375.
7.  Schmier  JK,  Ong  KL,  Fonarow  GC.  Cost-effectiveness  of  remote  cardiac  monitoring  with  the  CardioMEMS  heart  failure  system. Clin  Cardiol. 2017;40:430-436.
8.  Heywood JT, Jermyn R, Shavelle D, et al. Impact of practice-based management of pulmonary artery pressures in 2000 patients implanted with the CardioMEMS sensor. Circulation. 2017;135:1509-1517.
9.  Desai AS, Bhimaraj A, Bharmi R, et al. Ambulatory hemodynamic monitoring reduces heart failure hospitalizations in "real-world" clinical practice. J Am Coll Cardiol. 2017;69:2357-2365.
10.  Abraham J, Bharmi R, Jonsson O, et al. Association of ambulatory hemodynamic monitoring of heart failure with clinical outcomes in a concurrent matched cohort analysis. JAMA Cardiol. 2019;4:556-563.
11.  Ong MK, Romano PS, Edgington S, et al. Effectiveness of remote patient monitoring  after  discharge  of  hospitalized  patients  with  heart  failure:  the Better Effectiveness After Transition--Heart Failure (BEAT-HF) randomized clinical trial. JAMA Intern Med. 2016;176:310-318.
12. Galinier  M,  Roubille  F,  Berdague  P,  et  al.  T elemonitoring  versus  standard care  in  heart  failure:  a  randomised  multicentre  trial. Eur  J  Heart  Fail. 2020;22:985-994.
13.  Böhm M, Drexler H, Oswald H, et al. Fluid status telemedicine alerts for heart  failure:  a  randomized  controlled  trial. Eur  Heart  J. 2016;37:31543363.
14.  Boriani G, Da Costa A, Quesada A, et al. Effects of remote monitoring on clinical outcomes and use of healthcare resources in heart failure patients with biventricular defibrillators: results of the MORE-CARE multicentre randomized controlled trial. Eur J Heart Fail. 2017;19:416-425.
15. Hindricks  G,  Taborsky  M,  Glikson  M,  et  al.  Implant-based  multiparameter telemonitoring of patients with heart failure (IN-TIME): a randomised controlled trial. Lancet. 2014;384:583-590.
16. Klersy C, Boriani G, De Silvestri A, et al. Effect of telemonitoring of cardiac implantable electronic devices on healthcare utilization: a meta-analysis of randomized controlled trials in patients with heart failure. Eur J Heart Fail. 2016;18:195-204.
17. 17 . Morgan JM, Kitt S, Gill J, et al. Remote management of heart failure using implantable electronic devices. Eur Heart J. 2017;38:2352-2360.
18.  Parthiban N, Esterman A, Mahajan R, et al. Remote monitoring of implantable  cardioverter-defibrillators:  a  systematic  review  and  meta-analysis  of clinical outcomes. J Am Coll Cardiol. 2015;65:2591-2600.
19.  Loh JP, Barbash IM, Waksman R. Overview of the 2011 Food and Drug Administration  circulatory  system  devices  panel  of  the  medical  devices advisory committee meeting on the CardioMEMS Champion Heart Failure Monitoring System. J Am Coll Cardiol. 2013;61:1571-1576.
20.  Ollendorf  DA,  Sandhu  AT,  Pearson  SD.  CardioMEMS  HF  for  the  management  of  heart  failure-effectiveness  and  value. JAMA  Intern  Med. 2016;176:1551-1552.
21.  Krumholz HM, Dhruva SS. Real-world data on heart failure readmission reduction: real or real uncertain? J Am Coll Cardiol. 2017;69:2366-2368.
22. Inglis SC, Clark RA, Dierckx R, et al. Structured telephone support or noninvasive telemonitoring for patients with heart failure. Cochrane Database Syst Rev. 2015:CD007228.
23.  Koehler F, Koehler K, Deckwart O, et al. Efficacy of telemedical interventional management in patients with heart failure (TIM-HF2): a randomised, controlled, parallel-group, unmasked trial. Lancet. 2018;392:1047-1057.

## 4.7. Exercise and Functional Capacity Testing

1. Nomenclature and Criteria for Diagnosis of Diseases of the Heart and Great Vessels . 9th ed. Little, Brown &amp; Co; 1994.
2.  Ahmed  A,  Aronow  WS,  Fleg  JL.  Higher  New  York  Heart  Association  classes  and  increased  mortality  and  hospitalization  in  patients with heart failure and preserved left ventricular function. Am Heart J. 2006;151:444-450.
3.  Muntwyler J, Abetel G, Gruner C, Follath F. One-year mortality among unselected outpatients with heart failure. Eur Heart J. 2002;23:1861-1866.

4.  Brawner CA, Shafiq A, Aldred HA, et al. Comprehensive analysis of cardiopulmonary exercise testing and mortality in patients with systolic heart failure: the Henry Ford Hospital cardiopulmonary exercise testing (FIT-CPX) project. J Card Fail. 2015;21:710-718.
5. Corra  U,  Giordano  A,  Mezzani  A,  et  al.  Cardiopulmonary  exercise  testing and prognosis in heart failure due to systolic left ventricular dysfunction: a  validation  study  of  the  European  Society  of  Cardiology  Guidelines  and Recommendations (2008) and further developments. Eur  J  Prev  Cardiol. 2012;19:32-40.
6.  Feldman D, Pamboukian SV, Teuteberg JJ, et al.  The  2013  International Society for Heart and Lung Transplantation Guidelines for mechanical circulatory support: executive summary. J Heart Lung Transplant. 2013;32:157187.
7.  Mancini DM, Eisen H, Kussmaul W, et al. Value of peak exercise oxygen consumption for optimal timing of cardiac transplantation in ambulatory patients with heart failure. Circulation. 1991;83:778-786.
8.  Mehra MR, Canter CE, Hannan MM, et al. The 2016 International Society for  Heart  Lung  Transplantation  listing  criteria  for  heart  transplantation:  a 10-year update. J Heart Lung Transplant. 2016;35:1-23.
9.  Alahdab MT, Mansour IN, Napan S, Stamos TD. Six minute walk test predicts long-term all-cause mortality and heart failure rehospitalization in African-American patients hospitalized with acute decompensated heart failure. J Card Fail. 2009;15:130-135.
10. Bittner  V,  Weiner  DH,  Yusuf  S,  et  al.  Prediction  of  mortality  and  morbidity  with  a  6-minute  walk  test  in  patients  with  left  ventricular  dysfunction. SOLVD Investigators. JAMA. 1993;270:1702-1707.
11. Boxer R, Kleppinger A, Ahmad A, et al. The 6-minute walk is associated with frailty and predicts mortality in older adults with heart failure. Congest Heart Fail. 2010;16:208-213.
12. Forman DE, Fleg JL, Kitzman DW, et al. 6-min walk test provides prognostic utility comparable to cardiopulmonary exercise testing in ambulatory outpatients with systolic heart failure. J Am Coll Cardiol. 2012;60:2653-2661.
13. Grundtvig M, Eriksen-Volnes T, Orn S, et al. 6 min walk test is a strong independent predictor of death in outpatients with heart failure. ESC Heart Fail. 2020;7:2904-2911.
14. Keteyian SJ, Patel M, Kraus WE, et al. Variables measured during cardiopulmonary exercise testing as predictors of mortality in chronic systolic heart failure. J Am Coll Cardiol. 2016;67:780-789.
15.  McCabe N, Butler J, Dunbar SB, et al. Six-minute walk distance predicts 30-day  readmission  after  acute  heart  failure  hospitalization. Heart  Lung. 2017;46:287-292.
16. Ramalho  SHR,  Cipriano  Junior  G,  Vieira  PJC,  et  al.  Inspiratory  muscle strength and six-minute walking distance in heart failure: prognostic utility in a 10 years follow up cohort study. PLoS One. 2019;14:e0220638.
14. 17 .  Parshall MB, Schwartzstein RM, Adams L, et al. An official American Thoracic Society statement: update on the mechanisms, assessment, and management of dyspnea. Am J Respir Crit Care Med. 2012;185:435-452.
18.  Reddy YNV, Olson TP, Obokata M, et al. Hemodynamic correlates and diagnostic role of cardiopulmonary exercise testing in heart failure with preserved ejection fraction. J Am Coll Cardiol HF. 2018;6:665-675.
19.  Guyatt GH, Sullivan MJ, Thompson PJ, et al. The 6-minute walk: a new measure  of  exercise  capacity  in  patients  with  chronic  heart  failure. Can Med Assoc J. 1985;132:919-923.
20. Lans C, Cider A, Nylander E, Brudin L. Test-retest reliability of six-minute walk tests over a one-year period in patients with chronic heart failure. Clin Physiol Funct Imaging. 2020;40:284-289.
21. Pollentier B, Irons SL, Benedetto CM, et al. Examination of the six minute walk test to determine functional capacity in people with chronic heart failure: a systematic review. Cardiopulm Phys Ther J. 2010;21:13-21.
22.  Guazzi M, Bandera F, Ozemek C, et al. Cardiopulmonary exercise testing: what is its value? J Am Coll Cardiol. 2017;70:1618-1636.
23.  Raphael C, Briscoe C, Davies J, et al. Limitations of the New York Heart Association functional classification system and self-reported walking distances in chronic heart failure. Heart. 2007;93:476-482.
24.  Parikh MN, Lund LH, Goda A, et al. Usefulness of peak exercise oxygen consumption and the heart failure survival score to predict survival in patients &gt;65 years of age with heart failure. Am J Cardiol. 2009;103:9981002.
25. Pohwani AL, Murali S, Mathier MM, et al. Impact of beta-blocker therapy on functional capacity criteria for heart transplant listing. J Heart Lung Transplant. 2003;22:78-86.
26.  Peterson LR, Schechtman KB, Ewald GA, et al. Timing of cardiac transplantation  in  patients  with  heart  failure  receiving  beta-adrenergic  blockers. J Heart Lung Transplant. 2003;22:1141-1148.
24. 27 .  Rostagno C, Olivo G, Comeglio M, et al. Prognostic value of 6-minute walk corridor test in patients with mild to moderate heart failure: comparison with other methods of functional evaluation. Eur J Heart Fail. 2003;5:247-252.
28. Balady GJ, Arena R, Sietsema K, et al. Clinician's guide to cardiopulmonary exercise testing in adults: a scientific statement from the American Heart Association. Circulation. 2010;122:191-225.

## 4.8. Initial and Serial Evaluation: Clinical Assessment: HF Risk Scoring

1.  Aaronson KD, Schwartz JS, Chen TM, et al. Development and prospective validation  of  a  clinical  index  to  predict  survival  in  ambulatory  patients  referred for cardiac transplant evaluation. Circulation. 1997;95:2660-2667.
2. Levy WC, Mozaffarian D, Linker DT, et al. The Seattle Heart Failure Model: prediction of survival in heart failure. Circulation. 2006;113:1424-1433.
3. Pocock SJ, Ariti  CA,  McMurray  JJ,  et  al.  Predicting  survival  in  heart  failure: a risk score based on 39 372 patients from 30 studies. Eur Heart J. 2013;34:1404-1413.
4. Pocock SJ, Wang D, Pfeffer MA, et al. Predictors of mortality and morbidity in patients with chronic heart failure. Eur Heart J. 2006;27:65-75.
5. Wedel H, McMurray JJ, Lindberg M, et al. Predictors of fatal and non-fatal outcomes in the Controlled Rosuvastatin Multinational Trial in Heart Failure (CORONA):  incremental  value  of  apolipoprotein  A-1,  high-sensitivity  Creactive peptide and N-terminal pro B-type natriuretic peptide. Eur J Heart Fail. 2009;11:281-291.
6.  Simpson J, Jhund PS, Lund LH, et al. Prognostic models derived in PARADIGM-HF and validated in ATMOSPHERE and the Swedish Heart Failure Registry to predict mortality  and  morbidity  in  chronic  heart  failure. JAMA Cardiol. 2020;5:432-441.
7. O'Connor CM, Whellan DJ, Wojdyla D, et al. Factors related to morbidity and mortality in patients with chronic heart failure with systolic dysfunction: the HF-ACTION predictive risk score model. Circ Heart Fail. 2012;5:63-71.
8.  O'Connor C, Fiuzat M, Mulder H, et al. Clinical factors related to morbidity and mortality in high-risk heart failure patients: the GUIDE-IT predictive model and risk score. Eur J Heart Fail. 2019;21:770-778.
9.  Komajda M, Carson PE, Hetzel S, et al. Factors associated with outcome in heart failure with preserved ejection fraction: findings from the Irbesartan in Heart Failure with Preserved Ejection Fraction Study (I-PRESERVE). Circ Heart Fail. 2011;4:27-35.
10. Angraal S, Mortazavi BJ, Gupta A, et al. Machine learning prediction of mortality and hospitalization in heart failure with preserved ejection fraction. J Am Coll Cardiol HF. 2020;8:12-21.
11.  Fonarow GC, Adams KF Jr, Abraham WT, et al. Risk stratification for inhospital mortality in acutely decompensated heart failure: classification and regression tree analysis. JAMA. 2005;293:572-580.
12. Peterson  PN,  Rumsfeld  JS,  Liang  L,  et  al.  A  validated  risk  score  for  inhospital mortality in patients with heart failure from the American Heart Association Get With The Guidelines program. Circ Cardiovasc Qual Outcomes. 2010;3:25-32.
13.  Lee DS, Austin PC, Rouleau JL, et al. Predicting mortality among patients hospitalized for heart failure: derivation and validation of a clinical model. JAMA. 2003;290:2581-2587.
14.  O'Connor CM, Hasselblad V, Mehta RH, et al. Triage after hospitalization with  advanced  heart  failure:  the  ESCAPE  (Evaluation  Study  of  Congestive Heart Failure and Pulmonary Artery Catheterization Effectiveness) risk model and discharge score. J Am Coll Cardiol. 2010;55:872-878.
15. University  of  Washington.  Seattle  Heart  Failure  Model.  2017 .  Accessed September 16, 2020. https://deptswashingtonedu/shfm/?width=1440&amp;h eight=900
16. Meta-AnalysisGlobalGroupinChronicHeartFailure  (MAGGIC).  Heart  Failure  Risk Calculator. Accessed September 16, 2020. http://wwwheartfailureriskorg/
17. 17 .  Fonarow GC. GWTG-heart failure risk score. 2021 Accessed September 29, 2021.https://wwwmdcalccom/gwtg-heart-failure-risk-score
18.  Canadian Cardiovascular Outcomes Research Team. EFFECT heart failure mortality prediction. 2016. Accessed September 16, 2020. http://wwwccortca/Research/CHFRiskModelhtml

## 5.1. Patients at Risk Factor for HF (Stage A-Primary Prevention)

1.  Beckett NS, Peters R, Fletcher AE, et al. Treatment of hypertension in patients 80 years of age or older. N Engl J Med. 2008;358:1887-1898.

2. Ettehad D, Emdin CA, Kiran A, et al. Blood pressure lowering for prevention of cardiovascular disease and death: a systematic review and meta-analysis. Lancet. 2016;387:957-967.
3. Kostis JB, Davis BR, Cutler J, et al. Prevention of heart failure by antihypertensive drug treatment in older persons with isolated systolic hypertension. SHEP Cooperative Research Group. JAMA. 1997;278:212-216.
4.  Staessen JA, Fagard R, Thijs L, et al. Randomised double-blind comparison of placebo and active treatment for older patients with isolated systolic hypertension. The Systolic Hypertension in Europe (Syst-Eur) Trial Investigators. Lancet . 1997;350:757-764.
5.  Thomopoulos C, Parati G, Zanchetti A. Effects of blood pressure-lowering treatment. 6. Prevention of heart failure and new-onset heart failure--metaanalyses of randomized trials. J Hypertens. 2016;34:373-384.
6.  Upadhya B, Rocco M, Lewis CE, et al. Effect of intensive blood pressure treatment on heart failure events in the Systolic Blood Pressure Reduction Intervention Trial. Circ Heart Fail. 2017;10:e003613.
7.  SPRINT Research Group, Wright JT Jr, Williamson JD, et al.  A  randomized trial of intensive versus standard blood-pressure control. N Engl J Med. 2015;373:2103-2116.
8.  Levy D, Larson MG, Vasan RS, et al. The progression from hypertension to congestive heart failure. JAMA. 1996;275:1557-1562.
9.  Butler J, Kalogeropoulos AP, Georgiopoulou VV, et al. Systolic blood pressure  and  incident  heart  failure  in  the  elderly.  The  Cardiovascular  Health Study  and  the  Health,  Ageing  and  Body  Composition  Study. Heart. 2011;97:1304-1311.
10. Neal B, Perkovic V, Mahaffey KW, et al. Canagliflozin and cardiovascular and renal events in type 2 diabetes. N Engl J Med. 2017;377:644-657.
11.  Wiviott SD, Raz I, Bonaca MP, et al. Dapagliflozin and cardiovascular outcomes in type 2 diabetes. N Engl J Med. 2019;380:347-357.
12. Zinman B, Wanner C, Lachin JM, et al. Empagliflozin, cardiovascular outcomes, and mortality in type 2 diabetes. N Engl J Med. 2015;373:2117-2128.
13.  Del Gobbo LC, Kalantarian S, Imamura F, et al. Contribution of major lifestyle risk factors for incident heart failure in older adults: the Cardiovascular Health Study. J Am Coll Cardiol HF. 2015;3:520-528.
14. Wang Y, Tuomilehto J, Jousilahti P, et al. Lifestyle factors in relation to heart failure among Finnish men and women. Circ Heart Fail. 2011;4:607-612.
15. Young DR, Reynolds K, Sidell M, et al. Effects of physical activity and sedentary time on the risk of heart failure. Circ Heart Fail. 2014;7:21-27.
16. Hu G, Jousilahti P, Antikainen R, et al. Joint effects of physical activity, body mass index, waist circumference, and waist-to-hip ratio on the risk of heart failure. Circulation. 2010;121:237-244.
16. 17 .  Folsom AR, Shah AM, Lutsey PL, et al. American Heart Association's Life's Simple 7: avoiding heart failure and preserving cardiac structure and function. Am J Med. 2015;128:970-976.e2.
18.  Tektonidis TG, Åkesson A, Gigante B, et al. Adherence to a Mediterranean diet is associated with reduced risk of heart failure in men. Eur J Heart Fail. 2016;18:253-259.
19.  Levitan EB, Wolk A, Mittleman MA. Consistency with the DASH diet and incidence of heart failure. Arch Intern Med. 2009;169:851-857.
20. Levitan EB, Wolk A, Mittleman MA. Relation of consistency with the dietary approaches to stop hypertension diet and incidence of heart failure in men aged 45 to 79 years. Am J Cardiol. 2009;104:1416-1420.
21. Lara  KM,  Levitan  EB,  Gutierrez  OM,  et  al.  Dietary  patterns  and  incident heart failure in US adults without known coronary disease. J Am Coll Cardiol. 2019;73:2036-2045.
22. Ledwidge M, Gallagher J, Conlon C, et al. Natriuretic peptide-based screening and collaborative care for heart failure: the STOP-HF randomized trial. JAMA. 2013;310:66-74.
23.  Huelsmann M, Neuhold S, Resl M, et al. PONTIAC (NT-proBNP selected prevention of cardiac events in a population of diabetic patients without a history of cardiac disease): a prospective randomized controlled trial. J Am Coll Cardiol. 2013;62:1365-1372.
24. Kannel WB, D'Agostino RB, Silbershatz H, et al. Profile for estimating risk of heart failure. Arch Intern Med. 1999;159:1197-1204.
25. Butler  J,  Kalogeropoulos  A,  Georgiopoulou  V,  et  al.  Incident  heart  failure prediction in the elderly: the health ABC heart failure score. Circ Heart Fail. 2008;1:125-133.
26. Agarwal  SK,  Chambless  LE,  Ballantyne  CM,  et  al.  Prediction  of  incident heart failure in general practice: the Atherosclerosis Risk in Communities (ARIC) Study. Circ Heart Fail. 2012;5:422-429.
26. 27 . Aggarwal M, Bozkurt B, Panjrath G, et al. Lifestyle modifications for preventing and treating heart failure. J Am Coll Cardiol. 2018;72:2391-2405.
28.  Arnett DK, Blumenthal RS, Albert MA, et al. 2019 ACC/AHA guideline on the primary prevention of cardiovascular disease: a report of the American

College of Cardiology/American Heart Association Task Force on Clinical Practice Guidelines. Circulation . 2019;140:e596-e646.

29. Khan SS, Ning H, Shah SJ, et al. 10-year risk equations for incident heart failure in the general population. J Am Coll Cardiol. 2019;73:2388-2397.
30.  Whelton PK, Carey RM, Aronow WS, et al. 2017 ACC/AHA/AAPA/ABC/ ACPM/AGS/APhA/ASH/ASPC/NMA/PCNA guideline for the prevention, detection, evaluation, and management of high blood pressure in adults: a report of the American College of Cardiology/American Heart Association Task  Force  on  Clinical  Practice  Guidelines. Hypertension .  2018;71:e13e115.
31. Zelniker TA, Wiviott SD, Raz I, et al. SGL T2 inhibitors for primary and secondary prevention of cardiovascular and renal outcomes in type 2 diabetes: a systematic review and meta-analysis of cardiovascular outcome trials. Lancet. 2019;393:31-39.
32.  Messerli FH, Rimoldi SF, Bangalore S. The transition from hypertension to heart failure: contemporary update. J Am Coll Cardiol HF. 2017;5:543-551.
33. Packer M, Anker SD, Butler J, et al. Effects of sodium-glucose cotransporter 2 inhibitors for the treatment of patients with heart failure: proposal of a novel mechanism of action. JAMA Cardiol. 2017;2:1025-1029.
34.  Verma S, McMurray JJV. SGLT2 inhibitors and mechanisms of cardiovascular benefit: a state-of-the-art review. Diabetologia. 2018;61:2108-2117.
35. Vardeny  O,  Vaduganathan  M.  Practical  guide  to  prescribing  sodium-glucose  cotransporter  2  inhibitors  for  cardiologists. J  Am  Coll  Cardiol  HF. 2019;7:169-172.
36.  Allen LA, Matlock DD, Shetterly SM, et al. Use of risk models to predict death in the next year among individual ambulatory patients with heart failure. JAMA Cardiol. 2017;2:435-441.
9. 37 . Liu Y, Chen PC, Krause J, et al. How to read articles that use machine learning: users' guides to the medical literature. JAMA. 2019;322:1806-1816.

## 6.1. Management of Stage B: Preventing the Syndrome of Clinical HF in Patients With Pre-HF

1. SOLVD Investigators. Effect of enalapril on mortality and the development of heart failure in asymptomatic patients with reduced left ventricular ejection fractions. N Engl J Med. 1992;327:685-691.
2. Pfeffer MA, Braunwald E, Moyé LA, et al. Effect of captopril on mortality and morbidity in patients with left ventricular dysfunction after myocardial infarction:  results  of  the  Survival  and  Ventricular  Enlargement  Trial. The  SAVE Investigators. N Engl J Med. 1992;327:669-677.
3. Jong P, Yusuf S, Rousseau MF, et al. Effect of enalapril on 12-year survival and life expectancy in patients with left ventricular systolic dysfunction: a follow-up study. Lancet. 2003;361:1843-1848.
4.  Køber L, Torp-Pedersen C, Carlsen JE, et al. A clinical trial of the angiotensin-converting-enzyme inhibitor trandolapril  in  patients  with  left ventricular dysfunction after myocardial infarction. Trandolapril Cardiac Evaluation  (TRACE)  Study  Group. N  Engl  J  Med. 1995;333:16701676.
5. Afilalo J, Majdan AA, Eisenberg MJ. Intensive statin therapy in acute coronary  syndromes and stable coronary heart disease: a comparative metaanalysis of randomised controlled trials. Heart. 2007;93:914-921.
6.  Heart Protection Study Collaborative GroupEmberson JR, Ng LL, et al. Nterminal Pro-B-type natriuretic peptide, vascular disease risk, and cholesterol reduction among 20 536 patients in the MRC/BHF heart protection study. J Am Coll Cardiol. 2007;49:311-319.
7.  Preiss D, Campbell RT, Murray HM, et al. The effect of statin therapy on heart failure events: a collaborative meta-analysis of unpublished data from major randomized trials. Eur Heart J. 2015;36:1536-1546.
8.  Scirica BM, Morrow DA, Cannon CP, et al. Intensive statin therapy and the risk of hospitalization for heart failure after an acute coronary syndrome in the PROVE IT-TIMI 22 study. J Am Coll Cardiol. 2006;47:2326-2331.
9.  Strandberg TE, Holme I, Faergeman O, et al. Comparative effect of atorvastatin (80 mg) versus simvastatin (20 to 40 mg) in preventing hospitalizations for heart failure in patients with previous myocardial infarction. Am J Cardiol. 2009;103:1381-1385.
10. Pfeffer MA, McMurray JJ, Velazquez EJ, et al. Valsartan, captopril, or both in myocardial infarction complicated by heart failure, left ventricular dysfunction, or both. N Engl J Med. 2003;349:1893-1906.
11.  Dargie HJ. Effect of carvedilol on outcome after myocardial infarction in patients with left-ventricular dysfunction: the CAPRICORN randomised trial. Lancet. 2001;357:1385-1390.
12.  Exner DV, Dries DL, Waclawiw MA, et al. Beta-adrenergic blocking agent use and mortality in patients with asymptomatic and symptomatic left ven-

- tricular systolic dysfunction: a post hoc analysis of the studies of left ventricular dysfunction. J Am Coll Cardiol. 1999;33:916-923.
13. Vantrimpont  P,  Rouleau  JL,  Wun  CC,  et  al.  Additive  beneficial  effects  of beta-blockers  to  angiotensin-converting  enzyme  inhibitors  in  the  Survival and Ventricular Enlargement (SAVE) Study. SAVE Investigators. J Am Coll Cardiol. 1997;29:229-236.
14. Moss AJ, Zareba W, Hall WJ, et al. Prophylactic implantation of a defibrillator in patients with myocardial infarction and reduced ejection fraction. N Engl J Med. 2002;346:877-883.
15. Dargie  HJ,  Hildebrandt  PR,  Riegger  GA,  et  al.  A  randomized,  placebocontrolled trial assessing the effects of rosiglitazone on echocardiographic  function  and  cardiac  status  in  type  2  diabetic  patients  with  New  Y ork Heart Association Functional class I or II heart failure. J Am Coll Cardiol. 2007;49:1696-1704.
16. Multicenter Diltiazem Postinfarction Trial Research Group. The effect of diltiazem  on  mortality  and  reinfarction  after  myocardial  infarction. N Engl J Med. 1988;319:385-392.
- 17 . Goldstein RE, Boccuzzi SJ, Cruess D, et al. Diltiazem increases late-onset congestive  heart  failure  in  postinfarction  patients  with  early  reduction  in ejection fraction. Circulation. 1991;83:52-60.
18.  Ammar KA, Jacobsen SJ, Mahoney DW, et al. Prevalence and prognostic significance of heart failure stages: application of the American College of Cardiology/American Heart Association heart failure staging criteria in the community. Circulation. 2007;115:1563-1570.
19.  Shah AM, Claggett B, Loehr LR, et al. Heart failure stages among older adults  in  the  community:  the  Atherosclerosis  Risk  in  Communities  study. Circulation . 2017;135:224-240.
20.  Wang Y, Yang H, Huynh Q, et al. Diagnosis of nonischemic stage B heart failure in type 2 diabetes mellitus: optimal parameters for prediction of heart failure. J Am Coll Cardiol Img. 2018;11:1390-1400.
21.  Xanthakis V, Enserro DM, Larson MG, et al. Prevalence, neurohormonal correlates, and prognosis of heart failure stages in the community. J Am Coll Cardiol HF. 2016;4:808-815.
22. Al Saikhan L, Park C, Hardy R, et al. Prognostic implications of left ventricular strain by speckle-tracking echocardiography in the general population: a meta-analysis. Vasc Health Risk Manag. 2019;15:229-251.
23.  Biering-Sorensen T, Biering-Sorensen SR, Olsen FJ, et al. Global longitudinal strain by echocardiography predicts long-term risk of cardiovascular morbidity and mortality in a low-risk general population: the Copenhagen City Heart Study. Circ Cardiovasc Imaging. 2017;10:e005521.
24.  Echouffo-Tcheugui JB, Erqou S, Butler J, et al. Assessing the risk of progression  from  asymptomatic  left  ventricular  dysfunction  to  overt  heart failure:  a  systematic  overview  and  meta-analysis. J  Am  Coll  Cardiol  HF. 2016;4:237-248.
25. Wang  TJ,  Evans  JC,  Benjamin  EJ,  et  al.  Natural  history  of  asymptomatic  left  ventricular  systolic  dysfunction  in  the  community. Circulation. 2003;108:977-982.
26.  Yang H, Negishi K, Wang Y, et al. Echocardiographic screening for nonischaemic  stage  B  heart  failure  in  the  community. Eur  J  Heart  Fail. 2016;18:1331-1339.
- 27 .  Echouffo-Tcheugui JB, Erqou S, Butler J, et al. Assessing the risk of progression  from  asymptomatic  left  ventricular  dysfunction  to  overt  heart failure:  a  systematic  overview  and  meta-analysis. J  Am  Coll  Cardiol  HF. 2016;4:237-248.
28.  From AM, Scott CG, Chen HH. The development of heart failure in patients with  diabetes  mellitus  and  pre-clinical  diastolic  dysfunction  a  populationbased study. J Am Coll Cardiol. 2010;55:300-305.
29.  Kane GC, Karon BL, Mahoney DW, et al. Progression of left ventricular diastolic dysfunction and risk of heart failure. JAMA. 2011;306:856-863.
30.  Kosmala W, Sanders P, Marwick TH. Subclinical myocardial impairment in metabolic diseases. J Am Coll Cardiol Img. 2017;10:692-703.
31. Holland DJ, Marwick TH, Haluska BA, et al. Subclinical L V dysfunction and 10-year  outcomes  in  type  2  diabetes  mellitus. Heart. 2015;101:10611066.
32. Beygui F, Cayla G, Roule V, et al. Early aldosterone blockade in acute myocardial infarction: the ALBATROSS randomized clinical trial. J Am Coll Cardiol. 2016;67:1917-1927.
33. Montalescot G, Pitt B, Lopez de Sa E, et al. Early eplerenone treatment in patients with acute ST-elevation myocardial infarction without heart failure: the Randomized Double-Blind Reminder Study. Eur Heart J. 2014;35:22952302.
34. Pitt B, Remme W, Zannad F, et al. Eplerenone, a selective aldosterone blocker, in patients with left ventricular dysfunction after myocardial infarction. N Engl J Med. 2003;348:1309-1321.
35. Jering KS, Claggett B, Pfeffer MA, et al. Prospective ARNI vs. ACE inhibitor trial to DetermIne Superiority in reducing heart failure Events after Myocardial Infarction (PARADISE-MI): design and baseline characteristics. Eur J Heart Fail. 2021;23:1040-1048.
36.  Pfeffer MA, Lamas GA, Vaughan DE, et al. Effect of captopril on progressive ventricular dilatation after anterior myocardial infarction. N Engl J Med. 1988;319:80-86.
- 37 . Sharpe N, Murphy J, Smith H, et al. Treatment of patients with symptomless left ventricular dysfunction after myocardial infarction. Lancet. 1988;1:255259.
38.  Velazquez EJ, Pfeffer MA, McMurray JV, et al. VALsartan In Acute myocardial  iNfarcTion  (VALIANT)  trial:  baseline  characteristics  in  context. Eur  J Heart Fail. 2003;5:537-544.
39.  Dickstein K, Kjekshus JOPTIMAAL Steering Committee of the OPTIMAAL Study Group. Effects of losartan and captopril on mortality and morbidity in high-risk patients after acute myocardial infarction: the OPTIMAAL randomised trial. Optimal Trial in Myocardial Infarction with Angiotensin II Antagonist Losartan. Lancet . 2002;360:752-760.
40.  Mann DL, Deswal A.  Angiotensin-receptor  blockade  in  acute  myocardial infarction--a matter of dose. N Engl J Med. 2003;349:1963-1965.
41. Doughty RN, Whalley GA, Walsh HA, et al. Effects of carvedilol on left ventricular remodeling after acute myocardial infarction: the CAPRICORN Echo Substudy. Circulation. 2004;109:201-206.
42.  Grundy SM, Stone NJ, Bailey AL, et al. 2018 AHA/ACC/AACVPR/AAPA/ ABC/ACPM/ADA/AGS/APhA/ASPC/NLA/PCNA guideline  on  the  management of blood cholesterol: a report of the American College of Cardiology/American Heart Association Task Force on Clinical Practice Guidelines. Circulation . 2019;139:e1082-e1143.
43. Colucci WS, Kolias T J, Adams KF, et al. Metoprolol reverses left ventricular remodeling in patients with asymptomatic systolic dysfunction: the REversal  of  VEntricular  Remodeling  with  Toprol-XL  (REVERT)  trial. Circulation. 2007;116:49-56.
44.  Cleland JGF, Bunting KV, Flather MD, et al. Beta-blockers for heart failure  with  reduced,  mid-range,  and  preserved  ejection  fraction:  an  individual  patient-level  analysis  of  double-blind  randomized  trials. Eur  Heart  J. 2018;39:26-35.
45. Figulla  HR,  Gietzen  F,  Zeymer  U,  et  al.  Diltiazem  improves  cardiac  function  and  exercise  capacity  in  patients  with  idiopathic  dilated  cardiomyopathy. Results of the diltiazem in dilated cardiomyopathy trial. Circulation . 1996;94:346-352.
46.  Effect of verapamil on mortality and major events after acute myocardial infarction (the Danish Verapamil Infarction Trial II--DAVIT II). Am J Cardiol. 1990;66:779-785.
- 47 . Erdmann E,  Charbonnel  B,  Wilcox  RG,  et  al.  Pioglitazone  use  and  heart failure  in  patients  with  type  2  diabetes  and  preexisting  cardiovascular disease:  data  from  the  PROactive  study  (PROactive  08). Diabetes  Care. 2007;30:2773-2778.
48.  Komajda M, McMurray JJ, Beck-Nielsen H, et al. Heart failure events with rosiglitazone in type 2 diabetes: data from the RECORD clinical trial. Eur Heart J. 2010;31:824-831.
49.  Lago RM, Singh PP, Nesto RW. Congestive heart failure and cardiovascular death in patients with prediabetes and type 2 diabetes given thiazolidinediones: a meta-analysis of randomised clinical trials. Lancet. 2007;370:11291136.
50. Giles TD, Miller AB, Elkayam U, et al. Pioglitazone and heart failure: results from a controlled study in patients with type 2 diabetes mellitus and systolic dysfunction. J Card Fail. 2008;14:445-452.
51.  O'Gara PT, Kushner FG, Ascheim DD, et al. 2013 ACCF/AHA guideline for the management of ST-elevation myocardial infarction: a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Circulation . 2013;127:e362-e42.
52.  Amsterdam EA, Wenger NK, Brindis RG, et al. 2014 AHA/ACC guideline for the management of patients with non-ST-elevation acute coronary syndromes: a report of the American College of Cardiology/American Heart Association Task Force on Practice Guidelines. Circulation .  2014;130:e344e426.
53.  Levine GN, Bates ER, Blankenship JC, et al. 2015 ACC/AHA/SCAI focused update on primary percutaneous coronary intervention for patients with  ST-elevation  myocardial  infarction:  an  update  of  the  2011  ACCF/ AHA/SCAI guideline for percutaneous coronary intervention and the 2013 ACCF/AHA guideline for the management of ST-elevation myocardial infarction. Circulation . 2016;133:1135-1147.
54.  Lawton JS, Tamis-Holland JE, Bangalore S, et al. 2021 ACC/AHA/SCAI guideline for coronary artery revascularization: a report of the American Col-

lege of Cardiology/American Heart Association Joint Committee on Clinical Practice Guidelines. Circulation . 2022;145:e18-e114.

55.  Fihn  SD,  Blankenship  JC,  Alexander  KP,  et  al.  2014  ACC/AHA/AATS/ PCNA/SCAI/STS focused update of the guideline for the diagnosis and management of patients with stable ischemic heart disease: a report of the American College of Cardiology/American Heart Association Task Force on Practice Guidelines, and the American Association for Thoracic Surgery, Preventive Cardiovascular Nurses Association, Society for Cardiovascular Angiography and Interventions, and Society of Thoracic Surgeons. Circulation . 2014;130:1749-1767.
56. Hillis  LD,  Smith  PK,  Anderson  JL,  et  al.  2011  ACCF/AHA  guideline  for coronary artery bypass graft surgery. a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Developed in collaboration with the American Association for Thoracic Surgery, Society of Cardiovascular Anesthesiologists, and Society of Thoracic Surgeons. Circulation . 2011;124:e652-e735.
3. 57 .  Nishimura RA, Otto CM, Bonow RO, et al. 2017 AHA/ACC focused update of the 2014 AHA/ACC guideline for the management of patients with valvular heart disease: a report of the American College of Cardiology/American Heart Association Task Force on Clinical Practice Guidelines. Circulation . 2017;135:e1159-e1195.
58.  Otto CM, Nishimura RA, Bonow RO, et al. 2020 ACC/AHA guideline for the management of patients with valvular heart disease: a report of the American College of Cardiology/American Heart Association Joint Committee on Clinical Practice Guidelines. Circulation . 2021;143:e72-e227.
59.  Stout KK, Daniels CJ, Aboulhosn JA, et al. 2018 AHA/ACC guideline for the management of adults with congenital heart disease: a report of the American College of Cardiology/American Heart Association Task Force on Clinical Practice Guidelines. Circulation . 2019;139:e698-e800.

## 7.1.1. Self-Care Support in HF

1. Holland R, Battersby J, Harvey I, et al. Systematic review of multidisciplinary interventions in heart failure. Heart. 2005;91:899-906.
2. McAlister FA, Stewart S, Ferrua S, et al. Multidisciplinary strategies for the management of heart failure patients at high risk for admission: a systematic review of randomized trials. J Am Coll Cardiol. 2004;44:810-819.
3. Parajuli DR, Kourbelis C, Franzon J, et al. Effectiveness of the pharmacistinvolved multidisciplinary management of heart failure to improve hospitalizations and mortality rates in 4630 patients: a systematic review and metaanalysis of randomized controlled trials. J Card Fail. 2019;25:744-756.
4. Takeda A, Martin N, Taylor RS, Taylor SJ. Disease management interventions for heart failure. Cochrane Database Syst Rev. 2019;1:CD002752.
5.  Jonkman NH, Westland H, Groenwold RH, et al. Do self-management interventions work in patients with heart failure? An individual patient data meta-analysis. Circulation. 2016;133:1189-1198.
6. Inglis SC, Clark RA, Dierckx R, et al. Structured telephone support or noninvasive telemonitoring for patients with heart failure. Cochrane Database Syst Rev. 2015:CD007228.
7. Inglis  SC,  Clark  RA,  McAlister  FA,  et  al.  Structured  telephone  support  or telemonitoring programmes for patients with chronic heart failure. Cochrane Database Syst Rev. 2010:CD007228.
8.  Jovicic A, Holroyd-Leduc JM, Straus SE. Effects of self-management intervention on health outcomes of patients with heart failure: a systematic review of randomized controlled trials. BMC Cardiovasc Disord. 2006;6:43.
9.  Ruppar TM, Cooper PS, Mehr DR, et al. Medication adherence interventions improve heart failure mortality and readmission rates: systematic review and meta-analysis of controlled trials. J Am Heart Assoc. 2016;5:e002606.
10. Butt  AA,  Omer  SB,  Yan  P,  et  al.  SARS-CoV-2  vaccine  effectiveness  in a  high-risk  national  population  in  a  real-world  setting. Ann  Intern  Med. 2021;174:1404-1408.
11. Gotsman I, Shuvy M, Tahiroglu I, et al. Influenza vaccination and outcome in heart failure. Am J Cardiol. 2020;128:134-139.
12. Modin D, Jorgensen ME, Gislason G, et al. Influenza vaccine in heart failure. Circulation. 2019;139:575-586.
13. Mohseni H, Kiran A, Khorshidi R, et al. Influenza vaccination and risk of hospitalization in patients with heart failure: a self-controlled case series study. Eur Heart J. 2017;38:326-333.
14. Vardeny  O,  Claggett  B,  Udell  JA,  et  al.  Influenza  vaccination  in  patients with chronic heart failure: the PARADIGM-HF trial. J Am Coll Cardiol HF. 2016;4:152-158.
15.  Yedlapati SH, Khan SU, Talluri S, et al. Effects of influenza vaccine on mortality  and  cardiovascular  outcomes  in  patients  with  cardiovascular  disease: a systematic review and meta-analysis. J Am Heart Assoc. 2021;10:e019636.
16.  Ahmed MB, Patel K, Fonarow GC, et al. Higher risk for incident heart failure and cardiovascular mortality among community-dwelling octogenarians without pneumococcal vaccination. ESC Heart Fail. 2016;3:11-17.
17. 17 .  Freedland KE, Carney RM, Rich MW, et al. Depression and multiple rehospitalizations in patients with heart failure. Clin Cardiol. 2016;39:257-262.
18.  Freedland KE, Hesseler MJ, Carney RM, et al. Major depression and longterm survival of patients with heart failure. Psychosom Med. 2016;78:896903.
19. Murberg TA. Long-term effect of social relationships on mortality in patients with congestive heart failure. Int J Psychiatry Med. 2004;34:207-217.
20. Murberg TA, Bru E. Social relationships and mortality in patients with congestive heart failure. J Psychosom Res. 2001;51:521-527.
21.  Heidari Gorji MA, Fatahian A, Farsavian A. The impact of perceived and objective social isolation on hospital readmission in patients with heart failure: a systematic review and meta-analysis of observational studies. Gen Hosp Psychiatry. 2019;60:27-36.
22.  Gallagher R, Luttik ML, Jaarsma T. Social support and self-care in heart failure. J Cardiovasc Nurs. 2011;26:439-445.
23. Uchmanowicz I, Lee CS, Vitale C, et al. Frailty and the risk of all-cause mortality and hospitalization in chronic heart failure: a meta-analysis. ESC Heart Fail. 2020;7:3427-3437.
24.  Uchmanowicz I, Wleklik M, Gobbens RJ. Frailty syndrome and self-care ability in elderly patients with heart failure. Clin Interv Aging. 2015;10:871-877.
25.  Fabbri M, Murad MH, Wennberg AM, et al. Health literacy and outcomes among patients with heart failure: a systematic review and meta-analysis. J Am Coll Cardiol HF. 2020;8:451-460.
26. Macabasco-O'Connell  A,  DeWalt  DA,  Broucksou  KA,  et  al.  Relationship between  literacy,  knowledge,  self-care  behaviors,  and  heart  failure-related  quality  of  life  among  patients  with  heart  failure. J  Gen  Intern  Med. 2011;26:979-986.
27. 27 .  Bellam N, Kelkar AA, Whellan DJ. Team-based care for managing cardiac comorbidities in heart failure. Heart Fail Clin. 2015;11:407-417.
28.  Creaser JW, DePasquale EC, Vandenbogaart E, et al. Team-based care for outpatients with heart failure. Heart Fail Clin. 2015;11:379-405.
29.  Vader JM, Rich MW. Team-based care for managing noncardiac conditions in patients with heart failure. Heart Fail Clin. 2015;11:419-429.
30.  Wever-Pinzon O, Drakos SG, Fang JC. Team-based care for advanced heart failure. Heart Fail Clin. 2015;11:467-477.
31. Davidson  PM,  Newton  PJ,  Tankumpuan  T,  et  al.  Multidisciplinary  management of chronic  heart  failure:  principles  and  future  trends. Clin  Ther. 2015;37:2225-2233.
32.  Grady KL, Dracup K, Kennedy G, et al. Team management of patients with heart  failure:  a  statement  for  healthcare  professionals  from  the  Cardiovascular  Nursing  Council  of  the  American  Heart  Association. Circulation. 2000;102:2443-2456.
33.  Cooper LB, Hernandez AF. Assessing the quality and comparative effectiveness of team-based care for heart failure: who, what, where, when, and how. Heart Fail Clin. 2015;11:499-506.
34.  Riegel B, Moser DK, Anker SD, et al. State of the science: promoting selfcare in persons with heart failure: a scientific statement from the American Heart Association. Circulation. 2009;120:1141-1163.
35.  Riegel B, Moser DK, Buck HG, et al. Self-care for the prevention and management of cardiovascular disease and stroke: a scientific statement for healthcare professionals from the American Heart Association. J Am Heart Assoc. 2017;6:e006997.
36. Moser DK, Dickson V, Jaarsma T, et al. Role of self-care in the patient with heart failure. Curr Cardiol Rep. 2012;14:265-275.
37. 37 . Riegel B, Lee CS, Dickson VV, et al. Self care in patients with chronic heart failure. Nat Rev Cardiol. 2011;8:644-654.
38. Hwang  B,  Moser  DK,  Dracup  K.  Knowledge  is  insufficient  for  self-care among heart  failure  patients  with  psychological  distress. Health  Psychol. 2014;33:588-596.
39. Allida S, Du H, Xu X, et al. mHealth education interventions in heart failure. Cochrane Database Syst Rev. 2020;7:CD011845.
40.  Hwang B, Pelter MM, Moser DK, Dracup K. Effects of an educational intervention on heart failure knowledge, self-care behaviors, and health-related quality of life of patients with heart failure: exploring the role of depression. Patient Educ Couns. 2020;103:1201-1208.
41.  Dracup K, Moser DK, Pelter MM, et al. Randomized, controlled trial to improve self-care in patients with heart failure living in rural areas. Circulation. 2014;130:256-264.
42. Van Spall HGC, Lee SF, Xie F, et al. Effect of patient-centered transitional care services on clinical outcomes in patients hospitalized for heart failure: the PACT-HF randomized clinical trial. JAMA. 2019;321:753-761.

43.  Mohseni Z, Spaanderman MEA, Oben J, et al. Cardiac remodeling and preeclampsia: an overview of microRNA expression patterns. Ultrasound Obstet Gynecol. 2018;52:310-317.
44.  Bhatt AS, Adler ED, Albert NM, et al. Coronavirus disease-2019 and heart failure: a scientific statement from the Heart Failure Society of America. J Card Fail. 2021;S1071-9164(21):00354-00357.
45. Bhatt  AS,  Jering  KS,  Vaduganathan  M,  et  al.  Clinical  outcomes  in  patients with heart failure hospitalized with COVID-19. J Am Coll Cardiol HF. 2021;9:65-73.
46.  Cannata A, Bromage DI, Rind IA, et al. Temporal trends in decompensated heart failure and outcomes during COVID-19: a multisite report from heart failure referral centres in London. Eur J Heart Fail. 2020;22:2219-2224.
5. 47 . Tomasoni  D,  Inciardi  RM,  Lombardi  CM,  et  al.  Impact  of  heart  failure  on the  clinical  course  and  outcomes  of  patients  hospitalized  for  COVID-19. Results  of  the  Cardio-COVID-Italy  multicentre  study. Eur  J  Heart  Fail. 2020;22:2238-2247.
48. Patel A, Parikh R, Howell EH, et al. Mini-cog performance: novel marker of post discharge risk among patients hospitalized for heart failure. Circ Heart Fail. 2015;8:8-16.
49.  Lovell J, Pham T, Noaman SQ, et al. Self-management of heart failure in dementia and cognitive impairment: a systematic review. BMC Cardiovasc Disord. 2019;19:99.
50. Cannon  JA,  Moffitt  P,  Perez-Moreno  AC,  et  al.  Cognitive  impairment and  heart  failure:  systematic  review  and  meta-analysis. J Card  Fail. 2017;23:464-475.
51. Sbolli M, Fiuzat M, Cani D, et al. Depression and heart failure: the lonely comorbidity. Eur J Heart Fail. 2020;22:2007-2017.
52.  Zambrano J, Celano CM, Januzzi JL, et al. Psychiatric and psychological interventions for depression in patients with heart disease: a scoping review. J Am Heart Assoc. 2020;9:e018686.
53. Nishimura M, Bhatia H, Ma J, et al. The impact of substance abuse on heart failure hospitalizations. Am J Med. 2020;133:207-213.e1.
54. Fried LP, Tangen CM, Walston J, et al. Frailty in older adults: evidence for a phenotype. J Gerontol A Biol Sci Med Sci. 2001;56:M146-M156.
55.  Smith GH, Shore S, Allen LA, et al. Discussing out-of-pocket costs with patients: shared decision making for sacubitril-valsartan in heart failure. J Am Heart Assoc. 2019;8:e010635.
56. Sun Y, Liu B, Rong S, et al. Food insecurity is associated with cardiovascular and all-cause mortality among adults in the United States. J Am Heart Assoc. 2020;9:e014629.
15. 57 .  Makelarski JA, Abramsohn E, Benjamin JH, et al. Diagnostic accuracy of two food insecurity screeners recommended for use in health care settings. Am J Public Health. 2017;107:1812-1817.
58.  Sims M, Kershaw KN, Breathett K, et al. Importance of housing and cardiovascular health and well-being: a scientific statement from the American Heart Association. Circ Cardiovasc Qual Outcomes. 2020;13:e000089.
59. Jayawardana  S,  Mossialos  E.  Lives  cut  short:  socioeconomic  inequities, homelessness, and cardiovascular disease. Eur  Heart  J. 2020;41:40214023.
60.  Baggett TP, Liauw SS, Hwang SW. Cardiovascular disease and homelessness. J Am Coll Cardiol. 2018;71:2585-2597.
61. US Preventive Services Task Force. Screening for intimate partner violence, elder abuse, and abuse of vulnerable adults: US Preventive Services Task Force Final Recommendation Statement. JAMA. 2018;320:1678-1687.
62.  Chandan JS, Thomas T, Bradbury-Jones C, et al. Risk of cardiometabolic disease and all-cause mortality in female survivors of domestic abuse. J Am Heart Assoc. 2020;9:e014580.
63.  Rawal S, Srighanthan J, Vasantharoopan A, et al. Association between limited English proficiency and revisits and readmissions after hospitalization for patients with acute and chronic conditions in Toronto, Ontario, Canada. JAMA. 2019;322:1605-1607.
64.  Magnani JW, Mujahid MS, Aronow HD, et al. Health literacy and cardiovascular disease: fundamental relevance to primary and secondary prevention: a  scientific  statement  from  the  American  Heart  Association. Circulation. 2018;138:e48-e74.
65. Manemann SM,  Chamberlain  AM,  Roger  VL,  et  al.  Perceived  social  isolation  and  outcomes  in  patients  with  heart  failure. J  Am  Heart  Assoc. 2018;7:e008069.

## 7.1.2. Dietary Sodium Restriction

1. Philipson H, Ekman I, Forslund HB, et al. Salt and fluid restriction is effective in patients with chronic heart failure. Eur J Heart Fail. 2013;15:1304-1310.
2. Doukky R, Avery E, Mangla A, et al. Impact of dietary sodium restriction on heart failure outcomes. J Am Coll Cardiol HF . 2016;4:24-35.
3.  Kalogeropoulos A, Papadimitriou L, Georgiopoulou VV, et al. Low- versus moderate-sodium diet in patients with recent hospitalization for heart failure: the PROHIBIT (Prevent Adverse Outcomes in Heart Failure by Limiting Sodium) pilot study. Circ Heart Fail. 2020;13:e006389.
4. Colin-Ramirez E, McAlister FA, Zheng Y, et al. The long-term effects of dietary sodium restriction on clinical outcomes in patients with heart failure. The SODIUM-HF (Study of Dietary Intervention Under 100 mmol in Heart Failure): a pilot study. Am Heart J. 2015;169:274-281.e1.
5. Colin-Ramirez E, McAlister FA, Zheng Y, et al. Changes in dietary intake and nutritional status associated with a significant reduction in sodium intake in patients with heart failure. A sub-analysis of the SODIUM-HF pilot study. Clin Nutr ESPEN. 2016;11:e26-e32.
6.  Hummel SL, Karmally W, Gillespie BW, et al. Home-delivered meals postdischarge from heart failure hospitalization. Circ Heart Fail. 11;2018:e004886.
7.  Yancy CW, Jessup M, Bozkurt B, et al. 2013 ACCF/AHA guideline for the management of heart failure: a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Circulation . 2013;128:e240-e327.
8. Yancy CW. The uncertainty of sodium restriction in heart failure: we can do better than this. J Am Coll Cardiol HF. 2016;4:39-41.
9. Yancy CW. Sodium restriction in heart failure: too much uncertainty-do the trials. JAMA Intern Med. 2018;178:1700-1701.
10. Francis GS. Notice of concern. J Card Fail. 2013;19:523.
11. Alexopoulos D, Moulias A, Koutsogiannis N, et al. Differential effect of ticagrelor versus prasugrel on coronary blood flow velocity in patients with non-ST-elevation acute coronary syndrome undergoing percutaneous coronary intervention: an exploratory study. Circ Cardiovasc Interv . 2013;6:277283.
12.  Van Horn L, Carson JA, Appel LJ, et al. Recommended dietary pattern to achieve adherence to the American Heart Association/American College of Cardiology (AHA/ACC) guidelines: a scientific statement from the American Heart Association. Circulation. 2016;134:e505-e529.
13.  Mahtani KR, Heneghan C, Onakpoya I, et al. Reduced salt intake for heart failure: a systematic review. JAMA Intern Med. 2018;178:1693-1700.
14. Jefferson K, Ahmed M, Choleva M, et al. Effect of a sodium-restricted diet on intake of other nutrients in heart failure: implications for research and clinical practice. J Card Fail. 2015;21:959-962.
15.  Lennie TA, Andreae C, Rayens MK, et al. Micronutrient deficiency independently predicts time to event in patients with heart failure. J Am Heart Assoc. 2018;7:e007251.
16.  Bonilla-Palomas JL, Gámez-López AL, Castillo-Domínguez JC, et al. Nutritional intervention in malnourished hospitalized patients with heart failure. Arch Med Res. 2016;47:535-540.
17. 17 . Bilgen F, Chen P, Poggi A, et al. Insufficient calorie intake worsens postdischarge quality of life and increases readmission burden in heart failure. J Am Coll Cardiol HF . 2020;8:756-764.
18. Lewis GD, Malhotra R, Hernandez AF, et al. Effect of oral iron repletion on exercise capacity in patients with heart failure with reduced ejection fraction and iron deficiency: the IRONOUT HF randomized clinical trial. JAMA. 2017;317:1958-1966.
19.  Keith M, Quach S, Ahmed M, et al. Thiamin supplementation does not improve left ventricular ejection fraction in ambulatory heart failure patients: a randomized controlled trial. Am J Clin Nutr. 2019;110:1287-1295.
20. Rosenblum H, Wessler JD, Gupta A, et al. Zinc deficiency and heart failure: a systematic review of the current literature. J Card Fail. 2020;26:180-189.
21. Wang T, Liu Z, Fu J, Min Z. Meta-analysis of vitamin D supplementation in the treatment of chronic heart failure. Scand Cardiovasc J. 2019;53:110-116.
22.  McKeag NA, McKinley MC, Harbinson MT, et al. The effect of multiple micronutrient supplementation on left ventricular ejection fraction in patients with chronic stable heart failure: a randomized, placebo-controlled trial. J Am Coll Cardiol HF. 2014;2:308-317.
23.  Ò Miró, Estruch R, Martín-Sánchez FJ, et al. Adherence to Mediterranean diet and all-cause mortality after an episode of acute heart failure: results of the MEDIT-AHF study. J Am Coll Cardiol HF. 2018;6:52-62.
24. Aliti GB, Rabelo ER, Clausell N, et al. Aggressive fluid and sodium restriction in acute decompensated heart failure: a randomized clinical trial. JAMA Intern Med. 2013;173:1058-1064.
25. Machado  d'Almeida  KS,  Rabelo-Silva  ER,  Souza  GC,  et  al.  Aggressive fluid  and  sodium  restriction  in  decompensated  heart  failure  with  preserved ejection fraction: results from a randomized clinical trial. Nutrition. 2018;54:111-117.
26.  Welsh D, Lennie TA, Marcinek R, et al. Low-sodium diet self-management intervention  in  heart  failure:  pilot  study  results. Eur  J  Cardiovasc  Nurs. 2013;12:87-95.

## 7.1.3. Management of Stage C HF: Activity, Exercise Prescription, and Cardiac Rehabilitation

1.  O'Connor CM, Whellan DJ, Lee KL, et al. Efficacy and safety of exercise training in patients with chronic heart failure: HF-ACTION randomized controlled trial. JAMA. 2009;301:1439-1450.
2. Davies  EJ,  Moxham  T,  Rees  K,  et  al.  Exercise  training  for  systolic  heart failure:  Cochrane  systematic  review  and  meta-analysis. Eur  J  Heart  Fail. 2010;12:706-715.
3.  Haykowsky  MJ,  Timmons  MP,  Kruger  C,  et  al.  Meta-analysis  of  aerobic  interval  training  on  exercise  capacity  and  systolic  function  in  patients  with  heart  failure  and  reduced  ejection  fractions. Am  J  Cardiol. 2013;111:1466-1469.
4.  Santos FV, Chiappa GR, Ramalho SHR, et al. Resistance exercise enhances oxygen  uptake  without  worsening  cardiac  function  in  patients  with  systolic  heart  failure:  a  systematic  review  and  meta-analysis. Heart Fail Rev. 2018;23:73-89.
5. Taylor RS, Walker S, Smart NA, et al. Impact of exercise rehabilitation on exercise  capacity  and  quality-of-life  in  heart  failure:  individual  participant meta-analysis. J Am Coll Cardiol. 2019;73:1430-1443.
6.  Sagar  VA,  Davies  EJ,  Briscoe  S,  et  al.  Exercise-based  rehabilitation for  heart  failure:  systematic  review  and  meta-analysis. Open  Heart. 2015;2:e000163.
7. Piepoli  MF,  Davos  C,  Francis  DP,  Coats  AJ.  Exercise  training  meta-analysis  of  trials  in  patients  with  chronic  heart  failure  (ExTraMATCH). BMJ. 2004;328:189.
8. Taylor RS, Sagar VA, Davies EJ, et al. Exercise-based rehabilitation for heart failure. Cochrane Database Syst Rev. 2014:CD003331.
9.  Kitzman DW,  Whellan DJ, Duncan  P, et al. Physical rehabilitation  for  older  patients  hospitalized  for  heart  failure. N  Engl  J  Med. 2021;385:203-216.
10. Pina IL, Apstein CS, Balady GJ, et al. Exercise and heart failure: a statement from the American Heart Association Committee on Exercise, Rehabilitation, and Prevention. Circulation. 2003;107:1210-1225.
11.  Forman DE, Sanderson BK, Josephson RA, et al. Heart failure as a newly approved diagnosis for cardiac rehabilitation: challenges and opportunities. J Am Coll Cardiol. 2015;65:2652-2659.
12. McKelvie RS. Exercise training in patients with heart failure: clinical  outcomes, safety, and indications. Heart Fail Rev. 2008;13:3-11.
13. Achttien RJ, Staal JB, van der Voort S, et al. Exercise-based cardiac rehabilitation in patients with chronic heart failure: a Dutch practice guideline. Neth Heart J. 2015;23:6-17.
14. Davies EJ, Moxham T, Rees K, et al. Exercise based rehabilitation for heart failure. Cochrane Database Syst Rev . 2010:CD003331.
15.  Long  L,  Mordi  IR,  Bridges  C,  et  al.  Exercise-based  cardiac  rehabilitation  for  adults  with  heart  failure. Cochrane  Database  Syst  Rev. 2019;1:CD003331.
16. Fukuta H, Goto T, Wakami K, et al. Effects of exercise training on cardiac function, exercise capacity, and quality of life in heart failure with preserved ejection fraction: a meta-analysis of randomized controlled trials. Heart Fail Rev. 2019;24:535-547.
17. 17 . Dieberg G, Ismail H, Giallauria F, et al. Clinical outcomes and cardiovascular responses to exercise training in heart failure patients with preserved ejection fraction: a systematic review and meta-analysis. J Appl Physiol (1985). 2015;119:726-733.
18. Kitzman  DW,  Brubaker  PH,  Morgan  TM,  et  al.  Exercise  training  in  older patients  with  heart  failure  and  preserved  ejection  fraction:  a  randomized, controlled, single-blind trial. Circ Heart Fail. 2010;3:659-667.
19.  Edelmann  F,  Gelbrich  G,  Dungen  HD,  et  al.  Exercise  training  improves  exercise  capacity  and  diastolic  function  in  patients  with  heart failure  with  preserved  ejection  fraction:  results  of  the  Ex-DHF  (Exercise  training  in  Diastolic  Heart  Failure)  pilot  study. J  Am Coll  Cardiol. 2011;58:1780-1791.
20. Fujimoto N, Prasad A, Hastings JL, et al. Cardiovascular effects of 1 year of progressive endurance exercise training in patients with heart failure with preserved ejection fraction. Am Heart J. 2012;164:869-877.
21.  Kitzman DW, Brubaker PH, Herrington DM, et al. Effect of endurance exercise training on endothelial function and arterial stiffness in older patients with heart failure and preserved ejection fraction: a randomized, controlled, single-blind trial. J Am Coll Cardiol. 2013;62:584-592.
22. Kitzman  DW,  Brubaker  P,  Morgan  T,  et  al.  Effect  of  caloric  restriction  or aerobic exercise training on peak oxygen consumption and quality of life in obese older patients with heart failure with preserved ejection fraction: a randomized clinical trial. JAMA. 2016;315:36-46.

## 7.2. Diuretics and Decongestion Strategies in Patients With HF

1. Patterson  JH,  Adams  KF  Jr,  Applefeld  MM,  et  al.  Oral  torsemide  in  patients with chronic congestive heart failure: effects on body weight, edema, and electrolyte excretion. Torsemide Investigators Group. Pharmacotherapy. 1994;14:514-521.
2.  Goebel KM. Six-week study of torsemide in patients with congestive heart failure. Clin Ther. 1993;15:1051-1059.
3.  Wilson JR, Reichek N, Dunkman WB, et al. Effect of diuresis on the performance of the failing left ventricle in man. Am J Med. 1981;70:234-239.
4. Parker JO. The effects of oral ibopamine in patients with mild heart failure-a double blind placebo controlled comparison to furosemide. The Ibopamine Study Group. Int J Cardiol. 1993;40:221-227.
5. Richardson A, Bayliss J, Scriven AJ, et al. Double-blind comparison of captopril alone against frusemide plus amiloride in mild heart failure. Lancet. 1987;2:709-711.
6. Grodin JL, Stevens SR, de Las Fuentes L, et al. Intensification of medication therapy for cardiorenal syndrome in acute decompensated heart failure. J Card Fail. 2016;22:26-32.
7. Ellison DH, Felker GM. Diuretic treatment in heart failure. N Engl J Med. 2017;377:1964-1975.
8.  Cody RJ, Kubo SH, Pickworth KK. Diuretic treatment for the sodium retention of congestive heart failure. Arch Intern Med. 1994;154:1905-1914.
9. Faselis  C,  Arundel  C,  Patel  S,  et  al.  Loop  diuretic  prescription  and  30day  outcomes  in  older  patients  with  heart  failure. J  Am  Coll  Cardiol. 2020;76:669-679.
10. Vargo DL, Kramer WG, Black PK, et al. Bioavailability, pharmacokinetics, and pharmacodynamics of torsemide and furosemide in patients with congestive heart failure. Clin Pharmacol Ther. 1995;57:601-609.
11.  Murray MD, Deer MM, Ferguson JA, et al. Open-label randomized trial of torsemide compared with furosemide therapy for patients with heart failure. Am J Med. 2001;111:513-520.
12. Cosin J, Diez J, TORIC Investigators. Torasemide in chronic heart failure: results of the TORIC study. Eur J Heart Fail. 2002;4:507-513.
13. Sica  DA,  Gehr  TW.  Diuretic  combinations  in  refractory  oedema  states: pharmacokinetic-pharmacodynamic relationships. Clin Pharmacokinet. 1996;30:229-249.
14. Ellison DH. The physiologic basis of diuretic synergism: its role in treating diuretic resistance. Ann Intern Med. 1991;114:886-894.
15.  Jentzer JC, DeWald TA, Hernandez AF. Combination of loop diuretics with thiazide-type diuretics in heart failure. J Am Coll Cardiol. 2010;56:15271534.
16. Cox ZL, Hung R, Lenihan DJ, et al. Diuretic strategies for loop diuretic resistance in acute heart failure: the 3T trial. J Am Coll Cardiol HF. 2020;8:157168.
17. 17 .  Brisco-Bacik MA, Ter Maaten JM, Houser SR, et al. Outcomes associated with a strategy of adjuvant metolazone or high-dose loop diuretics in acute decompensated  heart  failure:  a  propensity  analysis. J  Am  Heart  Assoc. 2018;7:e009149.
18. Felker GM, Lee KL, Bull DA, et al. Diuretic strategies in patients with acute decompensated heart failure. N Engl J Med. 2011;364:797-805.

## 7.3.1. Renin-Angiotensin System Inhibition With ACEi or ARB or ARNi

1.  McMurray JJ, Packer M, Desai AS, et al. Angiotensin-neprilysin inhibition versus enalapril in heart failure. N Engl J Med. 2014;371:993-1004.
2. Wachter R, Senni M, Belohlavek J, et al. Initiation of sacubitril/valsartan in haemodynamically stabilised heart failure patients in hospital or early after discharge: primary results of the randomised TRANSITION study. Eur J Heart Fail. 2019;21:998-1007.
3.  Velazquez EJ, Morrow DA, DeVore AD, et al. Angiotensin-neprilysin inhibition in acute decompensated heart failure. N Engl J Med. 2019;380:539548.
4. Desai AS, Solomon SD, Shah AM, et al. Effect of sacubitril-valsartan vs enalapril on aortic stiffness in patients with heart failure and reduced ejection fraction: a randomized clinical trial. JAMA. 2019;322:1077-1084.
5. Wang Y, Zhou R, Lu C, et al. Effects of the angiotensin-receptor neprilysin inhibitor on cardiac reverse remodeling: meta-analysis. J Am Heart Assoc. 2019;8:e012272.
6. Consensus Trial Study Group. Effects of enalapril on mortality in severe congestive heart failure. Results of the Cooperative North Scandinavian Enalapril Survival Study (CONSENSUS). N Engl J Med. 1987;316:1429-1435.

7. SOLVD Investigators. Effect of enalapril on survival in patients with reduced left ventricular ejection fractions and congestive heart failure. N Engl J Med. 1991;325:293-302.
8. Packer M, Poole-Wilson PA, Armstrong PW, et al. Comparative effects of low and high doses of the angiotensin-converting enzyme inhibitor, lisinopril, on morbidity and mortality in chronic heart failure. ATLAS Study Group. Circulation . 1999;100:2312-2318.
9. Pfeffer MA, Braunwald E, Moyé LA, et al. Effect of captopril on mortality and morbidity in patients with left ventricular dysfunction after myocardial infarction:  results  of  the  Survival  and  Ventricular  Enlargement  Trial.  The  SAVE Investigators. N Engl J Med. 1992;327:669-677.
10. Effect of ramipril on mortality and morbidity of survivors of acute myocardial  infarction  with  clinical  evidence  of  heart  failure.  The  Acute  Infarction Ramipril Efficacy (AIRE) Study Investigators. Lancet. 1993;342:821-828.
11. Køber L, Torp-Pedersen C, Carlsen JE, et al. A clinical trial of the angiotensin-converting-enzyme inhibitor trandolapril in patients with left ventricular dysfunction after myocardial infarction. Trandolapril Cardiac Evaluation (TRACE) Study Group. N Engl J Med. 1995;333:1670-1676.
12.  Garg R, Yusuf S. Overview of randomized trials of angiotensin-converting enzyme inhibitors on mortality and morbidity in patients with heart failure. Collaborative Group on ACE Inhibitor Trials. JAMA. 1995;273:1450-1456.
13.  Woodard-Grice AV, Lucisano AC, Byrd JB, et al. Sex-dependent and racedependent association of XPNPEP2 C-2399A polymorphism with angiotensin-converting enzyme inhibitor-associated angioedema. Pharmacogenet Genomics. 2010;20:532-536.
14. Cohn JN, Tognoni GValsartan Heart Failure Trial Investigators. A randomized trial of the angiotensin-receptor blocker valsartan in chronic heart failure. N Engl J Med. 2001;345:1667-1675.
15. Pfeffer MA, McMurray JJ, Velazquez EJ, et al. Valsartan, captopril, or both in myocardial infarction complicated by heart failure, left ventricular dysfunction, or both [published correction appears in N Engl J Med. 2004;350:203]. N Engl J Med. 2003;349:1893-1906.
16.  Konstam MA, Neaton JD, Dickstein K, et al; HEAAL Investigators. Effects of  high-dose  versus  low-dose  losartan  on  clinical  outcomes  in  patients with heart failure (HEAAL study): a randomised, double-blind trial. Lancet. 2009;374:1840-1848.
11. 17 . ONTARGET Investigators, Yusuf S, Teo KK, et al. T elmisartan, ramipril, or both in patients at high risk for vascular events. N Engl J Med. 2008;358:1547-1559.
18.  Telmisartan Randomised AssessmeNt Study in ACE iNtolerant subjects with cardiovascular Disease (TRANSCEND) Investigators, Yusuf S, Teo K, et al. Effects of the angiotensin-receptor blocker telmisartan on cardiovascular events in high-risk patients intolerant to angiotensin-converting enzyme inhibitors: a randomised controlled trial. Lancet. 2008;372:1174-1183.
19.  Banka G, Heidenreich PA, Fonarow GC. Incremental cost-effectiveness of guideline-directed  medical  therapies  for  heart  failure. J  Am  Coll  Cardiol. 2013;61:1440-1446.
20.  Dasbach EJ, Rich MW, Segal R, et al. The cost-effectiveness of losartan versus  captopril  in  patients  with  symptomatic  heart  failure. Cardiology. 1999;91:189-194.
21. Glick H, Cook J, Kinosian B, et al. Costs and effects of enalapril therapy in patients with symptomatic heart failure: an economic analysis of the Studies  of  Left  Ventricular  Dysfunction  (SOL VD)  Treatment  Trial. J  Card  Fail. 1995;1:371-380.
22. Paul SD, Kuntz KM, Eagle KA, et al. Costs and effectiveness of angiotensin converting enzyme inhibition in patients with congestive heart failure. Arch Intern Med. 1994;154:1143-1149.
23.  Reed SD, Friedman JY, Velazquez EJ, et al. Multinational economic evaluation of valsartan in patients with chronic heart failure: results from the Valsartan Heart Failure Trial (Val-HeFT). Am Heart J. 2004;148:122-128.
24. Shekelle P, Morton S, Atkinson S, et al. Pharmacologic management of heart failure and left ventricular systolic dysfunction: effect in female, black, and diabetic patients, and cost-effectiveness. Evid Rep Technol Assess (Summ). 2003:1-6.
25. Tsevat J, Duke D, Goldman L, et al. Cost-effectiveness of captopril therapy after myocardial infarction. J Am Coll Cardiol. 1995;26:914-919.
26.  Gaziano TA, Fonarow GC, Claggett B, et al. Cost-effectiveness analysis of sacubitril/valsartan vs enalapril in patients with heart failure and reduced ejection fraction. JAMA Cardiol. 2016;1:666-672.
21. 27 .  Gaziano TA, Fonarow GC, Velazquez EJ, et al. Cost-effectiveness of sacubitril-valsartan in hospitalized patients who have heart failure with reduced ejection fraction. JAMA Cardiol. 2020;5:1236-1244.
28. King JB, Shah RU, Bress AP, et al. Cost-effectiveness of sacubitril-valsartan combination therapy compared with enalapril for the treatment of heart failure with reduced ejection fraction. J Am Coll Cardiol HF. 2016;4:392-402.
29.  Sandhu AT, Ollendorf DA, Chapman RH, et al. Cost-effectiveness of sacubitril-valsartan in patients with heart failure with reduced ejection fraction. Ann Intern Med. 2016;165:681-689.
30.  Packer M, Califf RM, Konstam MA, et al. Comparison of omapatrilat and enalapril in patients with chronic heart failure: the Omapatrilat Versus Enalapril Randomized Trial of Utility in Reducing Events (OVERTURE). Circulation . 2002;106:920-926.
31. Kostis JB, Packer M, Black HR, et al. Omapatrilat and enalapril in patients with hypertension: the Omapatrilat Cardiovascular Treatment vs. Enalapril (OCTAVE) trial. Am J Hypertens. 2004;17:103-111.
32.  Vardeny O, Miller R, Solomon SD. Combined neprilysin and renin-angiotensin system inhibition for the treatment of heart failure. J Am Coll Cardiol HF. 2014;2:663-670.
33. Messerli  FH,  Nussberger  J.  Vasopeptidase  inhibition  and  angio-oedema. Lancet. 2000;356:608-609.
34.  Braunwald E. The path to an angiotensin receptor antagonist-neprilysin inhibitor in the treatment of heart failure. J Am Coll Cardiol. 2015;65:10291041.
35.  Ruilope LM, Dukat A, Böhm M, et al. Blood-pressure reduction with LCZ696, a novel dual-acting inhibitor of the angiotensin II receptor and neprilysin: a randomised, double-blind, placebo-controlled, active comparator study. Lancet. 2010;375:1255-1266.
36.  Byrd JB, Adam A, Brown NJ. Angiotensin-converting enzyme inhibitor-associated angioedema. Immunol Allergy Clin North Am. 2006;26:725-737.
31. 37 .  Toh S, Reichman ME, Houstoun M, et al. Comparative risk for angioedema associated with the use of drugs that target the renin-angiotensin-aldosterone system. Arch Intern Med. 2012;172:1582-1589.
38. Makani H, Messerli FH, Romero J, et al. Meta-analysis of randomized trials of angioedema as an adverse event of renin-angiotensin system inhibitors. Am J Cardiol. 2012;110:383-391.
39.  Rasmussen ER, Pottegard A, Bygum A, et al. Angiotensin II receptor blockers are safe in patients with prior angioedema related to angiotensin-converting enzyme inhibitors - a nationwide registry-based cohort study. J Intern Med. 2019;285:553-561.
40. Jering KS, Claggett B, Pfeffer MA, et al. Prospective ARNI vs. ACE inhibitor trial to DetermIne Superiority in reducing heart failure Events after Myocardial Infarction (PARADISE-MI): design and baseline characteristics. Eur J Heart Fail. 2021;23:1040-1048.
41.  Zueger PM, Kumar VM, Harrington RL, et al. Cost-effectiveness analysis of sacubitril/valsartan for the treatment of heart failure with reduced ejection fraction in the United States. Pharmacotherapy. 2018;38:520-530.

## 7.3.2. Beta Blockers

1. Cardiac Insufficiency Authors. The Cardiac Insufficiency Bisoprolol Study II (CIBIS-II): a randomised trial. Lancet. 1999;353:9-13.
2. Effect  of  metoprolol  CR/XL  in  chronic  heart  failure:  Metoprolol  CR/XL Randomised  Intervention  Trial  in  Congestive  Heart  Failure  (MERIT-HF). Lancet . 1999;353:2001-2007.
3. Packer M, Fowler MB, Roecker EB, et al. Effect of carvedilol on the morbidity of patients with severe chronic heart failure: results of the carvedilol prospective randomized cumulative survival (COPERNICUS) study. Circulation. 2002;106:2194-2199.
4.  Banka G, Heidenreich PA, Fonarow GC. Incremental cost-effectiveness of guideline-directed  medical  therapies  for  heart  failure. J  Am  Coll  Cardiol. 2013;61:1440-1446.
5. Caro JJ, Migliaccio-Walle K, O'Brien JA, et al. Economic implications of extended-release metoprolol succinate for heart failure in the MERIT-HF trial: a US perspective of the MERIT-HF trial. J Card Fail. 2005;11:647-656.
6. Delea TE, Vera-Llonch M, Richner RE, et al. Cost effectiveness of carvedilol for heart failure. Am J Cardiol. 1999;83:890-896.
7.  Gregory D, Udelson JE, Konstam MA. Economic impact of beta blockade in heart failure. Am J Med. 2001;110(suppl 7A):74S-80S.
8. Vera-Llonch  M,  Menzin  J,  Richner  RE,  et  al.  Cost-effectiveness  results from  the  US  Carvedilol  Heart  Failure  Trials  Program. Ann  Pharmacother. 2001;35:846-851.
9. Bristow MR, Gilbert EM, Abraham WT, et al. Carvedilol produces dose-related improvements in left ventricular function and survival in subjects with chronic heart failure. MOCHA Investigators. Circulation . 1996;94:2807-2816.
10.  Cleland JGF, Bunting KV, Flather MD, et al. Beta-blockers for heart failure  with  reduced,  mid-range,  and  preserved  ejection  fraction:  an  individual  patient-level  analysis  of  double-blind  randomized  trials. Eur  Heart  J. 2018;39:26-35.
11. Hjalmarson A, Goldstein S, Fagerberg B, et al. Effects of controlled-release metoprolol on total mortality, hospitalizations, and well-being in patients with

- heart failure: the Metoprolol CR/XL Randomized Intervention Trial in congestive heart failure (MERIT-HF). JAMA . 2000;283:1295-1302.
12.  Kotecha D, Holmes J, Krum H, et al. Efficacy of beta blockers in patients with heart failure plus atrial fibrillation: an individual-patient data meta-analysis. Lancet. 2014;384:2235-2243.
13. Flather  MD,  Shibata  MC,  Coats  AJ,  et  al.  Randomized  trial  to  determine the effect of nebivolol on mortality and cardiovascular hospital admission in elderly patients with heart failure (SENIORS). Eur Heart J. 2005;26:215225.
14.  Beta-Blocker Evaluation of Survival Trial Investigators, Eichhorn EJ, Domanski MJ, et al. A trial of the beta-blocker bucindolol in patients with advanced chronic heart failure. N Engl J Med. 2001;344:1659-1667.
15.  Poole-Wilson PA, Swedberg K, Cleland JG, et al. Comparison of carvedilol and metoprolol on clinical outcomes in patients with chronic heart failure in the Carvedilol Or Metoprolol European Trial (COMET): randomised controlled trial. Lancet. 2003;362:7-13.
16. Willenheimer  R,  van  Veldhuisen  DJ,  Silke  B,  et  al.  Effect  on  survival  and hospitalization of initiating treatment for chronic heart failure with bisoprolol followed by enalapril, as compared with the opposite sequence: results of the randomized Cardiac Insufficiency Bisoprolol Study (CIBIS) III. Circulation. 2005;112:2426-2435.
- 17 . Gattis  WA,  O'Connor  CM.  Predischarge  initiation  of  carvedilol  in  patients hospitalized for decompensated heart failure. Am J Cardiol. 2004;93:74B76B.
18. Halliday BP, Wassall R, Lota AS, et al. Withdrawal of pharmacological treatment  for  heart  failure  in  patients  with  recovered  dilated  cardiomyopathy (TRED-HF): an open-label, pilot, randomised trial. Lancet. 2019;393:61-73.
19.  Waagstein F, Caidahl K, Wallentin I, et al. Long-term beta-blockade in dilated  cardiomyopathy:  effects  of  short-  and  long-term  metoprolol  treatment followed by withdrawal and readministration of metoprolol. Circulation. 1989;80:551-563.

## 7.3.3. Mineralocorticoid Receptor Antagonists (MRAs)

1. Pitt B, Zannad F, Remme WJ, et al. The effect of spironolactone on morbidity and mortality in patients with severe heart failure. Randomized Aldactone Evaluation Study Investigators. N Engl J Med. 1999;341:709-717.
2.  Pitt B, Remme W, Zannad F. Eplerenone Post-Acute Myocardial Infarction Heart Failure Efficacy and Survival Study Investigators. Eplerenone, a selective  aldosterone blocker, in patients with left ventricular dysfunction after myocardial infarction. N Engl J Med. 2003;348:1309-1321.
3. Zannad F, McMurray JJ, Krum H, et al. Eplerenone in patients with systolic heart failure and mild symptoms. N Engl J Med. 2011;364:11-21.
4.  Banka G, Heidenreich PA, Fonarow GC. Incremental cost-effectiveness of guideline-directed  medical  therapies  for  heart  failure. J  Am  Coll  Cardiol. 2013;61:1440-1446.
5. Glick HA, Orzol SM, Tooley JF, et al. Economic evaluation of the randomized aldactone evaluation study (RALES): treatment of patients with severe heart failure. Cardiovasc Drugs Ther . 2002;16:53-59.
6.  Weintraub  WS,  Zhang  Z,  Mahoney  EM,  et  al.  Cost-effectiveness  of eplerenone compared with placebo in patients with myocardial infarction complicated  by  left  ventricular  dysfunction  and  heart  failure. Circulation. 2005;111:1106-1113.
7.  Zhang Z, Mahoney EM, Kolm P, et al. Cost effectiveness of eplerenone in patients with heart failure after acute myocardial infarction who were taking both ACE inhibitors and beta-blockers: subanalysis of the EPHESUS. Am J Cardiovasc Drugs. 2010;10:55-63.
8. Hernandez AF, Mi X, Hammill BG, et al. Associations between aldosterone antagonist therapy and risks of mortality and readmission among patients with heart failure and reduced ejection fraction. JAMA. 2012;308:2097-2107.
9. Juurlink  DN,  Mamdani  MM,  Lee  DS,  et  al.  Rates  of  hyperkalemia  after publication of the Randomized Aldactone Evaluation Study. N Engl J Med. 2004;351:543-551.
10.  FDA Aldactone label 2008. Accessed June 28, 2021. https://www.accessdata.fda.gov/drugsatfda\_docs/label/2008/012151s062lbl.pdf
11.  FDA INSPRA label 2008. Accessed June 28, 2021. https://www.accessdata.fda.gov/drugsatfda\_docs/label/2008/021437s006lbl.pdf
12. Butler J, Anstrom KJ, Felker GM, et al. Efficacy and safety of spironolactone in  acute  heart  failure:  the  ATHENA-HF  Randomized  Clinical  Trial. JAMA Cardiol. 2017;2:950-958.
13.  McMurray JJ, Packer M, Desai AS, et al. Angiotensin-neprilysin inhibition versus enalapril in heart failure. N Engl J Med. 2014;371:993-1004.
14. Velazquez EJ, Morrow DA, DeVore AD, et al. Angiotensin-neprilysin inhibition in acute decompensated heart failure. N Engl J Med. 2019;380:539-548.
15. Pitt B, Anker SD, Bushinsky DA, et al. Evaluation of the efficacy and safety of RL Y5016, a polymeric potassium binder, in a double-blind, placebo-controlled study in patients with chronic heart failure (the PEARL-HF) trial. Eur Heart J. 2011;32:820-828.
16.  Anker SD, Kosiborod M, Zannad F, et al. Maintenance of serum potassium with sodium zirconium cyclosilicate (ZS-9) in heart failure patients: results from  a  phase  3  randomized,  double-blind,  placebo-controlled  trial. Eur  J Heart Fail. 2015;17:1050-1056.

## 7.3.4. Sodium-Glucose Cotransporter 2 Inhibitors (SGLT2i)

1. McMurray JJV, Solomon SD, Inzucchi SE, et al. Dapagliflozin in patients with heart failure and reduced ejection fraction. N Engl J Med. 2019;381:19952008.
2. Packer M, Anker SD, Butler J, et al. Cardiovascular and renal outcomes with empagliflozin in heart failure. N Engl J Med. 2020;383:1413-1424.
3.  Parizo JT, Goldhaber-Fiebert JD, Salomon JA, et al. Cost-effectiveness of dapagliflozin for treatment of patients with heart failure with reduced ejection fraction. JAMA Cardiol. 2021;6:926-935.
4. Isaza N, Calvachi P, Raber I, et al. Cost-effectiveness of dapagliflozin for the treatment of heart failure with reduced ejection fraction. JAMA Netw Open. 2021;4:e2114501.
5. Neal B, Perkovic V, Mahaffey KW, et al. Canagliflozin and cardiovascular and renal events in type 2 diabetes. N Engl J Med. 2017;377:644-657.
6.  Wiviott SD, Raz I, Bonaca MP, et al. Dapagliflozin and cardiovascular outcomes in type 2 diabetes. N Engl J Med. 2019;380:347-357.
7. Zinman B, Wanner C, Lachin JM, et al. Empagliflozin, cardiovascular outcomes, and mortality in type 2 diabetes. N Engl J Med. 2015;373:2117-2128.
8.  Zelniker TA, Braunwald E. Mechanisms of cardiorenal effects of sodiumglucose cotransporter 2 inhibitors: JACC state-of-the-art review. J Am Coll Cardiol. 2020;75:422-434.
9. Zannad F, Ferreira JP, Pocock SJ, et al. SGL T2 inhibitors in patients with heart failure with reduced ejection fraction: a meta-analysis of the EMPEROR-Reduced and DAPA-HF trials. Lancet. 2020;396:819-829.
10. Bhatt DL, Szarek M, Steg PG, et al. Sotagliflozin in patients with diabetes and recent worsening heart failure. N Engl J Med. 2021;384:117-128.
11. Vardeny  O,  Vaduganathan  M.  Practical  guide  to  prescribing  sodium-glucose  cotransporter  2  inhibitors  for  cardiologists. J  Am  Coll  Cardiol  HF. 2019;7:169-172.

## 7.3.5. Hydralazine and Isosorbide Dinitrate (H-ISDN)

1.  Carson P, Ziesche S, Johnson G, et al. Racial differences in response to therapy for heart failure: analysis of the vasodilator-heart failure trials. Vasodilator-Heart Failure Trial Study Group. J Card Fail. 1999;5:178-187.
2. Taylor AL, Ziesche S, Yancy C, et al. Combination of isosorbide dinitrate and hydralazine in blacks with heart failure. N Engl J Med. 2004;351:20492057.
3.  Angus DC, Linde-Zwirble WT, Tam SW, et al. Cost-effectiveness of fixeddose combination of isosorbide dinitrate and hydralazine therapy for blacks with heart failure. Circulation. 2005;112:3745-3753.
4.  Cohn JN, Archibald DG, Ziesche S, et al. Effect of vasodilator therapy on mortality in chronic congestive heart failure. Results of a Veterans Administration Cooperative Study. N Engl J Med. 1986;314:1547-1552.
5. Khazanie P, Liang L, Curtis LH, et al. Clinical effectiveness of hydralazineisosorbide dinitrate therapy in patients with heart failure and reduced ejection fraction: findings from the Get With The Guidelines-Heart Failure Registry. Circ Heart Fail. 2016;9:e002444.
6.  Cohn JN, Johnson G, Ziesche S, et al. A comparison of enalapril with hydralazine-isosorbide dinitrate in the treatment of chronic congestive heart failure. N Engl J Med. 1991;325:303-310.
7.  Fonarow GC, Chelimsky-Fallick C, Stevenson LW, et al. Effect of direct vasodilation with hydralazine versus angiotensin-converting enzyme inhibition with captopril on mortality in advanced heart failure: the Hy-C trial. J Am Coll Cardiol. 1992;19:842-850.

## 7.3.6. Other Drug Treatment

1. Macchia A, Levantesi G, Franzosi MG, et al. Left ventricular systolic dysfunction, total mortality, and sudden death in patients with myocardial infarction treated with n-3 polyunsaturated fatty acids. Eur J Heart Fail. 2005;7:904909.
2. Tavazzi L, Maggioni AP, Marchioli R, et al. Effect of n-3 polyunsaturated fatty acids in patients with chronic heart failure (the GISSI-HF trial): a randomised, double-blind, placebo-controlled trial. Lancet. 2008;372:1223-1230.

3. Bhatt DL, Steg PG, Miller M, et al. Cardiovascular risk reduction with icosapent ethyl for hypertriglyceridemia. N Engl J Med. 2019;380:11-22.
4. Peterson BE, Bhatt DL, Steg PG, et al. Reduction in revascularization with icosapent ethyl: insights from REDUCE-IT revascularization analyses. Circulation. 2021;143:33-44.
5. Pitt B, Anker SD, Bushinsky DA, et al. Evaluation of the efficacy and safety of RL Y5016, a polymeric potassium binder, in a double-blind, placebo-controlled study in patients with chronic heart failure (the PEARL-HF) trial. Eur Heart J. 2011;32:820-828.
6.  Anker SD, Kosiborod M, Zannad F, et al. Maintenance of serum potassium with sodium zirconium cyclosilicate (ZS-9) in heart failure patients: results from  a  phase  3  randomized,  double-blind,  placebo-controlled  trial. Eur  J Heart Fail. 2015;17:1050-1056.
7.  Massie BM, Collins JF, Ammon SE, et al. Randomized trial of warfarin, aspirin, and clopidogrel in patients with chronic heart failure: the Warfarin and Antiplatelet  Therapy  in  Chronic  Heart  Failure  (WATCH)  trial. Circulation. 2009;119:1616-1624.
8. Homma S, Thompson JL, Pullicino PM, et al. Warfarin and aspirin in patients with heart failure and sinus rhythm. N Engl J Med. 2012;366:1859-1869.
9.  Zannad F, Anker SD, Byra WM, et al. Rivaroxaban in patients with heart failure, sinus rhythm, and coronary disease. N Engl J Med . 2018;379:13321342.
10. Marchioli  R,  Barzi  F,  Bomba  E,  et  al.  Early  protection  against  sudden death by n-3 polyunsaturated fatty acids after myocardial infarction: timecourse  analysis  of  the  results  of  the  Gruppo  Italiano  per  lo  Studio  della Sopravvivenza nell'Infarto Miocardico (GISSI)-Prevenzione. Circulation. 2002;105:1897-1903.
11. Ferreira JP, Butler J, Rossignol P, et al. Abnormalities of potassium in heart failure:  JACC  state-of-the-art  review. J  Am  Coll  Cardiol. 2020;75:28362850.
12. Savarese G, Carrero JJ, Pitt B, et al. Factors associated with underuse of mineralocorticoid receptor antagonists in heart failure with reduced ejection fraction:  an  analysis  of  11  215  patients  from  the  Swedish  Heart  Failure Registry. Eur J Heart Fail. 2018;20:1326-1334.
13. Kosiborod  M,  Rasmussen  HS,  Lavin  P,  et  al.  Effect  of  sodium  zirconium cyclosilicate on potassium lowering for 28 days among outpatients with  hyperkalemia:  the  HARMONIZE  randomized  clinical  trial. JAMA . 2014;312:2223-2233.
14.  Lavie CJ, Milani RV, Mehra MR, et al. Omega-3 polyunsaturated fatty acids and cardiovascular diseases. J Am Coll Cardiol. 2009;54:585-594.
15. Malik A, Masson R, Singh S, et al. Digoxin discontinuation and outcomes in patients with heart failure with reduced ejection fraction. J Am Coll Cardiol. 2019;74:617-627.
16.  Nicholls SJ, Lincoff AM, Garcia M, et al. Effect of high-dose omega-3 fatty acids vs corn oil on major adverse cardiovascular events in patients at high cardiovascular risk: the STRENGTH randomized clinical trial. JAMA. 2020;324:2268-2280.
15. 17 .  Dunkman WB, Johnson GR, Carson PE, et al. Incidence of thromboembolic events  in  congestive  heart  failure.  The  V-HeFT  VA  Cooperative  Studies Group. Circulation . 876 suppl1993:VI94-VI101.
18.  Dunkman WB. Thromboembolism and antithrombotic therapy in congestive heart failure. J Cardiovasc Risk. 1995;2:107-117.
19. Cioffi G, Pozzoli M, Forni G, et al. Systemic thromboembolism in chronic heart failure. A prospective study in 406 patients. Eur Heart J. 1996;17:13811389.
20.  Loh E, Sutton MS, Wun CC, et al. Ventricular dysfunction and the risk of stroke after myocardial infarction. N Engl J Med. 1997;336:251-257.
21. Al-Khadra  AS,  Salem  DN,  Rand  WM,  et  al.  Warfarin  anticoagulation  and survival: a cohort analysis from the studies of left ventricular dysfunction. J Am Coll Cardiol. 1998;31:749-753.
22.  Dries DL, Domanski MJ, Waclawiw MA, et al. Effect of antithrombotic therapy on risk of sudden coronary death in patients with congestive heart failure. Am J Cardiol. 1997;79:909-913.

## 7.3.7. Drugs of Unproven Value or That May Worsen HF

1.  Packer M, O'Connor CM, Ghali JK, et al. Effect of amlodipine on morbidity and mortality in severe chronic heart failure. Prospective Randomized Amlodipine Survival Evaluation Study Group. N Engl J Med. 1996;335:11071114.
2. Packer M, Carson P, Elkayam U, et al. Effect of amlodipine on the survival of patients with severe chronic heart failure due to a nonischemic cardiomyopathy: results of the PRAISE-2 study (prospective randomized amlodipine survival evaluation 2). J Am Coll Cardiol HF. 2013;1:308-314.
3.  Djoussé L, Cook NR, Kim E, et al. Supplementation with vitamin D and omega-3 fatty acids and incidence of heart failure hospitalization: VITAL-Heart Failure. Circulation. 2020;141:784-786.
4.  Wang T, Liu Z, Fu J, Min Z. Meta-analysis of vitamin D supplementation in the treatment of chronic heart failure. Scand Cardiovasc J. 2019;53:110116.
5. Zittermann A, Ernst JB, Prokop S, et al. Vitamin D supplementation of 4000 IU daily and cardiac function in patients with advanced heart failure: the EVITA trial. Int J Cardiol. 2019;280:117-123.
6.  Lonn E, Bosch J, Yusuf S, et al. Effects of long-term vitamin E supplementation on cardiovascular events and cancer: a randomized controlled trial. JAMA. 2005;293:1338-1347.
7. Marchioli R, Levantesi G, Macchia A, et al. Vitamin E increases the risk of developing heart failure after myocardial infarction: results from the GISSIPrevenzione trial. J Cardiovasc Med (Hagerstown). 2006;7:347-350.
8.  Mortensen SA, Rosenfeldt F, Kumar A, et al. The effect of coenzyme Q10 on morbidity and mortality in chronic heart failure: results from Q-SYMBIO: a randomized double-blind trial. J Am Coll Cardiol HF. 2014;2:641-649.
9.  Madmani ME, Yusuf Solaiman A, Tamr Agha K, et al. Coenzyme Q10 for heart failure. Cochrane Database Syst Rev. 2014:CD008684.
10.  Effect of verapamil on mortality and major events after acute myocardial infarction (the Danish Verapamil Infarction Trial II-DAVIT II). Am J Cardiol. 1990;66:779-785.
11. Multicenter Diltiazem Postinfarction Trial Research Group. The effect of diltiazem  on  mortality  and  reinfarction  after  myocardial  infarction. N Engl J Med. 1988;319:385-392.
12. Goldstein RE, Boccuzzi SJ, Cruess D, et al. Diltiazem increases late-onset congestive  heart  failure  in  postinfarction  patients  with  early  reduction  in ejection fraction. The Adverse Experience Committee; and the Multicenter Diltiazem Postinfarction Research Group. Circulation. 1991;83:52-60.
13. Figulla  HR,  Gietzen  F,  Zeymer  U,  et  al.  Diltiazem  improves  cardiac  function  and exercise capacity in patients with idiopathic dilated cardiomyopathy.  Results  of  the  Diltiazem  in  Dilated  Cardiomyopathy  Trial. Circulation . 1996;94:346-352.
14. Echt DS, Liebson PR, Mitchell LB, et al. Mortality and morbidity in patients receiving  encainide,  flecainide,  or  placebo.  The  Cardiac  Arrhythmia  Suppression Trial. N Engl J Med. 1991;324:781-788.
15.  Waldo AL, Camm AJ, deRuyter H, et al. Effect of d-sotalol on mortality in patients with left ventricular dysfunction after recent and remote myocardial infarction. The SWORD Investigators. Survival With Oral d-Sotalol. Lancet. 1996;348:7-12.
16.  Kober L, Torp-Pedersen C, McMurray JJ, et al. Increased mortality  after  dronedarone  therapy  for  severe  heart  failure. N  Engl  J  Med. 2008;358:2678-2687.
17. 17 .  Lipscombe LL, Gomes T, Levesque LE, et al. Thiazolidinediones and cardiovascular outcomes in older patients with diabetes. JAMA. 2007;298:26342643.
18. Lago RM,  Singh  PP,  Nesto  RW.  Congestive  heart  failure  and  cardiovascular  death in patients with prediabetes and type 2 diabetes given thiazolidinediones: a meta-analysis of randomised clinical trials. Lancet. 2007;370:1129-1136.
19. Dargie  HJ,  Hildebrandt  PR,  Riegger  GA,  et  al.  A  randomized,  placebocontrolled trial assessing the effects of rosiglitazone on echocardiographic  function  and  cardiac  status  in  type  2  diabetic  patients  with  New  Y ork Heart Association functional class I or II heart failure. J  Am Coll  Cardiol. 2007;49:1696-1704.
20.  Home PD, Pocock SJ, Beck-Nielsen H, et al. Rosiglitazone evaluated for cardiovascular  outcomes  in  oral  agent  combination  therapy  for  type  2 diabetes  (RECORD):  a  multicentre,  randomised,  open-label  trial. Lancet. 2009;373:2125-2135.
21. Giles TD, Miller AB, Elkayam U, et al. Pioglitazone and heart failure: results from a controlled study in patients with type 2 diabetes mellitus and systolic dysfunction. J Card Fail. 2008;14:445-452.
22. Scirica BM, Braunwald E, Raz I, et al. Heart failure, saxagliptin, and diabetes mellitus: observations from the SAVOR-TIMI 53 randomized trial. Circulation. 2014;130:1579-1588.
23. Zannad  F,  Cannon  CP,  Cushman  WC,  et  al.  Heart  failure  and  mortality outcomes in patients with type 2 diabetes taking alogliptin versus placebo  in  EXAMINE:  a  multicentre,  randomised,  double-blind  trial. Lancet . 2015;385:2067-2076.
24. Verma S, Goldenberg RM, Bhatt DL, et al. Dipeptidyl peptidase-4 inhibitors and the risk of heart failure: a systematic review and meta-analysis. CMAJ Open. 2017;5:E152-E177.
25. Mamdani M, Juurlink DN, Lee DS, et al. Cyclo-oxygenase-2 inhibitors versus non-selective non-steroidal anti-inflammatory drugs and congestive heart

failure outcomes in elderly patients: a population-based cohort study. Lancet. 2004;363:1751-1756.

26.  Hudson M, Richard H, Pilote L. Differences in outcomes of patients with congestive  heart  failure  prescribed  celecoxib,  rofecoxib,  or  non-steroidal anti-inflammatory drugs: population based study. BMJ. 2005;330:1370.
2. 27 .  Gislason GH, Rasmussen JN, Abildstrom SZ, et al. Increased mortality and cardiovascular morbidity associated with use of nonsteroidal anti-inflammatory drugs in chronic heart failure. Arch Intern Med. 2009;169:141-149.
28.  Feenstra J, Heerdink ER, Grobbee DE, et al. Association of nonsteroidal anti-inflammatory drugs with first occurrence of heart failure and with relapsing heart failure: the Rotterdam Study. Arch Intern Med. 2002;162:265270.
29. Packer M, Carson P, Elkayam U, et al. Effect of amlodipine on the survival of patients with severe chronic heart failure due to a nonischemic cardiomyopathy: results of the PRAISE-2 study (prospective randomized amlodipine survival evaluation 2). J Am Coll Cardiol HF. 2013;1:308-314.
30.  Salzano A, Marra AM, D'Assante R, et al. Growth hormone therapy in heart failure. Heart Fail Clin. 2018;14:501-515.
31.  Sharma A, Fonarow GC, Butler J, et al. Coenzyme Q10 and heart failure: a state-of-the-art review. Circ Heart Fail. 2016;9:e002639.
32. Vest AR, Chan M, Deswal A, et al. Nutrition, obesity, and cachexia in patients with heart failure: a consensus statement from the Heart Failure Society of America Scientific Statements Committee. J Card Fail. 2019;25:380-400.
33. Hopper I,  Connell  C,  Briffa  T,  et  al.  Nutraceuticals  in  patients  with  heart failure: a systematic review. J Card Fail. 2020;26:166-179.
34.  Keith M, Quach S, Ahmed M, et al. Thiamin supplementation does not improve left ventricular ejection fraction in ambulatory heart failure patients: a randomized controlled trial. Am J Clin Nutr. 2019;110:1287-1295.
35. Jain A, Mehta R, Al-Ani M, et al. Determining the role of thiamine deficiency in systolic heart failure: a meta-analysis and systematic review. J Card Fail. 2015;21:1000-1007.
36. DiNicolantonio JJ, Niazi AK, Lavie CJ, et al. Thiamine supplementation for the treatment of heart failure: a review of the literature. Congest Heart Fail. 2013;19:214-222.
12. 37 . Song X, Qu H, Yang Z, et al. Efficacy and safety of L-carnitine treatment for chronic heart failure: a meta-analysis of randomized controlled trials. BioMed Res Int. 2017;2017:6274854.
38.  Azuma J, Sawamura A, Awata N. Usefulness of taurine in chronic congestive heart failure and its prospective application. Jpn Circ J. 1992;56:95-99.
39.  Ahmadian M, Dabidi Roshan V, Ashourpore E. Taurine supplementation improves functional capacity, myocardial oxygen consumption, and electrical activity in heart failure. J Diet Suppl. 2017;14:422-432.
40. Tao J, Liu X, Bai W. Testosterone supplementation in patients with chronic heart failure: a meta-analysis of randomized controlled trials. Front Endocrinol (Lausanne) . 2020;11:110.
41. D'Assante R, Piccioli L, Valente P, et al. Testosterone treatment in chronic heart  failure.  Review  of  literature  and  future  perspectives. Monaldi  Arch Chest Dis. 2018;88:976.
42.  Salzano A, D'Assante R, Lander M, et al. Hormonal replacement therapy in heart failure: focus on growth hormone and testosterone. Heart Fail Clin. 2019;15:377-391.
43.  Zhang X, Wang WY, Zhang K, et al. Efficacy and safety of levothyroxine (L-T4)  replacement  on  the  exercise  capability  in  chronic  systolic  heart failure patients with subclinical hypothyroidism: study protocol for a multicenter, open label, randomized, parallel group trial (ThyroHeart-CHF). Trials . 2019;20:143.
44.  Holmager P, Schmidt U, Mark P, et al. Long-term L-Triiodothyronine (T3) treatment  in  stable  systolic  heart  failure  patients:  a  randomised,  doubleblind,  cross-over,  placebo-controlled  intervention  study. Clin  Endocrinol. 2015;83:931-937.
45. Einfeldt MN, Olsen AS, Kristensen SL, et al. Long-term outcome in patients with  heart  failure  treated  with  levothyroxine:  an  observational  nationwide cohort study. J Clin Endocrinol Metab. 2019;104:1725-1734.
46. Doval HC, Nul DR, Grancelli HO, et al. Randomised trial of low-dose amiodarone in severe congestive heart failure. Grupo de Estudio de la Sobrevida en la Insuficiencia Cardiaca en Argentina (GESICA). Lancet . 1994;344:493498.
22. 47 .  Singh SN, Fletcher RD, Fisher SG, et al. Amiodarone in patients with congestive  heart  failure  and  asymptomatic  ventricular  arrhythmia.  Survival Trial of Antiarrhythmic Therapy in Congestive Heart Failure. N Engl J Med. 1995;333:77-82.
48. Kober L, Bloch Thomsen PE, Moller M, et al. Effect of dofetilide in patients with  recent  myocardial  infarction  and  left-ventricular  dysfunction:  a  randomised trial. Lancet. 2000;356:2052-2058.
49. Torp-Pedersen C, Moller M, Bloch-Thomsen PE, et al. Dofetilide in patients with congestive heart failure and left ventricular dysfunction. Danish Investigations of Arrhythmia and Mortality on Dofetilide Study Group. N Engl J Med. 1999;341:857-865.
50. White WB, Cannon CP, Heller SR, et al. Alogliptin after acute coronary syndrome in patients with type 2 diabetes. N Engl J Med. 2013;369:13271335.
51.  McGuire DK, Van de Werf F, Armstrong PW, et al. Association between sitagliptin use and heart failure hospitalization and related outcomes in type 2 diabetes mellitus: secondary analysis of a randomized clinical trial. JAMA Cardiol. 2016;1:126-135.
52.  Green JB, Bethel MA, Armstrong PW, et al. Effect of sitagliptin on cardiovascular outcomes in type 2 diabetes. N Engl J Med. 2015;373:232-242.
53. McGuire  DK,  Alexander  JH,  Johansen  OE,  et  al.  Linagliptin  effects  on heart  failure  and  related  outcomes  in  individuals  with  type  2  diabetes mellitus at high cardiovascular and renal risk in CARMELINA. Circulation. 2019;139:351-361.
54. Rosenstock J, Perkovic V, Johansen OE, et al. Effect of linagliptin vs placebo on major cardiovascular events in adults with type 2 diabetes and high cardiovascular and renal risk: the CARMELINA randomized clinical trial. JAMA. 2019;321:69-79.
55. Rosenstock J, Kahn SE, Johansen OE, et al. Effect of linagliptin vs glimepiride on major adverse cardiovascular outcomes in patients with type 2 diabetes:  the  CAROLINA  randomized  clinical  trial. JAMA. 2019;322:11551166.
56. Communication:  FDS.  FDA  adds  warnings  about  heart  failure  risk  to  labels  of  type  2  diabetes  medicines  containing  saxagliptin  and  alogliptin. 2018  Accessed  June  5,  2020.  https://www.fda.gov/drugs/drug-safetyand-availability/fda-drug-safety-communication-fda-adds-warnings-aboutheart-failure-risk-labels-type-2-diabetes
32. 57 .  Page RL 2nd, O'Bryant CL, Cheng D, et al. Drugs that may cause or exacerbate heart failure: a scientific statement from the American Heart Association. Circulation. 2016;134:e32-e69.

## 7.3.8. Guideline-Directed Medical Therapy (GDMT) Dosing, Sequencing, and Uptitration

1. Cardiac Insufficiency Authors. The Cardiac Insufficiency Bisoprolol Study II (CIBIS-II): a randomised trial. Lancet. 1999;353:9-13.
2. Packer M, Fowler MB, Roecker EB, et al. Effect of carvedilol on the morbidity of patients with severe chronic heart failure: results of the carvedilol prospective randomized cumulative survival (COPERNICUS) study. Circulation. 2002;106:2194-2199.
3. SOLVD Investigators. Effect of enalapril on survival in patients with reduced left ventricular ejection fractions and congestive heart failure. N Engl J Med. 1991;325:293-302.
4.  Garg R, Yusuf S. Overview of randomized trials of angiotensin-converting enzyme inhibitors  on  mortality  and  morbidity  in  patients  with  heart  failure. Collaborative Group on ACE Inhibitor Trials. JAMA . 1995;273:14501456.
5.  McMurray JJ, Packer M, Desai AS, et al. Angiotensin-neprilysin inhibition versus enalapril in heart failure. N Engl J Med. 2014;371:993-1004.
6. Pitt B, Zannad F, Remme WJ, et al. The effect of spironolactone on morbidity and mortality in patients with severe heart failure. Randomized Aldactone Evaluation Study Investigators. N Engl J Med. 1999;341:709-717.
7. Zannad F, McMurray JJ, Krum H, et al. Eplerenone in patients with systolic heart failure and mild symptoms. N Engl J Med. 2011;364:11-21.
8. McMurray JJV, Solomon SD, Inzucchi SE, et al. Dapagliflozin in patients with heart failure and reduced ejection fraction. N Engl J Med. 2019;381:19952008.
9. Packer M, Anker SD, Butler J, et al. Cardiovascular and renal outcomes with empagliflozin in heart failure. N Engl J Med. 2020;383:1413-1424.
10. Taylor AL, Ziesche S, Yancy C, et al. Combination of isosorbide dinitrate and hydralazine in blacks with heart failure. N Engl J Med. 2004;351:20492057.
11. Effect  of  metoprolol  CR/XL  in  chronic  heart  failure:  Metoprolol  CR/XL Randomised  Intervention  Trial  in  Congestive  Heart  Failure  (MERIT-HF). Lancet . 1999;353:2001-2007.
12. Flather MD, Yusuf S, Kober L, et al. Long-term ACE-inhibitor therapy in patients with heart failure or left-ventricular dysfunction: a systematic overview of data from individual patients. ACE-inhibitor myocardial infarction collaborative group. Lancet . 2000;355:1575-1581.
13. Pitt B, Remme W, Zannad F, et al. Eplerenone, a selective aldosterone blocker, in patients with left ventricular dysfunction after myocardial infarction. N Engl J Med. 2003;348:1309-1321.

14. Ezekowitz  JA,  McAlister  FA.  Aldosterone  blockade  and  left  ventricular dysfunction: a systematic review of randomized clinical trials. Eur Heart J. 2009;30:469-477.
15.  Bassi NS, Ziaeian B, Yancy CW, et al. Association of optimal implementation of sodium-glucose cotransporter 2 inhibitor therapy with outcome for patients with heart failure. JAMA Cardiol. 2020;5:948-951.
16.  Bristow MR, Gilbert EM, Abraham WT, et al. Carvedilol produces dose-related improvements in left ventricular function and survival in subjects with chronic  heart  failure.  MOCHA  Investigators. Circulation .  1996;94:28072816.
4. 17 . Packer M, Poole-Wilson PA, Armstrong PW, et al. Comparative effects of low and high doses of the angiotensin-converting enzyme inhibitor, lisinopril, on morbidity and mortality in chronic heart failure. ATLAS Study Group. Circulation . 1999;100:2312-2318.
18.  Konstam MA, Neaton JD, Dickstein K, et al. HEAAL Investigators. Effects of  high-dose  versus  low-dose  losartan  on  clinical  outcomes  in  patients with heart failure (HEAAL study): a randomised, double-blind trial. Lancet. 2009;374:1840-1848.
19.  Pfeffer MA, Braunwald E, Moyé LA, et al. Effect of captopril on mortality and morbidity in patients with left ventricular dysfunction after myocardial infarction: results of the survival and ventricular enlargement trial. The SAVE Investigators. N Engl J Med. 1992;327:669-677.
20. Pfeffer  MA,  Swedberg  K,  Granger  CB,  et  al.  Effects  of  candesartan  on mortality and morbidity in patients with chronic heart failure: the CHARMOverall programme. Lancet. 2003;362:759-766.
21.  Cohn JN, Tognoni G. Valsartan Heart Failure Trial Investigators. A randomized trial of the angiotensin-receptor blocker valsartan in chronic heart failure. N Engl J Med. 2001;345:1667-1675.
22.  McMurray JJ, Packer M, Desai AS, et al. Angiotensin-neprilysin inhibition versus enalapril in heart failure. N Engl J Med. 2014;371:993-1004.
23. Packer M, Coats AJ, Fowler MB, et al. Effect of carvedilol on survival  in severe chronic heart failure. N Engl J Med. 2001;344:1651-1658.
24.  Cohn JN, Archibald DG, Ziesche S, et al. Effect of vasodilator therapy on mortality in chronic congestive heart failure. Results of a Veterans Administration Cooperative Study. N Engl J Med. 1986;314:1547-1552.
25. Fox K, Ford I, Steg PG, et al. Ivabradine for patients with stable coronary artery disease and left-ventricular systolic dysfunction (BEAUTIFUL): a randomised, double-blind, placebo-controlled trial. Lancet. 2008;372:807-816.
26. Fox K, Ford I, Steg PG, et al. Ivabradine in stable coronary artery disease without clinical heart failure. N Engl J Med. 2014;371:1091-1099.
14. 27 .  Swedberg K, Komajda M, Böhm M, et al. Ivabradine and outcomes in chronic  heart  failure  (SHIFT):  a  randomised  placebo-controlled  study. Lancet. 2010;376:875-885.
28. Armstrong PW, Pieske B, Anstrom KJ, et al. Vericiguat in patients with heart failure and reduced ejection fraction. N Engl J Med. 2020;382:1883-1893.
29.  Rathore SS, Foody JM, Wang Y, et al. Race, quality of care, and outcomes of elderly patients hospitalized with heart failure. JAMA. 2003;289:25172524.
30. Digitalis Investigation Group. The effect of digoxin on mortality and morbidity in patients with heart failure. N Engl J Med. 1997;336:525-533.
31.  Bristow MR, Saxon LA, Boehmer J, et al. Cardiac-resynchronization therapy with or without an implantable defibrillator in advanced chronic heart failure. N Engl J Med. 2004;350:2140-2150.
32. Cleland  JG,  Daubert  JC,  Erdmann  E,  et  al.  The  effect  of  cardiac  resynchronization  on  morbidity  and  mortality  in  heart  failure. N  Engl  J  Med. 2005;352:1539-1549.
33. Moss AJ, Zareba W, Hall WJ, et al. Prophylactic implantation of a defibrillator in patients with myocardial infarction and reduced ejection fraction. N Engl J Med. 2002;346:877-883.
34. Bardy GH, Lee KL, Mark DB, et al. Amiodarone or an implantable cardioverterdefibrillator for congestive heart failure. N Engl J Med. 2005;352:225-237.
35. Stone GW, Lindenfeld J, Abraham WT, et al. Transcatheter mitral-valve repair in patients with heart failure. N Engl J Med. 2018;379:2307-2318.
36.  Fonarow GC, Yancy CW, Hernandez AF, et al. Potential impact of optimal implementation of evidence-based heart failure therapies on mortality. Am Heart J. 2011;161:1024-1030.
24. 37 . Heidenreich PA, Lee TT, Massie BM. Effect of beta-blockade on mortality in patients with heart failure: a meta-analysis of randomized clinical trials. J Am Coll Cardiol. 1997;30:27-34.
38. Brophy JM, Joseph L, Rouleau JL. Beta-blockers in congestive heart failure. A Bayesian meta-analysis. Ann Intern Med. 2001;134:550-560.
39. McAlister FA, Ezekowitz J, Hooton N, et al. Cardiac resynchronization therapy for patients with left ventricular systolic dysfunction: a systematic review. JAMA. 2007;297:2502-2514.
40.  Rivero-Ayerza M, Theuns DA, Garcia-Garcia HM, et al. Effects of cardiac resynchronization therapy on overall mortality and mode of death: a metaanalysis of randomized controlled trials. Eur Heart J. 2006;27:2682-2688.
41. Desai AS, Fang JC, Maisel WH, et al. Implantable defibrillators for the prevention of mortality in patients with nonischemic cardiomyopathy: a metaanalysis of randomized controlled trials. JAMA. 2004;292:2874-2879.
42.  Ezekowitz JA, Rowe BH, Dryden DM, et al. Systematic review: implantable cardioverter defibrillators for adults with left ventricular systolic dysfunction. Ann Intern Med. 2007;147:251-262.

## 7.3.9.1. Management of Stage C HF: Ivabradine

1.  Swedberg K, Komajda M, Böhm M, et al. Ivabradine and outcomes in chronic  heart  failure  (SHIFT):  a  randomised  placebo-controlled  study. Lancet . 2010;376:875-885.
2. Borer JS, Böhm M, Ford I, et al. Effect of ivabradine on recurrent hospitalization for worsening heart failure in patients with chronic systolic heart failure: the SHIFT Study. Eur Heart J. 2012;33:2813-2820.
3.  Fox K, Komajda M, Ford I, et al. Effect of ivabradine in patients with leftventricular systolic dysfunction: a pooled analysis of individual patient data from  the  BEAUTIFUL  and  SHIFT  trials. Eur  Heart  J. 2013;34:22632270.
4. Fox K, Ford I, Steg PG, et al. Ivabradine for patients with stable coronary artery  disease  and  left-ventricular  systolic  dysfunction  (BEAUTIFUL):  a randomised, double-blind, placebo-controlled trial. Lancet. 2008;372:807816.
5. Böhm M, Borer J, Ford I, et al. Heart rate at baseline influences the effect of ivabradine on cardiovascular outcomes in chronic heart failure: analysis from the SHIFT study. Clin Res Cardiol. 2013;102:11-22.
6. Bohm M, Robertson M, Ford I, et al. Influence of cardiovascular and noncardiovascular co-morbidities on outcomes and treatment effect of heart rate reduction with ivabradine in stable heart failure (from the SHIFT Trial). Am J Cardiol. 2015;116:1890-1897.

## 7.3.9.2. Pharmacological Treatment for Stage C Heart Failure With Reduced Ejection Fraction (HFrEF) (Digoxin)

1. Digitalis Investigation Group. The effect of digoxin on mortality and morbidity in patients with heart failure. N Engl J Med. 1997;336:525-533.
2.  Ahmed A, Rich MW, Love TE, et al. Digoxin and reduction in mortality and hospitalization  in  heart  failure:  a  comprehensive  post  hoc  analysis  of  the DIG trial. Eur Heart J. 2006;27:178-186.
3. Lader E, Egan D, Hunsberger S, et al. The effect of digoxin on the quality of life in patients with heart failure. J Card Fail. 2003;9:4-12.
4. Ahmed A, Pitt B, Rahimtoola SH, et al. Effects of digoxin at low serum concentrations  on  mortality  and  hospitalization  in  heart  failure:  a  propensitymatched study of the DIG trial. Int J Cardiol. 2008;123:138-146.
5. Aguirre Dávila L, Weber K, Bavendiek U, et al. Digoxin-mortality: randomized vs. observational comparison in the DIG trial. Eur Heart J. 2019;40:33363341.
6.  Ambrosy AP, Butler J, Ahmed A, et al. The use of digoxin in patients with worsening chronic heart failure: reconsidering an old drug to reduce hospital admissions. J Am Coll Cardiol. 2014;63:1823-1832.
7. Gheorghiade M, Patel K, Filippatos G, et al. Effect of oral digoxin in high-risk heart failure patients: a pre-specified subgroup analysis of the DIG trial. Eur J Heart Fail. 2013;15:551-559.
8. Adams KF Jr, Butler J, Patterson JH, et al. Dose response characterization of the association of serum digoxin concentration with mortality outcomes in the Digitalis Investigation Group trial. Eur J Heart Fail. 2016;18:10721081.
9. Lopes RD, Rordorf R, De Ferrari GM, et al. Digoxin and mortality in patients with atrial fibrillation. J Am Coll Cardiol. 2018;71:1063-1074.
10. Malik A, Masson R, Singh S, et al. Digoxin discontinuation and outcomes in patients with heart failure with reduced ejection fraction. J Am Coll Cardiol. 2019;74:617-627.
11. Uretsky  BF,  Young  JB,  Shahidi  FE,  et  al.  Randomized  study  assessing the effect of digoxin withdrawal in patients with mild to moderate chronic congestive  heart  failure:  results  of  the  PROVED  trial. J  Am  Coll  Cardiol. 1993;22:955-962.

## 7.3.9.3. Pharmacological Treatment for Stage C HFrEF: Soluble Guanylyl Cyclase Stimulators

1. Armstrong PW, Pieske B, Anstrom KJ, et al. Vericiguat in patients with heart failure and reduced ejection fraction. N Engl J Med. 2020;382:1883-1893.

2. Arnold WP, Mittal CK, Katsuki S, et al. Nitric oxide activates guanylate cyclase and increases guanosine 3',5'-cyclic monophosphate levels in various tissue preparations. Proc Natl Acad Sci U S A. 1977;74:3203-3207.
3.  Hardman JG, Davis JW, Sutherland EW. Effects of some hormonal and other factors on the excretion of guanosine 3',5'-monophosphate and adenosine 3',5'-monophosphate in rat urine. J Biol Chem. 1969;244:6354-6362.
4.  Hardman JG, Sutherland EW. Guanyl cyclase, an enzyme catalyzing the formation  of  guanosine  3',5'-monophosphate  from  guanosine  trihosphate. J Biol Chem. 1969;244:6363-6370.
5.  McNamara DB, Kadowitz PJ, Hyman AL, et al. Adenosine 3',5'-monophosphate formation by preparations of rat liver soluble guanylate cyclase activated with nitric oxide, nitrosyl ferroheme, S-nitrosothiols, and other nitroso compounds. Can J Physiol Pharmacol. 1980;58:1446-1456.
6. Moncada S, Higgs EA. Nitric oxide and the vascular endothelium. Handb Exp Pharmacol. 2006:213-254.
7.  Moncada S, Palmer RM, Higgs EA. The discovery of nitric oxide as the endogenous nitrovasodilator. Hypertension. 1988;12:365-372.

## 7.4.1. Implantable Cardioverter Defibrillators (ICDs) and Cardiac Resynchronization Therapy (CRT)

1. Antiarrhythmics  versus  Implantable  Defibrillators  Investigators.  A  comparison of antiarrhythmic-drug therapy with implantable defibrillators in patients resuscitated from near-fatal ventricular arrhythmias. N Engl J Med. 1997;337:1576-1583.
2.  Kuck KH, Cappato R, Siebels J, et al. Randomized comparison of antiarrhythmic drug therapy with implantable defibrillators in patients resuscitated from cardiac arrest: the Cardiac Arrest Study Hamburg (CASH). Circulation . 2000;102:748-754.
3. Connolly SJ, Gent M, Roberts RS, et al. Canadian Implantable Defibrillator Study (CIDS); a randomized trial of the implantable cardioverter defibrillator against amiodarone. Circulation. 2000;101:1297-1302.
4.  Moss AJ, Hall J, Cannom DS, et al. Improved survival with an implanted defibrillator in patients with coronary disease at high risk for ventricular arrhythmia. Multicenter Automatic Defibrillator Implantation Trial Investigators. N Engl J Med. 1996;335:1933-1940.
5.  Buxton AE, Lee KL, Fisher JD, et al. A randomized study of the prevention of sudden death in patients with coronary artery disease. Multicenter Unsustained Tachycardia Trial Investigators. N Engl J Med. 1999;341:18821890.
6. Moss AJ, Zareba W, Hall WJ, et al. Prophylactic implantation of a defibrillator in patients with myocardial infarction and reduced ejection fraction. N Engl J Med. 2002;346:877-883.
7. Kadish  A,  Dyer  A,  Daubert  JP,  et  al.  Prophylactic  defibrillator  implantation  in  patients  with  nonischemic  dilated  cardiomyopathy. N Engl J Med. 2004;350:2151-2158.
8. Bardy GH, Lee KL, Mark DB, et al. Amiodarone or an implantable cardioverterdefibrillator for congestive heart failure. N Engl J Med. 2005;352:225-237.
9. Kober L, Thune JJ, Nielsen JC, et al. Defibrillator implantation in patients with  nonischemic  systolic  heart  failure. N Engl  J  Med. 2016;375:12211230.
10.  Al-Khatib SM, Anstrom KJ, Eisenstein EL, et al. Clinical and economic implications of the Multicenter Automatic Defibrillator Implantation Trial-II. Ann Intern Med. 2005;142:593-600.
11. Cowie  MR,  Marshall  D,  Drummond  M,  et  al.  Lifetime  cost-effectiveness of  prophylactic  implantation  of  a  cardioverter  defibrillator  in  patients  with reduced left ventricular systolic function: results of Markov modelling in a European population. Europace. 2009;11:716-726.
12.  Mark DB, Nelson CL, Anstrom KJ, et al. Cost-effectiveness of defibrillator therapy or amiodarone in chronic stable heart failure: results from the Sudden  Cardiac  Death  in  Heart  Failure  Trial  (SCD-HeFT). Circulation . 2006;114:135-142.
13. Mushlin AI, Hall WJ, Zwanziger J, et al. The cost-effectiveness of automatic implantable cardiac defibrillators: results from MADIT. Multicenter Automatic Defibrillator Implantation Trial. Circulation . 1998;97:2129-2135.
14. Sanders  GD,  Hlatky  MA,  Owens  DK.  Cost-effectiveness  of  implantable cardioverter-defibrillators. N Engl J Med. 2005;353:1471-1480.
15. Zwanziger J, Hall WJ, Dick AW, et al. The cost effectiveness of implantable cardioverter-defibrillators: results from the Multicenter Automatic Defibrillator Implantation Trial (MADIT)-II. J Am Coll Cardiol. 2006;47:2310-2318.
16. Abraham  WT,  Fisher  WG,  Smith  AL,  et  al.  Cardiac  resynchronization  in chronic heart failure. N Engl J Med. 2002;346:1845-1853.
17. 17 .  Bristow MR, Saxon LA, Boehmer J, et al. Cardiac-resynchronization therapy with or without an implantable defibrillator in advanced chronic heart failure. N Engl J Med. 2004;350:2140-2150.
18. Cleland  JG,  Daubert  JC,  Erdmann  E,  et  al.  The  effect  of  cardiac  resynchronization  on  morbidity  and  mortality  in  heart  failure. N  Engl  J  Med. 2005;352:1539-1549.
19.  Linde C, Abraham WT, Gold MR, et al. Randomized trial of cardiac resynchronization in mildly symptomatic heart failure patients and in asymptomatic  patients  with  left  ventricular  dysfunction  and  previous  heart  failure symptoms. J Am Coll Cardiol. 2008;52:1834-1843.
20. Goldenberg I, Kutyifa V, Klein HU, et al. Survival with cardiac-resynchronization therapy in mild heart failure. N Engl J Med. 2014;370:1694-1701.
21. Tang AS, Wells GA, Talajic M, et al. Cardiac-resynchronization therapy for mild-to-moderate heart failure. N Engl J Med. 2010;363:2385-2395.
22. Feldman AM, de Lissovoy G, Bristow MR, et al. Cost effectiveness of cardiac resynchronization therapy in the Comparison of Medical Therapy, Pacing, and Defibrillation in Heart Failure (COMPANION) trial. J Am Coll Cardiol. 2005;46:2311-2321.
23.  Gold MR, Padhiar A, Mealing S, et al. Economic value and cost-effectiveness of cardiac resynchronization therapy among patients with mild heart failure: projections from the REVERSE long-term follow-up. J Am Coll Cardiol HF. 2017;5:204-212.
24. Heerey A, Lauer M, Alsolaiman F, et al. Cost effectiveness of biventricular pacemakers in heart failure patients. Am J Cardiovasc Drugs. 2006;6:129137.
25. Nichol G, Kaul P, Huszti E, et al. Cost-effectiveness of cardiac resynchronization therapy in patients with symptomatic heart failure. Ann Intern Med. 2004;141:343-351.
26. Noyes  K,  Veazie  P,  Hall  WJ,  et  al.  Cost-effectiveness  of  cardiac  resynchronization  therapy  in  the  MADIT-CRT  trial. J  Cardiovasc  Electrophysiol. 2013;24:66-74.
27. 27 . Woo  CY,  Strandberg  EJ,  Schmiegelow  MD,  et  al.  Cost-effectiveness  of adding  cardiac  resynchronization  therapy  to  an  implantable  cardioverter-defibrillator  among  patients  with  mild  heart  failure. Ann  Intern  Med. 2015;163:417-426.
28.  Sipahi I,  Chou JC, Hyden M, et al. Effect of QRS morphology on clinical event  reduction  with  cardiac  resynchronization  therapy:  meta-analysis  of randomized controlled trials. Am Heart J. 2012;163:260-267.e3.
29. Gervais R, Leclercq C, Shankar A, et al. Surface electrocardiogram to predict outcome in candidates for cardiac resynchronization therapy: a sub-analysis of the CARE-HF trial. Eur J Heart Fail. 2009;11:699-705.
30. Zareba W, Klein H, Cygankiewicz I, et al. Effectiveness of cardiac resynchronization therapy by QRS morphology in the Multicenter Automatic Defibrillator  Implantation  Trial-Cardiac  Resynchronization  Therapy  (MADIT-CRT). Circulation . 2011;123:1061-1072.
31. Gold MR, Thebault C, Linde C, et al. Effect of QRS duration and morphology on cardiac resynchronization therapy outcomes in mild heart failure: results from the Resynchronization Reverses Remodeling in Systolic Left Ventricular Dysfunction (REVERSE) study. Circulation. 2012;126:822-829.
32.  Birnie DH, Ha A, Higginson L, et al. Impact of QRS morphology and duration on outcomes after cardiac resynchronization therapy: results from the Resynchronization-Defibrillation for Ambulatory Heart Failure Trial (RAFT). Circ Heart Fail. 2013;6:1190-1198.
33.  Nery PB, Ha AC, Keren A, et al. Cardiac resynchronization therapy in patients with left ventricular systolic dysfunction and right bundle branch block: a systematic review. Heart Rhythm. 2011;8:1083-1087.
34. Curtis AB. Biventricular pacing for atrioventricular block and systolic dysfunction. N Engl J Med. 2013;369:579.
35. Doshi RN, Daoud EG, Fellows C, et al. Left ventricular-based cardiac stimulation post AV nodal ablation evaluation (the PAVE study). J Cardiovasc Electrophysiol. 2005;16:1160-1165.
36. Pugh TJ, Kelly MA, Gowrisankar S, et al. The landscape of genetic variation in dilated cardiomyopathy as surveyed by clinical DNA sequencing. Genet Med. 2014;16:601-608.
37. 37 . Gigli  M,  Merlo  M,  Graw  SL,  et  al.  Genetic  risk  of  arrhythmic  phenotypes in patients with dilated cardiomyopathy. J Am Coll Cardiol. 2019;74:14801490.
38.  Towbin JA, McKenna WJ, Abrams DJ, et al. 2019 HRS expert consensus statement on evaluation, risk stratification, and management of arrhythmogenic cardiomyopathy. Heart Rhythm. 2019;16:e301-e372.
39. Moss  AJ,  Hall  WJ,  Cannom  DS,  et  al.  Cardiac-resynchronization  therapy for the prevention of heart-failure events. N Engl J Med. 2009;361:13291338.
40. Beshai JF,  Grimm RA, Nagueh SF, et al.  Cardiac-resynchronization  therapy  in  heart failure with narrow QRS complexes. N Engl J Med. 2007;357:2461-2471.
41.  Ruschitzka F, Abraham  WT,  Singh  JP, et al. Cardiac-resynchronization  therapy  in  heart  failure  with  a  narrow  QRS  complex. N Engl J Med. 2013;369:1395-1405.

42. Smith  T,  Jordaens  L,  Theuns  DA,  et  al.  The  cost-effectiveness  of  primary  prophylactic  implantable  defibrillator  therapy  in  patients  with  ischaemic or non-ischaemic heart disease: a European analysis. Eur Heart J. 2013;34:211-219.
43. Bigger JT Jr. Prophylactic use of implanted cardiac defibrillators in patients at  high  risk  for  ventricular  arrhythmias  after  coronary-artery  bypass  graft surgery. Coronary Artery Bypass Graft (CABG) Patch Trial Investigators. N Engl J Med. 1997;337:1569-1575.
44.  Mild therapeutic hypothermia to improve the neurologic outcome after cardiac arrest. N Engl J Med. 2002;346:549-556.
45. Healey  JS,  Hohnloser  SH,  Exner  DV,  et  al.  Cardiac  resynchronization therapy in patients with permanent atrial fibrillation: results from the Resynchronization for Ambulatory Heart Failure Trial (RAFT). Circ Heart Fail. 2012;5:566-570.
46.  Tolosana JM, Hernandez Madrid A, Brugada J, et al. Comparison of benefits  and  mortality  in  cardiac  resynchronization  therapy  in  patients  with atrial  fibrillation  versus  patients  in  sinus  rhythm  (results  of  the  Spanish Atrial  Fibrillation  And  Resynchronization  [SPARE]  study). Am  J  Cardiol. 2008;102:444-449.
6. 47 .  Kalscheur MM, Saxon LA, Lee BK, et al. Outcomes of cardiac resynchronization therapy in patients with intermittent atrial fibrillation or atrial flutter in the COMPANION trial. Heart Rhythm. 2017;14:858-865.
48. Adelstein  E,  Schwartzman  D,  Gorcsan  J  3rd,  et  al.  Predicting  hyperresponse  among  pacemaker-dependent  nonischemic  cardiomyopathy  patients  upgraded  to  cardiac  resynchronization. J  Cardiovasc  Electrophysiol. 2011;22:905-911.
49.  Al-Khatib SM, Stevenson WG, Ackerman MJ, et al. 2017 AHA/ACC/HRS guideline for management of patients with ventricular arrhythmias and the prevention of sudden cardiac death: a report of the American College of Cardiology/American  Heart  Association  Task  Force  on  Clinical  Practice Guidelines  and  the  Heart  Rhythm  Society. Circulation .  2018;138:e272e391.
50.  Ruschitzka F, Abraham  WT,  Singh  JP, et al. Cardiac-resynchronization  therapy  in  heart  failure  with  a  narrow  QRS  complex. N Engl J Med. 2013;369:1395-1405.
51. Thibault B, Harel F, Ducharme A, et al. Cardiac resynchronization therapy in patients with heart failure and a QRS complex &lt;120 milliseconds: the Evaluation Of Resynchronization Therapy For Heart Failure (LESSER-EARTH) trial. Circulation. 2013;127:873-881.
52. Muto C, Solimene F, Gallo P, et al. A randomized study of cardiac resynchronization therapy defibrillator versus dual-chamber implantable cardioverterdefibrillator in ischemic cardiomyopathy with narrow QRS: the NARROWCRT study. Circ Arrhythm Electrophysiol. 2013;6:538-545.

## 7.4.2. Other Implantable Electrical Interventions

1.  Hartupee J, Mann DL. Neurohormonal activation in heart failure with reduced ejection fraction. Nat Rev Cardiol. 2017;14:30-38.
2. Wagner  BR,  Frishman  WH.  Devices  for  autonomic  regulation  therapy  in heart failure with reduced ejection fraction. Cardiol Rev. 2018;26:43-49.
3. Zile  MR,  Lindenfeld  J,  Weaver  FA,  et  al.  Baroreflex  activation  therapy  in patients with heart failure with reduced ejection fraction. J Am Coll Cardiol. 2020;76:1-13.
4.  Gold MR, Van Veldhuisen DJ, Hauptman PJ, et al. Vagus nerve stimulation for the treatment of heart failure: the INOVATE-HF trial. J Am Coll Cardiol. 2016;68:149-158.
5.  Leclercq C, Gadler F, Kranig W, et al. A randomized comparison of triplesite versus dual-site ventricular stimulation in patients with congestive heart failure. J Am Coll Cardiol. 2008;51:1455-1462.
6. Niazi I, Baker J 2nd, Corbisiero R, et al. Safety and efficacy of multipoint pacing in cardiac resynchronization therapy: the multipoint pacing trial. J Am Coll Cardiol EP. 2017;3:1510-1518.
7.  LeClercq C. Personal communication about phase 2 trial data . 2020.
8. Abdelrahman  M,  Subzposh  FA,  Beer  D,  et  al.  Clinical  outcomes  of  his bundle  pacing  compared  to  right  ventricular  pacing. J  Am  Coll  Cardiol. 2018;71:2319-2330.
9.  Upadhyay GA, Vijayaraman P, Nayak HM, et al. On-treatment comparison between corrective his bundle pacing and biventricular pacing for cardiac resynchronization: a secondary analysis of the His-SYNC pilot trial. Heart Rhythm. 2019;16:1797-1807.
10. Upadhyay GA, Vijayaraman P,  Nayak  HM,  et  al.  His  corrective  pacing  or biventricular pacing for cardiac resynchronization in heart failure. J Am Coll Cardiol. 2019;74:157-159.
11. Neelagaru SB, Sanchez JE, Lau SK, et al. Nonexcitatory, cardiac contractility modulation electrical impulses: feasibility study for advanced heart failure in patients with normal QRS duration. Heart Rhythm. 2006;3:1140-1147.
12.  Borggrefe MM, Lawo T, Butter C, et al. Randomized, double blind study of non-excitatory, cardiac contractility modulation electrical impulses for symptomatic heart failure. Eur Heart J. 2008;29:1019-1028.
13. Kadish  A,  Nademanee  K,  Volosin  K,  et  al.  A  randomized  controlled  trial evaluating the safety and efficacy of cardiac contractility modulation in advanced heart failure. Am Heart J. 2011;161:329-337.e1-2.
14.  Abraham WT, Kuck KH, Goldsmith RL, et al. A randomized controlled trial to evaluate the safety and efficacy of cardiac contractility modulation. J Am Coll Cardiol HF . 2018;6:874-883.

## 7.4.3. Revascularization for Coronary Artery Disease

1.  Caracciolo EA, Davis KB, Sopko G, et al. Comparison of surgical and medical group survival in patients with left main equivalent coronary artery disease. Long-term CASS experience. Circulation . 1995;91:2335-2344.
2.  Howlett JG, Stebbins A, Petrie MC, et al. CABG improves outcomes in patients with ischemic cardiomyopathy: 10-year follow-up of the STICH Trial. J Am Coll Cardiol HF. 2019;7:878-887.
3. Mark DB, Knight JD, Velazquez EJ, et al. Quality-of-life outcomes with coronary artery bypass graft surgery in ischemic left ventricular dysfunction: a randomized trial. Ann Intern Med. 2014;161:392-399.
4. Park S, Ahn JM, Kim TO, et al. Revascularization in patients with left main coronary artery disease and left ventricular dysfunction. J Am Coll Cardiol. 2020;76:1395-1406.
5.  Petrie MC, Jhund PS, She L, et al. Ten-year outcomes after coronary artery bypass grafting according to age in patients with heart failure and left ventricular  systolic  dysfunction:  an  analysis  of  the  extended  follow-up  of the STICH Trial (Surgical Treatment for Ischemic Heart Failure). Circulation . 2016;134:1314-1324.
6. Tam DY, Dharma C, Rocha R, et al. Long-term survival after surgical or percutaneous revascularization in patients with diabetes and multivessel coronary disease. J Am Coll Cardiol. 2020;76:1153-1164.
7.  Velazquez EJ, Lee KL, Deja MA, et al. Coronary-artery bypass surgery in patients with left ventricular dysfunction. N Engl J Med. 2011;364:16071616.
8.  Velazquez EJ, Lee KL, Jones RH, et al. Coronary-artery bypass surgery in patients  with  ischemic  cardiomyopathy. N  Engl  J  Med. 2016;374:15111520.
9. Perera  D,  Clayton  T,  Petrie  MC,  et  al.  Percutaneous  revascularization  for ischemic  ventricular  dysfunction:  rationale  and  design  of  the  REVIVEDBCIS2 Trial: percutaneous coronary intervention for ischemic cardiomyopathy. J Am Coll Cardiol HF. 2018;6:517-526.
10.  Nagendran J, Bozso SJ, Norris CM, et al. Coronary artery bypass surgery improves outcomes in patients with diabetes and left ventricular dysfunction. J Am Coll Cardiol. 2018;71:819-827.
11.  Chaitman BR, Fisher LD, Bourassa MG, et al. Effect of coronary bypass surgery on survival patterns in subsets of patients with left main coronary artery disease. Report of the Collaborative Study in Coronary Artery Surgery (CASS). Am J Cardiol. 1981;48:765-777.
12.  Jolicoeur EM, Dunning A, Castelvecchio S, et al. Importance of angina in patients with coronary disease, heart failure, and left ventricular systolic dysfunction: insights from STICH. J Am Coll Cardiol. 2015;66:2092-2100.
13.  Veterans  Administration  Coronary  Artery  Bypass  Surgery  Cooperative Study  Group.  Eleven-year  survival  in  the  Veterans  Administration  randomized trial of coronary bypass surgery for stable angina. N Engl J Med. 1984;311:1333-1339.
14.  VA Coronary Artery Bypass Surgery Cooperative Study Group. Eighteenyear follow-up in the Veterans Affairs Cooperative Study of Coronary Artery Bypass Surgery for stable angina. Circulation. 1992;86:121-130.
15. Jones RH, Velazquez EJ, Michler RE, et al. Coronary bypass surgery with or without surgical ventricular reconstruction. N Engl J Med. 2009;360:17051717.
16. Dor V, Civaia F, Alexandrescu C, et al. Favorable effects of left ventricular reconstruction in patients excluded from the Surgical Treatments for Ischemic Heart Failure (STICH) trial. J Thorac Cardiovasc Surg. 2011;141:905-916, 916e1-4.

## 7.5. Valvular Heart Disease

1. Nasser R, Van Assche L, Vorlat A, et al. Evolution of functional mitral regurgitation and prognosis in medically managed heart failure patients with reduced ejection fraction. J Am Coll Cardiol HF. 2017;5:652-659.
2. Lowes BD, Gill EA, Abraham WT, et al. Effects of carvedilol on left ventricular mass, chamber geometry, and mitral regurgitation in chronic heart failure. Am J Cardiol. 1999;83:1201-1205.

3.  Capomolla S, Febo O, Gnemmi M, et al. β -Blockade therapy in chronic heart failure: diastolic function and mitral regurgitation improvement by carvedilol. Am Heart J. 2000;139:596-608.
4. Kang DH, Park SJ, Shin SH, et al. Angiotensin receptor neprilysin inhibitor for functional mitral regurgitation. Circulation. 2019;139:1354-1365.
5.  van Bommel RJ, Marsan NA, Delgado V, et al. Cardiac resynchronization therapy as a therapeutic option in patients with moderate-severe functional mitral regurgitation and high operative risk. Circulation. 2011;124:912-919.
6. Obadia  J-F,  Messika-Zeitoun  D,  Leurent  G,  et  al.  Percutaneous  repair or  medical  treatment  for  secondary  mitral  regurgitation. N  Engl  J  Med. 2018;379:2297-2306.
7. Inohara T, Manandhar P, Kosinski AS, et al. Association of renin-angiotensin inhibitor treatment with mortality and heart failure readmission in patients with transcatheter aortic valve replacement. JAMA. 2018;320:2231-2241.
8.  Kapadia SR, Leon MB, Makkar RR, et al. 5-year outcomes of transcatheter aortic  valve  replacement  compared  with  standard  treatment  for  patients with inoperable aortic stenosis (PARTNER 1): a randomised controlled trial. Lancet. 2015;385:2485-2491.
9. Evangelista A, Tornos P, Sambola A, et al. Long-term vasodilator therapy in patients with severe aortic regurgitation. N Engl J Med. 2005;353:13421349.
10.  Bhudia SK, McCarthy PM, Kumpati GS, et al. Improved outcomes after aortic valve surgery for chronic aortic regurgitation with severe left ventricular dysfunction. J Am Coll Cardiol. 2007;49:1465-1471.
11. Mack MJ, Leon MB, Smith CR, et al. 5-year outcomes of transcatheter aortic valve replacement or surgical aortic valve replacement for high surgical risk patients with aortic stenosis (PARTNER 1): a randomised controlled trial. Lancet. 2015;385:2477-2484.
12. Agricola E, Ielasi A, Oppizzi M, et al. Long-term prognosis of medically treated patients with functional mitral regurgitation and left ventricular dysfunction. Eur J Heart Fail. 2009;11:581-587.
13.  Karaca O, Omaygenc MO, Cakal B, et al. Effect of QRS narrowing after cardiac resynchronization therapy on functional mitral regurgitation in patients with systolic heart failure. Am J Cardiol. 2016;117:412-419.
14.  St John Sutton MG, Plappert T, Abraham WT, et al. Effect of cardiac resynchronization therapy on left ventricular size and function in chronic heart failure. Circulation. 2003;107:1985-1990.
15.  Otto CM, Nishimura RA, Bonow RO, et al. 2020 ACC/AHA guideline for the management of patients with valvular heart disease: a report of the American College of Cardiology/American Heart Association Joint Committee on Clinical Practice Guidelines. Circulation . 2021;143:e72-e227.
16. De la Espriella R, Santas E, Miñana G, et al. Functional mitral regurgitation predicts short-term adverse events in patients with acute heart failure and reduced left ventricular ejection fraction. Am J Cardiol. 2017;120:13441348.
15. 17 .  Breithardt OA, Sinha AM, Schwammenthal E, et al. Acute effects of cardiac resynchronization  therapy  on  functional  mitral  regurgitation  in  advanced systolic heart failure. J Am Coll Cardiol. 2003;41:765-770.
18. Kheiri  B,  Zayed  Y,  Barbarawi  M,  et  al.  Interventions  for  secondary  mitral regurgitation in patients with heart failure: a network meta-analysis of randomized controlled comparisons of surgery, medical therapy and transcatheter intervention. Cardiovasc Revasc Med. 2020;21:155-163.
19. Grayburn  PA,  Sannino  A,  Packer  M.  Proportionate  and  disproportionate functional  mitral  regurgitation:  a  new  conceptual  framework  that  reconciles the results of the MITRA-FR and COAPT Trials. J Am Coll Cardiol Img. 2019;12:353-362.
20. Packer M. Disproportionate functional mitral regurgitation: a new therapeutic target in patients with heart failure and a reduced ejection fraction. Eur J Heart Fail. 2020;22:23-25.
21. Packer M, Grayburn PA. Contrasting effects of pharmacological, procedural, and surgical interventions on proportionate and disproportionate functional mitral regurgitation in chronic heart failure. Circulation. 2019;140:779-789.
22. Yu C-M, Chan J-S, Zhang Q, et al. Impact of cardiac contractility modulation on left ventricular global and regional function and remodeling. J Am Coll Cardiol Img. 2009;2:1341-1349.
23.  Clavel MA, Magne J, Pibarot P. Low-gradient aortic stenosis. Eur Heart J. 2016;7:2645-2657.
24.  Vamvakidou A, Jin W, Danylenko O, et al. Low transvalvular flow rate predicts mortality in patients with low-gradient aortic stenosis following aortic valve intervention. J Am Coll Cardiol Img. 2019;12:1715-1724.
25.  Spitzer E, Van Mieghem NM, Pibarot P, et al. Rationale and design of the Transcatheter  Aortic  Valve  Replacement  to  UNload  the  Left  ventricle  in patients  with  ADvanced heart failure  (TAVR UNLOAD) trial. Am Heart J. 2016;182:80-88.
26.  Nishimura RA, Otto CM, Bonow RO, et al. 2014 AHA/ACC guideline for the  management  of  patients  with  valvular  heart  disease:  a  report  of  the American College of Cardiology/American Heart Association Task Force on Practice Guidelines. Circulation . 2014;129:e521-e643.
25. 27 . Packer  M,  Grayburn  PA.  Neurohormonal  and  transcatheter  repair  strategies for proportionate and disproportionate functional mitral regurgitation in heart failure. J Am Coll Cardiol HF. 2019;7:518-521.
28. Stone GW, Lindenfeld J, Abraham WT, et al. Transcatheter mitral-valve repair in patients with heart failure. N Engl J Med. 2018;379:2307-2318.
29.  Leon MB, Smith CR, Mack M, et al. Transcatheter aortic-valve implantation for aortic stenosis in patients who cannot undergo surgery. N Engl J Med. 2010;363:1597-1607.
30. Makkar RR, Fontana GP, Jilaihawi H, et al. Transcatheter aortic-valve replacement for inoperable severe aortic stenosis. N Engl J Med. 2012;366:16961704.
31. Tribouilloy C, Levy F, Rusinaru D, et al. Outcome after aortic valve replacement for low-flow/low-gradient aortic stenosis without contractile reserve on dobutamine stress echocardiography. J Am Coll Cardiol. 2009;53:18651873.
32. Herrmann HC, Pibarot P, Hueter I, et al. Predictors of mortality and outcomes of therapy in low-flow severe aortic stenosis: a Placement of Aortic Transcatheter  Valves  (PARTNER)  trial  analysis. Circulation. 2013;127:23162326.
33. Anjan VY, Herrmann HC, Pibarot P, et al. Evaluation of flow after transcatheter  aortic  valve  replacement  in  patients  with  low-flow  aortic  stenosis:  a secondary analysis of the PARTNER randomized clinical trial. JAMA Cardiol. 2016;1:584-592.
34. Klodas E, Enriquez-Sarano M, Tajik AJ, et al. Optimizing timing of surgical correction in patients with severe aortic regurgitation: role of symptoms. J Am Coll Cardiol. 1997;30:746-752.
35. Chaliki HP, Mohty D, Avierinos JF, et al. Outcomes after aortic valve replacement in patients with severe aortic regurgitation and markedly reduced left ventricular function. Circulation. 2002;106:2687-2693.

## 7.6.1. Heart Failure With Mildly Reduced Ejection Fraction (HFmrEF)

1. Anker SD, Butler J, Filippatos G, et al. Empagliflozin in heart failure with a preserved ejection fraction. N Engl J Med. 2021;385:1451-1461.
2.  Cleland JGF, Bunting KV, Flather MD, et al. Beta-blockers for heart failure  with  reduced,  mid-range,  and  preserved  ejection  fraction:  an  individual  patient-level  analysis  of  double-blind  randomized  trials. Eur  Heart  J. 2018;39:26-35.
3. Solomon  SD,  McMurray  JJV,  Anand  IS,  et  al.  Angiotensin-neprilysin  inhibition  in  heart  failure  with  preserved  ejection  fraction. N  Engl  J  Med. 2019;381:1609-1620.
4. Halliday  BP,  Wassall  R,  Lota  AS,  et  al.  Withdrawal  of  pharmacological treatment  for  heart  failure  in  patients  with  recovered  dilated  cardiomyopathy  (TRED-HF):  an  open-label,  pilot,  randomised  trial. Lancet. 2019;393:61-73.
5. Nilsson BB, Lunde P, Grogaard HK, et al. Long-term results of high-intensity exercise-based cardiac rehabilitation  in  revascularized  patients  for  symptomatic coronary artery disease. Am J Cardiol. 2018;121:21-26.
6. Solomon SD, Claggett B, Desai AS, et al. Influence of ejection fraction on outcomes and efficacy of sacubitril/valsartan (lcz696) in heart failure with reduced ejection fraction: the Prospective Comparison of ARNI with ACEI to  Determine  Impact  on  Global  Mortality  and  Morbidity  in  Heart  Failure (PARADIGM-HF) trial. Circ Heart Fail. 2016;9:e002744.
7. Tsuji K, Sakata Y, Nochioka K, et al. Characterization of heart failure patients with mid-range left ventricular ejection fraction-a report from the CHART-2 Study. Eur J Heart Fail. 2017;19:1258-1269.
8.  Solomon  SD,  Vaduganathan  M,  Claggett  BL,  et  al.  Sacubitril/valsartan  across  the  spectrum  of  ejection  fraction  in  heart  failure. Circulation. 2020;141:352-361.
9.  Zheng SL, Chan FT, Nabeebaccus AA, et al. Drug treatment effects on outcomes in heart failure with preserved ejection fraction: a systematic review and meta-analysis. Heart. 2018;104:407-415.
10.  Packer M, Butler J, Zannad F, et al. Effect of empagliflozin on worsening heart failure events in patients with heart failure and a preserved ejection fraction:  the  EMPEROR-Preserved  trial. Circulation. 2021;144:12841294.

## 7.6.2. HF With Improved Ejection Fraction

1. Halliday BP, Wassall R, Lota AS, et al. Withdrawal of pharmacological treatment  for  heart  failure  in  patients  with  recovered  dilated  cardiomyopathy

- (TRED-HF): an open-label, pilot, randomised trial. Lancet. 2019;393:6173.
2. Wilcox JE, Fang JC, Margulies KB, et al. Heart failure with recovered left ventricular ejection fraction: JACC Scientific Expert Panel. J Am Coll Cardiol. 2020;76:719-734.
3. Bozkurt B, Coats AJS, Tsutsui H, et al. Universal definition and classification of heart failure: a report of the Heart Failure Society of America, Heart Failure Association of the European Society of Cardiology, Japanese Heart Failure Society and Writing Committee of the Universal Definition of Heart Failure. J Card Fail. 2021;27:387-413.

## 7.7.1. HF With Preserved EF (HFpEF)

1.  Thomopoulos C, Parati G, Zanchetti A. Effects of blood-pressure-lowering treatment in hypertension: 9. Discontinuations for adverse events attributed to different classes of antihypertensive drugs: meta-analyses of randomized trials. J Hypertens. 2016;34:1921-1932.
2. Williamson  JD,  Supiano  MA,  Applegate  WB,  et  al.  Intensive  vs  standard blood pressure control and cardiovascular disease outcomes in adults aged ≥ 75 years: a randomized clinical trial. JAMA. 2016;315:2673-2682.
3.  SPRINT Research Group, Wright JT Jr, Williamson JD, et al.  A  randomized trial of intensive versus standard blood-pressure control. N Engl J Med. 2015;373:2103-2116.
4. Anker SD, Butler J, Filippatos G, et al. Empagliflozin in heart failure with a preserved ejection fraction. N Engl J Med. 2021;385:1451-1461.
5. Pitt B, Pfeffer MA, Assmann SF, et al. Spironolactone for heart failure with preserved ejection fraction. N Engl J Med. 2014;370:1383-1392.
6. Pfeffer  MA,  Claggett  B,  Assmann  SF,  et  al.  Regional  variation  in  patients  and  outcomes  in  the  Treatment  of  Preserved  Cardiac  Function Heart Failure With an Aldosterone Antagonist (TOPCAT) trial. Circulation. 2015;131:34-42.
7. Solomon SD, Claggett B, Desai AS, et al. Influence of ejection fraction on outcomes and efficacy of sacubitril/valsartan (lcz696) in heart failure with reduced ejection fraction: the Prospective Comparison of ARNI with ACEI to  Determine  Impact  on  Global  Mortality  and  Morbidity  in  Heart  Failure (PARADIGM-HF) trial. Circ Heart Fail. 2016;9:e002744.
8. Yusuf S, Pfeffer MA, Swedberg K, et al. Effects of candesartan in patients with chronic heart failure and preserved left-ventricular ejection fraction: the CHARM-Preserved Trial. Lancet. 2003;362:777-781.
9. Lund LH, Claggett B, Liu J, et al. Heart failure with mid-range ejection fraction in CHARM: characteristics, outcomes and effect of candesartan across the  entire  ejection  fraction  spectrum. Eur  J  Heart  Fail. 2018;20:12301239.
10. Solomon  SD,  McMurray  JJV,  Anand  IS,  et  al.  Angiotensin-neprilysin  inhibition  in  heart  failure  with  preserved  ejection  fraction. N  Engl  J  Med. 2019;381:1609-1620.
11.  Solomon SD, Vaduganathan M, B LC, et al. Sacubitril/valsartan across the spectrum of ejection fraction in heart failure. Circulation. 2020;141:352361.
12. Redfield MM, Anstrom KJ, Levine JA, et al. Isosorbide mononitrate in heart failure  with  preserved  ejection  fraction. N Engl J Med. 2015;373:23142324.
13.  Redfield MM, Chen HH, Borlaug BA, et al. Effect of phosphodiesterase-5 inhibition on exercise capacity and clinical status in heart failure with preserved ejection fraction: a randomized clinical trial. JAMA. 2013;309:12681277.
14. Cincin A, Abul Y, Ozben B, et al. Pleural fluid amino-terminal brain natriuretic peptide in patients with pleural effusions. Respir Care. 2013;58:313-319.
15. Ather  S,  Chan  W,  Bozkurt  B,  et  al.  Impact  of  noncardiac  comorbidities on morbidity and mortality in a predominantly male population with heart failure and preserved versus reduced ejection fraction. J Am Coll Cardiol. 2012;59:998-1005.
16. Mentz RJ, Kelly JP, von Lueder TG, et al. Noncardiac comorbidities in heart failure with reduced versus preserved ejection fraction. J Am Coll Cardiol. 2014;64:2281-2293.
17. 17 .  Paulus WJ, Tschope C. A novel paradigm for heart failure with preserved ejection fraction: comorbidities drive myocardial dysfunction and remodeling through coronary microvascular endothelial inflammation. J Am Coll Cardiol. 2013;62:263-271.
18. Ho JE, Zern EK, Wooster L, et al. Differential clinical profiles, exercise responses, and outcomes associated with existing HFpEF definitions. Circulation. 2019;140:353-365.
19. Massie BM, Carson PE, McMurray JJ, et al. Irbesartan in patients with heart failure  and  preserved  ejection  fraction. N Engl  J  Med. 2008;359:24562467.
20.  Cleland JG, Tendera M, Adamus J, et al. The perindopril in elderly people with chronic heart failure (PEP-CHF) study. Eur Heart J. 2006;27:23382345.
21.  Beckett NS, Peters R, Fletcher AE, et al. Treatment of hypertension in patients 80 years of age or older. N Engl J Med. 2008;358:1887-1898.
22. Kostis JB, Davis BR, Cutler J, et al. Prevention of heart failure by antihypertensive drug treatment in older persons with isolated systolic hypertension. SHEP Cooperative Research Group. JAMA . 1997;278:212-216.
23. Piller LB, Baraniuk S, Simpson LM, et al. Long-term follow-up of participants with heart failure in the antihypertensive and lipid-lowering treatment to prevent heart attack trial (ALLHAT). Circulation . 2011;124:1811-1818.
24. Xie X, Atkins E, Lv J, et al. Effects of intensive blood pressure lowering on cardiovascular and renal outcomes: updated systematic review and metaanalysis. Lancet. 2016;387:435-443.
25.  Law MR, Morris JK, Wald NJ. Use of blood pressure lowering drugs in the prevention of cardiovascular disease: meta-analysis of 147 randomised trials in the context of expectations from prospective epidemiological studies. BMJ . 2009;338:b1665.
26.  Whelton PK, Carey RM, Aronow WS, et al. 2017 ACC/AHA/AAPA/ABC/ ACPM/AGS/APhA/ASH/ASPC/NMA/PCNA guideline for the prevention, detection, evaluation, and management of high blood pressure in adults: a report of the American College of Cardiology/American Heart Association Task  Force  on  Clinical  Practice  Guidelines. Hypertension .  2018;71:e13e115.
27. 27 .  Aronow WS, Ahn C, Kronzon I. Effect of propranolol versus no propranolol on total mortality plus nonfatal myocardial infarction in older patients with prior myocardial infarction, congestive heart failure, and left ventricular ejection fraction &gt; or = 40% treated with diuretics plus angiotensin-converting enzyme inhibitors. Am J Cardiol. 1997;80:207-209.
28. van  Veldhuisen  DJ,  Cohen-Solal  A,  Böhm  M,  et  al.  Beta-blockade  with nebivolol in elderly heart failure patients with impaired and preserved left ventricular  ejection  fraction:  Data  From  SENIORS  (Study  of  Effects  of Nebivolol Intervention on Outcomes and Rehospitalization in Seniors With Heart Failure). J Am Coll Cardiol. 2009;53:2150-2158.
29.  Borlaug BA, Olson TP, Lam CS, et al. Global cardiovascular reserve dysfunction in heart failure with preserved ejection fraction. J Am Coll Cardiol. 2010;56:845-854.
30. Anker SD, Butler J, Filippatos G, et al. Empagliflozin in heart failure with a preserved ejection fraction. N Engl J Med. 2021;385:1451-1461.
31.  Packer M, Butler J, Zannad F, et al. Effect of empagliflozin on worsening heart failure events in patients with heart failure and a preserved ejection fraction:  the  EMPEROR-Preserved  trial. Circulation. 2021;144:12841294.
32. Kotecha D, Bunting KV, Gill SK, et al. Effect of digoxin vs bisoprolol for heart rate control in atrial fibrillation on patient-reported quality of life: the RATEAF randomized clinical trial. JAMA. 2020;324:2497-2508.
33.  January CT, Wann LS, Alpert JS, et al. 2014 AHA/ACC/HRS guideline for the management of patients with atrial fibrillation: a report of the American College of Cardiology/American Heart Association Task Force on Practice Guidelines  and  the  Heart  Rhythm  Society. Circulation. 2014;130:e199e267.
34.  January CT, Wann LS, Calkins H, et al. 2019 AHA/ACC/HRS focused update of the 2014 AHA/ACC/HRS guideline for the management of patients with atrial fibrillation: a report of the American College of Cardiology/ American Heart Association Task Force on Clinical Practice Guidelines and the Heart Rhythm Society. Circulation . 2019;140:e125-e151.
35.  Edelmann F, Wachter R, Schmidt AG, et al. Effect of spironolactone on diastolic function and exercise capacity in patients with heart failure with preserved ejection fraction: the Aldo-DHF randomized controlled trial. JAMA. 2013;309:781-791.
36. Martos R, Baugh J, Ledwidge M, et al. Diastolic heart failure: evidence of increased myocardial collagen turnover linked to diastolic dysfunction. Circulation. 2007;115:888-895.
37. 37 .  Yamamoto K, Masuyama T, Sakata Y, et al. Roles of renin-angiotensin and endothelin systems in development of diastolic heart failure in hypertensive hearts. Cardiovasc Res. 2000;47:274-283.
38. Yusuf S, Pfeffer MA, Swedberg K, et al. Effects of candesartan in patients with chronic heart failure and preserved left-ventricular ejection fraction: the CHARM-Preserved Trial. Lancet. 2003;362:777-781.
39. Nilsson BB, Lunde P, Grogaard HK, et al. Long-term results of high-intensity exercise-based cardiac rehabilitation  in  revascularized  patients  for  symptomatic coronary artery disease. Am J Cardiol. 2018;121:21-26.
40.  Lumbers RT, Martin N, Manoharan K, et al. Do beta-blockers and inhibitors  of  the  renin-angiotensin  aldosterone  system  improve  outcomes  in

- patients with heart failure and left ventricular ejection fraction &gt;40. Heart . 2019;105:1533-1535.
41.  Martin  N,  Manoharan K, Thomas J, et al. Beta-blockers and inhibitors of the renin-angiotensin aldosterone system for chronic heart failure with preserved ejection fraction. Cochrane Database Syst Rev. 2018;6:CD012721.
42.  Solomon SD, Zile M, Pieske B, et al. The angiotensin receptor neprilysin inhibitor LCZ696 in heart failure with preserved ejection fraction: a phase 2 double-blind randomised controlled trial. Lancet. 2012;380:1387-1395.
43. McMurray  JJV,  Jackson  AM,  Lam  CSP,  et  al.  Effects  of  sacubitril-valsartan  versus  valsartan  in  women  compared  with  men  with  heart  failure and preserved ejection fraction: insights from PARAGON-HF. Circulation. 2020;141:338-351.
44.  Solomon  SD,  Vaduganathan  M,  Claggett  BL,  et  al.  Sacubitril/valsartan  across  the  spectrum  of  ejection  fraction  in  heart  failure. Circulation . 2020;141:352-361.
45. Redfield MM, Anstrom KJ, Levine JA, et al. Isosorbide mononitrate in heart failure  with  preserved  ejection  fraction. N Engl J Med. 2015;373:23142324.

## 7.8.1. Diagnosis of Cardiac Amyloidosis

1. Castano  A,  Narotsky  DL,  Hamid  N,  et  al.  Unveiling  transthyretin  cardiac amyloidosis  and  its  predictors  among  elderly  patients  with  severe  aortic stenosis  undergoing  transcatheter  aortic  valve  replacement. Eur  Heart  J. 2017;38:2879-2887.
2.  Gonzalez-Lopez E, Gallego-Delgado M, Guzzo-Merello G, et al. Wild-type transthyretin amyloidosis as a cause of heart failure with preserved ejection fraction. Eur Heart J. 2015;36:2585-2594.
3. Sperry  BW,  Reyes  BA,  Ikram  A,  et  al.  Tenosynovial  and  cardiac  amyloidosis  in  patients  undergoing  carpal  tunnel  release. J  Am  Coll  Cardiol. 2018;72:2040-2050.
4.  Westermark P, Westermark GT, Suhr OB, et al. Transthyretin-derived amyloidosis: probably a common cause of lumbar spinal stenosis. Ups J Med Sci. 2014;119:223-228.
5.  Maurer MS, Hanna M, Grogan M, et al. Genotype and phenotype of transthyretin cardiac amyloidosis: THAOS (Transthyretin Amyloid Outcome Survey). J Am Coll Cardiol. 2016;68:161-172.
6.  Muchtar E, Gertz MA, Kyle RA, et al. A modern primer on light chain amyloidosis in 592 patients with mass spectrometry-verified typing. Mayo Clin Proc. 2019;94:472-483.
7. Gillmore  JD,  Maurer  MS,  Falk  RH,  et  al.  Nonbiopsy  diagnosis  of  cardiac transthyretin amyloidosis. Circulation. 2016;133:2404-2412.
8.  Brown EE, Lee YZJ, Halushka MK, et al. Genetic testing improves identification of transthyretin amyloid (ATTR) subtype in cardiac amyloidosis. Amyloid. 2017;24:92-95.
9.  Kittleson MM, Maurer MS, Ambardekar AV, et al. Cardiac amyloidosis: evolving diagnosis and management: a scientific statement from the American Heart Association. Circulation. 2020;142:e7-e22.
10. Quarta CC, Solomon SD, Uraizee I, et al. Left ventricular structure and function in transthyretin-related versus light-chain cardiac amyloidosis. Circulation. 2014;129:1840-1849.
11.  Katzmann JA, Abraham RS, Dispenzieri A, et al. Diagnostic performance of quantitative kappa and lambda free light chain assays in clinical practice. Clin Chem. 2005;51:878-881.
12.  Castano A, Haq M, Narotsky DL, et al. Multicenter study of planar technetium 99m pyrophosphate cardiac imaging: predicting survival for patients with ATTR cardiac amyloidosis. JAMA Cardiol. 2016;1:880-889.
13. Adams  D,  Gonzalez-Duarte  A,  O'Riordan  WD,  et  al.  Patisiran,  an  RNAi therapeutic, for hereditary transthyretin amyloidosis. N  Engl  J  Med. 2018;379:11-21.
14. Benson  MD,  Waddington-Cruz  M,  Berk  JL,  et  al.  Inotersen  treatment for  patients  with  hereditary  transthyretin  amyloidosis. N  Engl  J  Med. 2018;379:22-31.

## 7.8.2. Treatment of Cardiac Amyloidosis

1. Maurer  MS,  Schwartz  JH,  Gundapaneni  B,  et  al.  Tafamidis  treatment for  patients  with  transthyretin  amyloid  cardiomyopathy. N  Engl  J  Med. 2018;379:1007-1016.
2. Kazi DS, Bellows BK, Baron SJ, et al. Cost-effectiveness of tafamidis therapy for transthyretin amyloid cardiomyopathy. Circulation . 2020;141:1214-1224.
3. El-Am EA, Dispenzieri  A,  Melduni  RM,  et  al.  Direct  current  cardioversion of atrial arrhythmias in adults with cardiac amyloidosis. J Am Coll Cardiol. 2019;73:589-597.
4. Feng D, Syed IS, Martinez M, et al. Intracardiac thrombosis and anticoagulation therapy in cardiac amyloidosis. Circulation . 2009;119:2490-2497.
5. Kim  EJ,  Holmes  BB,  Huang  S,  et  al.  Outcomes  in  patients  with  cardiac amyloidosis and implantable cardioverter-defibrillator. Europace . 2020;22:1216-1223.
6. Benson  MD,  Waddington-Cruz  M,  Berk  JL,  et  al.  Inotersen  treatment for  patients  with  hereditary  transthyretin  amyloidosis. N  Engl  J  Med. 2018;379:22-31.
7. Adams  D,  Gonzalez-Duarte  A,  O'Riordan  WD,  et  al.  Patisiran,  an  RNAi therapeutic, for hereditary transthyretin amyloidosis. N  Engl  J  Med. 2018;379:11-21.
8. Berk JL, Suhr OB, Obici L, et al. Repurposing diflunisal for familial amyloid polyneuropathy: a randomized clinical trial. JAMA . 2013;310:2658-2667.
9. Wixner  J,  Pilebro  B,  Lundgren  HE,  Olsson  M,  Anan  I.  Effect  of  doxycycline  and  ursodeoxycholic  acid  on  transthyretin  amyloidosis. Amyloid. 2017;24:78-79.
10.  Obici L, Cortese A, Lozza A, et al. Doxycycline plus tauroursodeoxycholic acid for transthyretin amyloidosis: a phase II study. Amyloid. 2012; 19(suppl 1):34-36.
11. aus dem Siepen F, Bauer R, Aurich M, et al. Green tea extract as a treatment for patients with wild-type transthyretin amyloidosis: an observational study. Drug Des Devel Ther. 2015;9:6319-6325.
12.  Feng D, Edwards WD, Oh JK, et al. Intracardiac thrombosis and embolism in patients with cardiac amyloidosis. Circulation. 2007;116:2420-2426.
13. Donnellan  E,  Elshazly  MB,  Vakamudi  S,  et  al.  No  association  between CHADS-VASc score and left atrial appendage thrombus in patients with transthyretin amyloidosis. J Am Coll Cardiol EP. 2019;5:1473-1474.

## 8.1. Specialty Referral for Advanced HF

1.  Crespo-Leiro MG, Metra M, Lund LH, et al. Advanced heart failure: a position statement of the Heart Failure Association of the European Society of Cardiology. Eur J Heart Fail. 2018;20:1505-1535.
2.  Fang JC, Ewald GA, Allen LA, et al. Advanced (stage D) heart failure: a statement from the Heart Failure Society of America Guidelines Committee. J Card Fail. 2015;21:519-534.
3. Greenberg B, Fang J, Mehra M, et al. Advanced heart failure: trans-atlantic perspectives on the heart failure association of the European Society of Cardiology position statement. Eur J Heart Fail. 2018;20:1536-1539.
4.  Hunt SA, Abraham WT, Chin MH, et al. 2009 Focused update incorporated into the ACC/AHA 2005 guidelines for the diagnosis and management of heart failure in adults a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Circulation . 2009;119:e391-e479.
5.  Yancy CW, Jessup M, Bozkurt B, et al.  2017 ACC/AHA/HFSA focused update of the 2013 ACCF/AHA guideline for the management of heart failure: a report of the American College of Cardiology/American Heart Association Task Force on Clinical Practice Guidelines and the Heart Failure Society of America. Circulation . 2017;136:e137-e161.
6.  Thomas R, Huntley A, Mann M, et al. Specialist clinics for reducing emergency admissions in  patients  with  heart  failure:  a  systematic  review  and meta-analysis of randomised controlled trials. Heart. 2013;99:233-239.
7.  Stevenson  LW,  Pagani  FD,  Young  JB,  et  al.  INTERMACS  profiles  of advanced  heart  failure:  the  current  picture. J  Heart  Lung  Transplant. 2009;28:535-541.
8. Ambardekar  AV,  Fonarow  GC,  Hernandez  AF,  et  al.  Characteristics  and in-hospital outcomes for nonadherent patients with heart failure: findings from  Get  With  The  Guidelines-Heart  Failure  (GWTG-HF). Am  Heart  J. 2009;158:644-652.
9.  Andrews AM, Russell CL, Cheng AL. Medication adherence interventions for  older  adults  with  heart  failure:  a  systematic  review. J  Gerontol  Nurs. 2017;43:37-45.
10.  Fitzgerald AA, Powers JD, Ho PM, et al. Impact of medication nonadherence on hospitalizations and mortality in heart failure. J Card Fail. 2011;17:664669.
11.  Ruppar TM, Cooper PS, Mehr DR, et al. Medication adherence interventions improve heart failure mortality and readmission rates: systematic review and meta-analysis of controlled trials. J Am Heart Assoc. 2016;5:e002606.
12.  Yancy CW, Jessup M, Bozkurt B, et al. 2013 ACCF/AHA guideline for the management of heart failure:  a  report  of  the  American  College  of  Cardiology  Foundation/American  Heart  Association  Task  Force  on  Practice Guidelines. Circulation . 2013;128:e240-e327.
13. Russell SD, Miller LW, Pagani FD. Advanced heart failure: a call to action. Congest Heart Fail. 2008;14:316-321.
14.  Yancy CW, Januzzi JL Jr, Allen LA, et al. 2017 ACC expert consensus decision pathway for optimization of heart failure treatment: answers to 10 piv-

- otal issues about heart failure with reduced ejection fraction: a report of the American College of Cardiology Task Force on expert consensus decision pathways. J Am Coll Cardiol. 2018;71:201-230.
15.  Guglin M, Zucker MJ, Borlaug BA, et al. Evaluation for heart transplantation and L VAD implantation: JACC council perspectives. J Am Coll Cardiol. 2020;75:1471-1487.
16. Thorvaldsen T, Benson L, Stahlberg M, et al. Triage of patients with moderate to severe heart failure: who should be referred to a heart failure center? J Am Coll Cardiol. 2014;63:661-671.
- 17 . Lietz K, Long JW, Kfoury AG, et al. Outcomes of left ventricular assist device implantation as destination therapy in the post-REMATCH era: implications for patient selection. Circulation . 2007;116:497-505.
18.  Baumwol J.  'I Need Help'-A mnemonic to aid timely referral in advanced heart failure. J Heart Lung Transplant. 2017;36:593-594.
19. Feldman D, Pamboukian SV, Teuteberg JJ, et al. The 2013 International Society for Heart and Lung Transplantation guidelines for mechanical circulatory support: executive summary. J Heart Lung Transplant. 2013;32:157-187.
20.  Mehra MR, Canter CE, Hannan MM, et al. The 2016 International Society for  Heart  Lung  Transplantation  listing  criteria  for  heart  transplantation:  a 10-year update. J Heart Lung Transplant. 2016;35:1-23.
21. Pocock SJ, Ariti  CA,  McMurray  JJ,  et  al.  Predicting  survival  in  heart  failure: a risk score based on 39 372 patients from 30 studies. Eur Heart J. 2013;34:1404-1413.
22. Levy WC, Mozaffarian D, Linker DT, et al. The Seattle Heart Failure Model: prediction of survival in heart failure. Circulation. 2006;113:1424-1433.
23.  Ambrosy AP, Pang P, Khan S, et al; Everest Trial Investigators. Clinical course and predictive value of congestion during hospitalization in patients admitted for worsening signs and symptoms of heart failure with reduced ejection fraction: findings from the EVEREST trial. Eur Heart J. 2013;34:835-843.
24. Caldentey G, Khairy P, Roy D, et al. Prognostic value of the physical examination in patients with heart failure and atrial fibrillation: insights from the AF-CHF trial (atrial fibrillation and chronic heart failure). J Am Coll Cardiol HF. 2014;2:15-23.
25. Drazner  MH,  Rame JE, Stevenson L, et al.  Prognostic  importance  of  elevated  jugular  venous  pressure  and  a  third  heart  sound  in  patients  with heart failure. N Engl J Med . 2001;345:574-581.
26. Fudim M, Parikh KS, Dunning A, et al. Relation of volume overload to clinical  outcomes  in  acute  heart  failure  (from  ASCEND-HF). Am  J  Cardiol. 2018;122:1506-1512.
- 27 . Selvaraj S, Claggett B, Shah SJ, et al. Utility of the cardiovascular physical examination and impact of spironolactone in heart failure with preserved ejection fraction. Circ Heart Fail. 2019;12:e006125.
28. Selvaraj  S,  Claggett  B,  Pozzi  A,  et  al.  Prognostic  implications  of  congestion  on  physical  examination  among  contemporary  patients  with heart  failure  and  reduced  ejection  fraction:  PARADIGM-HF. Circulation. 2019;140:1369-1379.
29.  Simonavicius J, Sanders van-Wijk S, Rickenbacher P, et al. Prognostic significance of longitudinal clinical congestion pattern in chronic heart failure: insights from TIME-CHF Trial. Am J Med. 2019;132:e679-e692.
30.  Gorodeski EZ, Chu E, Reese JR, et al. Prognosis on chronic dobutamine or milrinone infusions for stage D heart failure. Circ Heart Fail. 2009;2:320324.
31.  Eshaghian S, Horwich TB, Fonarow GC. Relation of loop diuretic dose to mortality in advanced heart failure. Am J Cardiol. 2006;97:1759-1764.
32. Poole JE, Johnson GW, Hellkamp AS, et al. Prognostic importance of defibrillator shocks in patients with heart failure. N Engl J Med. 2008;359:10091017.
33. Zamora E, Diez-Lopez C, Lupon J, et al. Weight loss in obese patients with heart failure. J Am Heart Assoc. 2016;5:e002468.
34.  Anker SD, Negassa A, Coats AJ, et al. Prognostic importance of weight loss  in  chronic  heart  failure  and  the  effect  of  treatment  with  angiotensin-converting-enzyme inhibitors: an observational study. Lancet. 2003;361:1077-1083.
35. Kittleson M, Hurwitz S, Shah MR, et al. Development of circulatory-renal limitations to angiotensin-converting enzyme inhibitors identifies patients with severe heart failure and early mortality. J Am Coll Cardiol. 2003;41:2029-2035.
36.  Setoguchi S, Stevenson LW, Schneeweiss S. Repeated hospitalizations predict mortality in the community population with heart failure. Am Heart J. 2007;154:260-266.
- 37 . Cook  JL,  Colvin  M,  Francis  GS,  et  al.  Recommendations  for  the  use  of mechanical  circulatory  support:  ambulatory  and  community  patient  care: a  scientific  statement  from  the  American  Heart  Association. Circulation. 2017;135:e1145-e1158.

## 8.2. Nonpharmacological Management: Advanced HF

1.  Dunlap ME, Hauptman PJ, Amin AN, et al. Management of hyponatremia in acute heart failure: a report from the hyponatremia registry for patients with euvolemic and hypervolemic hyponatremia (HN Registry). J Am Heart Assoc. 2017;6:e005261.
2. Philipson H, Ekman I, Forslund HB, et al. Salt and fluid restriction is effective in patients with chronic heart failure. Eur J Heart Fail. 2013;15:1304-1310.
3. Albert NM, Nutter B, Forney J, et al. A randomized controlled pilot study of outcomes of strict allowance of fluid therapy in hyponatremic heart failure (SALT-HF). J Card Fail. 2013;19:1-9.
4. De Vecchis R, Baldi C, Cioppa C, et al. Effects of limiting fluid intake on clinical and laboratory outcomes in patients with heart failure. Results of a meta-analysis of randomized controlled trials. Herz . 2016;41:63-75.
5.  Gheorghiade M, Abraham WT, Albert NM, et al. Relationship between admission serum sodium concentration and clinical outcomes in patients hospitalized for heart failure: an analysis from the OPTIMIZE-HF registry. Eur Heart J. 2007;28:980-988.
6.  Lu DY, Cheng HM, Cheng YL, et al. Hyponatremia and worsening sodium levels  are  associated with long-term outcome in patients hospitalized for acute heart failure. J Am Heart Assoc. 2016;5:e002668.
7. Allen LA, Gheorghiade M, Reid KJ, et al. Identifying patients hospitalized with heart failure at risk for unfavorable future quality of life. Circ Cardiovasc Qual Outcomes. 2011;4:389-398.
8.  Wang J, Zhou W, Yin X. Improvement of hyponatremia is associated with lower mortality risk in patients with acute decompensated heart failure: a meta-analysis of cohort studies. Heart Fail Rev. 2019;24:209-217.
9.  Omar HR, Charnigo R, Guglin M. Prognostic significance of discharge hyponatremia in heart failure patients with normal admission sodium (from the ESCAPE Trial). Am J Cardiol . 2017;120:607-615.
10.  Yancy CW, Jessup M, Bozkurt B, et al. 2013 ACCF/AHA guideline for the management of heart failure: a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Circulation . 2013;128:e240-e327.
11. Vest AR, Chan M, Deswal A, et al. Nutrition, obesity, and cachexia in patients with heart failure: a consensus statement from the Heart Failure Society of America Scientific Statements Committee. J Card Fail. 2019;25:380-400.
12.  Expression of concern: normal-sodium diet compared with low-sodium diet in compensated congestive heart failure: is sodium an old enemy or a new friend? Clin Sci (Lond). 2020;134:1841.

## 8.3. Inotropic Support

1.  Al-Kindi SG, Farhoud M, Zacharias M, et al. Left ventricular assist devices  or  inotropes  for  decreasing  pulmonary  vascular  resistance  in  patients with  pulmonary  hypertension  listed  for  heart  transplantation. J  Card  Fail. 2017;23:209-215.
2.  Hübner T, Nickel T, Steinbeck G, et al. A single German center experience with intermittent inotropes for patients on the high-urgent heart transplant waiting list. Clin Res Cardiol. 2015;104:929-934.
3.  Aranda JM Jr, Schofield RS, Pauly DF, et al. Comparison of dobutamine versus milrinone therapy in hospitalized patients awaiting cardiac transplantation: a prospective, randomized trial. Am Heart J. 2003;145:324-329.
4.  Brozena SC, Twomey C, Goldberg LR, et al. A prospective study of continuous intravenous milrinone therapy for status IB patients awaiting heart transplant at home. J Heart Lung Transplant. 2004;23:1082-1086.
5.  Gorodeski EZ, Chu E, Reese JR, et al. Prognosis on chronic dobutamine or milrinone infusions for stage D heart failure. Circ Heart Fail. 2009;2:320324.
6.  O'Connor CM, Gattis WA, Uretsky BF, et al. Continuous intravenous dobutamine is associated with an increased risk of death in patients with advanced heart failure: insights from the Flolan International Randomized Survival Trial (FIRST). Am Heart J. 1999;138:78-86.
7.  Hershberger  RE,  Nauman  D,  Walker  TL,  et  al.  Care  processes  and clinical  outcomes  of  continuous  outpatient  support  with  inotropes (COSI) in patients with refractory endstage heart failure. J  Card  Fail. 2003;9:180-187.
8. Abraham WT, Adams KF, Fonarow GC, et al. In-hospital mortality in patients with  acute  decompensated  heart  failure  requiring  intravenous  vasoactive medications: an analysis from the Acute Decompensated Heart Failure National Registry (ADHERE). J Am Coll Cardiol. 2005;46:57-64.
9.  Nizamic T, Murad MH, Allen LA, et al. Ambulatory inotrope infusions in advanced heart failure: a systematic review and meta-analysis. J Am Coll Cardiol HF. 2018;6:757-767.

10. Oliva  F,  Latini  R,  Politi  A,  et  al.  Intermittent  6-month  low-dose  dobutamine infusion in severe heart failure: DICE multicenter trial. Am Heart J. 1999;138:247-253.
11.  Cuffe MS, Califf RM, Adams KF Jr, et al. Short-term intravenous milrinone for acute exacerbation of chronic heart failure: a randomized controlled trial. JAMA. 2002;287:1541-1547.
12. Elkayam U, Tasissa G, Binanay C, et al. Use and impact of inotropes and vasodilator therapy in hospitalized patients with severe heart failure. Am Heart J. 2007;153:98-104.
13.  Mebazaa A, Nieminen MS, Filippatos GS, et al. Levosimendan vs. dobutamine: outcomes for acute heart failure patients on beta-blockers in SURVIVE. Eur J Heart Fail. 2009;11:304-311.
14. Acharya  D,  Sanam  K,  Revilla-Martinez  M,  et  al.  Infections,  arrhythmias, and hospitalizations on home intravenous inotropic therapy. Am J Cardiol. 2016;117:952-956.
15. Hashim T, Sanam K, Revilla-Martinez M, et al. Clinical characteristics and outcomes of intravenous inotropic therapy in advanced heart failure. Circ Heart Fail. 2015;8:880-886.
16. Greenberg B, Butler J, Felker GM, et al. Calcium upregulation by percutaneous administration of gene therapy in patients with cardiac disease (CUPID 2): a randomised, multinational, double-blind, placebo-controlled, phase 2b trial. Lancet. 2016;387:1178-1186.

## 8.4. Mechanical Circulatory Support (MCS)

1. Miller LW, Pagani FD, Russell SD, et al. Use of a continuous-flow device in patients awaiting heart transplantation. N Engl J Med. 2007;357:885-896.
2. Mehra MR, Uriel N, Naka Y, et al. A fully magnetically levitated left ventricular assist device - final report. N Engl J Med. 2019;380:1618-1627.
3. Jakovljevic DG, Yacoub MH, Schueler S, et al. Left Ventricular assist device as a bridge to recovery for patients with advanced heart failure. J Am Coll Cardiol. 2017;69:1924-1933.
4. Grady KL, Naftel D, Stevenson L, et al. Overall quality of life improves to similar levels after mechanical circulatory support regardless of severity of heart failure before implantation. J Heart Lung Transplant. 2014;33:412-421.
5.  Lund LH, Trochu JN, Meyns B, et al. Screening for heart transplantation and left ventricular assist system: results from the ScrEEning for advanced Heart Failure treatment (SEE-HF) study. Eur J Heart Fail. 2018;20:152160.
6. Alba  AC,  Rao  V,  Ross  HJ,  et  al.  Impact  of  fixed  pulmonary  hypertension on post-heart transplant outcomes in bridge-to-transplant patients. J Heart Lung Transplant . 2010;29:1253-1258.
7. Slaughter  MS,  Rogers  JG,  Milano  CA,  et  al.  Advanced  heart  failure treated with continuous-flow left ventricular assist device. N Engl J Med. 2009;361:2241-2251.
8.  Milano CA, Rogers JG, Tatooles AJ, et al. HVAD: the ENDURANCE supplemental trials. J Am Coll Cardiol HF. 2018;6:792-802.
9.  Petroni  T,  D'Alessandro  C,  Combes  A,  et  al.  Long-term  outcome  of heart  transplantation  performed  after  ventricular  assist  device  compared with standard heart transplantation. Arch Cardiovasc Dis. 2019;112:485-493.
10.  Molina EJ, Shah P, Kiernan MS, et al. The Society of Thoracic Surgeons Intermacs 2020 annual report. Ann Thorac Surg. 2021;111:778-792.
11. Selim AM, Wadhwani L, Burdorf A, et al. Left ventricular assist devices in pulmonary hypertension group 2 with significantly elevated pulmonary vascular resistance: a bridge to cure. Heart Lung Circ. 2019;28:946-952.
12. Rose EA, Gelijns AC, Moskowitz AJ, et al. Long-term use of a left ventricular assist device for end-stage heart failure. N Engl J Med. 2001;345:14351443.
13. Shah KB, Starling RC, Rogers JG, et al. Left ventricular assist devices versus medical management in ambulatory heart failure patients: an analysis of INTERMACS Profiles 4 and 5 to 7 from the ROADMAP study. J Heart Lung Transplant. 2018;37:706-714.
14.  Stewart GC, Kittleson MM, Patel PC, et al. INTERMACS (Interagency Registry for Mechanically Assisted Circulatory Support) profiling identifies ambulatory patients at high risk on medical therapy after hospitalizations for heart failure. Circ Heart Fail. 2016;9:e003032.
15.  Kiernan MS, Sundareswaran KS, Pham DT, et al. Preoperative determinants of quality of life and functional capacity response to left ventricular assist device therapy. J Card Fail. 2016;22:797-805.
16. Krabatsch T, Netuka I, Schmitto JD, et al. Heartmate 3 fully magnetically levitated left ventricular assist device for the treatment of advanced heart failure -1 year results from the Ce mark trial. J Cardiothorac Surg. 2017;12:23.
17. 17 . Nassif ME, Spertus JA, Jones PG, et al. Changes in disease-specific versus generic health status measures after left ventricular assist device implantation: insights from INTERMACS. J Heart Lung Transplant. 2017;36:12431249.
18. Rogers JG, Butler J, Lansman SL, et al. Chronic mechanical circulatory support for inotrope-dependent heart failure patients who are not transplant candidates: results of the INTrEPID Trial. J Am Coll Cardiol. 2007;50:741747.
19.  Starling RC, Estep JD, Horstmanshof DA, et al. Risk assessment and comparative effectiveness of left ventricular assist device and medical management in ambulatory heart failure patients: the ROADMAP study 2-year results. J Am Coll Cardiol HF. 2017;5:518-527.
20. Baras Shreibati J, Goldhaber-Fiebert JD, Banerjee D, et al. Cost-effectiveness of left ventricular assist devices in ambulatory patients with advanced heart failure. J Am Coll Cardiol HF. 2017;5:110-119.
21.  Long EF, Swain GW, Mangi AA. Comparative survival and cost-effectiveness  of  advanced  therapies  for  end-stage  heart  failure. Circ  Heart  Fail. 2014;7:470-478.
22.  Mahr C, McGee E Jr, Cheung A, et al. Cost-effectiveness of thoracotomy approach for the implantation of a centrifugal left ventricular assist device. ASAIO J. 2020;66:855-861.
23.  Rogers JG, Bostic RR, Tong KB, et al. Cost-effectiveness analysis of continuous-flow left ventricular assist devices as destination therapy. Circ Heart Fail. 2012;5:10-16.
24. Silvestry SC, Mahr C, Slaughter MS, et al. Cost-effectiveness of a small intrapericardial centrifugal left ventricular assist device. ASAIO J. 2020;66:862870.
25.  Garbade J, Gustafsson F, Shaw S, et al. Postmarket experience with HeartMate 3 left ventricular assist device: 30-day outcomes from the ELEVATE registry. Ann Thorac Surg. 2019;107:33-39.
26.  Trivedi JR, Cheng A, Singh R, Williams ML, Slaughter MS. Survival on the heart transplant waiting list: impact of continuous flow left ventricular assist device as bridge to transplant. Ann Thorac Surg. 2014;98:830-834.
27. 27 .  Thiele  H,  Jobs  A,  Ouweneel  DM,  et  al.  Percutaneous  short-term  active  mechanical  support  devices  in  cardiogenic  shock:  a  systematic  review  and  collaborative  meta-analysis  of  randomized  trials. Eur  Heart  J. 2017;38:3523-3531.
28.  den Uil CA, Van Mieghem NM, M BB, et al. Primary intra-aortic balloon support  versus  inotropes  for  decompensated heart failure  and  low  output:  a randomised trial. EuroIntervention. 2019;15:586-593.
29.  Ouyang D, Gulati G, Ha R, et al. Incidence of temporary mechanical circulatory support before heart transplantation and impact on post-transplant outcomes. J Heart Lung Transplant. 2018;37:1060-1066.
30.  Arnold SV, Jones PG, Allen LA, et al. Frequency of poor outcome (death or poor quality of life) after left ventricular assist device for destination therapy: results from the INTERMACS registry. Circ Heart Fail. 2016;9:e002800.
31. Rogers JG, Pagani FD, Tatooles AJ, et al. Intrapericardial left ventricular assist device for advanced heart failure. N Engl J Med. 2017;376:451-460.
32. Allen JG, Weiss ES, Schaffer JM, et al. Quality of life and functional status in patients surviving 12 months after left ventricular assist device implantation. J Heart Lung Transplant. 2010;29:278-285.
33.  Slaughter MS, Pagani FD, McGee EC, et al. HeartWare ventricular assist system for bridge to transplant: combined results of the bridge to transplant and continued access protocol trial. J Heart Lung Transplant. 2013;32:675683.
34. Bellavia D, Iacovoni A, Scardulla C, et al. Prediction of right ventricular failure after ventricular assist device implant: systematic review and meta-analysis of observational studies. Eur J Heart Fail. 2017;19:926-946.
35. Joseph SM, Manghelli JL, Vader JM, et al. Prospective assessment of frailty using the Fried criteria in patients undergoing left ventricular assist device therapy. Am J Cardiol. 2017;120:1349-1354.
36.  Adamo L, Tang Y, Nassif ME, et al. The HeartMate risk score identifies patients with similar mortality risk across all INTERMACS profiles in a large multicenter analysis. J Am Coll Cardiol HF. 2016;4:950-958.
37. 37 .  Baumann Kreuziger LM, Kim B, Wieselthaler GM. Antithrombotic therapy for left ventricular assist devices in adults: a systematic review. J Thromb Haemost. 2015;13:946-955.
38. Goldstein  DJ,  John  R,  Salerno  C,  et  al.  Algorithm  for  the  diagnosis  and management  of  suspected  pump  thrombus. J  Heart  Lung  Transplant. 2013;32:667-670.
39.  Coffin  ST,  Haglund  NA,  Davis  ME,  et  al.  Adverse  neurologic  events in  patients  bridged  with  long-term  mechanical  circulatory  support: a  device-specific  comparative  analysis. J  Heart  Lung  Transplant. 2015;34:1578-1585.

40.  Kato TS, Schulze PC, Yang J, et al. Pre-operative and post-operative risk factors associated with neurologic complications in patients with advanced heart  failure  supported  by  a  left  ventricular  assist  device. J  Heart  Lung Transplant. 2012;31:1-8.
41.  Zhigalov K, Mashhour A, Szczechowicz M, et al. Clinical outcome and comparison of three different left ventricular assist devices in a high-risk cohort. Artif Organs. 2018;42:1035-1042.
42.  Hawkins RB, Go K, Raymond SL, et al. Laparoscopic sleeve gastrectomy in patients with heart failure and left ventricular assist devices as a bridge to transplant. Surg Obes Relat Dis. 2018;14:1269-1273.
43. Kerrigan  DJ,  Williams  CT,  Ehrman  JK,  et  al.  Muscular  strength  and  cardiorespiratory  fitness  are  associated  with  health  status  in  patients  with recently  implanted  continuous-flow  L VADs. J  Cardiopulm  Rehabil  Prev. 2013;33:396-400.
44.  Kumarasinghe G, Jain P, Jabbour A, et al. Comparison of continuous-flow ventricular assist device therapy with intensive medical therapy in fixed pulmonary hypertension secondary to advanced left heart failure. ESC Heart Fail. 2018;5:695-702.
45.  Pham BN, Chaparro SV. Left ventricular assist device recovery: does duration of mechanical support matter? Heart Fail Rev. 2019;24:237-244.
46. Lampropulos JF, Kim N, Wang Y, et al. Trends in left ventricular assist device use and outcomes among Medicare beneficiaries, 2004-2011. Open Heart. 1;2014:e000109.
8. 47 . Mehra MR, Salerno C, Cleveland JC, et al. Healthcare resource use and cost implications  in  the  MOMENTUM 3 long-term outcome study. Circulation. 2018;138:1923-1934.
48. Teuteberg JJ, Cleveland JC Jr, Cowger J, et al. The Society of Thoracic Surgeons Intermacs 2019 annual report: the changing landscape of devices and indications. Ann Thorac Surg. 2020;109:649-660.

## 8.5. Cardiac Transplantation

1.  Khush KK, Cherikh WS, Chambers DC, et al.  The  International  Thoracic Organ Transplant Registry of the International Society for Heart and Lung Transplantation:  thirty-sixth  adult  heart  transplantation  report  -  2019;  focus  theme:  donor  and  recipient  size  match. J  Heart  Lung  Transplant. 2019;38:1056-1066.
2.  Colvin M, Smith JM, Hadley N, et al. OPTN/SRTR 2018 annual data report: heart. Am J Transplant. 2020;20(Suppl 1):340-426.
3. Teuteberg JJ, Cleveland JC Jr, Cowger J, et al. The Society of Thoracic Surgeons Intermacs 2019 annual report: the changing landscape of devices and indications. Ann Thorac Surg. 2020;109:649-660.
4.  Long EF, Swain GW, Mangi AA. Comparative survival and cost-effectiveness  of  advanced  therapies  for  end-stage  heart  failure. Circ  Heart  Fail. 2014;7:470-478.
5. US  Department  of  Health  and  Human  Services.  Adult  heart  allocation. 2018.  Accessed  September  15,  2020.  https://optn.transplant.hrsa.gov/ learn/professional-education/adult-heart-allocation/
6. Cogswell R, John R, Estep JD, et al. An early investigation of outcomes with the new 2018 donor heart allocation system in the United States. J Heart Lung Transplant. 2020;39:1-4.
7. Goff  RR,  Uccellini  K,  Lindblad  K,  et  al.  A  change  of  heart:  preliminary results  of  the  US  2018  adult  heart  allocation  revision. Am J Transplant. 2020;20:2781-2790.
8.  Jawitz OK, Fudim M, Raman V, et al. Reassessing recipient mortality under the new heart allocation system: an updated UNOS registry analysis. J Am Coll Cardiol HF. 2020;8:548-556.
9. Kilic A, Hickey G, Mathier MA, et al. Outcomes of the first 1300 adult heart transplants in the United States after the allocation policy change. Circulation. 2020;141:1662-1664.
10.  Trivedi  JR,  Slaughter  MS.  'Unintended'  consequences  of  changes  in heart  transplant  allocation  policy:  impact  on  practice  patterns. ASAIO  J. 2020;66:125-127.
11.  Varshney AS, Hirji SA, Givertz MM. Outcomes in the 2018 UNOS donor heart allocation system: a perspective on disparate analyses. J Heart Lung Transplant. 2020;39:1191-1194.
12.  Habedank D, Ewert R, Hummel M, et al. Changes in exercise capacity, ventilation,  and body weight following heart transplantation. Eur J Heart Fail. 2007;9:310-316.
13. Kobashigawa JA, Leaf DA, Lee N, et al. A controlled trial of exercise rehabilitation after heart transplantation. N Engl J Med. 1999;340:272-277.
14. Salyer J, Flattery MP, Joyner PL, et al. Lifestyle and quality of life in longterm cardiac transplant recipients. J Heart Lung Transplant. 2003;22:309321.
15. Grady KL, Naftel DC, Kobashigawa J, et al. Patterns and predictors of quality of life at 5 to 10 years after heart transplantation. J Heart Lung Transplant. 2007;26:535-543.
16.  Kanwar M, Raina A, Aponte MP, et al. Pulmonary hypertension in potential heart transplant recipients: current treatment strategies. Curr  Opin  Organ Transplant. 2015;20:570-576.
17. 17 . Givertz  MM,  DeFilippis  EM,  Landzberg  MJ,  et  al.  Advanced  heart  failure therapies for adults with congenital heart disease: JACC state-of-the-art review. J Am Coll Cardiol. 2019;74:2295-2312.
18.  Maron MS, Kalsmith BM, Udelson JE, et al. Survival  after  cardiac  transplantation  in  patients  with  hypertrophic  cardiomyopathy. Circ  Heart  Fail. 2010;3:574-579.
19.  Wu RS, Gupta S, Brown RN, et al. Clinical outcomes after cardiac transplantation in muscular  dystrophy patients. J Heart Lung  Transplant. 2010;29:432-438.
20.  Crawford TC, Okada DR, Magruder JT, et al. A contemporary analysis of heart transplantation and bridge-to-transplant mechanical circulatory support outcomes in cardiac sarcoidosis. J Card Fail. 2018;24:384-391.
21.  Barrett CD, Alexander KM, Zhao H, et al. Outcomes in patients with cardiac  amyloidosis  undergoing heart transplantation. J  Am Coll  Cardiol  HF. 2020;8:461-468.
22.  Arena R, Myers J, Aslam SS, et al. Peak VO2 and VE/VCO2 slope in patients  with  heart  failure:  a  prognostic  comparison. Am  Heart  J. 2004;147:354-360.
23.  Kato TS, Collado E, Khawaja T, et al. Value of peak exercise oxygen consumption combined with B-type natriuretic peptide levels for optimal timing of cardiac transplantation. Circ Heart Fail. 2013;6:6-14.
24. Ferreira AM, Tabet JY, Frankenstein L, et al. Ventilatory efficiency and the selection of patients for heart transplantation. Circ Heart Fail. 2010;3:378386.
25. Corra  U,  Agostoni  PG,  Anker  SD,  et  al.  Role  of  cardiopulmonary  exercise testing in clinical stratification in heart failure. A position paper from the  Committee  on  Exercise  Physiology  and  Training  of  the  Heart  Failure Association of the European Society of Cardiology. Eur J Heart Fail. 2018;20:3-15.
26.  Peterson LR, Schechtman KB, Ewald GA, et al. The effect of beta-adrenergic blockers on the prognostic value of peak exercise oxygen uptake in patients with heart failure. J Heart Lung Transplant. 2003;22:70-77.
27. 27 .  Mancini DM, Eisen H, Kussmaul W, et al. Value of peak exercise oxygen consumption for optimal timing of cardiac transplantation in ambulatory patients with heart failure. Circulation. 1991;83:778-786.
28. O'Neill  JO,  Bott-Silverman  CE,  McRae  AT  3rd,  et  al.  B-type  natriuretic peptide  levels  are  not  a  surrogate  marker  for  invasive  hemodynamics during  management  of  patients  with  severe  heart  failure. Am  Heart  J. 2005;149:363-369.
29.  Mehra MR, Canter CE, Hannan MM, et al. The 2016 International Society for  Heart  Lung  Transplantation  listing  criteria  for  heart  transplantation:  a 10-year update. J Heart Lung Transplant. 2016;35:1-23.
30. Kazi DS, Bellows BK, Baron SJ, et al. Cost-effectiveness of tafamidis therapy for transthyretin amyloid cardiomyopathy. Circulation . 2020;141:12141224.

## 9.1. Assessment of Patients Hospitalized With Decompensated HF

1. Drazner MH, Hellkamp AS, Leier CV, et al. Value of clinician assessment of hemodynamics in advanced heart failure: the ESCAPE trial. Circ Heart Fail. 2008;1:170-177.
2. Chioncel  O,  Mebazaa  A,  Maggioni  AP,  et  al.  Acute  heart  failure  congestion and perfusion status-impact of the clinical classification on in-hospital and long-term outcomes; insights from the ESC-EORP-HFA Heart Failure Long-Term Registry. Eur J Heart Fail. 2019;21:1338-1352.
3. Cleland JG, Chiswell K, Teerlink JR, et al. Predictors of postdischarge outcomes from information acquired shortly after admission for acute heart failure: a report from the placebo-controlled randomized study of the selective A1 adenosine receptor antagonist rolofylline for patients hospitalized with acute decompensated heart failure and volume overload to assess treatment effect on congestion and renal function (PROTECT) study. Circ Heart Fail. 2014;7:76-87.
4. Ambrosy  AP,  Pang  P,  Khan  S,  et  al  Everest  Trial  Investigators.  Clinical course  and  predictive  value  of  congestion  during  hospitalization  in  patients  admitted  for  worsening  signs  and  symptoms  of  heart  failure  with reduced ejection fraction: findings from the EVEREST trial. Eur Heart J. 2013;34:835-843.

5. Hollenberg  SM,  Warner  Stevenson  L,  Ahmad  T,  et  al.  2019  ACC  expert consensus decision pathway on risk assessment, management, and clinical trajectory of patients hospitalized with heart failure: a report of the American College of Cardiology Solution Set Oversight Committee. J Am Coll Cardiol. 2019;74:1966-2011.
6. Kapoor JR, Kapoor R, Ju C, et al. Precipitating clinical factors, heart failure characterization,  and  outcomes  in  patients  hospitalized  with  heart  failure with reduced, borderline, and preserved ejection fraction. J Am Coll Cardiol HF. 2016;4:464-472.
7.  Kociol RD, Cooper LT, Fang JC, et al. Recognition and initial management of  fulminant  myocarditis:  a  scientific  statement  from  the  American  Heart Association. Circulation. 2020;141:e69-e92.
8. Peretto G, Sala S, Rizzo S, et al. Ventricular arrhythmias in myocarditis: characterization and relationships with myocardial inflammation. J Am Coll Cardiol. 2020;75:1046-1057.
9. Thibodeau JT, Drazner MH. The role of the clinical examination in patients with heart failure. J Am Coll Cardiol HF. 2018;6:543-551.
10.  Nohria A, Tsang SW, Fang JC, et al. Clinical assessment identifies hemodynamic profiles that predict outcomes in patients admitted with heart failure. J Am Coll Cardiol. 2003;41:1797-1804.
11. Campbell P, Drazner MH, Kato M, et al. Mismatch of right and left-sided filling pressures in chronic heart failure. J Card Fail. 2011;17:561-568.
12. Zymlinski R, Biegus J, Sokolski M, et al. Increased blood lactate is prevalent and identifies  poor  prognosis  in  patients  with  acute  heart  failure  without overt peripheral hypoperfusion. Eur J Heart Fail. 2018;20:1011-1018.
13. Bhagat  AA,  Greene  SJ,  Vaduganathan  M,  et  al.  Initiation,  continuation, switching and withdrawal of heart failure medical therapies during hospitalization. J Am Coll Cardiol. 2019;7:1-12.
14. Fonarow  GC,  Abraham  WT,  Albert  NM,  et  al.  Influence  of  beta-blocker continuation  or  withdrawal  on  outcomes  in  patients  hospitalized  with heart failure: findings from the OPTIMIZE-HF program. J Am Coll Cardiol. 2008;52:190-199.

## 9.2. Maintenance or Optimization of GDMT During Hospitalization

1. Fonarow  GC,  Abraham  WT,  Albert  NM,  et  al.  Influence  of  beta-blocker continuation  or  withdrawal  on  outcomes  in  patients  hospitalized  with heart failure: findings from the OPTIMIZE-HF program. J Am Coll Cardiol. 2008;52:190-199.
2. Gilstrap LG, Fonarow GC, Desai AS, et al. Initiation, continuation, or withdrawal  of  angiotensin-converting  enzyme  inhibitors/angiotensin  receptor blockers and outcomes in patients hospitalized with heart failure with reduced ejection fraction. J Am Heart Assoc. 2017;6:e004675.
3.  Maisel A, Xue Y, van Veldhuisen DJ, et al. Effect of spironolactone on 30day death and heart failure rehospitalization (from the COACH Study). Am J Cardiol. 2014;114:737-742.
4. Prins  KW,  Neill  JM,  T yler  JO,  et  al.  Effects  of  beta-blocker  withdrawal  in acute decompensated heart failure: a systematic review and meta-analysis. J Am Coll Cardiol HF. 2015;3:647-653.
5. Tran RH, Aldemerdash A, Chang P, et al. Guideline-directed medical therapy and survival following hospitalization in patients with heart failure. Pharmacotherapy. 2018;38:406-416.
6. Peri-Okonny PA, Mi X, Khariton Y, et al. Target doses of heart failure medical therapy and blood pressure: insights from the CHAMP-HF Registry. J Am Coll Cardiol HF. 2019;7:350-358.
7.  Bohm M, Young R, Jhund PS, et al. Systolic blood pressure, cardiovascular outcomes and efficacy and safety of sacubitril/valsartan (LCZ696) in patients with chronic heart failure and reduced ejection fraction: results from PARADIGM-HF. Eur Heart J. 2017;38:1132-1143.
8. Montero-Perez-Barquero  M,  Flather  M,  Roughton  M,  et  al.  Influence  of systolic  blood  pressure  on  clinical  outcomes  in  elderly  heart  failure  patients treated with nebivolol: data from the SENIORS trial. Eur J Heart Fail. 2014;16:1009-1015.
9.  Anand IS, Rector TS, Kuskowski M, et al. Effect of baseline and changes in systolic blood pressure over time on the effectiveness of valsartan in the Valsartan Heart Failure Trial. Circ Heart Fail. 2008;1:34-42.
10. Ahmad T, Jackson K, Rao VS, et al. Worsening renal function in patients with acute heart failure undergoing aggressive diuresis is not associated with tubular injury. Circulation. 2018;137:2016-2028.
11.  Brunner-La Rocca HP, Knackstedt C, Eurlings L, et al. Impact of worsening renal function related to medication in heart failure. Eur J Heart Fail. 2015;17:159-168.
12.  Fonarow GC, Abraham WT, Albert NM, et al. Carvedilol use at discharge in  patients  hospitalized  for  heart  failure  is  associated  with  improved  survival: an analysis from Organized Program to Initiate Lifesaving Treatment in  Hospitalized  Patients  with  Heart  Failure  (OPTIMIZE-HF). Am Heart J. 2007;153:82e1-e11.
13.  Hernandez AF, Hammill BG, O'Connor CM, et al. Clinical effectiveness of beta-blockers in heart failure: findings from the OPTIMIZE-HF (Organized Program to Initiate Lifesaving Treatment in Hospitalized Patients with Heart Failure) Registry. J Am Coll Cardiol. 2009;53:184-192.
14.  Bhatia V, Bajaj NS, Sanam K, et al. Beta-blocker use and 30-day all-cause readmission in Medicare beneficiaries with systolic heart failure. Am J Med. 2015;128:715-721.
15. Sanam K, Bhatia V, Bajaj NS, et al. Renin-angiotensin system inhibition and lower  30-day  all-cause  readmission  in  Medicare  beneficiaries  with  heart failure. Am J Med. 2016;129:1067-1073.
16.  Hernandez AF, Mi X, Hammill BG, et al. Associations between aldosterone antagonist therapy and risks of mortality and readmission among patients with heart failure and reduced ejection fraction. JAMA. 2012;308:20972107.
17. 17 . Bhatt DL, Szarek M, Steg PG, et al. Sotagliflozin in patients with diabetes and recent worsening heart failure. N Engl J Med. 2021;384:117-128.
18.  Velazquez EJ, Morrow DA, DeVore AD, et al. Angiotensin-neprilysin inhibition in acute decompensated heart failure. N Engl J Med. 2019;380:539548.
19. Greene  SJ,  Butler  J,  Albert  NM,  et  al.  Medical  therapy  for  heart  failure with reduced ejection fraction: the CHAMP-HF registry. J Am Coll Cardiol. 2018;72:351-366.
20. Deschaseaux C, McSharry M, Hudson E, et al. Treatment initiation patterns, modifications,  and  medication  adherence  among  newly  diagnosed  heart failure  patients:  a  retrospective  claims  database  analysis. J  Manag  Care Spec Pharm. 2016;22:561-571.
21. Wirtz  HS,  Sheer  R,  Honarpour  N,  et  al.  Real-world  analysis  of  guidelinebased  therapy  after  hospitalization  for  heart  failure. J  Am  Heart  Assoc. 2020;9:e015042.
22. Greene  SJ,  Fonarow  GC,  DeVore  AD,  et  al.  Titration  of  medical  therapy  for  heart  failure  with  reduced  ejection  fraction. J  Am  Coll  Cardiol. 2019;73:2365-2383.
23.  Yancy CW, Januzzi JL Jr, Allen LA, et al. 2017 ACC expert consensus decision pathway for optimization of heart failure treatment: answers to 10 pivotal issues about heart failure with reduced ejection fraction: a report of the American College of Cardiology Task Force on Expert Consensus Decision Pathways. J Am Coll Cardiol. 2018;71:201-230.
24. Bhagat  AA,  Greene  SJ,  Vaduganathan  M,  et  al.  Initiation,  continuation, switching and withdrawal of heart failure medical therapies during hospitalization. J Am Coll Cardiol. 2019;7:1-12.
25. Curtis LH, Mi X, Qualls LG, et al. Transitional adherence and persistence in the use of aldosterone antagonist therapy in patients with heart failure. Am Heart J. 2013;165:979-986.e1.

## 9.3. Diuretics in Hospitalized Patients: Decongestion Strategy

1. Felker GM, Lee KL, Bull DA, et al. Diuretic strategies in patients with acute decompensated heart failure. N Engl J Med. 2011;364:797-805.
2.  Binanay C, Califf RM, Hasselblad V, et al. Evaluation study of congestive heart  failure  and  pulmonary  artery  catheterization  effectiveness:  the  ESCAPE trial. JAMA. 2005;294:1625-1633.
3. Bart BA, Goldsmith SR, Lee KL, et al. Ultrafiltration in decompensated heart failure with cardiorenal syndrome. N Engl J Med. 2012;367:2296-2304.
4.  Rubio-Gracia J, Demissei BG, Ter Maaten JM, et al. Prevalence, predictors and clinical outcome of residual congestion in acute decompensated heart failure. Int J Cardiol. 2018;258:185-191.
5. Ambrosy AP, Pang P, Khan S, et al Everest Trial Investigators. Clinical course and predictive value of congestion during hospitalization in patients admitted for worsening signs and symptoms of heart failure with reduced ejection fraction: findings from the EVEREST trial. Eur Heart J. 2013;34:835-843.
6.  Chioncel O, Mebazaa A, Maggioni AP, et al. Acute heart failure congestion and perfusion status-impact of the clinical classification on in-hospital and long-term outcomes; insights from the ESC-EORP-HFA heart failure longterm registry. Eur J Heart Fail. 2019;21:1338-1352.
7. Faselis  C,  Arundel  C,  Patel  S,  et  al.  Loop  diuretic  prescription  and  30day  outcomes  in  older  patients  with  heart  failure. J  Am  Coll  Cardiol. 2020;76:669-679.

8.  Velazquez EJ, Morrow DA, DeVore AD, et al. Angiotensin-neprilysin inhibition in acute decompensated heart failure. N Engl J Med. 2019;380:539548.
9.  Wan S-H, Stevens SR, Borlaug BA, et al. Differential response to low-dose dopamine or low-dose nesiritide in acute heart failure with reduced or preserved ejection fraction. Circ Heart Fail. 2016;9:1-12.
10. Cox ZL, Stevenson LW. The weight of evidence for diuretics and parachutes. J Am Coll Cardiol. 2020;76:680-683.
11. Hollenberg  SM,  Warner  Stevenson  L,  Ahmad  T,  et  al.  2019  ACC  expert consensus decision pathway on risk assessment, management, and clinical trajectory of patients hospitalized with heart failure: a report of the American College of Cardiology Solution Set Oversight Committee. J Am Coll Cardiol. 2019;74:1966-2011.
12.  Gilstrap LG, Stevenson LW, Small R, et al. Reasons for guideline nonadherence at heart failure discharge. J Am Heart Assoc. 2018;7:e008789.
13. Metra M, Cotter G, Senger S, et al. Prognostic significance of creatinine increases during an acute heart failure admission in patients with and without residual congestion: a post hoc analysis of the PROTECT Data. Circ Heart Fail. 2018;11:e004644.
14. Testani  JM,  Chen  J,  McCauley  BD,  et  al.  Potential  effects  of  aggressive decongestion during the treatment of decompensated heart failure on renal function and survival. Circulation. 2010;122:265-272.
15.  Costanzo MR, Guglin ME, Saltzberg MT, et al. Ultrafiltration versus intravenous diuretics for patients hospitalized for acute decompensated heart failure. J Am Coll Cardiol. 2007;49:675-683.
16.  Costanzo MR, Negoianu D, Jaski BE, et al. Aquapheresis versus intravenous diuretics and hospitalizations for heart failure. J Am Coll Cardiol HF. 2016;4:95-105.

## 9.4a. Parenteral Vasodilation Therapy in Patients Hospitalized With HF

1.  Publication Committee for the VMAC Investigators. Intravenous nesiritide vs nitroglycerin for treatment of decompensated congestive heart failure: a randomized controlled trial. JAMA . 2002;287:1531-1540.
2. Cioffi G, Stefenelli C, Tarantini L, et al. Hemodynamic response to intensive unloading therapy (furosemide and nitroprusside) in patients &gt;70 years of age with left ventricular systolic dysfunction and decompensated chronic heart failure. Am J Cardiol. 2003;92:1050-1056.
3. Elkayam  U,  Kulick  D,  McIntosh  N,  et  al.  Incidence  of  early  tolerance to  hemodynamic  effects  of  continuous  infusion  of  nitroglycerin  in patients  with  coronary  artery  disease  and  heart  failure. Circulation. 1987;76:577-584.
4. Fung  HL,  Bauer  JA.  Mechanisms  of  nitrate  tolerance. Cardiovasc  Drugs Ther. 1994;8:489-499.
5.  Khot UN, Novaro GM, Popovic ZB, et al. Nitroprusside in critically ill patients with left ventricular dysfunction and aortic stenosis. N Engl J Med. 2003;348:1756-1763.
6. Kozhuharov N, Goudev A, Flores D, et al. Effect of a strategy of comprehensive vasodilation vs usual care on mortality and heart failure rehospitalization among patients with acute heart failure: the GALACTIC randomized clinical trial. JAMA. 2019;322:2292-2302.
7.  Peacock WF, Chandra A, Char D, et al. Clevidipine in acute heart failure: results of the A Study of Blood Pressure Control in Acute Heart Failure-A Pilot Study (PRONTO). Am Heart J. 2014;167:529-536.

## 9.4b. Venous Thromboembolism (VTE) Prophylaxis in Hospitalized Patients

1.  Kleber FX, Witt C, Vogel G, et al. Randomized comparison of enoxaparin with unfractionated heparin for the prevention of venous thromboembolism in medical patients with heart failure or severe respiratory disease. Am Heart J. 2003;145:614-621.
2. Cohen AT, Spiro TE, Buller HR, et al. Rivaroxaban for thromboprophylaxis in acutely ill medical patients. N Engl J Med. 2013;368:513-523.
3. Mebazaa  A,  Spiro  TE,  Buller  HR,  et  al.  Predicting  the  risk  of  venous thromboembolism  in  patients  hospitalized  with  heart  failure. Circulation. 2014;130:410-418.
4.  Aispuru GR, Clavier MM, Cardone AJ, et al. Thrombotic biomarkers and left ventricle  characteristics  as  short-term  predictors  of  thrombotic  events  in patients  hospitalized  for  acute  decompensated  heart  failure. Eur  J  Intern Med. 2012;23:545-551.
5.  Fanola CL, Norby FL, Shah AM, et al. Incident heart failure and long-term risk for venous thromboembolism. J Am Coll Cardiol. 2020;75:148-158.
6.  Smilowitz NR, Zhao Q, Wang L, et al. Risk of venous thromboembolism after new onset heart failure. Sci Rep. 2019;9:17415.
7.  Al Yami MS, Silva MA, Donovan JL, et al. Venous thromboembolism prophylaxis in medically ill patients: a mixed treatment comparison meta-analysis. J Thromb Thrombolysis. 2018;45:36-47.
8. Tang L, Wu YY, Lip GY, et al. Heart failure and risk of venous thromboembolism: a systematic review and meta-analysis. Lancet Haematol. 2016;3:e30e44.
9. Barba R, Zapatero A, Losa JE, et al. Venous thromboembolism in acutely ill hospitalized medical patients. Thromb Res. 2010;126:276-279.
10.  Riess H, Haas S, Tebbe U, et al. A randomized, double-blind study of certoparin vs. unfractionated heparin to prevent venous thromboembolic events in  acutely  ill,  non-surgical  patients:  CERTIFY  Study. J  Thromb  Haemost. 2010;8:1209-1215.
11. Spyropoulos  AC,  Ageno  W,  Albers  GW,  et  al.  Rivaroxaban  for  thromboprophylaxis  after  hospitalization  for  medical  illness. N  Engl  J  Med. 2018;379:1118-1127.
12.  Miranda  S,  Le  Cam-Duchez  V,  Benichou  J,  et  al.  Adjusted  value  of thromboprophylaxis in hospitalized obese patients: a comparative study of  two  regimens  of  enoxaparin:  the  ITOHENOX  study. Thromb  Res. 2017;155:1-5.
13.  Samama MM, Cohen AT, Darmon JY, et al. A comparison of enoxaparin with placebo for the prevention of venous thromboembolism in acutely ill medical patients. N Engl J Med. 1999;341:793-800.
14.  Belch JJ, Lowe GD, Ward AG, et al. Prevention of deep vein thrombosis in medical patients by low-dose heparin. Scott Med J. 1981;26:115-117.
15. Tebbe  U,  Schellong  SM,  Haas  S,  et  al.  Certoparin  versus  unfractionated heparin to prevent venous thromboembolic events in patients hospitalized because of heart failure: a subgroup analysis of the randomized, controlled CERTIFY study. Am Heart J. 2011;161:322-328.
16.  King CS, Holley AB, Jackson JL, et al. Twice vs three times daily heparin dosing for thromboembolism prophylaxis in the general medical population: a metaanalysis. Chest. 2007;131:507-516.
17. 17 .  Phung OJ, Kahn SR, Cook DJ, et al. Dosing frequency of unfractionated heparin thromboprophylaxis: a meta-analysis. Chest. 2011;140:374-381.

## 9.5. Evaluation and Management of Cardiogenic Shock

1.  Mathew R, Di Santo P, Jung RG, et al. Milrinone as compared with dobutamine in the treatment of cardiogenic shock. N Engl J Med. 2021;385:516525.
2.  De Backer D, Biston P, Devriendt J, et al. Comparison of dopamine and norepinephrine in the treatment of shock. N Engl J Med. 2010;362:779789.
3. Lewis TC, Aberle C, Altshuler D, et al. Comparative effectiveness and safety between milrinone or dobutamine as initial inotrope therapy in cardiogenic shock. J Cardiovasc Pharmacol Ther. 2019;24:130-138.
4.  Levy B, Clere-Jehl R, Legras A, et al. Epinephrine versus norepinephrine for cardiogenic shock after acute myocardial infarction. J Am Coll Cardiol. 2018;72:173-182.
5. 5 .Levy B, Perez P, Perny J, et al. Comparison of norepinephrine-dobutamine to epinephrine for hemodynamics, lactate metabolism, and organ function variables in cardiogenic shock. A prospective, randomized pilot study. Crit Care Med. 2011;39:450-455.
6. Pirracchio R, Parenica J, Resche Rigon M, et al. The effectiveness of inodilators in reducing short term mortality among patient with severe cardiogenic shock: a propensity-based analysis. PLoS One. 2013;8:e71659.
7. Schumann  J.  Cochrane  corner:  inotropic  agents  and  vasodilator  strategies  for  cardiogenic  shock  or  low  cardiac  output  syndrome. Heart. 2019;105:178-179.
8. Belletti A, Castro ML, Silvetti S, et al. The effect of inotropes and vasopressors on mortality: A meta-analysis of randomized clinical trials. Br J Anaesth . 2015;115:656-675.
9. Stretch R, Sauer CM, Yuh DD, et al. National trends in the utilization of shortterm mechanical circulatory support: incidence, outcomes, and cost analysis. J Am Coll Cardiol. 2014;64:1407-1415.
10. Lauten A, Engstrom AE, Jung C, et al. Percutaneous left-ventricular support with the Impella-2.5-assist device in acute cardiogenic shock: results of the Impella-EUROSHOCK-registry. Circ Heart Fail. 2013;6:23-30.
11. Flaherty MP, Khan AR, O'Neill WW. Early initiation of Impella in acute myocardial  infarction  complicated  by  cardiogenic  shock  improves  survival:  a meta-analysis. J Am Coll Cardiol Intv. 2017;10:1805-1806.

12. Basir MB, Schreiber TL, Grines CL, et al. Effect of early initiation of mechanical circulatory support on survival in cardiogenic shock. Am J Cardiol. 2017;119:845-851.
13.  Takayama H, Truby L, Koekort M, et al. Clinical outcome of mechanical circulatory support for refractory cardiogenic shock in the current era. J Heart Lung Transplant. 2013;32:106-111.
14. Schrage B, Ibrahim K, Loehn T, et al. Impella support for acute myocardial infarction complicated by cardiogenic shock. Circulation. 2019;139:12491258.
15. Xie A, Phan K, Tsai YC, et al. Venoarterial extracorporeal membrane oxygenation for cardiogenic shock and cardiac arrest: a meta-analysis. J Cardiothorac Vasc Anesth. 2015;29:637-645.
16.  Dangers L, Brechot N, Schmidt M, et al. Extracorporeal membrane oxygenation for acute decompensated heart failure. Crit Care Med. 2017;45:13591366.
6. 17 . Basir  MB,  Schreiber  T,  Dixon  S,  et  al.  Feasibility  of  early  mechanical  circulatory support in acute myocardial infarction complicated by cardiogenic shock: the Detroit cardiogenic shock initiative. Catheter Cardiovasc Interv. 2018;91:454-461.
18.  Basir MB, Kapur NK, Patel K, et al. Improved outcomes associated with the use of shock protocols: updates from the national cardiogenic shock initiative. Catheter Cardiovasc Interv. 2019;93:1173-1183.
19. Taleb I, Koliopoulou AG, Tandar A, et al. Shock team approach in refractory cardiogenic  shock  requiring  short-term  mechanical  circulatory  support:  a proof of concept. Circulation. 2019;140:98-100.
20.  Tehrani BN, Truesdell AG, Sherwood MW, et al. Standardized team-based care for cardiogenic shock. J Am Coll Cardiol. 2019;73:1659-1669.
21. Lee F, Hutson JH, Boodhwani M, et al. Multidisciplinary code shock team in cardiogenic shock: a Canadian centre experience. CJC Open. 2020;2:249257.
22. Shaefi S, O'Gara B, Kociol RD, et al. Effect of cardiogenic shock hospital volume on mortality in patients with cardiogenic shock. J Am Heart Assoc. 2015;4:e001462.
23.  Garan AR, Kanwar M, Thayer KL, et al. Complete hemodynamic profiling with  pulmonary  artery  catheters  in  cardiogenic  shock  is  associated  with lower in-hospital mortality. J Am Coll Cardiol HF. 2020;8:903-913.
24. Vallabhajosyula  S,  Shankar  A,  Patlolla  SH,  et  al.  Pulmonary  artery  catheter  use in acute myocardial infarction-cardiogenic shock. ESC Heart Fail. 2020;7:1234-1245.
25. Hernandez GA, Lemor A, Blumer V, et al. Trends in utilization and outcomes of pulmonary artery catheterization in heart failure with and without cardiogenic shock. J Card Fail. 2019;25:364-371.
26. Nalluri N, Patel NJ, Atti V, et al. T emporal trends in utilization of right-sided heart catheterization among percutaneous ventricular assist device recipients in acute myocardial infarction complicated by cardiogenic shock. Am J Cardiol. 2018;122:2014-2017.
16. 27 . Rossello X, Vila M, Rivas-Lasarte M, et al. Impact of pulmonary artery catheter use on short- and long-term mortality in patients with cardiogenic shock. Cardiology . 2017;136:61-69.
28.  van Diepen S, Katz JN, Albert NM, et al. Contemporary management of cardiogenic shock: a scientific statement from the American Heart Association. Circulation. 2017;136:e232-e268.
29. Baran DA, Grines CL, Bailey S, et al. SCAI clinical expert consensus statement on the classification of cardiogenic shock. Catheter Cardiovasc Interv. 2019;94:29-37.
30. Kivikko M, Pollesello P, Tarvasmaki T, et al. Effect of baseline characteristics on mortality in the SURVIVE trial on the effect of levosimendan vs dobutamine in acute heart failure: sub-analysis of the Finnish patients. Int J Cardiol. 2016;215:26-31.
31.  O'Neill WW, Grines C, Schreiber T, et al. Analysis of outcomes for 15 259 US patients with acute myocardial infarction cardiogenic shock (AMICS) supported with the Impella device. Am Heart J. 2018;202:33-38.
32. Schmidt M, Burrell A, Roberts L, et al. Predicting survival after ECMO for refractory cardiogenic shock: the survival after veno-arterial-ECMO (SAVE)score. Eur Heart J. 2015;36:2246-2256.
33.  Thiele H, Jobs A, Ouweneel DM, et al. Percutaneous short-term active mechanical support devices in cardiogenic shock: a systematic review and collaborative meta-analysis of randomized trials. Eur Heart J. 2017;38:35233531.
34.  Prondzinsky  R,  Lemm  H,  Swyter  M,  et  al.  Intra-aortic  balloon  counterpulsation  in  patients  with  acute  myocardial  infarction  complicated by cardiogenic shock: the prospective, randomized IABP SHOCK trial for  attenuation  of  multiorgan  dysfunction  syndrome. Crit  Care  Med. 2010;38:152-160.
35.  Thiele H, Zeymer U, Neumann FJ, et al. Intraaortic balloon support for myocardial infarction with cardiogenic shock. N Engl J Med. 2012;367:12871296.
36. Seyfarth  M,  Sibbing  D,  Bauer  I,  et  al.  A  randomized  clinical  trial  to evaluate the safety and efficacy of a percutaneous left ventricular assist  device  versus  intra-aortic  balloon  pumping  for  treatment  of  cardiogenic  shock  caused  by  myocardial  infarction. J  Am  Coll  Cardiol. 2008;52:1584-1588.
26. 37 .  Ouweneel DM, Eriksen E, Sjauw KD, et al. Percutaneous mechanical circulatory support versus intra-aortic balloon pump in cardiogenic shock after acute myocardial infarction. J Am Coll Cardiol. 2017;69:278-287.
38. Thiele H, Sick P, Boudriot E, et al. Randomized comparison of intra-aortic balloon support with a percutaneous left ventricular assist device in patients with revascularized acute myocardial infarction complicated by cardiogenic shock. Eur Heart J. 2005;26:1276-1283.
39. Burkhoff D, Cohen H, Brunckhorst C, et al. A randomized multicenter clinical study to evaluate the safety and efficacy of the TandemHeart percutaneous ventricular assist device versus conventional therapy with intraaortic balloon pumping for treatment of cardiogenic shock. Am Heart J. 2006;152:469. e1-469.e8.
40.  Thayer KL, Zweck E, Ayouty M, et al. Invasive hemodynamic assessment and classification of in-hospital mortality risk among patients with cardiogenic shock. Circ Heart Fail. 13;2020:e007099.
41.  Saxena A, Garan AR, Kapur NK, et al. Value of hemodynamic monitoring in patients with cardiogenic shock undergoing mechanical circulatory support. Circulation. 2020;141:1184-1197.
42.  Hernandez-Montfort J, Sinha SS, Thayer KL, et al. Clinical outcomes associated with acute mechanical circulatory support utilization in heart failure related cardiogenic shock. Circ Heart Fail. 14;2021:e007924.
43. Rab T, Ratanapo S, Kern KB, et al. Cardiac shock care centers: JACC review topic of the week. J Am Coll Cardiol. 2018;72:1972-1980.

## 9.6. Integration of Care: Transitions and Team-Based Approaches

1. Feltner C, Jones CD, Cene CW, et al. Transitional care interventions to prevent readmissions for persons with heart failure: a systematic review and meta-analysis. Ann Intern Med. 2014;160:774-784.
2. Kalogirou F, Forsyth F, Kyriakou M, et al. Heart failure disease management: a systematic review of effectiveness in heart failure with preserved ejection fraction. ESC Heart Fail. 2020;7:194-212.
3. Takeda A, Martin N, Taylor RS, Taylor SJ. Disease management interventions for heart failure. Cochrane Database Syst Rev. 2019;1:CD002752.
4.  Van Spall HGC, Rahman T, Mytton O, et al. Comparative effectiveness of transitional care services in patients discharged from the hospital with heart failure:  a  systematic  review  and  network  meta-analysis. Eur  J  Heart  Fail. 2017;19:1427-1443.
5.  Koelling  TM,  Johnson  ML,  Cody  RJ,  et  al.  Discharge  education  improves clinical outcomes in patients with chronic heart failure. Circulation. 2005;111:179-185.
6.  The Joint Commission. Heart failure (HF): specifications manual for Joint Commission National Quality core measures (2010A1). 2010. Accessed September 27, 2020. https://manual.jointcommission.org/releases/archive/TJC2010B/HeartFailure.html
7.  Driscoll A, Meagher S, Kennedy R, et al. What is the impact of systems of care for heart failure on patients diagnosed with heart failure: a systematic review. BMC Cardiovasc Disord. 2016;16:195.
8.  Fonarow GC, Abraham WT, Albert NM, et al. Influence of a performanceimprovement initiative on quality of care for patients hospitalized with heart failure: results of the Organized Program to Initiate Lifesaving Treatment in Hospitalized Patients With Heart Failure (OPTIMIZE-HF). Arch Intern Med. 2007;167:1493-1502.
9.  Lappe JM, Muhlestein JB, Lappe DL, et al. Improvements in 1-year cardiovascular clinical outcomes associated with a hospital-based discharge medication program. Ann Intern Med. 2004;141:446-453.
10. Heidenreich P. Improving heart failure care with a reminder attached to the echocardiography report. Am J Med. 2008;121:853-854.

11.  Hernandez AF, Greiner MA, Fonarow GC, et al. Relationship between early physician follow-up and 30-day readmission among Medicare beneficiaries

hospitalized for heart failure.

JAMA.

2010;303:1716-1722.

12.  Lee KK, Yang J, Hernandez AF, et al. Post-discharge follow-up characteristics associated with 30-day readmission after heart failure hospitalization. Med Care. 2016;54:365-372.

13.  Dharmarajan K, Hsieh AF, Lin Z, et al. Diagnoses and timing of 30-day readmissions after hospitalization for heart failure, acute myocardial infarction, or pneumonia. JAMA. 2013;309:355-363.
14. Albert NM, Barnason S, Deswal A, et al. Transitions of care in heart failure: a scientific statement from the American Heart Association. Circ Heart Fail. 2015;8:384-409.
15.  Gislason GH, Rasmussen JN, Abildstrom SZ, et al. Persistent use of evidence-based pharmacotherapy in heart failure is associated with improved outcomes. Circulation. 2007;116:737-744.
16. Naylor MD, Brooten DA, Campbell RL, et al. Transitional care of older adults hospitalized with heart failure: a randomized, controlled trial. J Am Geriatr Soc. 2004;52:675-684.
5. 17 .  Chan WV, Pearson TA, Bennett GC, et al. ACC/AHA special report: clinical practice guideline implementation strategies: a summary of systematic reviews by the NHLBI implementation science work group: a report of the American College of Cardiology/American Heart Association task force on clinical practice guidelines. Circulation . 2017;135:e122-e137.
18.  Ellrodt AG, Fonarow GC, Schwamm LH, et al. Synthesizing lessons learned from get with the guidelines: the value of disease-based registries in improving quality and outcomes. Circulation. 2013;128:2447-2460.
19. Coma  E,  Medina  M,  Mendez  L,  et  al.  Effectiveness  of  electronic  pointof-care  reminders  versus  monthly  feedback  to  improve  adherence  to  10 clinical recommendations in primary care: a cluster randomized clinical trial. BMC Med Inform Decis Mak. 2019;19:245.
20.  DeVore AD, Granger BB, Fonarow GC, et al. Care optimization through patient and hospital engagement clinical trial for heart failure: rationale and design of CONNECT-HF. Am Heart J. 2020;220:41-50.
21.  Hansen LO, Young RS, Hinami K, et al. Interventions to reduce 30-day rehospitalization: a systematic review. Ann Intern Med. 2011;155:520528.
22. Lee KK, Thomas RC, Tan TC, et al. The heart failure readmission intervention by variable early follow-up (THRIVE) study. Circ Cardiovasc Qual Outcomes. 2020;13:e006553.
23.  O'Connor CM, Hasselblad V, Mehta RH, et al. Triage after hospitalization with  advanced  heart  failure:  the  ESCAPE  (Evaluation  Study  of  Congestive Heart Failure and Pulmonary Artery Catheterization Effectiveness) risk model and discharge score. J Am Coll Cardiol. 2010;55:872-878.
24.  Keenan PS, Normand SL, Lin Z, et al. An administrative claims measure suitable for profiling hospital performance on the basis of 30-day all-cause readmission rates among patients with heart failure. Circ Cardiovasc Qual Outcomes. 2008;1:29-37.
25. Win S, Hussain I, Hebl VB, et al. Inpatient mortality risk scores and postdischarge events in hospitalized heart failure patients: a community-based study. Circ Heart Fail. 2017;10:e003926.

## 10.1. Management of Comorbidities in Patients With HF

1.  Anker SD, Comin Colet J, Filippatos G, et al. Ferric carboxymaltose in patients with heart failure and iron deficiency. N Engl J Med. 2009;361:24362448.
2.  Ponikowski P, van Veldhuisen DJ, Comin-Colet J, et al. Beneficial effects of long-term intravenous iron therapy with ferric carboxymaltose in patients with  symptomatic  heart  failure  and  iron  deficiencydagger. Eur  Heart  J. 2015;36:657-668.
3. Beck-da-Silva  L,  Piardi  D,  Soder  S,  et  al.  IRON-HF  study:  a  randomized trial to assess the effects of iron in heart failure patients with anemia. Int J Cardiol. 2013;168:3439-3442.
4.  Ponikowski P, Kirwan BA, Anker SD, et al. Ferric carboxymaltose for iron deficiency at discharge after acute heart failure: a multicentre, double-blind, randomised, controlled trial. Lancet. 2020;396:1895-1904.
5.  Swedberg K, Young JB, Anand IS, et al. Treatment of anemia with darbepoetin alfa in systolic heart failure. N Engl J Med. 2013;368:1210-1219.
6. Kang  J,  Park  J,  Lee  JM,  et  al.  The  effects  of  erythropoiesis  stimulating therapy for anemia in chronic heart failure: A meta-analysis of randomized clinical trials. Int J Cardiol. 2016;218:12-22.
7. Banach M, Bhatia V, Feller  MA,  et  al.  Relation  of  baseline  systolic  blood pressure and long-term outcomes in ambulatory patients with chronic mild to moderate heart failure. Am J Cardiol. 2011;107:1208-1214.
8.  Lee  TT,  Chen  J,  Cohen  DJ,  et  al.  The  association  between  blood pressure  and  mortality  in  patients  with  heart  failure. Am  Heart  J. 2006;151:76-83.
9. Arzt M, Schroll S, Series F, et al. Auto-servoventilation in heart failure with sleep apnoea: a randomised controlled trial. Eur Respir J. 2013;42:12441254.
10.  Arzt M, Floras JS, Logan AG, et al. Suppression of central sleep apnea by continuous positive airway pressure and transplant-free survival in heart failure: a post hoc analysis of the Canadian Continuous Positive Airway Pressure for Patients with Central Sleep Apnea and Heart Failure Trial (CANPAP). Circulation . 2007;115:3173-3180.
11.  O'Connor CM, Whellan DJ, Fiuzat M, et al. Cardiovascular outcomes with minute ventilation-targeted adaptive servo-ventilation therapy in heart failure: the CAT-HF trial. J Am Coll Cardiol. 2017;69:1577-1587.
12.  Cowie MR, Woehrle H, Wegscheider K, et al. Adaptive servo-ventilation for central sleep apnea in systolic heart failure. N Engl J Med. 2015;373:10951105.
13.  Yamamoto S, Yamaga T, Nishie K, et al. Positive airway pressure therapy for the treatment of central sleep apnoea associated with heart failure. Cochrane Database Syst Rev. 2019;12:CD012803.
14. Zannad F, Ferreira JP, Pocock SJ, et al. SGL T2 inhibitors in patients with heart failure with reduced ejection fraction: a meta-analysis of the EMPEROR-Reduced and DAPA-HF trials. Lancet. 2020;396:819-829.
15. Kato ET, Silverman MG, Mosenzon O, et al. Effect of dapagliflozin on heart failure and mortality in type 2 diabetes mellitus. Circulation. 2019;139:25282536.
16. McMurray JJV, Solomon SD, Inzucchi SE, et al. Dapagliflozin in patients with heart failure and reduced ejection fraction. N Engl J Med. 2019;381:19952008.
17. 17 . Packer M, Anker SD, Butler J, et al. Cardiovascular and renal outcomes with empagliflozin in heart failure. N Engl J Med . 2020;383:1413-1424.
18. Chamberlain AM, St Sauver JL, Gerber Y, et al. Multimorbidity in heart failure: a community perspective. Am J Med. 2015;128:38-45.
19. Wong CY, Chaudhry SI, Desai MM, et al. Trends in comorbidity, disability, and polypharmacy in heart failure. Am J Med. 2011;124:136-143.
20.  Angermann CE, Gelbrich G, Stork S, et al. Effect of escitalopram on allcause  mortality  and  hospitalization  in  patients  with  heart  failure  and  depression: the MOOD-HF randomized clinical trial. JAMA. 2016;315:26832693.
21.  Rutledge T, Reis VA, Linke SE, et al. Depression in heart failure a metaanalytic  review  of  prevalence,  intervention  effects,  and  associations  with clinical outcomes. J Am Coll Cardiol. 2006;48:1527-1537.
22. Glassman  AH,  O'Connor  CM,  Califf  RM,  et  al.  Sertraline  treatment  of major  depression  in  patients  with  acute  MI  or  unstable  angina. JAMA. 2002;288:701-709.
23. Tuegel  C,  Bansal  N.  Heart  failure  in  patients  with  kidney  disease. Heart. 2017;103:1848-1853.
24. Lunney  M,  Ruospo  M,  Natale  P,  et  al.  Pharmacological  interventions  for heart failure in people with chronic kidney disease. Cochrane Database Syst Rev. 2020;2:CD012466.
25.  Groenveld HF, Januzzi JL, Damman K, et al. Anemia and mortality in heart failure patients a systematic review and meta-analysis. J Am Coll Cardiol. 2008;52:818-827.
26.  Ebner N, Jankowska EA, Ponikowski P, et al. The impact of iron deficiency and anaemia on exercise capacity and outcomes in patients with chronic heart failure. results from the studies investigating co-morbidities aggravating heart failure. Int J Cardiol. 2016;205:6-12.
27. 27 .  Anker SD, Kirwan BA, van Veldhuisen DJ, et al. Effects of ferric carboxymaltose  on  hospitalisations  and  mortality  rates  in  iron-deficient  heart failure patients: an individual patient data meta-analysis. Eur J Heart Fail. 2018;20:125-133.
28. Lewis GD, Malhotra R, Hernandez AF, et al. Effect of oral iron repletion on exercise capacity in patients with heart failure with reduced ejection fraction and iron deficiency: the IRONOUT HF randomized clinical trial. JAMA. 2017;317:1958-1966.
29.  Kapoor M, Schleinitz MD, Gemignani A, et al. Outcomes of patients with chronic  heart  failure  and  iron  deficiency  treated  with  intravenous  iron:  a meta-analysis. Cardiovasc Hematol Disord Drug Targets. 2013;13:35-44.
30.  Montero D, Haider T, Flammer AJ. Erythropoietin response to anaemia in heart failure. Eur J Prev Cardiol. 2019;26:7-17.
31.  Nagai T, Nishimura K, Honma T, et al. Prognostic significance of endogenous erythropoietin in long-term outcome of patients with acute decompensated heart failure. Eur J Heart Fail. 2016;18:803-813.
32. Bello NA, Lewis EF, Desai AS, et al. Increased risk of stroke with darbepoetin alfa in anaemic heart failure patients with diabetes and chronic kidney disease. Eur J Heart Fail. 2015;17:1201-1207.
33. Zhang Y, Liang M, Sun C, et al. Effect of intensive lowering of systolic blood pressure treatment on heart failure events: a meta-analysis of randomized controlled studies. J Hum Hypertens. 2019;33:648-657.
34.  A randomized trial of intensive versus standard blood-pressure control. N Engl J Med. 2017;377:2506.

35.  Upadhya B, Rocco M, Lewis CE, et al. Effect of intensive blood pressure treatment on heart failure events in the Systolic Blood Pressure Reduction Intervention Trial. Circ Heart Fail. 2017;10:e003613.
36.  Whelton PK, Carey RM, Aronow WS, et al. 2017 ACC/AHA/AAPA/ABC/ ACPM/AGS/APhA/ASH/ASPC/NMA/PCNA guideline for the prevention, detection, evaluation, and management of high blood pressure in adults: a report of the American College of Cardiology/American Heart Association Task  Force  on  Clinical  Practice  Guidelines. Hypertension .  2018;71:e13e115.
3. 37 . Mehra  R,  Wang  L,  Andrews  N,  et  al.  Dissociation  of  objective  and  subjective  daytime  sleepiness  and  biomarkers  of  systemic  inflammation  in sleep-disordered  breathing  and  systolic  heart  failure. J  Clin  Sleep  Med. 2017;13:1411-1422.
38. Bradley TD, Logan AG, Kimoff RJ, et al. Continuous positive airway pressure for central sleep apnea and heart failure. N Engl J Med. 2005;353:20252033.
39. Zhang XB, Yuan YT, Du YP, et al. Efficacy of positive airway pressure on brain natriuretic peptide in patients with heart failure and sleep-disorder breathing: a meta-analysis of randomized controlled trials. Lung. 2015;193:255-260.
40.  Aggarwal S, Nadeem R, Loomba RS, et al. The effects of continuous positive airways pressure therapy on cardiovascular end points in patients with sleep-disordered breathing and heart failure: a meta-analysis of randomized controlled trials. Clin Cardiol. 2014;37:57-65.
41. Voigt J, Emani S, Gupta S, et al. Meta-analysis comparing outcomes of therapies for patients with central sleep apnea and heart failure with reduced ejection fraction. Am J Cardiol. 2020;127:73-83.
42.  Yamamoto S, Yamaga T, Nishie K, et al. Positive airway pressure therapy for the treatment of central sleep apnoea associated with heart failure. Cochrane Database Syst Rev. 2019;12:CD012803.
43.  American Diabetes Association. Addendum. 9. Pharmacologic approaches to glycemic treatment: standards of medical care in diabetes-2020. Diabetes Care. 2020; 43( suppl 1):S98-S110.
44.  McGuire DK, Shih WJ, Cosentino F, et al. Association of SGLT2 inhibitors with cardiovascular and kidney outcomes in patients with type 2 diabetes: a meta-analysis. JAMA Cardiol. 2021;6:148-158.
45. Li J, Woodward M, Perkovic V, et al. Mediators of the effects of canagliflozin on  heart  failure  in  patients  with  type  2  diabetes. J  Am  Coll  Cardiol  HF. 2020;8:57-66.
46. US National Library of Medicine. Clinical Trials.gov. Dapagliflozin Evaluation to Improve the LIVEs of Patients With PReserved Ejection Fraction Heart Failure. (DELIVER). 2018. Accessed June 28, 2021. https://clinicaltrials. gov/ct2/show/NCT03619213
13. 47 . Anker SD, Butler J, Filippatos GS, et al. Evaluation of the effects of sodiumglucose co-transporter 2 inhibition with empagliflozin on morbidity and mortality in patients with chronic heart failure and a preserved ejection fraction: rationale for and design of the EMPEROR-Preserved Trial. Eur J Heart Fail. 2019;21:1279-1287.
48. Bhatt DL, Szarek M, Steg PG, et al. Sotagliflozin in patients with diabetes and recent worsening heart failure. N Engl J Med. 2021;384:117-128.
49.  Liu D, Chen H, Song F, et al. Adverse drug events observed with the novel sodium/glucose co-transporter 2 inhibitor ipragliflozin for the treatment of patients with type 2 diabetes mellitus: a systematic review and meta-analysis of randomized studies. Adv Ther. 2020;37:4356-4369.
50.  Yancy CW, Jessup M, Bozkurt B, et al. 2013 ACCF/AHA guideline for the management of heart failure: a report of the American College of Cardiology Foundation/American Heart Association Task Force on Practice Guidelines. Circulation . 2013;128:e240-e327.

## 10.2. Management of Atrial Fibrillation (AF) in HF

1.  Mason PK, Lake DE, DiMarco JP,  et  al.  Impact  of  the  CHA2DS2-VASc score on anticoagulation recommendations for atrial fibrillation. Am J Med. 2012;125:603e1-603e6.
2.  Connolly SJ, Ezekowitz MD, Yusuf S, et al. Dabigatran versus warfarin in patients with atrial fibrillation. N Engl J Med. 2009;361:1139-1151.
3.  Patel MR, Mahaffey KW, Garg J, et al. Rivaroxaban versus warfarin in nonvalvular atrial fibrillation. N Engl J Med. 2011;365:883-891.
4.  Granger CB, Alexander JH, McMurray JJ, et al. Apixaban versus warfarin in patients with atrial fibrillation. N Engl J Med. 2011;365:981-982.
5.  Giugliano RP, Ruff CT, Braunwald E, et al. Edoxaban versus warfarin in patients with atrial fibrillation. N Engl J Med. 2013;369:2093-2104.
6. Ferreira  J,  Ezekowitz  MD,  Connolly  SJ,  et  al.  Dabigatran  compared  with warfarin in patients with atrial fibrillation and symptomatic heart failure: a subgroup analysis of the RE-L Y trial. Eur J Heart Fail. 2013;15:1053-1061.
7.  McMurray JJ, Ezekowitz JA, Lewis BS, et al. Left ventricular systolic dysfunction, heart failure, and the risk of stroke and systemic embolism in patients with atrial fibrillation: insights from the ARISTOTLE trial. Circ Heart Fail. 2013;6:451-460.
8. Siller-Matula JM, Pecen L, Patti G, et al. Heart failure subtypes and thromboembolic risk in patients with atrial fibrillation: the PREFER in AF - HF substudy. Int J Cardiol. 2018;265:141-147.
9.  Magnani G, Giugliano RP, Ruff CT, et al. Efficacy and safety of edoxaban  compared  with  warfarin  in  patients  with  atrial  fibrillation  and heart  failure:  insights  from  ENGAGE  AF-TIMI  48. Eur  J  Heart  Fail. 2016;18:1153-1161.
10.  Savarese G, Giugliano RP, Rosano GM, et al. Efficacy and safety of novel oral anticoagulants in patients with atrial fibrillation and heart failure: a meta-analysis. J Am Coll Cardiol HF. 2016;4:870-880.
11.  Di Biase L, Mohanty P, Mohanty S, et al. Ablation versus amiodarone for treatment  of  persistent  atrial  fibrillation  in  patients  with  congestive  heart failure and an implanted device: results from the AATAC multicenter randomized trial. Circulation. 2016;133:1637-1644.
12. Marrouche NF, Brachmann J, Andresen D, et al. Catheter ablation for atrial fibrillation with heart failure. N Engl J Med. 2018;378:417-427.
13. Chen S, Purerfellner  H,  Meyer  C,  et  al.  Rhythm  control  for  patients  with atrial fibrillation complicated with heart failure in the contemporary era of catheter ablation: a stratified pooled analysis of randomized data. Eur Heart J. 2020;41:2863-2873.
14. Packer DL, Piccini JP, Monahan KH, et al. Ablation versus drug therapy for atrial fibrillation in heart failure: results from the CABANA trial. Circulation. 2021;143:1377-1390.
15.  Wood MA, Brown-Mahoney C, Kay GN, et al. Clinical outcomes after ablation  and  pacing  therapy  for  atrial  fibrillation:  a  meta-analysis. Circulation. 2000;101:1138-1144.
16. Brignole M, Menozzi C, Gianfranchi L, et al. Assessment of atrioventricular junction ablation and VVIR pacemaker versus pharmacological treatment in patients with heart failure and chronic atrial fibrillation: a randomized, controlled study. Circulation. 1998;98:953-960.
17. 17 .  Doshi RN, Daoud EG, Fellows C, et al. Left ventricular-based cardiac stimulation Post AV nodal ablation Evaluation (the PAVE study). J Cardiovasc Electrophysiol. 2005;16:1160-1165.
18. Brignole  M,  Gammage  M,  Puggioni  E,  et  al.  Comparative  assessment  of right, left, and biventricular pacing in patients with permanent atrial fibrillation. Eur Heart J. 2005;26:712-722.
19. Brignole  M,  Botto  G,  Mont  L,  et  al.  Cardiac  resynchronization  therapy  in patients undergoing atrioventricular junction ablation for permanent atrial fibrillation: a randomized trial. Eur Heart J. 2011;32:2420-2429.
20. Brignole M, Pokushalov E, Pentimalli F, et al. A randomized controlled trial of  atrioventricular  junction  ablation  and  cardiac  resynchronization therapy in patients with permanent atrial fibrillation and narrow QRS. Eur Heart J. 2018;39:3999-4008.
21.  Chatterjee NA, Upadhyay GA, Ellenbogen KA, et al. Atrioventricular nodal ablation in atrial fibrillation: a meta-analysis of biventricular vs. right ventricular pacing mode. Eur J Heart Fail. 2012;14:661-667.
22. Prabhu S, Taylor AJ, Costello BT, et al. Catheter ablation versus medical rate control in atrial fibrillation and systolic dysfunction: the CAMERA-MRI study. J Am Coll Cardiol. 2017;70:1949-1961.
23.  Freudenberger RS, Hellkamp AS, Halperin JL, et al. Risk of thromboembolism in heart failure: an analysis from the Sudden Cardiac Death in Heart Failure Trial (SCD-HEFT). Circulation. 2007;115:2637-2641.
24.  Camm AJ, Kirchhof P, Lip GY, et al. Guidelines for the management of atrial fibrillation: the Task Force for the Management of Atrial Fibrillation of the European Society of Cardiology (ESC). Eur Heart J. 2010;31:23692429.
25. Melgaard  L,  Gorst-Rasmussen  A,  Lane  DA,  et  al.  Assessment  of  the CHA2DS2-VASc  score  in  predicting  ischemic  stroke,  thromboembolism, and death in patients with heart failure with and without atrial fibrillation. JAMA. 2015;314:1030-1038.
26.  Mogensen UM, Jhund PS, Abraham WT, et al. Type of atrial fibrillation and outcomes in patients with heart failure and reduced ejection fraction. J Am Coll Cardiol. 2017;70:2490-2500.
27. 27 .  January CT, Wann LS, Alpert JS, et al. 2014 AHA/ACC/HRS guideline for the management of patients with atrial fibrillation: a report of the American College of Cardiology/American Heart Association Task Force on Practice Guidelines  and  the  Heart  Rhythm  Society. Circulation .  2014;130:e199e267.
28.  January CT, Wann LS, Calkins CH, et al. 2019 AHA/ACC/HRS focused update of the 2014 AHA/ACC/HRS guideline for the management of patients with atrial fibrillation: a report of the American College of Cardiology/

American Heart Association Task Force on Clinical Practice Guidelines and the Heart Rhythm Society. Circulation . 2019;140:e125-e151.

29. Witt BJ, Brown RD Jr, Jacobsen SJ, et al. Ischemic stroke after heart failure: a community-based study. Am Heart J. 2006;152:102-109.

## 11.1. Disparities and Vulnerable Populations

1.  Colvin M, Sweitzer NK, Albert NM, et al. Heart failure in non-Caucasians, women, and older adults: a white paper on special populations from the Heart  Failure  Society  of  America  Guideline  Committee. J  Card  Fail. 2015;21:674-693.
2.  Virani SS, Alonso A, Benjamin EJ, et al. Heart disease and stroke statistics-2020 update: a report From the American Heart Association. Circulation. 2020;141:e139-e596.
3.  Ziaeian B, Kominski GF, Ong MK, et al. National differences in trends for heart failure hospitalizations by sex and race/ethnicity. Circ Cardiovasc Qual Outcomes. 2017;10:e003552.
4. Nayak A, Hicks AJ, Morris AA. Understanding the complexity of heart failure risk and treatment in black patients. Circ Heart Fail. 2020. CIRCHEARTFAILURE120007264.
5.  Schultz WM, Kelli HM, Lisko JC, et al. Socioeconomic status and cardiovascular outcomes: challenges and interventions. Circulation . 2018;137:21662178.
6.  Bevan GH, Josephson R, Al-Kindi SG. Socioeconomic deprivation and heart failure mortality in the United States. J Card Fail. 2020;26:1106-1167.
7. Rodriguez CJ, Allison M, Daviglus ML, et al. Status of cardiovascular disease and stroke in Hispanics/Latinos in the United States: a science advisory from the American Heart Association. Circulation. 2014;130:593-625.
8. Carnethon  MR,  Pu  J,  Howard  G,  et  al.  Cardiovascular  health  in  African Americans:  a  scientific  statement  from  the  American  Heart  Association. Circulation. 2017;136:e393-e423.
9. Sterling  MR,  Ringel  JB,  Pinheiro  LC,  et  al.  Social  determinants  of  health and 90-day mortality after hospitalization for heart failure in the REGARDS study. J Am Heart Assoc. 2020;9:e014836.
10. Khariton Y,  Nassif  ME,  Thomas L,  et  al.  Health  status  disparities  by  sex, race/ethnicity, and socioeconomic status in outpatients with heart failure. J Am Coll Cardiol HF. 2018;6:465-473.
11.  Breathett K, Sims M, Gross M, et al. Cardiovascular health in American Indians and Alaska Natives: a scientific statement from the American Heart Association. Circulation. 2020;141:e948-e959.
12. Eberly LA, Richterman A, Beckett AG, et al. Identification of racial inequities in access to specialized inpatient heart failure care at an academic medical center. Circ Heart Fail. 2019;12:e006214.
13. Sentell T, Miyamura J, Ahn HJ, et al. Potentially preventable hospitalizations for congestive heart failure among Asian Americans and Pacific Islanders in Hawai'i. J Immigr Minor Health. 2015;17:1289-1297.
14. Brown AF,  Liang  LJ,  Vassar  SD,  et  al.  Trends  in  racial/ethnic  and  nativity disparities in cardiovascular health among adults without prevalent cardiovascular disease in the United States, 1988 to 2014. Ann Intern Med. 2018;168:541-549.
15. Lawson CA, Zaccardi F, Squire I, et al. Risk factors for heart failure: 20-year population-based trends by sex, socioeconomic status, and ethnicity. Circ Heart Fail. 2020;13:e006472.
16.  Brewer LC, Cooper LA. Race, discrimination, and cardiovascular disease. Virtual Mentor. 2014;16:455-460.
17. 17 . Cresci S, Pereira NL, Ahmad F, et al. Heart failure in the era of precision medicine: a scientific statement from the American Heart Association. Circ Genom Precis Med. 2019;12:458-485.
18.  White-Williams C, Rossi LP, Bittner VA, et al. Addressing social determinants of health in the care of patients with heart failure: a scientific statement from the American Heart Association. Circulation. 2020;141:e841e863.
19.  Lam CSP, Arnott C, Beale AL, et al. Sex differences in heart failure. Eur Heart J. 2019;40:3859-3868c.
20. Roger VL, Weston SA, Redfield MM, et al. Trends in heart failure incidence and survival in a community-based population. JAMA. 2004;292:344-350.
21.  Ehrmann Feldman D, Xiao Y, Bernatsky S, et al. Consultation with cardiologists for persons with new-onset chronic heart failure: a population-based study. Can J Cardiol. 2009;25:690-694.
22. Feldman DE, Huynh T, Des Lauriers J, et al. Gender and other disparities in referral to specialized heart failure clinics following emergency department visits. J Womens Health (Larchmt) . 2013;22:526-531.
23.  Al-Khatib SM, Hellkamp AS, Hernandez AF, et al. Trends in use of implantable cardioverter-defibrillator therapy among patients hospitalized for heart
24. failure: have the previously observed sex and racial disparities changed over time? Circulation . 2012;125:1094-1101.
24.  Hsich EM. Sex differences in advanced heart failure therapies. Circulation. 2019;139:1080-1093.
25. Rethy L, Petito LC, Vu THT, et al. Trends in the prevalence of self-reported heart failure by race/ethnicity and age from 2001 to 2016. JAMA Cardiol. 2020;5:1-5.
26.  Bahrami H, Kronmal R, Bluemke DA, et al. Differences in the incidence of congestive heart failure by ethnicity: the multi-ethnic study of atherosclerosis. Arch Intern Med. 2008;168:2138-2145.
28. 27 . Glynn P, Lloyd-Jones DM, Feinstein MJ, et al. Disparities in cardiovascular mortality  related  to  heart  failure  in  the  United  States. J  Am  Coll  Cardiol. 2019;73:2354-2355.
28. Churchwell  K,  Elkind  MSV,  Benjamin  RM,  et  al.  Call  to  action:  structural racism as a fundamental driver of health disparities: a presidential advisory from the American Heart Association. Circulation. 2020;142:e454-e468.
29. Butrous  H,  Hummel  SL.  Heart  failure  in  older  adults. Can  J  Cardiol. 2016;32:1140-1147.
30. Allen LA, Hernandez AF, Peterson ED, et al. Discharge to a skilled nursing facility and subsequent clinical outcomes among older patients hospitalized for heart failure. Circ Heart Fail. 2011;4:293-300.
31. Silver  JK,  Bean AC, Slocum C, et al. Physician workforce disparities and patient care: a narrative review. Health Equity. 2019;3:360-377.
32. Mehta LS, Fisher K, Rzeszut AK, et al. Current demographic status of cardiologists in the United States. JAMA Cardiol. 2019;4:1029-1033.
33. Hall  WJ,  Chapman  MV,  Lee  KM,  et  al.  Implicit  racial/ethnic  bias  among health care professionals and its influence on health care outcomes: a systematic review. Am J Public Health. 2015;105:e60-e76.
34.  Williams JS, Walker RJ, Egede LE. Achieving equity in an evolving healthcare system: opportunities and challenges. Am J Med Sci. 2016;351:3343.
35.  Serchen J, Doherty R, Atiq O, Hilden D. Racism and health in the United States: a policy statement from the American College of Physicians. Ann Intern Med. 2020;173:556-557.
36.  Kalogeropoulos A, Georgiopoulou V, Kritchevsky SB, et al. Epidemiology of incident heart failure in a contemporary elderly cohort: the health, aging, and body composition study. Arch Intern Med. 2009;169:708-715.
38. 37 .  Whelton PK, Carey RM, Aronow WS, et al. 2017 ACC/AHA/AAPA/ABC/ ACPM/AGS/APhA/ASH/ASPC/NMA/PCNA guideline for the prevention, detection, evaluation, and management of high blood pressure in adults: a report of the American College of Cardiology/American Heart Association Task  Force  on  Clinical  Practice  Guidelines. Hypertension .  2018;71:e13e115.
38. Leiby DA, Rentas FJ, Nelson KE, et al. Evidence of Trypanosoma cruzi infection (Chagas' disease) among patients undergoing cardiac surgery. Circulation. 2000;102:2978-2982.
39. Bank IEM, Gijsberts CM, Teng TK, et al. Prevalence and clinical significance of diabetes in Asian versus white patients with heart failure. J Am Coll Cardiol HF. 2017;5:14-24.
40. Bitton A, Zaslavsky AM, Ayanian JZ. Health risks, chronic diseases, and access to care among US Pacific Islanders. J Gen Intern Med. 2010;25:435440.
41.  Sharma A, Zhao X, Hammill BG, et al. Trends in noncardiovascular comorbidities among patients hospitalized for heart failure: insights from the Get With The Guidelines-Heart Failure Registry. Circ Heart Fail. 2018;11:e004646.
42. Manemann SM,  Chamberlain  AM,  Roger  VL,  et  al.  Perceived  social  isolation  and  outcomes  in  patients  with  heart  failure. J  Am  Heart  Assoc. 2018;7:e008069.
43. Orr NM, Boxer RS, Dolansky MA, et al. Skilled nursing facility care for patients with heart failure: can we make it 'heart failure ready? J Card Fail. 2016;22:1004-1014.
44.  Gorodeski EZ, Goyal P, Hummel SL, et al. Domain management approach to heart failure in the geriatric patient: present and future. J Am Coll Cardiol. 2018;71:1921-1936.
45. Jurgens  CY,  Goodlin  S,  Dolansky  M,  et  al.  Heart  failure  management  in skilled  nursing  facilities:  a  scientific  statement  from  the  American  Heart Association  and  the  Heart  Failure  Society  of  America. Circ  Heart  Fail. 2015;8:655-687.
46. Akwo  EA,  Kabagambe  EK,  Harrell  FE  Jr,  et  al.  Neighborhood  deprivation  predicts  heart  failure  risk  in  a  low-income  population  of  blacks  and whites in the Southeastern United States. Circ Cardiovasc Qual Outcomes. 2018;11:e004052.
48. 47 .  Topel ML, Kim JH, Mujahid MS, et al. Neighborhood socioeconomic status and adverse outcomes in patients with cardiovascular disease. Am J Cardiol. 2019;123:284-290.

48.  Baggett TP, Liauw SS, Hwang SW. Cardiovascular disease and homelessness. J Am Coll Cardiol. 2018;71:2585-2597.
49. Rich MW, Beckham V, Wittenberg C, et al. A multidisciplinary intervention to prevent the readmission of elderly patients with congestive heart failure. N Engl J Med. 1995;333:1190-1195.
50.  Fonarow GC, Abraham WT, Albert NM, et al. Age- and gender-related differences in quality of care and outcomes of patients hospitalized with heart failure (from OPTIMIZE-HF). Am J Cardiol. 2009;104:107-115.
51. Steinberg RS, Nayak A, O'Connell C, et al. Sex differences in eligibility for advanced heart failure therapies. Clin Transplant. 2020;34:e13839.
52. DeFilippis EM, Truby LK, Garan AR, et al. Sex-related differences in use and outcomes of left ventricular assist devices as bridge to transplantation. J Am Coll Cardiol HF. 2019;7:250-257.
53. Breathett K, Y ee E, Pool N, et al. Does race influence decision making for advanced heart failure therapies? J Am Heart Assoc. 2019;8:e013592.
54. Breathett  K,  Y ee  E,  Pool  N,  et  al.  Association  of  gender  and  race  with allocation of advanced heart failure therapies. JAMA  Netw Open. 3;2020:e2011044.
55. Breathett K, Liu WG, Allen LA, et al. African Americans are less likely to receive care by a cardiologist during an intensive care unit admission for heart failure. J Am Coll Cardiol HF. 2018;6:413-420.
56. Aviles-Santa  ML,  Heintzman  J,  Lindberg  NM,  et  al.  Personalized  medicine  and  Hispanic health: improving health outcomes and reducing health disparities - a National Heart, Lung, and Blood Institute workshop report. BMC Proc. 2017;11:11.
10. 57 . Vivo RP, Krim SR, Cevik C, et al. Heart failure in Hispanics. J Am Coll Cardiol. 2009;53:1167-1175.
58. Victor RG, Lynch K, Li N, et al. A cluster-randomized trial of blood-pressure reduction in black barbershops. N Engl J Med. 2018;378:1291-1301.
59. Ebinger J, Blyler CA, Brettler J, et al. Barbershop management of hypertension in the African American population: pitfalls and opportunities for extension to other underserved communities. Curr Cardiol Rep. 2020;22:64.
60.  Weiss B. Health Literacy: A Manual for Clinicians . American Medical Association Foundation; 2003.
61. Jin X, Chandramouli C, Allocco B, et al. Women's participation in cardiovascular clinical trials from 2010 to 2017 . Circulation . 2020;141:540-548.
62. Khan MS, Shahid I, Siddiqi T J, et al. Ten-year trends in enrollment of women and  minorities  in  pivotal  trials  supporting  recent  US  Food  and  Drug  Administration  approval  of  novel  cardiometabolic  drugs. J  Am  Heart  Assoc. 2020;9:e015594.
63. Tahhan AS, Vaduganathan M, Greene SJ, et al. Enrollment of older patients, women, and racial and ethnic minorities in contemporary heart failure clinical trials: a systematic review. JAMA Cardiol . 2018;3:1011-1019.
64. Sullivan L T 2nd, Randolph T, Merrill P, et al. Representation of black patients in randomized clinical trials of heart failure with reduced ejection fraction. Am Heart J. 2018;197:43-52.
65.  Ortega RF, Yancy CW, Mehran R, et al. Overcoming lack of diversity in cardiovascular clinical trials: a new challenge and strategies for success. Circulation. 2019;140:1690-1692.
66. Ho JE, Gona P, Pencina MJ, et al. Discriminating clinical features of heart failure with preserved vs. reduced ejection fraction in the community. Eur Heart J. 2012;33:1734-1741.
20. 67 .  Suthahar N, Lau ES, Blaha MJ, et al. Sex-specific associations of cardiovascular risk factors and biomarkers with incident heart failure. J Am Coll Cardiol. 2020;76:1455-1465.
68. Medina-Inojosa JR, Vinnakota S, Garcia M, et al. Role of stress and psychosocial determinants on women's cardiovascular risk and disease development. J Womens Health (Larchmt). 2019;28:483-489.
69.  Virani SS, Alonso A, Benjamin EJ, et al. Heart disease and stroke statistics-2020 update: a report from the American Heart Association. Circulation. 2020;141:e139-e596.
70.  Motiejunaite J, Akiyama E, Cohen-Solal A, et al. The association of longterm outcome and biological sex in patients with acute heart failure from different geographic regions. Eur Heart J. 2020;41:1357-1364.
71. Dewan  P,  Rorth  R,  Jhund  PS,  et  al.  Differential  impact  of  heart  failure with  reduced  ejection  fraction  on  men  and  women. J  Am  Coll  Cardiol. 2019;73:29-40.
72. Lloyd-Jones  DM,  Larson  MG,  Leip  EP,  et  al.  Lifetime  risk  for  developing  congestive  heart  failure:  the  Framingham  Heart  Study. Circulation . 2002;106:3068-3072.
73.  Shah AM, Claggett B, Loehr LR, et al. Heart failure stages among older adults  in  the  community:  the  Atherosclerosis  Risk  in  Communities  study. Circulation. 2017;135:224-240.
27. 7 4.  Sung SH, Wang TJ, Cheng HM, et al. Clinical characteristics and outcomes in the very elderly patients hospitalized for acute heart failure: importance of pharmacologic guideline adherence. Sci Rep. 2018;8:14270.
75. Graham G. Disparities in cardiovascular disease risk in the United States. Curr Cardiol Rev. 2015;11:238-245.
76. Lewis EF, Claggett B, Shah AM, et al. Racial differences in characteristics and outcomes of patients with heart failure and preserved ejection fraction in the treatment of preserved cardiac function heart failure trial. Circ Heart Fail. 11;2018:e004457.
30. 77 . Lui C, Fraser CD 3rd, Zhou X, et al. Racial disparities in patients bridged to heart transplantation with left ventricular assist devices. Ann Thorac Surg. 2019;108:1122-1126.
78.  Morris AA, Kransdorf EP, Coleman BL, et al. Racial and ethnic disparities in outcomes after heart transplantation: a systematic review of contributing factors and future directions to close the outcomes gap. J Heart Lung Transplant. 2016;35:953-961.
79.  Wayda B, Clemons A, Givens RC, et al. Socioeconomic disparities in adherence and outcomes after heart transplant: a UNOS (United Network for Organ Sharing) registry analysis. Circ Heart Fail. 2018;11:e004173.
80. Balfour  PC  Jr,  Ruiz  JM,  T alavera  GA,  Allison  MA,  Rodriguez  CJ.  Cardiovascular disease in Hispanics/Latinos in the United States. J Lat Psychol. 2016;4:98-113.
81.  Alexander M, Grumbach K, Remy L, et al. Congestive heart failure hospitalizations and survival in California: patterns according to race/ethnicity. Am Heart J. 1999;137:919-927.
82. Vivo  RP,  Krim  SR,  Krim  NR,  et  al.  Care  and  outcomes  of  Hispanic  patients admitted with heart failure with preserved or reduced ejection fraction: findings from Get With The Guidelines-Heart Failure. Circ Heart Fail. 2012;5:167-175.
83.  Shulman E, Shah T, Mazori AY, et al. Heart failure and the development of atrial fibrillation in Hispanics, African Americans and non-Hispanic Whites. Int J Cardiol. 2018;271:186-191.
84.  Volgman AS, Palaniappan LS, Aggarwal NT, et al. Atherosclerotic cardiovascular disease in South Asians in the United States: epidemiology, risk factors, and treatments: a scientific statement from the American Heart Association. Circulation. 2018;138:e1-e34.
85. Palaniappan LP, Araneta MR, Assimes TL, et al. Call to action: cardiovascular disease in Asian Americans: a science advisory from the American Heart Association. Circulation. 2010;122:1242-1252.
86. Jose PO, Frank AT, Kapphahn KI, et al. Cardiovascular disease mortality in Asian Americans. J Am Coll Cardiol. 2014;64:2486-2494.
40. 87 .  Muller CJ, Noonan CJ, MacLehose RF, et al. Trends in cardiovascular disease morbidity and mortality in American Indians over 25 years: the Strong Heart study. J Am Heart Assoc. 2019;8:e012289.
88.  Benjamin EJ, Muntner P, Alonso A, et al. Heart disease and stroke statistics-2019 update: a report from the American Heart Association. Circulation. 2019;139:e56-e528.

## 11.2. Cardio-Oncology

1. Wang SY, Long JB, Hurria A, et al. Cardiovascular events, early discontinuation of trastuzumab, and their impact on survival. Breast Cancer Res Treat. 2014;146:411-419.
2. Guarneri  V,  Lenihan  DJ,  Valero  V,  et  al.  Long-term  cardiac  tolerability  of trastuzumab in metastatic breast cancer: the M.D. Anderson Cancer Center experience. J Clin Oncol. 2006;24:4107-4115.
3.  Cardinale D, Colombo A, Lamantia G, et al. Anthracycline-induced cardiomyopathy: clinical relevance and response to pharmacologic therapy. J Am Coll Cardiol. 2010;55:213-220.
4.  Cardinale D, Colombo A, Bacchiani G, et al. Early detection of anthracycline cardiotoxicity and improvement with heart failure therapy. Circulation. 2015;131:1981-1988.
5.  Chavez-MacGregor M, Zhang N, Buchholz TA, et al. Trastuzumab-related cardiotoxicity  among  older  patients  with  breast  cancer. J  Clin  Oncol. 2013;31:4222-4228.
6. Goldhar HA, Yan AT, Ko DT, et al. The temporal risk of heart failure associated with adjuvant trastuzumab in breast cancer patients: a population study. J Natl Cancer Inst. 2016;108:djv301.
7.  Armenian SH, Sun CL, Shannon T, et al. Incidence and predictors of congestive heart failure after autologous hematopoietic cell transplantation. Blood. 2011;118:6023-6029.
8. Henry  ML,  Niu  J,  Zhang  N,  et  al.  Cardiotoxicity  and  cardiac  monitoring among chemotherapy-treated breast cancer patients. J Am Coll Cardiol Img. 2018;11:1084-1093.
9.  Wang L, Tan TC, Halpern EF, et al. Major cardiac events and the value of echocardiographic  evaluation  in  patients  receiving  anthracycline-based chemotherapy. Am J Cardiol. 2015;116:442-446.

10. Seferina  SC,  de  Boer  M,  Derksen  MW,  et  al.  Cardiotoxicity  and  cardiac monitoring  during  adjuvant  trastuzumab  in  daily  Dutch  practice:  a  study of  the  Southeast  Netherlands  Breast  Cancer  Consortium. Oncologist. 2016;21:555-562.
11.  Abu-Khalaf MM, Safonov A, Stratton J, et al. Examining the cost-effectiveness of baseline left ventricular function assessment among breast cancer patients undergoing anthracycline-based therapy. Breast Cancer Res Treat. 2019;176:261-270.
12. Truong SR, Barry WT, Moslehi JJ, et al. Evaluating the utility of baseline cardiac function screening in early-stage breast cancer treatment. Oncologist. 2016;21:666-670.
13.  Jeyakumar A, DiPenta J, Snow S, et al. Routine cardiac evaluation in patients  with  early-stage  breast  cancer  before  adjuvant  chemotherapy. Clin Breast Cancer. 2012;12:4-9.
14. Steuter J, Bociek R, Loberiza F, et al. Utility of prechemotherapy evaluation of left ventricular function for patients with lymphoma. Clin Lymphoma Myeloma Leuk. 2015;15:29-34.
15. Conrad AL, Gundrum JD, McHugh VL, et al. Utility of routine left ventricular ejection  fraction  measurement before anthracycline-based chemotherapy in patients with diffuse large B-cell lymphoma. J Oncol Pract. 2012;8:336340.
16. O'Brien  PMK,  Jeyakumar  A,  et  al.  The  clinical  utility  of  baseline  cardiac assessments prior to adjuvant anthracycline chemotherapy in breast cancer:  a  systematic  review  and  meta-analysis. Breast  Cancer  Res  Treat. 2019;174:357-363.
8. 17 . Akpek  M,  Ozdogru  I,  Sahin  O,  et  al.  Protective  effects  of  spironolactone  against  anthracycline-induced  cardiomyopathy. Eur  J  Heart  Fail. 2015;17:81-89.
18. Avila MS, Ayub-Ferreira SM, de Barros Wanderley MR Jr, et al. Carvedilol for prevention of chemotherapy-related cardiotoxicity: the CECCY trial. J Am Coll Cardiol. 2018;71:2281-2290.
19. Bosch X, Rovira M, Sitges M, et al. Enalapril and carvedilol for preventing chemotherapy-induced left ventricular systolic dysfunction in patients with malignant hemopathies: the OVERCOME trial (preventiOn of left Ventricular dysfunction with Enalapril and caRvedilol in patients submitted to intensive ChemOtherapy for the treatment of Malignant hEmopathies). J Am Coll Cardiol. 2013;61:2355-2362.
20.  Cardinale D, Colombo A, Sandri MT, et al. Prevention of high-dose chemotherapy-induced cardiotoxicity in high-risk patients by angiotensin-converting enzyme inhibition. Circulation. 2006;114:2474-2481.
21. Guglin M, Krischer J, Tamura R, et al. Randomized trial of lisinopril versus carvedilol to prevent trastuzumab cardiotoxicity in patients with breast cancer. J Am Coll Cardiol. 2019;73:2859-2868.
22.  Gulati G, Heck SL, Ree AH, et al. Prevention of cardiac dysfunction during adjuvant breast cancer therapy (PRADA): a 2 x 2 factorial, randomized, placebo-controlled, double-blind clinical trial of candesartan and metoprolol. Eur Heart J. 2016;37:1671-1680.
23. Kalay N, Basar E, Ozdogru I, et al. Protective effects of carvedilol against anthracycline-induced cardiomyopathy. J Am Coll Cardiol. 2006;48:22582262.
24. Pituskin E, Mackey JR, Koshman S, et al. Multidisciplinary approach to novel therapies in cardio-oncology research (MANTICORE 101-Breast): a randomized trial for the prevention of trastuzumab-associated cardiotoxicity. J Clin Oncol. 2017;35:870-877.
25. Shah  P,  Garris  R,  Abboud  R,  et  al.  Meta-analysis  comparing  usefulness of beta blockers to preserve left ventricular function during anthracycline therapy. Am J Cardiol. 2019;124:789-794.
26. Cardinale D, Ciceri F, Latini R, et al. Anthracycline-induced cardiotoxicity: a multicenter randomised trial comparing two strategies for guiding prevention with enalapril: the International CardioOncology Society-one trial. Eur J Cancer. 2018;94:126-137.
18. 27 .  Vaduganathan M, Hirji SA, Qamar A, et al. Efficacy of neurohormonal therapies in preventing cardiotoxicity in patients with cancer undergoing chemotherapy. J Am Coll Cardiol CardioOnc. 2 019;1:54-65.
28. Wittayanukorn S, Qian J, Westrick SC, et al. Prevention of trastuzumab and anthracycline-induced  cardiotoxicity  using  angiotensin-converting  enzyme inhibitors or beta-blockers in older adults with breast cancer. Am J Clin Oncol. 2018;41:909-918.
29. Cardinale D, Sandri MT, Colombo A, et al. Prognostic value of troponin I in cardiac risk stratification of cancer patients undergoing high-dose chemotherapy. Circulation . 2004;109:2749-2754.
30. Cardinale D, Colombo A, Torrisi R, et al. Trastuzumab-induced cardiotoxicity: clinical  and  prognostic  implications  of  troponin  I  evaluation. J  Clin  Oncol. 2010;28:3910-3916.
31. Cardinale D, Sandri MT, Martinoni A, et al. Left ventricular dysfunction predicted by early troponin I release after high-dose chemotherapy. J Am Coll Cardiol. 2000;36:517-522.
32.  Zardavas D, Suter TM, Van Veldhuisen DJ, et al. Role of troponins I and T and N-terminal prohormone of brain natriuretic peptide in monitoring cardiac safety of patients with early-stage human epidermal growth factor receptor 2-positive breast cancer receiving trastuzumab: a herceptin adjuvant study cardiac marker substudy. J Clin Oncol. 2017;35:878-884.
33.  Howlader N, Noone A, Krapcho M, et al. SEER Cancer Statistics Review, 1975-2014, based on November 2016 SEER data submission, posted to the SEER website, April 2017 . National Cancer Institute; 2014.
34.  Siegel RL, Miller KD, Jemal A. Cancer statistics, 2018 CA. Cancer J Clin. 2018;68:7-30.
35. Bluethmann  SM,  Mariotto  AB,  Rowland  JH.  Anticipating  the  'silver  tsunami':  prevalence  trajectories  and  comorbidity  burden  among  older  cancer  survivors  in  the  United  States. Cancer  Epidemiol  Biomarkers  Prev. 2016;25:1029-1036.
36. Barac A, Murtagh G, Carver JR, et al. Cardiovascular health of patients with cancer and cancer survivors: a roadmap to the next level. J Am Coll Cardiol. 2015;65:2739-2746.
28. 37 . Albini A, Pennesi G, Donatelli F, et al. Cardiotoxicity of anticancer drugs: the need for cardio-oncology and cardio-oncological prevention. J Natl Cancer Inst. 2010;102:14-25.
38.  Felker GM, Thompson RE, Hare JM, et al. Underlying causes and long-term survival in patients with initially unexplained cardiomyopathy. N Engl J Med. 2000;342:1077-1084.
39. Johnson  DB,  Balko  JM,  Compton  ML,  et  al.  Fulminant  myocarditis  with combination immune checkpoint blockade. N Engl J Med. 2016;375:17491755.
40.  Mahmood SS, Fradely MG, Cohen JV, et al. Myocarditis in patients treated with immune checkpoint inhibitors. J Am College Cardiol. 2018;71:17551764.
41. Tarantini L, Gori S, Faggiano P, et al. Adjuvant trastuzumab cardiotoxicity in patients over 60 years of age with early breast cancer: a multicenter cohort analysis. Ann Oncol. 2012;23:3058-3063.
42. Seidman A, Hudis C, Pierri MK, et al. Cardiac dysfunction in the trastuzumab clinical trials experience. J Clin Oncol. 2002;20:1215-1221.
43.  Hershman DL, McBride RB, Eisenberger A, et al. Doxorubicin, cardiac risk factors, and cardiac toxicity in elderly patients with diffuse B-cell non-Hodgkin's lymphoma. J Clin Oncol. 2008;26:3159-3165.
44.  Chow EJ, Mueller BA, Baker KS, et al. Cardiovascular hospitalizations and mortality among recipients of hematopoietic stem cell transplantation. Ann Intern Med. 2011;155:21-32.
45. Hequet  O,  Le  QH,  Moullet  I,  et  al.  Subclinical  late  cardiomyopathy  after doxorubicin therapy for lymphoma in adults. J Clin Oncol. 2004;22:18641871.
46.  Doyle JJ, Neugut AI, Jacobson JS, et al. Chemotherapy and cardiotoxicity in older breast cancer patients: a population-based study. J Clin Oncol. 2005;23:8597-8605.
38. 47 .  Pinder MC, Duan Z, Goodwin JS, et al. Congestive heart failure in older women treated with adjuvant anthracycline chemotherapy for breast cancer. J Clin Oncol. 2007;25:3808-3815.
48.  Alexander J, Dainiak N, Berger HJ, et al. Serial assessment of doxorubicin cardiotoxicity with quantitative radionuclide angiocardiography. N Engl J Med. 1979;300:278-283.
49. Ky B, Putt M, Sawaya H, et al. Early increases in multiple biomarkers predict subsequent cardiotoxicity in patients with breast cancer treated with doxorubicin, taxanes, and trastuzumab. J Am Coll Cardiol. 2014;63:809-816.
50.  van Boxtel W, Bulten BF, Mavinkurve-Groothuis AM, et al. New biomarkers for early detection of cardiotoxicity after treatment with docetaxel, doxorubicin and cyclophosphamide. Biomarkers. 2015;20:143-148.
51.  Dodos F, Halbsguth T, Erdmann E, et al. Usefulness of myocardial performance index and biochemical markers for early detection of anthracyclineinduced cardiotoxicity in adults. Clin Res Cardiol. 2008;97:318-326.
52.  Ruggiero A, De Rosa G, Rizzo D, et al. Myocardial performance index and biochemical  markers  for  early  detection  of  doxorubicin-induced  cardiotoxicity  in  children  with  acute  lymphoblastic  leukaemia. Int  J  Clin  Oncol. 2013;18:927-933.
53.  Armenian SH, Gelehrter SK, Vase T, et al. Screening for cardiac dysfunction in anthracycline-exposed childhood cancer survivors. Clin Cancer Res. 2014;20:6314-6323.
54.  Hoeger CW, Hayek SS. Role of Cardiovascular biomarkers in the risk stratification, monitoring, and management of patients with cancer. Cardiol Clin. 2019;37:505-523.

55. Doxorubicin hydrochloride for injection, USP [package insert]. New York, NY: Pharmacia &amp; Upjohn Company; 2010.
56. Murbraech K, Wethal T, Smeland KB, et al. Valvular dysfunction in lymphoma survivors treated with autologous stem cell transplantation: a national crosssectional study. J Am Coll Cardiol Img. 2016;9:230-239.
3. 57 . Epirubicin hydrochloride for injection [package insert]. VIC, Australia: Mayne Pharma Limited Mulgrave; 2006.
58. Cyclophosphamide [package insert] . Deerfield, IL: Baxter Healthcare Corporation Deerfield; 2013.
59.  Quezado ZM, Wilson WH, Cunnion RE, et al. High-dose ifosfamide is associated  with  severe,  reversible  cardiac  dysfunction. Ann  Intern  Med. 1993;118:31-36.
60.  Pai VB, Nahata MC. Cardiotoxicity of chemotherapeutic agents: incidence, treatment and prevention. Drug Saf. 2000;22:263-302.
61.  Martin M, Pienkowski T, Mackey J, et al. Adjuvant docetaxel for node-positive breast cancer. N Engl J Med. 2005;352:2302-2313.
62. Docetaxel [package insert] . Princeton, NJ:Sandoz;2012.
63. Fluorouracil  [package  insert] .  Irvine,  CA:Spectrum  Pharmaceuticals,  Inc; 2016.
64. Meyer CC, Calis KA, Burke LB, et al. Symptomatic cardiotoxicity associated with 5-fluorouracil. Pharmacotherapy. 1997;17:729-736.
65.  Yeh ET, Bickford CL. Cardiovascular complications of cancer therapy: incidence,  pathogenesis,  diagnosis,  and  management. J  Am  Coll  Cardiol. 2009;53:2231-2247.
66. Sasson Z, Morgan CD, Wang B, et al. 5-Fluorouracil related toxic myocarditis: case reports and pathological confirmation. Can J Cardiol. 1994;10:861864.
13. 67 . Killu A, Madhavan M, Prasad K, et al. 5-fluorouracil induced pericarditis. BMJ Case Rep. 2011;2011:bcr0220113883.
68. Van Cutsem E, Hoff PM, Blum JL, et al. Incidence of cardiotoxicity with the oral fluoropyrimidine capecitabine is typical of that reported with 5-fluorouracil. Ann Oncol. 2002;13:484-485.
69. Capecitabine (Xeloda) [package insert] . South San Francisco, CA: Genentech USA, Inc; 2015.
70. Fludarabine (Fludara) [package insert]. Montville, NJ: Berlex; 2003.
71.  Hussein MA, Gundacker H, Head DR, et al. Cyclophosphamide followed by fludarabine for untreated chronic lymphocytic leukemia: a phase II SWOG TRIAL 9706. Leukemia . 2005;19:1880-1886.
72. Decitabine (Dacogen) [package insert] . Bloomington, MN: MGI Pharma, Inc; 2006.
73. Pertuzumab (Perjeta) [package insert] . South San Francisco, CA: Genentech, Inc; 2012.
20. 7 4. Trastuzuman (Herceptin) [package insert] . South San Francisco, CA: Genentech, Inc; 2010.
75.  Slamon DJ, Leyland-Jones B, Shak S, et al. Use of chemotherapy plus a monoclonal antibody against HER2 for metastatic breast cancer that overexpresses HER2. N Engl J Med. 2001;344:783-792.
76. Suter  TM,  Procter  M,  van  Veldhuisen  DJ,  et  al.  Trastuzumab-associated  cardiac  adverse  effects  in  the  herceptin  adjuvant  trial. J  Clin  Oncol. 2007;25:3859-3865.
23. 77 . Rituximab [package insert] . South San Francisco, CA: Genentech, Inc; 2010.
78. Dabrafenib (Tafinlar) [package insert] . Research Triangle Park, NC: GlaxoSmithKline; 2014.
79.  Flaherty KT, Infante JR, Daud A, et al. Combined BRAF and MEK inhibition in melanoma with BRAF V600 mutations. N Engl J Med. 2012;367:16941703.
80.  Bronte E, Bronte G, Novo G, et al. What links BRAF to the heart function? New insights from the cardiotoxicity of BRAF inhibitors in cancer treatment. Oncotarget. 2015;6:35589-35601.
81. Moslehi JJ, Deininger M. T yrosine kinase inhibitor-associated cardiovascular toxicity in chronic myeloid leukemia. J Clin Oncol. 2015;33:4210-4218.
82. Dasatinib  (Sprycel)  [package  insert] .  Princeton,  NJ:  Bristol-Myers  SquibbCompany; 2010.
83. Perez EA, Koehler M, Byrne J, et al. Cardiac safety of lapatinib: pooled analysis of 3689 patients enrolled in clinical trials. Mayo Clin Proc. 2008;83:679686.
84.  Battisti NML, Tong D, Ring A, et al. Long-term outcome with targeted therapy in advanced/metastatic HER2-positive breast cancer: the Royal Marsden experience. Breast Cancer Res Treat. 2019;178:401-408.
85. Lapatinib (Tykerb) [package insert] . Research Triangle Park, NC: GlaxoSmithKline; 2007.
86. Pazopanib (Votrient) [package insert] . Research Triangle Park, NC: GlaxoSmithKline; 2009.
33. 87 .  Motzer RJ, Hutson TE, Cella D, et al. Pazopanib versus sunitinib in metastatic renal-cell carcinoma. N Engl J Med. 2013;369:722-731.
88. Ponatinib (Iclusig) [package insert] .  Cambridge, MA: ARIAD Pharmaceuticals, Inc; 2012.
89.  Cortes  JE,  Kim  DW,  Pinilla-Ibarz  J,  et  al.  A  phase  2  trial  of  ponatinib  in  Philadelphia  chromosome-positive  leukemias. N  Engl  J  Med. 2013;369:1783-1796.
90.  Sudasena D, Balanescu DV, Donisan T, et al. Fulminant vascular and cardiac toxicity associated with tyrosine kinase inhibitor sorafenib. Cardiovasc Toxicol. 2019;19:382-387.
91.  Abdel-Rahman  O,  Fouad  M.  Risk  of  cardiovascular  toxicities  in  patients with solid tumors treated with sorafenib: an updated systematic review and meta-analysis. Future Oncol. 2014;10:1981-1992.
92.  Pantaleo MA, Mandrioli A, Saponara M, et al. Development of coronary artery stenosis in a patient with metastatic renal cell carcinoma treated with sorafenib. BMC Cancer. 2012;12:231.
93. Sorafenib (Nexavar) [package insert] .  Wayne,  NJ:  Bayer  HealthCare Pharmaceuticals Inc; 2010.
94. Trametinib (Mekinist) [package insert] . Research Triangle Park, NC: GlaxoSmithKline; 2014.
95.  Flaherty KT, Robert C, Hersey P, et al. Improved survival with MEK inhibition in BRAF-mutated melanoma. N Engl J Med. 2012;367:107-114.
96. Sunitinib (Sutent) [package insert] . New York, NY: Pfizer Labs; 2011.
97.  Li  W,  Croce  K,  Steensma  DP,  et  al.  Vascular  and  metabolic  implications of novel targeted cancer therapies: focus on kinase inhibitors. J Am Coll Cardiol. 2015;66:1160-1178.
98. Imatinib  [package  insert] .  East  Hanover,  NJ:  Novartis  Pharmaceuticals Corporation; 2001.
99. Vandetanib  (Caprelsa)  [package  insert] .  Wilmington,  DE:  AstraZeneca Pharmaceuticals LP; 2014.
100.  Santoni  M,  Guerra  F,  Conti  A,  et  al.  Incidence  and  risk  of  cardiotoxicity  in  cancer  patients  treated  with  targeted  therapies. Cancer Treat Rev. 2017;59:123-131.
101.  Ganatra S, Neilan TG. Immune checkpoint inhibitor associated myocarditis. Oncologist. 2018;23:879-886.
102. Bortezomib [package insert] . Cambridge, MA: Millennium Pharmaceuticals Inc; 2014.
103.  Zangari M, Fink L, Zhan F , et al. Low venous thromboembolic risk with bortezomib in multiple myeloma and potential protective effect with thalidomide/lenalidomide-based therapy: review of data from phase 3 trials and studies of novel combination regimens. Clin Lymphoma Myeloma Leuk. 2011;11:228-236.
104. Carfilzomib  [package insert] .  Thousand Oaks, CA: Onyx Pharmaceuticals, Inc; 2016.
105.  Siegel D, Martin T, Nooka A, et al. Integrated safety profile of single-agent carfilzomib:  experience  from  526  patients  enrolled  in  4  phase  II  clinical studies. Haematologica. 2013;98:1753-1761.
106.  Stewart  AK,  Rajkumar  SV,  Dimopoulos  MA,  et  al.  Carfilzomib,  lenalidomide, and dexamethasone for relapsed multiple myeloma. N Engl J Med. 2015;372:142-152.
107. Goserelin (Zoladex) [package insert] . Wilmington, DE: AstraZeneca Pharmaceuticals LP; 2015.
108. Leuprolide (Lupron) [package insert] . North Chicago, IL: AbbVie Inc; 2014.
109. Flutamide [package insert] . Kenilworth, NJ: Schering Corp; 2001.
110. Bicalutamide [package insert] . Wilmington, DE: AstraZeneca Pharmaceuticals LP; 2015.
111. Nilutamide [package insert] . Baudette, MN: ANI Pharmaceuticals, Inc; 2015.
112. Tisagenlecleucel  (Kymriah)  [package  insert] .  East  Hanover,  NJ:  Novartis Pharmaceuticals Corporation; 2017.
113. Axicabtagene ciloleucel (Yescarta) [package insert] . Santa Monica, CA: Kite Pharma, Inc; 2017.
114.  Alblooshi R, Kanfar S, Lord B, et al. Clinical prevalence and outcome of cardiovascular events in the first 100 days post allogeneic HSCT. Eur J Haematol. 2021;106:32-39.
115.  Gul Z, Bashir Q, Cremer M, et al. Short-term cardiac toxicity of autologous hematopoietic stem cell transplant for multiple myeloma. Leuk Lymphoma. 2015;56:533-535.
116.  Mo XD, Xu LP, Liu DH, et al. Heart failure after allogeneic hematopoietic stem cell transplantation. Int J Cardiol. 2013;167:2502-2506.
117.  Murdych T, Weisdorf DJ. Serious cardiac complications during bone marrow  transplantation  at  the  University  of  Minnesota,  1977-1997 .  Bone Marrow Transplant. 2001;28:283-287.
118.  van Nimwegen FA, Ntentas G, Darby SC, et al. Risk of heart failure in survivors of Hodgkin lymphoma: effects of cardiac exposure to radiation and anthracyclines. Blood. 2017;129:2257-2265.
119.  Nolan MT, Russell DJ, Negishi K, et al. Meta-analysis of association between mediastinal radiotherapy and long-term heart failure. Am J Cardiol. 2016;118:1685-1691.

## 11.3. HF and Pregnancy

1.  Cauldwell M, Steer PJ, Swan L, et al. Pre-pregnancy counseling for women with heart disease: a prospective study. Int J Cardiol. 2017;240:374-378.
2.  Roos-Hesselink JW, Ruys TP, Stein JI, et al. Outcome of pregnancy in patients with structural or ischaemic heart disease: results of a registry of the European Society of Cardiology. Eur Heart J. 2013;34:657-665.
3.  Dawson AJ, Krastev Y, Parsonage WA, et al. Experiences of women with cardiac disease in pregnancy: a systematic review and metasynthesis. BMJ Open. 2018;8:e022755.
4.  Elkayam U, Tummala PP, Rao K, et al. Maternal and fetal outcomes of subsequent pregnancies in women with peripartum cardiomyopathy. N Engl J Med. 2001;344:1567-1571.
5.  Elkayam U. Risk of subsequent pregnancy in women with a history of peripartum cardiomyopathy. J Am Coll Cardiol. 2014;64:1629-1636.
6. Hilfiker-Kleiner  D,  Haghikia  A,  Masuko  D,  et  al.  Outcome  of  subsequent pregnancies in patients with a history of peripartum cardiomyopathy. Eur J Heart Fail. 2017;19:1723-1728.
7.  Yameogo NV, Samadoulougou AK, Kagambega LJ, et al. Maternal and fetal prognosis of subsequent pregnancy in black African women with peripartum cardiomyopathy. BMC Cardiovasc Disord. 2018;18:119.
8.  Codsi E, Rose CH, Blauwet LA. Subsequent pregnancy outcomes in patients  with  peripartum  cardiomyopathy. Obstet  Gynecol. 2018;131:322327.
9. Sliwa K, Forster O, Libhaber E, et al. Peripartum cardiomyopathy: inflammatory markers as predictors of outcome in 100 prospectively studied patients. Eur Heart J. 2006;27:441-446.
10.  Amos AM, Jaber WA, Russell SD. Improved outcomes in peripartum cardiomyopathy with contemporary. Am Heart J. 2006;152:509-513.
11. Moulig V, Pfeffer T J, Ricke-Hoch M, et al. Long-term follow-up in peripartum cardiomyopathy patients with contemporary treatment: low mortality, high cardiac recovery, but significant cardiovascular co-morbidities. Eur J Heart Fail. 2019;21:1534-1542.
12.  Laghari AH, Khan AH, Kazmi KA. Peripartum cardiomyopathy: ten year experience at a tertiary care hospital in Pakistan. BMC Res Notes. 2013;6:495.
13. Regitz-Zagrosek  V,  Roos-Hesselink  JW,  Bauersachs  J,  et  al.  2018  ESC guidelines  for  the  management  of  cardiovascular  diseases  during  pregnancy. Eur Heart J. 2018;39:3165-3241.
14.  Bauersachs J, Konig T, van der Meer P, et al. Pathophysiology, diagnosis and management of peripartum cardiomyopathy: a position statement from the Heart Failure Association of the European Society of Cardiology Study Group on peripartum cardiomyopathy. Eur J Heart Fail. 2019;21:827-843.
15.  Halpern DG, Weinberg CR, Pinnelas R, et al. Use of medication for cardiovascular disease during pregnancy: JACC state-of-the-art review. J Am Coll Cardiol. 2019;73:457-476.
16. Bozkurt B, Colvin M, Cook J, et al. Current diagnostic and treatment strategies for specific dilated cardiomyopathies: a scientific statement from the American Heart Association. Circulation. 2016;134:e579-e646.
17. 17 .  Mehta LS, Warnes CA, Bradley E, et al. Cardiovascular considerations in caring for pregnant patients: a scientific statement from the American Heart Association. Circulation. 2020;141:e884-e903.
18.  Schaufelberger M. Cardiomyopathy and pregnancy. Heart . 2019;105:15431551.
19.  Davis MB, Arany Z, McNamara D, et al. Peripartum cardiomyopathy: JACC state-of-the-art review. J Am Coll Cardiol. 2020;75:207-221.
20.  Honigberg MC, Givertz MM. Peripartum cardiomyopathy. BMJ .  2019;364. k5287-k14.
21. Lindley KJ. Heart failure and pregnancy: thinking beyond peripartum cardiomyopathy. J Card Fail. 2021;27:153-156.
22. Ruys TP, Roos-Hesselink JW, Hall R, et al. Heart failure in pregnant women with cardiac disease: data from the ROPAC. Heart. 2014;100:231-238.
23. Sliwa K, Mebazaa A, Hilfiker-Kleiner D, et al. Clinical characteristics of patients from the worldwide registry on peripartum cardiomyopathy (PPCM): EURObservational  Research  Programme  in  conjunction  with  the  Heart Failure Association of the European Society of Cardiology Study Group on PPCM. Eur J Heart Fail. 2017;19:1131-1141.
24. Mogos  MF,  Piano  MR,  McFarlin  BL,  et  al.  Heart  failure  in  pregnant women:  a  concern  across  the  pregnancy  continuum. Circ  Heart  Fail. 11;2018:e004005.
25.  Kolte D, Khera S, Aronow WS, et al. Temporal trends in incidence and outcomes of peripartum  cardiomyopathy  in  the  United  States:  a  nationwide population-based study. J Am Heart Assoc. 2014;3:e001056.
26. Afana M, Brinjikji W, Kao D, et al. Characteristics and in-hospital outcomes of  peripartum  cardiomyopathy  diagnosed  during  delivery  in  the  United

States from the Nationwide Inpatient Sample (NIS) Database. J Card Fail. 2016;22:512-519.

- 27 .  Krishnamoorthy P, Garg J, Palaniswamy C, et al. Epidemiology and outcomes of peripartum cardiomyopathy in the United States: findings from the Nationwide Inpatient Sample. J Cardiovasc Med (Hagerstown) . 2016;17:756761.
28.  Nizamuddin J, Gupta A, Patel V, et al. Hypertensive diseases of pregnancy increase risk of readmission with heart failure: a national readmissions database study. Mayo Clin Proc. 2019;94:811-819.
29. Barasa A, Rosengren A, Sandström TZ, et al. Heart failure in late pregnancy and postpartum: incidence and long-term mortality in Sweden from 1997 to 2010. J Card Fail. 2017;23:370-378.
30. Davis MB, Jarvie J, Gambahaya E, et al. Risk prediction for peripartum cardiomyopathy in delivering mothers: a validated risk model: PPCM risk prediction model. J Card Fail. 2021;27:159-167.
31.  Haghikia A, Podewski E, Libhaber E, et al. Phenotyping and outcome on contemporary management in a German cohort of patients with peripartum cardiomyopathy. Basic Res Cardiol. 2013;108:366.
32.  Horne BD, Rasmusson KD, Alharethi R, et al. Genome-wide significance and replication of the chromosome 12p11.22 locus near the PTHLH gene for peripartum cardiomyopathy. Circ Cardiovasc Genet. 2011;4:359-366.
33. Morales A, Painter T, Li R, et al. Rare variant mutations in pregnancy-associated or peripartum cardiomyopathy. Circulation. 2010;121:2176-2182.
34.  van Spaendonck-Zwarts KY, Posafalvi A, van den Berg MP, et al. Titin gene mutations are common in families with both peripartum cardiomyopathy and dilated cardiomyopathy. Eur Heart J. 2014;35:2165-2173.
35. Ware JS, Li J, Mazaika E, et al. Shared genetic predisposition in peripartum and dilated cardiomyopathies. N Engl J Med. 2016;374:233-241.
36.  Hilfiker-Kleiner D, Kaminski K, Podewski E, et al. A cathepsin D-cleaved 16  kDa  form  of  prolactin  mediates  postpartum  cardiomyopathy. Cell. 2007;128:589-600.
- 37 . Sliwa K, Blauwet L, Tibazarwa K, et al. Evaluation of bromocriptine in the treatment of acute severe peripartum cardiomyopathy: a proof-of-concept pilot study. Circulation. 2010;121:1465-1473.
38. Hilfiker-Kleiner D, Haghikia A, Berliner D, et al. Bromocriptine for the treatment of peripartum cardiomyopathy: a multicentre randomized study. Eur Heart J. 2017;38:2671-2679.
39.  Yaméogo NV, Kagambèga LJ, Seghda A, et al. Bromocriptine in management of peripartum cardiomyopathy: a randomized study on 96 women in Burkina Faso. J Cardiol Clin Res. 2017;5:1098.
40.  Tremblay-Gravel M, Marquis-Gravel G, Avram R, et al. The effect of bromocriptine on left ventricular functional recovery in peripartum cardiomyopathy: insights from the BRO-HF retrospective cohort study. ESC Heart Fail. 2019;6:27-36.
41.  Haghikia A, Schwab J, Vogel-Claussen J, et al. Bromocriptine treatment in patients with peripartum cardiomyopathy and right ventricular dysfunction. Clin Res Cardiol. 2019;108:290-297.
42. Sieweke JT, Pfeffer T J, Berliner D, et al. Cardiogenic shock complicating peripartum cardiomyopathy: importance of early left ventricular unloading and bromocriptine  therapy. Eur  Heart  J  Acute  Cardiovasc  Care. 2020;9:173182.
43.  Sliwa K, Petrie MC, Hilfiker-Kleiner D, et al. Long-term prognosis, subsequent pregnancy, contraception and overall management of peripartum cardiomyopathy: practical guidance paper from the Heart Failure Association of the European Society of Cardiology Study Group on Peripartum Cardiomyopathy. Eur J Heart Fail. 2018;20:951-962.
44. Irizarry OC, Levine LD, Lewey J, et al. Comparison of clinical characteristics and  outcomes  of  peripartum  cardiomyopathy  between  African  American and non-African American women. JAMA Cardiol. 2017;2:1256-1260.
45. Blauwet LA,  Delgado-Montero  A,  Ryo  K,  et  al.  Right  ventricular  function in  peripartum  cardiomyopathy  at  presentation  is  associated  with  subsequent  left  ventricular  recovery  and  clinical  outcomes. Circ  Heart  Fail. 2016;9:e002756.
46.  McNamara DM, Elkayam U, Alharethi R, et al. Clinical outcomes for peripartum  cardiomyopathy  in  North  America:  results  of  the  IPAC  study  (Investigations of Pregnancy-Associated Cardiomyopathy). J Am Coll Cardiol. 2015;66:905-914.
- 47 . Lindley KJ, Conner SN, Cahill AG, et al. Impact of preeclampsia on clinical and functional outcomes in women with peripartum cardiomyopathy. Circ Heart Fail. 2017;10:e003797.
48. Goland S, Bitar F, Modi K, et al. Evaluation of the clinical relevance of baseline left ventricular ejection fraction as a predictor of recovery or persistence of severe dysfunction in women in the United States with peripartum cardiomyopathy. J Card Fail. 2011;17:426-430.

49.  Dayoub EJ, Datwani H, Lewey J, et al. One-year cardiovascular outcomes in patients with peripartum cardiomyopathy. J Card Fail. 2018;24:711-715.
50. Pfaller B, Sathananthan G, Grewal J, et al. Preventing complications in pregnant women with cardiac disease. J Am Coll Cardiol. 2020;75:1443-1452.
51. Billebeau G, Etienne M, Cheikh-Khelifa R, et al. Pregnancy in women with a cardiomyopathy: outcomes and predictors from a retrospective cohort. Arch Cardiovasc Dis. 2018;111:199-209.
52.  Lima F, Nie L, Yang J, et al. Postpartum cardiovascular outcomes among women  with  heart  disease  from  a  nationwide  study. Am  J  Cardiol. 2019;123:2006-2014.
53.  Krul SP, van der Smagt JJ, van den Berg MP, et al. Systematic review of pregnancy  in  women  with  inherited  cardiomyopathies. Eur  J  Heart  Fail. 2011;13:584-594.
54. Ng AT, Duan L, Win T, et al. Maternal and fetal outcomes in pregnant women with heart failure. Heart. 2018;104:1949-1954.
55.  Elkayam U, Goland S, Pieper PG, et al. High-risk cardiac disease in pregnancy: part I. J Am Coll Cardiol. 2016;68:396-410.
56. van Hagen IM, Boersma E, Johnson MR, et al. Global cardiac risk assessment in the Registry Of Pregnancy And Cardiac disease: results of a registry from the European Society of Cardiology. Eur J Heart Fail. 2016;18:523-533.
9. 57 . Silversides CK, Grewal J, Mason J, et al. Pregnancy outcomes in women with heart disease: the CARPREG II study. J Am Coll Cardiol. 2018;71:2419-2430.
58.  Drenthen W, Boersma E, Balci A, et al. Predictors of pregnancy complications in women with congenital heart disease. Eur Heart J. 2010;31:21242132.
59.  Cooper WO, Hernandez-Diaz S, Arbogast PG, et al. Major congenital malformations after first-trimester exposure to ACE inhibitors. N Engl J Med. 2006;354:2443-2451.
60.  Buawangpong  N, Teekachunhatean S, Koonrungsesomboon N. Adverse  pregnancy  outcomes  associated  with  first-trimester  exposure  to angiotensin-converting enzyme inhibitors or angiotensin II receptor blockers:  a  systematic  review  and  meta-analysis. Pharmacol  Res  Perspect. 8;2020:e00644.
61. Bateman BT, Patorno  E,  Desai  RJ,  et  al.  Angiotensin-converting  enzyme inhibitors and  the  risk of congenital  malformations. Obstet  Gynecol. 2017;129:174-184.
62.  Liszewski W, Boull C. Lack of evidence for feminization of males exposed to  spironolactone  in  utero:  a  systematic  review. J  Am  Acad  Dermatol. 2019;80:1147-1148.
63. Tanaka K, T anaka H, Kamiya C, et al. Beta-blockers and fetal growth restriction in pregnant women with cardiovascular disease. Circ J. 2016;80:2221-2226.
64.  Bateman BT, Heide-Jorgensen U, Einarsdottir K, et al. Beta-blocker use in pregnancy and the risk for congenital malformations: an international cohort study. Ann Intern Med. 2018;169:665-673.
65.  Bergman JEH, Lutke LR, Gans ROB, et al. Beta-blocker use in pregnancy and risk of specific congenital anomalies: a European case-malformed control study. Drug Saf. 2018;41:415-427.
66. Kearney L, Wright P, Fhadil S, et al. Postpartum cardiomyopathy and considerations for breastfeeding. Card Fail Rev. 2018;4:112-118.
19. 67 .  Koczo A, Marino A, Jeyabalan A, et al. Breastfeeding, cellular immune activation, and myocardial recovery in peripartum cardiomyopathy. J Am Coll Cardiol Basic Trans Science. 2019;4:291-300.
68.  Arany Z, Feldman AM. To breastfeed or not to breastfeed with peripartum cardiomyopathy. J Am Coll Cardiol Basic Trans Science. 2019;4:301-303.
69. Koenig T, Hilfiker-Kleiner D, Bauersachs J. Breastfeeding in patients with heart failure: lack of evidence and consensus. J Am Coll Cardiol Basic Trans Science. 2019;4:866-867.
70. Safirstein JG, Ro AS, Grandhi S, et al. Predictors of left ventricular recovery in a cohort of peripartum cardiomyopathy patients recruited via the internet. Int J Cardiol. 2012;154:27-31.
71.  American Academy of Pediatrics Committee on Drugs. Transfer of drugs and other chemicals into human milk. Pediatrics . 2001;108:776-789.
72. National Library of Medicine. Drugs and Lactation Database (LactMed) [Internet] . Bethesda (MD). Accessed October 2, 2020. https://wwwncbinlmnihgov/books/NBK501922/
73.  Kampman MA, Balci A, van Veldhuisen DJ, et al. N-terminal pro-B-type natriuretic peptide predicts cardiovascular complications in pregnant women with congenital heart disease. Eur Heart J. 2014;35:708-715.
26. 7 4.  Tanous D, Siu SC, Mason J, et al. B-type natriuretic peptide in pregnant women with heart disease. J Am Coll Cardiol. 2010;56:1247-1253.
75.  Gammill HS, Chettier R, Brewer A, et al. Cardiomyopathy and preeclampsia. Circulation. 2018;138:2359-2366.
76. Ersboll AS, Arany Z, Gustafsson F. Bromocriptine for the treatment of peripartum cardiomyopathy: comparison of outcome with a Danish cohort. Eur Heart J. 2018;39:3476-3477.

## 12.1. Performance Measurement

1.  Fonarow GC, Albert NM, Curtis AB, et al. Improving evidence-based care for  heart  failure  in  outpatient  cardiology  practices:  primary  results  of  the Registry to Improve the Use of Evidence-Based Heart Failure Therapies in the Outpatient Setting (IMPROVE HF). Circulation . 2010;122:585-596.
2. Nakano A, Vinter N, Egstrup K, et al. Association between process performance measures and 1-year mortality among patients with incident heart failure: a Danish nationwide study. Eur Heart J Qual Care Clin Outcomes. 2019;5:28-34.
3. Patel  DB,  Shah  RM,  Bhatt  DL,  et  al.  Guideline-appropriate  care  and  inhospital outcomes in patients with heart failure in teaching and nonteaching hospitals: findings from Get With The Guidelines-Heart Failure. Circ Cardiovasc Qual Outcomes. 2016;9:757-766.
4. Patel J, Sandhu A, Parizo J, et al. Validity of performance and outcome measures for heart failure. Circ Heart Fail. 2018;11:e005035.
5. Heidenreich PA, Hernandez AF, Yancy CW, et al. Get With The Guidelines program participation, process of care, and outcome for Medicare patients hospitalized with heart failure. Circ Cardiovasc Qual Outcomes. 2012;5:37-43.
6.  Heidenreich PA, Lewis WR, LaBresh KA, et al. Hospital performance recognition with the Get With The Guidelines Program and mortality for acute myocardial infarction and heart failure. Am Heart J. 2009;158:546-553.
7. Ivers NM, Grimshaw JM, Jamtvedt G, et al. Growing literature, stagnant science? Systematic review, meta-regression and cumulative analysis of audit and feedback interventions in health care. J Gen Intern Med. 2014;29:1534-1541.
8.  Heidenreich PA, Fonarow GC, Breathett K, et al. 2020 ACC/AHA clinical performance and quality measures for adults with heart failure: a report of the American College of Cardiology/American Heart Association Task Force on Performance Measures. Circ Cardiovasc Qual Outcomes . 2020;13:e000099.
9. Tu JV, Donovan LR, Lee DS, et al. Effectiveness of public report cards for improving the quality of cardiac care: the EFFECT study: a randomized trial. JAMA. 2009;302:2330-2337.
10.  Thomas RJ, Balady G, Banka G, et al. 2018 ACC/AHA clinical performance and quality  measures for cardiac rehabilitation:  a  report  of  the  American College of Cardiology/American Heart Association Task Force on Performance Measures. Circ Cardiovasc Qual Outcomes . 2018;11:e000037.

## 13.1. Palliative and Supportive Care, Shared DecisionMaking, and End-of-Life

1. Datla S, Verberkt CA, Hoye A, et al. Multi-disciplinary palliative care is effective in people with symptomatic heart failure: a systematic review and narrative synthesis. Palliat Med. 2019;33:1003-1016.
2.  Goldstein N, Carlson M, Livote E, et al. Brief communication: management of  implantable  cardioverter-defibrillators  in  hospice:  a  nationwide  survey. Ann Intern Med. 2010;152:296-299.
3.  McIlvennan CK, Jones J, Allen LA, et al. Bereaved caregiver perspectives on the end-of-life experience of patients with a left ventricular assist device. JAMA Intern Med. 2016;176:534-539.
4. Rogers JG, Patel CB, Mentz RJ, et al. Palliative care in heart failure: the PALHF randomized, controlled clinical trial. J Am Coll Cardiol. 2017;70:331-341.
5. Bekelman DB, Allen LA, McBryde CF, et al. Effect of a collaborative care intervention vs usual care on health status of patients with chronic heart failure: the CASA randomized clinical trial. JAMA Intern Med. 2018;178:511-519.
6.  O'Donnell AE, Schaefer KG, Stevenson LW, et al. Social Worker-Aided Palliative  Care  Intervention  in  High-risk  Patients  With  Heart  Failure  (SWAPHF): a pilot randomized clinical trial. JAMA Cardiol. 2018;3:516-519.
7.  Schichtel M, Wee B, Perera R, et al. The effect of advance care planning on heart failure: a systematic review and meta-analysis. J Gen Intern Med. 2020;35:874-884.
8.  Candy B, Holman A, Leurent B, et al. Hospice care delivered at home, in nursing homes and in dedicated hospice facilities: a systematic review of quantitative and qualitative evidence. Int J Nurs Stud. 2011;48:121-133.
9. Braun LT, Grady KL, Kutner JS, et al. Palliative care and cardiovascular disease and stroke: a policy statement from the American Heart Association/ American Stroke Association. Circulation. 2016;134:e198-e225.
10. McIlvennan CK, Allen LA. Palliative care in patients with heart failure. BMJ . 2016;353:i1010.
11.  Casarett D, Fishman J, O'Dwyer PJ, et al. How should we design supportive cancer care? The patient's perspective. J Clin Oncol. 2008;26:1296-1301.
12. Allen LA, Stevenson LW, Grady KL, et al. Decision making in advanced heart failure: a scientific statement from the American Heart Association. Circulation . 2012;125:1928-1952.
13. Lanken PN, Terry PB, Delisser HM, et al. An official American Thoracic Society clinical policy statement: palliative care for patients with respiratory diseases and critical illnesses. Am J Respir Crit Care Med. 2008;177:912-927.

14.  World Health Organization Expert Committee on Cancer Pain Relief and Active Supportive Care. Cancer pain relief and palliative care. World Health Organization Technical Report Series, No. 804. World Health Organization; 1990. Accessed December 15, 2020. https://apps.who.int/iris/bitstream/ handle/10665/39524/WHO\_TRS\_804.pdf?sequence=1&amp;isAllowed=y
15.  Gelfman LP, Kalman J, Goldstein NE. Engaging heart failure clinicians to increase palliative care referrals: overcoming barriers, improving techniques. J Palliat Med. 2014;17:753-760.
16.  Tulsky JA, Beach MC, Butow PN, et al. A research agenda for communication between health care professionals and patients living with serious illness. JAMA Intern Med . 2017;177:1361-1366.
4. 17 .  Allen LA, Yager JE, Funk MJ, et al. Discordance between patient-predicted and model-predicted life expectancy among ambulatory patients with heart failure. JAMA. 2008;299:2533-2542.
18. Matlock DD, Jones J, Nowels CT, et al. Evidence of cognitive bias in decision making around implantable-cardioverter defibrillators: a qualitative framework analysis. J Card Fail. 2017;23:794-799.
19. Ferrell BR, Twaddle ML, Melnick A, et al. National consensus project clinical practice guidelines for quality palliative care guidelines, 4th edition. J Palliat Med. 2018;21:1684-1689.
20. Temel JS, Greer JA, Muzikansky A, et al. Early palliative care for patients with metastatic non-small-cell lung cancer. N Engl J Med. 2010;363:733742.
21. A controlled trial to improve care for seriously ill hospitalized patients. The study  to  understand  prognoses  and  preferences  for  outcomes  and  risks of treatments (SUPPORT). The SUPPORT Principal Investigators. JAMA . 1995;274:1591-1598.
22.  Bakitas MA, Dionne-Odom JN, Ejem DB, et al. Effect of an early palliative  care telehealth intervention vs usual care on patients with heart failure:  the  ENABLE  CHF-PC  randomized  clinical  trial. JAMA  Intern  Med. 2020;180:1203-1213.
23. Carson SS, Cox CE, Wallenstein S, et al. Effect of palliative care-led meetings for families of patients with chronic critical illness: a randomized clinical trial. JAMA. 2016;316:51-62.
24. Sudore  RL,  Lum  HD,  You  JJ,  et  al.  Defining  advance  care  planning  for adults: a consensus definition from a multidisciplinary Delphi Panel. J Pain Symptom Manage. 2017;53:821-832.e1.
25. Yadav KN, Gabler NB, Cooney E, et al. Approximately one in three US adults completes any type of advance directive for end-of-life care. Health Aff (Millwood). 2017;36:1244-1251.
26. Keating NL, Huskamp HA, Kouri E, et al. Factors contributing to geographic variation  in  end-of-life  expenditures  for  cancer  patients. Health  Aff  (Millwood). 2018;37:1136-1143.
14. 27 . Chuzi S, Molsberry R, Ogunseitan A, et al. Trends in place of death for cardiovascular mortality related to heart failure in the United States from 2003 to 2017. Circ Heart Fail. 2020;13:e006587.

## 14.1. Patient-Reported Outcomes

1.  Green CP, Porter CB, Bresnahan DR, et al. Development and evaluation of the Kansas City Cardiomyopathy Questionnaire: a new health status measure for heart failure. J Am Coll Cardiol. 2000;35:1245-1255.
2. Spertus  J,  Peterson  E,  Conard  MW,  et  al.  Monitoring  clinical  changes  in  patients  with  heart  failure:  a  comparison  of  methods. Am Heart J. 2005;150:707-715.
3.  Rector TS, Cohn JN. Assessment of patient outcome with the Minnesota Living with Heart Failure Questionnaire: reliability and validity during a randomized, double-blind, placebo-controlled trial of pimobendan. Am Heart J. 1992;124:1017-1025.
4. Demers C, McKelvie RS, Negassa A, et al. Reliability, validity, and responsiveness of the six-minute walk test in patients with heart failure. Am Heart J. 2001;142:698-703.
5.  Rector TS, Anand IS, Cohn JN. Relationships between clinical assessments and patients' perceptions of the effects of heart failure on their quality of life. J Card Fail. 2006;12:87-92.
6. Gorkin L, Norvell NK, Rosen RC, et al. Assessment of quality of life as observed from the baseline data of the Studies of Left Ventricular Dysfunction (SOLVD) trial quality-of-life substudy. Am J Cardiol. 1993;71:1069-1073.
7. Quittan  M,  Wiesinger  GF,  Crevenna  R,  et  al.  Cross-cultural  adaptation  of the Minnesota living with heart failure questionnaire for German-speaking patients. J Rehabil Med. 2001;33:182-186.
8.  van den Berg-Emons RJ, Bussmann JB, Balk AH, et al. Factors associated with the level of movement-related everyday activity and quality of life in people with chronic heart failure. Phys Ther. 2005;85:1340-1348.
9.  Rector TS, Carson PE, Anand IS, et al. Assessment of long-term effects of irbesartan on heart failure with preserved ejection fraction as measured by the Minnesota Living with Heart Failure Questionnaire in the irbesartan in heart failure with preserved systolic function (I-PRESERVE) trial. Circ Heart Fail. 2012;5:217-225.
10. Carson P, Tam SW, Ghali JK, et al. Relationship of quality of life scores with baseline characteristics and outcomes in the African-American heart failure trial. J Card Fail. 2009;15:835-842.
11. Alla F, Briancon S, Guillemin F, et al. Self-rating of quality of life provides additional prognostic information in heart failure: insights into the EPICAL study. Eur J Heart Fail. 2002;4:337-343.
12. Tate CW 3rd, Robertson AD, Zolty R, et al. Quality of life and prognosis in heart failure: results of the Beta-Blocker Evaluation of Survival Trial (BEST). J Card Fail. 2007;13:732-737.
13.  Moser DK, Yamokoski L, Sun JL, et al. Improvement in health-related quality  of  life  after  hospitalization  predicts  event-free  survival  in  patients  with advanced heart failure. J Card Fail. 2009;15:763-769.
14. Hoekstra T, Jaarsma T, van Veldhuisen DJ, et al. Quality of life and survival in patients with heart failure. Eur J Heart Fail. 2013;15:94-102.
15.  Soto GE, Jones P, Weintraub WS, et al. Prognostic value of health status in patients with heart failure after acute myocardial infarction. Circulation. 2004;110:546-551.
16. Pokharel Y, Khariton Y, Tang Y, et al. Association of serial Kansas City Cardiomyopathy  Questionnaire  assessments  with  death  and  hospitalization in  patients  with  heart  failure  with  preserved  and  reduced  ejection  fraction:  a  secondary  analysis  of  2  randomized  clinical  trials. JAMA  Cardiol. 2017;2:1315-1321.
17. 17 . Dunlay SM, Gheorghiade M, Reid KJ, et al. Critical elements of clinical follow-up after hospital discharge for heart failure: insights from the EVEREST trial. Eur J Heart Fail. 2010;12:367-374.
18. Heidenreich PA, Spertus JA, Jones PG, et al. Health status identifies heart failure  outpatients  at  risk  for  hospitalization  or  death. J  Am  Coll  Cardiol. 2006;47:752-756.
19. Arnold SV, Spertus JA, Vemulapalli S, et al. Association of patient-reported health  status  with  long-term  mortality  after  transcatheter  aortic  valve  replacement: report from the STS/ACC TVT Registry. Circ Cardiovasc Interv. 2015;8:e002875.
20. Tran  AT,  Chan  PS,  Jones  PG,  et  al.  Comparison  of  patient  self-reported health status with clinician-assigned New York Heart Association classification. JAMA Netw Open. 2020;3:e2014319.
21.  Goode KM, Nabb S, Cleland JG, et al. A comparison of patient and physician-rated New York Heart Association class in a community-based heart failure clinic. J Card Fail. 2008;14:379-387.
22. Khariton Y, Hernandez AF, Fonarow GC, et al. Health status variation across practices  in  outpatients  with  heart  failure:  insights  from  the  CHAMP-HF (Change the Management of Patients With Heart Failure) Registry. Circ Cardiovasc Qual Outcomes. 2018;11:e004668.
23. Stehlik J, Rodriguez-Correa C, Spertus JA, et al. Implementation of real-time assessment of patient-reported outcomes in a heart failure clinic: a feasibility study. J Card Fail. 2017;23:813-816.
24.  Turgeon RD, Barry AR, Hawkins NM, et al. Pharmacotherapy for heart failure with reduced ejection fraction and health-related quality of life: a systematic review and meta-analysis. Eur J Heart Fail . 2021;23:578-589.
25. Chen S, Yin Y, Krucoff MW. Effect of cardiac resynchronization therapy and implantable cardioverter defibrillator on quality of life in patients with heart failure: a meta-analysis. Europace. 2012;14:1602-1607.
26.  O'Connor CM, Whellan DJ, Lee KL, et al. Efficacy and safety of exercise training in patients with chronic heart failure: HF-ACTION randomized controlled trial. JAMA . 2009;301:1439-1450.
27. 27 .  Di Biase L, Mohanty P, Mohanty S, et al. Ablation versus amiodarone for treatment  of  persistent  atrial  fibrillation  in  patients  with  congestive  heart failure and an implanted device: results from the AATAC multicenter randomized trial. Circulation. 2016;133:1637-1644.
28. Khan MN, Jaïs P, Cummings J, et al. Pulmonary-vein isolation for atrial fibrillation in patients with heart failure. N Engl J Med. 2008;359:1778-1785.
29.  Abraham WT, Adamson PB, Bourge RC, et al. Wireless pulmonary artery haemodynamic monitoring in chronic heart failure: a randomised controlled trial. Lancet. 2011;377:658-666.
30. Mark DB, Knight JD, Velazquez EJ, et al. Quality-of-life outcomes with coronary artery bypass graft surgery in ischemic left ventricular dysfunction: a randomized trial. Ann Intern Med. 2014;161:392-399.
31. Arnold SV, Chinnakondepalli KM, Spertus JA, et al. Health status after transcatheter mitral-valve repair in heart failure and secondary mitral regurgitation: COAPT trial. J Am Coll Cardiol. 2019;73:2123-2132.

Appendix 1. Author Relationships With Industry and Other Entities (Relevant)-2022 AHA/ACC/HFSA Guideline for the Management of Heart Failure

| Committee Member           | Employment                                                                                                                                                                                                                                                                                                                                                                                                 | Consultant                                                                                                                                | Speakers Bureau   | Ownership/ Partnership/ Principal   | Personal Research   | Institutional, Organizational, or Other Financial Benefit                                                                                           | Expert Witness   | Salary   |
|----------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------|-------------------|-------------------------------------|---------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------|------------------|----------|
| Paul A. Heidenreich, Chair | Stanford University School of Medi- cine-Professor and Vice-Chair for Quality, Department of Medicine                                                                                                                                                                                                                                                                                                      | None                                                                                                                                      | None              | None                                | None                | None                                                                                                                                                | None             | None     |
| Biykem Bozkurt, Vice Chair | Baylor College of Medicine and De- Bakey VA Medical Center Cardiology Department-Mary and Gordon Cain Chair; W.A. 'Tex' and Deborah Mon- crief, Jr., Chair; Professor of Medicine Medical Care Line Executive, DeBakey VA Medical Center; Director, Winters Center for Heart Failure Research; Associate Director, Cardiovascular Research Institute; Vice-Chair of Medi- cine, Baylor College of Medicine | • Abbott* • Amgen • Baxter • Bristol-Myers Squibb* • E.R. Squibb & Sons, L.L.C. * • Relypsa • Sanofi-aventis* • scPharmaceuticals • Vifor | None              | None                                | None                | • Abbott* • Amgen • Relypsa • Respicardia • Sanofi- Aventis‡ • Past Presi- dent, HFSA (2019-2020)                                                   | None             | None     |
| David Aguilar              | University of Kentucky-Professor of Medicine, Department of Medicine, Division of Cardiovascular Medicine                                                                                                                                                                                                                                                                                                  | None                                                                                                                                      | None              | None                                | None                | None                                                                                                                                                | None             | None     |
| Larry A. Allen             | University of Colorado School of Medicine, Anschutz Medical Campus-Professor of Medicine, Department of Medicine, Division of Cardiology                                                                                                                                                                                                                                                                   | • Abbott • ACI Clinical* • Amgen* • Boston Scientific* • Cytokinetics • Novartis                                                          | None              | None                                | None                | • Abbott‡ • Amgen • Boston Sci- entific*‡ • Janssen Phar- maceuticals • Medtronic Vascular Inc.                                                     | None             | None     |
| Joni J. Byun               | Penultimate PR-President                                                                                                                                                                                                                                                                                                                                                                                   | None                                                                                                                                      | None              | None                                | None                | None                                                                                                                                                | None             | None     |
| Monica M. Colvin           | University of Michigan-Professor of Medicine, Department of Medicine, Cardiovascular Division; Associate Director, Heart Transplant Program, Advanced Heart Failure, Transplant, and MCS Natera                                                                                                                                                                                                            | None                                                                                                                                      | None              | None                                | • CareDX            | • Abbott‡                                                                                                                                           | None             | None     |
| Anita Deswal               | UT MD Anderson Cancer Center- Ting Tsung and Wei Fong Chao Distinguished Chair, Professor of Medicine, and Chair of Cardiology                                                                                                                                                                                                                                                                             | None                                                                                                                                      | None              | None                                | None                | None                                                                                                                                                | None             | None     |
| Mark H. Drazner            | UT Southwestern Medical Cen- ter-Professor and Clinical Chief of Cardiology, Department of Internal Medicine, Cardiology                                                                                                                                                                                                                                                                                   | None                                                                                                                                      | None              | None                                | None                | None                                                                                                                                                | None             | None     |
| Shannon M. Dunlay          | Mayo Clinic-Professor of Health Services Research and Medicine, De- partment of Cardiovascular Medicine                                                                                                                                                                                                                                                                                                    | None                                                                                                                                      | None              | None                                | None                | None                                                                                                                                                | None             | None     |
| Linda R. Evers             | Stevens & Lee-Shareholder and Chair of Stevens & Lee's Energy, Communi- cations and Public Utility Group                                                                                                                                                                                                                                                                                                   | None                                                                                                                                      | None              | None                                | None                | None                                                                                                                                                | None             | None     |
| James C. Fang              | University of Utah-Professor of Medicine, Division of Cardiovascular Medicine                                                                                                                                                                                                                                                                                                                              | • Boston Scientific†                                                                                                                      | None              | None                                | None                | • ACI Clinical (Adjudication Committee)* • Amgen (Steering Committee) • AstraZeneca (Steering Committee) • Boston Scientific† • Novartis (Executive | None             | None     |

( Continued )

## Appendix 1. Continued

| Committee Member      | Employment                                                                                                                                                                                                                               | Consultant                                                                                                                                                                               | Speakers Bureau   | Ownership/ Partnership/ Principal   | Personal Research                                                                                                                                                                                   | Institutional, Organizational, or Other Financial Benefit   | Expert Witness   | Salary   |
|-----------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------|-------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------|------------------|----------|
| Savitri E. Fedson     | Michael E. DeBakey Medical Center-Professor, Medical Director, Advanced Heart Failure and Trans- plantation, Section of Cardiology                                                                                                       | None                                                                                                                                                                                     | None              | None                                | None                                                                                                                                                                                                | None                                                        | None             | None     |
| Gregg C. Fonarow      | Geffen School of Medicine at UCLA-Professor of Cardiovascular Medicine, Chief, UCLA Division of Cardiology, Department of Medicine                                                                                                       | • Abbott* • Amgen • AstraZeneca • CHF Solutions • Cytokinetics • Edwards Life- sciences* • Janssen Pharmaceuticals • Medtronic • Merck* • Novartis* • Regeneron                          | None              | None                                | None                                                                                                                                                                                                | • Boston Scientific • Novartis* • Medtronic                 | None             | None     |
| Salim S. Hayek        | University of Michigan in Ann Arbor- Assistant Professor, Department of Medicine, Division of Cardiology                                                                                                                                 | None                                                                                                                                                                                     | None              | None                                | None                                                                                                                                                                                                | None                                                        | None             | None     |
| Adrian F. Hernandez   | Duke University School of Medi- cine-Vice Dean of Clinical Research                                                                                                                                                                      | • Amgen • AstraZeneca • Bayer • BioFourmis • Boehringer Ingelheim* • Boston Scientific* • Cytokinetics • Eli Lilly • Merck* • Myokardia • Novartis* • Pfizer • Relypsa • Sanofi-aventis* | None              | None                                | • American Regent • Amgen • Boston Scientific • AstraZen- eca* • Boehringer Ingelheim • Daiichi Sankyo • Genentech • GlaxoS- mithKline* • Janssen Pharma- ceuticals* • Merck* • Novartis* • Verily* | None                                                        | None             | None     |
| Prateeti Kha- zanie   | University of Colorado-Assistant Professor of Medicine, Department of Medicine, Division of Cardiology                                                                                                                                   | None                                                                                                                                                                                     | None              | None                                | None                                                                                                                                                                                                | None                                                        | None             | None     |
| Michelle M. Kittleson | Smidt Heart Institute Cedars-Sinai- Professor of Medicine, Cardiology                                                                                                                                                                    | None                                                                                                                                                                                     | None              | None                                | None                                                                                                                                                                                                | None                                                        | None             | None     |
| Christopher S. Lee    | Boston College, William F. Connell School of Nursing-Professor and Associate Dean for Research                                                                                                                                           | None                                                                                                                                                                                     | None              | None                                | None                                                                                                                                                                                                | None                                                        | None             | None     |
| Mark S. Link          | UT Southwestern Medical Center, Dallas-Professor of Medicine and Director, Cardiac Electrophysiology; Laurence and Susan Hirsch/Centex Distinguished Chair in Heart Dis- ease, Department of Internal Medi- cine, Division of Cardiology | None                                                                                                                                                                                     | None              | None                                | None                                                                                                                                                                                                | None                                                        | None             | None     |
| Carmelo A. Milano     | Duke University Medical Cen- ter-Professor of Surgery, Surgery Department                                                                                                                                                                | • Abbott*                                                                                                                                                                                | None              | None                                | • Abbott* • Medtronic* • NuPulse†                                                                                                                                                                   | • Abbott* • AbioMed† • Allergan† • CryoLife† • Ethicon†     | None             | None     |

( Continued )

## Appendix 1. Continued

| Committee Member       | Employment                                                                                                                                                                                                                                                                                                                   | Consultant                          | Speakers Bureau   | Ownership/ Partnership/ Principal   | Personal Research         | Institutional, Organizational, or Other Financial Benefit                                                   | Expert Witness   | Salary   |
|------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------|-------------------|-------------------------------------|---------------------------|-------------------------------------------------------------------------------------------------------------|------------------|----------|
| Lorraine C. Nnacheta§  | American Heart Association/Ameri- can College of Cardiology-Guide- line Advisor                                                                                                                                                                                                                                              | None                                | None              | None                                | None                      | • AHA/ACC salaried employee                                                                                 | None             | None     |
| Alexander T. Sandhu    | Stanford University-Instructor of Medicine, Division of Cardiology, Department of Medicine                                                                                                                                                                                                                                   | None                                | None              | None                                | None                      | None                                                                                                        | None             | None     |
| Lynne Warner Stevenson | Vanderbilt University Medical Center, Vanderbilt Heart and Vascular Insti- tute-Director of Cardiomyopathy and Lisa M. Jacobson Professor of Cardiovascular Medicine                                                                                                                                                         | • Novartis                          | None              | None                                | None                      | • Abbott‡ • Biotronik • Boston Scientific • Bristol-Myers Squibb‡ • Endotronic† • Gore Medical† • Johnson & | None             | None     |
| Orly Vardeny           | Minneapolis VA Health Care System and University of Minnesota- Associate Professor of Medicine, Department of Medicine                                                                                                                                                                                                       | • Amgen • Novartis • Sanofi-Pasteur | None              | None                                | • AstraZen- eca* • Bayer* | • AstraZeneca‡                                                                                              | None             | None     |
| Amanda R. Vest         | Tufts Medical Center, Cardiovascu- lar Center-Assistant Professor of Medicine                                                                                                                                                                                                                                                | None                                | None              | None                                | None                      | • Boehringer Ingelheim‡* • CareDx‡ • Corvia‡ • Transmedics‡                                                 | None             | None     |
| Clyde W. Yancy         | Northwestern University, Feinberg School of Medicine; Northwestern Memorial Hospital-Professor of Medicine (Cardiology); Professor of Medical Social Sciences; Chief of Cardiology; Vice-Dean, Diversity & Inclusion; Associate Director Car- diovascular Institute Internal Medi- cine/Cardiology & Medical Social Sciences | None                                | None              | None                                | None                      | • Abbott† • JAMA Cardiology , Deputy Editor                                                                 | None             | None     |

This table represents the relationships of committee members with industry and other entities that were determined to be relevant to this document. These relationships were reviewed and updated in conjunction with all meetings and/or conference calls of the writing committee during the document development process. The table does not necessarily reflect relationships with industry at the time of publication. A person is deemed to have a significant interest in a business if the interest represents ownership of ≥ 5% of the voting stock or share of the business entity, or ownership of ≥ $5000 of the fair market value of the business entity; or if funds received by the person from the business entity exceed 5% of the person's gross income for the previous year. Relationships that exist with no financial benefit are also included for the purpose of transparency. Relationships in this table are modest unless otherwise noted. According to the ACC/AHA, a person has a relevant relationship IF: a) the relationship or interest relates to the same or similar subject matter, intellectual property or asset, topic, or issue addressed in the document; or b) the company/entity (with whom the relationship exists) makes a drug, drug class, or device addressed in the document or makes a competing drug or device addressed in the document ; or c) the person or a member of the person's household , has a reasonable potential for financial, professional or other personal gain or loss as a result of the issues/content addressed in the document . Writing committee members are required to recuse themselves from voting on sections to which their specific relationships with industry and other entities may apply.

*Significant relationship.

†No financial benefit.

‡This disclosure was entered under the Clinical Trial Enroller category in the ACC's disclosure system. To appear in this category, the author acknowledges that there is no direct or institutional relationship with the trial sponsor as defined in the (ACCF or AHA/ACC) Disclosure Policy for Writing Committees.

§Lorraine Nnacheta is an AHA/ACC joint staff member and acts as the guideline advisor for the '2022 AHA/ACC/HFSA Guideline for the Management of Heart Failure. ' No relevant relationships to report. Non-voting author on recommendations and not included/counted in the RWI balance for this committee.

ACC indicates American College of Cardiology; ACCF, American College of Cardiology Foundation; AHA, American Heart Association; HFSA, Heart Failure Society of America; RWI, relationships with industry and other entities; UCLA, University of California, Los Angeles; UT, University of Texas; and VA, Veterans Affairs.

Appendix 2. Reviewer Relationships With Industry and Other Entities (Comprehensive)-2022 AHA/ACC/HFSA Guideline for the Management of Heart Failure (June 2021)

| Reviewer             | Representation                                                    | Employment                                            | Consultant                                                                                                                                                                                                                                                           | Speakers Bureau                   | Ownership/ Partnership/ Principal   | Personal Research                                                                                                                                                                            | Institutional, Organizational, or Other Financial Benefit                                            | Expert Witness   |
|----------------------|-------------------------------------------------------------------|-------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------|-------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------|------------------|
| Anastasia Armbruster | Content Reviewer- Joint Committee on Clinical Practice Guidelines | University of Health Sciences & Pharmacy in St. Louis | None                                                                                                                                                                                                                                                                 | • AstraZen- eca Phar- maceuticals | None                                | None                                                                                                                                                                                         | None                                                                                                 | None             |
| Alison Bailey        | Content Reviewer- ACC                                             | Centennial Heart at Parkridge                         | None                                                                                                                                                                                                                                                                 | None                              | None                                | None                                                                                                                                                                                         | • American Society of Preventive Cardiology† • OptumRx                                               | None             |
| Joshua A. Beckman    | Content Reviewer- Joint Committee on Clinical Practice Guidelines | Vanderbilt University                                 | • Amgen • JanOne • Janssen Pharmaceuticals*                                                                                                                                                                                                                          | None                              | • EMX† • JanaCare†                  | • Bayer (DSMB) • Novartis                                                                                                                                                                    | • Vascular Interven- tional Advances* • NovoNordisk‡                                                 | None             |
| Claudio Bravo        | Content Reviewer- AHA                                             | University of Washington                              | None                                                                                                                                                                                                                                                                 | None                              | None                                | None                                                                                                                                                                                         | None                                                                                                 | None             |
| Patricia Chang       | Content Reviewer- AHA/ACC                                         | University of North Carolina                          | None                                                                                                                                                                                                                                                                 | None                              | None                                | None                                                                                                                                                                                         | None                                                                                                 | None             |
| Richard Cheng        | Content Reviewer- AHA                                             | University of Washington                              | None                                                                                                                                                                                                                                                                 | None                              | None                                | • Eidos‡ • Ionis‡                                                                                                                                                                            | None                                                                                                 | None             |
| Lisa de las Fuentes  | Content Reviewer- Joint Committee on Clinical Practice Guidelines | Washington University in St. Louis                    | • Acceleron • Aerovate • Altavant • Arena • Bayer • Complexa* • Express Scripts • Gossamer • Johnson&Johnson • Phase Bio • Sommetrics • V-wave • Vaderis • WebMD*                                                                                                    | • Simply Speaking*                | None                                | • Acceleron* • Bayer • Complexa* • Johnson&Johnson* • Liquidia* • Medtronic* • NIH* • Trio Analytics • United Therapeutics* • University of Kentucky (DSMB)† • University of Toronto (DSMB)† | • ACC† • AHA† • Circulation Journals • Foundation for the NIH† • Pulmonary Hypertension Association* | None             |
| Akshay Desai         | Content Reviewer- AHA/ACC                                         | Brigham and Women's Hospital                          | • Abbott Laboratories* • Alnylam* • Amgen* • AstraZeneca Pharmaceuticals* • Biofourmis* • Boehringer Ingelheim • Boston Scientific* • Corvidia Therapeutics* • Cytokinetics • Dalcor Pharma* • Lupin Pharma • Merck • Novartis* • Regeneron* • Relypsa* • Sun Pharma | None                              | None                                | • Alnylam* • AstraZeneca Pharmaceuticals* • Bayer† • Myokardia† • Novartis*                                                                                                                  | • Baim Clinical Research Institute* • TIMI Study Group*                                              | None             |
| Howard Eisen         | Official Reviewer- AHA                                            | Penn State Health                                     | None                                                                                                                                                                                                                                                                 | None                              | None                                | None                                                                                                                                                                                         | None                                                                                                 | None             |
| Mona Fiuzat          | Content Reviewer- AHA/ACC                                         | Duke University                                       | • Fire1                                                                                                                                                                                                                                                              | None                              | None                                | • Roche*                                                                                                                                                                                     | None                                                                                                 | None             |
| Bulent Gorenek       | Content Reviewer- Joint Committee on Clinical Practice Guidelines | Eskisehir Os- mangazi University                      | • AstraZeneca Pharmaceuticals • Bayer • Daiichi Sankyo • Roche • Sandoz • Sanofi                                                                                                                                                                                     | None                              | None                                | None                                                                                                                                                                                         | None                                                                                                 | None             |

( Continued )

## Appendix 2. Continued

| Reviewer            | Representation                                                    | Employment                                      | Consultant                                                                           | Speakers Bureau   | Ownership/ Partnership/ Principal   | Personal Research                                     | Institutional, Organizational, or Other Financial Benefit                        | Expert Witness   |
|---------------------|-------------------------------------------------------------------|-------------------------------------------------|--------------------------------------------------------------------------------------|-------------------|-------------------------------------|-------------------------------------------------------|----------------------------------------------------------------------------------|------------------|
| José A. Joglar      | Content Reviewer- Joint Committee on Clinical Practice Guidelines | UT Southwestern Medical Center                  | None                                                                                 | None              | None                                | None                                                  | None                                                                             | None             |
| W. Schuyler Jones   | Content Reviewer- Joint Committee on Clinical Practice Guidelines | Duke University                                 | • Bayer* • Janssen Pharmaceuticals                                                   | None              | None                                | • Boehringer Ingelheim • Bristol Myers Squibb • PCORI | None                                                                             | None             |
| Daniel Judge        | Content Reviewer- AHA/ACC                                         | The Medical University of South Carolina        | • ADRx • Cytokinetics • Pfizer • Tenaya Therapeutics                                 | None              | None                                | • Capricor (DSMB) • TRiNDS (DSMB)                     | • Array Biopharma‡ • Eidos Therapeutics‡ • Myokardia‡                            | None             |
| Kimberly Ketter     | Lay Reviewer                                                      | Morris Cardiovascular & Risk Reduc- tion Center | None                                                                                 | None              | None                                | None                                                  | • Verilogue                                                                      | None             |
| Dharam Kumbhani     | Content Reviewer- AHA/ACC                                         | UT Southwestern Medical Center                  | • ACC*                                                                               | None              | None                                | None                                                  | • Circulation , Associate Editor*                                                | None             |
| Daniel Mark         | Content Reviewer- Joint Committee on Clinical Practice Guidelines | Duke University                                 | • Novartis                                                                           | None              | None                                | None                                                  | • Elsevier* • Heartflow* • Merck* • NIH*                                         | None             |
| Paul Mather         | Content Reviewer- AHA/ACC                                         | University of Pennsylvania                      | None                                                                                 | None              | None                                | • Novartis*                                           | None                                                                             | None             |
| Shweta Motiwala     | Content Reviewer- AHA/ACC                                         | Harvard University                              | • Baim Institute for Clinical Research* • Eli Lilly • Relay Therapeutics*            | None              | • Relay Therapeu- tics*             | • Puma Biotechnology* • Relypsa†                      | • American Regent‡ • Boehringer Ingelheim‡ • Edwards Lifesciences‡ • NuPulse CV‡ | None             |
| Debabrata Mukherjee | Content Reviewer- Joint Committee on Clinical Practice Guidelines | Texas Tech University                           | • ACC*                                                                               | None              | None                                | None                                                  | None                                                                             | None             |
| Patrick T. O'Gara   | Content Reviewer- Joint Committee on Clinical Practice Guidelines | Brigham and Women's Hospital                    | None                                                                                 | None              | None                                | None                                                  | • Edwards Lifesciences† • Medtronic† • JAMA * • NIH*                             | None             |
| Francis D. Pagani   | Official Reviewer- AHA                                            | University of Michigan                          | None                                                                                 | None              | None                                | None                                                  | None                                                                             | None             |
| Gurusher Panjrath   | Content Reviewer- ACC                                             | George Washington University                    | • CVRx                                                                               | • Pfizer*         | None                                | None                                                  | • Abbott Laboratories‡                                                           | None             |
| Mariann Piano       | Content Reviewer- Joint Committee on Clinical Practice Guidelines | Vanderbilt University                           | None                                                                                 | None              | None                                | None                                                  | None                                                                             | None             |
| Sean Pinney         | Content Reviewer- AHA/ACC                                         | University of Chicago                           | • Abbott Laboratories • CareDX, Inc. • Medtronic • NuPulse • Procyrion • Transmedics | None              | None                                | None                                                  | None                                                                             | None             |
| Bunny Pozehl        | Content Reviewer- AHA/ACC                                         | University of Nebraska                          | None                                                                                 | None              | None                                | None                                                  | None                                                                             | None             |
| Tanveer Rab         | Content Reviewer- Joint Committee on Clinical Practice Guidelines | Emory University                                | None                                                                                 | None              | None                                | None                                                  | • ABIM • ACC† • American Bifurcation Club†                                       | None             |

( Continued )

## Appendix 2. Continued

| Reviewer                     | Representation                                                     | Employment                   | Consultant                                                                                                                                                                                                                                                                                                                                                                                                         | Speakers Bureau                      | Ownership/ Partnership/ Principal   | Personal Research                  | Institutional, Organizational, or Other Financial Benefit                                                           | Expert Witness   |
|------------------------------|--------------------------------------------------------------------|------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------|-------------------------------------|------------------------------------|---------------------------------------------------------------------------------------------------------------------|------------------|
| Nosheen Reza                 | Content Reviewer- ACC                                              | University of Pennsylvania   | None                                                                                                                                                                                                                                                                                                                                                                                                               | None                                 | None                                | None                               | None                                                                                                                | None             |
| Jo E. Rodgers                | Content Reviewer- AHA                                              | University of North Carolina | None                                                                                                                                                                                                                                                                                                                                                                                                               | None                                 | None                                | • Novartis†                        | • Duke Clinical Research Institute‡ • GlaxoSmithKline                                                               | None             |
| Chris Salerno                | Content Reviewer- ACC                                              | St. Vincent Hospital         | • Abbott                                                                                                                                                                                                                                                                                                                                                                                                           | • Medtronic                          | None                                | None                               | • Abbott‡ • Medtronic‡                                                                                              | None             |
| Sanjiv Shah                  | Official Reviewer- HFSA                                            | Northwestern University      | • Abbott • ABIM • Amgen • Aria • AstraZeneca Pharmaceuticals* • Axon • Bayer • Boehringer Ingelheim • Boston Scientific • Bristol Myers Squibb • Cardiora • CVRx • Cyclerion • Cytokinetics • Eisai • Ekoi.ai • GlaxoSmithKline • Imara • Ionis • Ironwood • Janssen Pharmaceuticals • Keyto • Eli Lilly • Merck • Myokardia • Novartis* • NovoNordisk • Pfizer • Prothena • Regeneron • Sanofi • Shifamed • Tenax | • Pulmonary Hypertension Association | None                                | • Actelion* • AHA* • Covia* • NIH* | None                                                                                                                | None             |
| Erica S. Spatz               | Official Reviewer, Joint Committee on Clinical Practice Guidelines | Yale University              | None                                                                                                                                                                                                                                                                                                                                                                                                               | None                                 | None                                | None                               | • Centers for Medi- care & Medicaid Services* • US Food and Drug Administration*                                    | None             |
| Nancy Sweitzer               | Official Reviewer- HFSA                                            | University of Arizona        | • Medscape* • Myokardia                                                                                                                                                                                                                                                                                                                                                                                            | None                                 | None                                | • NIH* • Merck • Novartis†         | • AHA* • Amgen‡ • Array BioPharma‡ • Cellular Logistics† • Corvia Medical‡ • CVRx‡ • NIH*‡ • University of Arizona* | None             |
| Jacqueline E. Tamis- Holland | Content Reviewer- Joint Committee on Clinical Practice Guidelines  | Mount Sinai                  | • Gaffney Events Educational Trust                                                                                                                                                                                                                                                                                                                                                                                 | None                                 | None                                | None                               | • AHA† • Bronx Lebanon Hospital, Cardiology Fellowship Program Director† • NYS† • The NGS Predict Study‡            | None             |

( Continued )

## Appendix 2. Continued

| Reviewer           | Representation                                                    | Employment                             | Consultant   | Speakers Bureau   | Ownership/ Partnership/ Principal   | Personal Research   | Institutional, Organizational, or Other Financial Benefit                                | Expert Witness   |
|--------------------|-------------------------------------------------------------------|----------------------------------------|--------------|-------------------|-------------------------------------|---------------------|------------------------------------------------------------------------------------------|------------------|
| Jennifer Thibodeau | Content Reviewer- AHA                                             | UT Southwestern Medical Center         | None         | None              | None                                | None                | • CareDX‡ • Cytokinetics‡ • Eidos Therapeutics‡ • NIH‡                                   | None             |
| Sanjeev Trehan     | Official Reviewer- ACC (Board of Governors)                       | Saint Francis Health System            | None         | None              | None                                | None                | None                                                                                     | None             |
| Mary Norine Walsh  | Content Reviewer- AHA/ACC                                         | Ascension Medical Group                | None         | None              | None                                | None                | • Amgen‡ • EBR Systems • PCORI‡ • Thoratec‡ • Uppsala University‡                        | None             |
| Barbara Wiggins    | Content Reviewer- ACC                                             | Medical University of South Carolina   | • Lexicomp   | None              | None                                | None                | • ACC† • American Journal of Cardiovascular Drugs† • PERT Consortium Clinical Protocols† | None             |
| Y. Joseph Woo      | Content Reviewer- Joint Committee on Clinical Practice Guidelines | Stanford University School of Medicine | None         | None              | None                                | None                | • Associate Editor, Journal of Thoracic and Cardiovascular Disease • NIH*                | None             |

This table represents all relationships of reviewers with industry and other entities that were reported at the time of peer review, including those not deemed to be relevant to this document, at the time this document was under review. The table does not necessarily reflect relationships with industry at the time of publication. A person is deemed to have a significant interest in a business if the interest represents ownership of ≥ 5% of the voting stock or share of the business entity, or ownership of ≥ $5000 of the fair market value of the business entity; or if funds received by the person from the business entity exceed 5% of the person's gross income for the previous year. Relationships that exist with no financial benefit are also included for the purpose of transparency. Relationships in this table are modest unless otherwise noted. Names are listed in alphabetical order within each category of review. Please refer to https://www.acc.org/guidelines/about-guidelines-and-clinical-documents/relationships-with-industry-policy for definitions of disclosure categories or additional information about the ACC/AHA Disclosure Policy for Writing Committees.

*Significant relationship.

†No financial benefit.

‡This disclosure was entered under the Clinical Trial Enroller category in the ACC's disclosure system. To appear in this category, the author acknowledges that there is no direct or institutional relationship with the trial sponsor as defined in the (ACCF or AHA/ACC) Disclosure Policy for Writing Committees.

ABIM indicates American Board of Internal Medicine; ACC, American College of Cardiology; ACCF, American College of Cardiology Foundation; AHA, American Heart Association; DSMB, Data and Safety Monitoring Board; JAMA, Journal of the American Medical Association; NGS, Next-generation sequencing; NIH, National Institutes of Health; NYS, New York State; PCORI, Patient-Centered Outcomes Research Institute; PERT, Pulmonary Embolism Response Team; TIMI, Thrombolysis in Myocardial Infarction; and UT, University of Texas.

Appendix 3. Appendix for Tables 3 and 4: Suggested Thresholds for Structural Heart Disease and Evidence of Increased Filling Pressures

| Morphology                     | • LAVI ≥ 29 mL/m 2 • LVMI >116/95 g/m 2 • RWT >0.42 • LV wall thickness ≥ 12 mm                                                                                    |
|--------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Ventricular systolic function  | • LVEF <50% • GLS <16%                                                                                                                                             |
| Ventricular diastolic function | • Average E/e ʹ ≥ 15 for increased filling pressures • Septal e ʹ <7 cm/s • Lateral e ʹ <10 cm/s • TR velocity >2.8 m/s • Estimated PA systolic pressure >35 mm Hg |
| Biomarker                      | • BNP ≥ 35 pg/mL* • NT-proBNP ≥ 125 pg/mL*                                                                                                                         |

AF indicates atrial fibrillation; BNP, brain natriuretic peptide; CKD, chronic kidney disease; GLS, global longitudinal strain; HF, heart failure; LAVI, left atrial volume index; LV, left ventricular; LVEF, left ventricular ejection fraction; LVMI, left ventricular mass index; NT-proBNP, natriuretic peptide tests; PA, pulmonary artery; RWT, relative wall thickness; and TR, tricuspid regurgitation.

*Cutoffs provided for natriuretic peptide levels may have lower specificity, especially in older patients or in patients with AF or CKD. Usually, higher cutoff values are recommended for the diagnosis of HF in these patients. Natriuretic peptide cutoffs selected for population screening for pre-HF (stage B HF) may be &lt;99% reference limits and need to be defined according to the population at risk.